(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    190731,       4068]*)
(*NotebookOutlinePosition[    193691,       4148]*)
(*  CellTagsIndexPosition[    193106,       4132]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Automatic Development:  Sorting", "Title"],

Cell["by Bruno Buchberger", "Subsubtitle",
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontVariations->{"CompatibilityType"->0}],

Cell[CellGroupData[{

Cell["Knowledge: relevant for the exploration", "Section"],

Cell["\<\
The knowledge base grouped here represents the definitions/properties that \
describe all the ingredients necessary for formulating the correctness \
theorem for the sorting function. As the exploration proceeds, more formulae \
will be added to the knowledge. \
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<knowledge: is sorted version\>\"", ",", " ", "\[IndentingNewLine]",
         GridBox[{
            {\(Definition["\<is sorted\>"]\)},
            {\(Definition["\<is permuted version\>"]\)},
            {\(Definition["\<is sorted version\>"]\)},
            {\(Proposition["\<is tuple tuple\>"]\)},
            {\(Definition["\<prepend\>"]\)},
            {\(Proposition["\<singleton tuple is singleton tuple\>"]\)},
            {\(Definition["\<is trivial tuple\>"]\)},
            {\(Definition["\<is element\>"]\)},
            {\(Definition["\<deletion of the first occurrence\>"]\)},
            {\(Definition["\<is longer than\>"]\)},
            {\(Proposition["\<trivial tuples are sorted\>"]\)},
            {\(Proposition["\<only trivial tuple permuted version of \
itself\>"]\)},
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", 
                "\"\<reflexivity of permuted version\>\"", "]"}]}
            }]}], "]"}]], "Input",
  CellLabel->"TS_In[86]:=",
  InitializationCell->True,
  CellTags->"Theory (knowledge: is sorted version)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Theory",
          FontWeight->"Bold"], "[", "\"\<knowledge: is sorted version\>\"", 
        "]"}], "//", "TraditionalForm"}]], "Input",
  CellLabel->"TS_In[103]:="],

Cell[BoxData[
    FormBox[
      RowBox[{
      "Theories", \(\(\ \)\((\)\), \(is\ sorted\ version\ #1\), \
\(\()\)\(:\)\(\n\)\), "\n", 
        RowBox[{
          RowBox[{
          "Definition", \(\(\ \)\((\)\), \(is\ sorted\), \(\()\)\(:\)\(\n\)\),
             GridBox[{
                {
                  RowBox[{\(for\ \(\(any\)\(:\)\)\), 
                    RowBox[{
                      StyleBox["x",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox["y",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox[\(z\&_\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}]}]}
                },
              ColumnAlignments->{Left}], "\n", 
            
            RowBox[{\(\((1)\)\tis\[Dash]sorted[\[LeftAngleBracket]\
\[RightAngleBracket]]\), "\n", 
              RowBox[{\((2)\), "\t", 
                RowBox[{"is\[Dash]sorted", "[", 
                  RowBox[{"\[LeftAngleBracket]", 
                    StyleBox["x",
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], "\[RightAngleBracket]"}], "]"}]}], 
              "\n", 
              RowBox[{\((3)\), "\t", 
                RowBox[{
                  RowBox[{"is\[Dash]sorted", "[", 
                    RowBox[{"\[LeftAngleBracket]", 
                      RowBox[{
                        StyleBox["x",
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], ",", 
                        StyleBox["y",
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], ",", 
                        StyleBox[\(z\&_\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], "\[RightAngleBracket]"}], 
                    "]"}], "\[DoubleLeftRightArrow]", 
                  RowBox[{
                    RowBox[{
                      StyleBox["x",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "\[GreaterEqual]", 
                      StyleBox["y",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "\[And]", 
                    RowBox[{"is\[Dash]sorted", "[", 
                      RowBox[{"\[LeftAngleBracket]", 
                        RowBox[{
                          StyleBox["y",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], ",", 
                          StyleBox[\(z\&_\),
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None]}], "\[RightAngleBracket]"}], 
                      "]"}]}]}]}]}]}], "\n", 
          RowBox[{
          "Definition", \(\(\ \)\((\)\), \(is\ permuted\ version\), \
\(\()\)\(:\)\(\n\)\), GridBox[{
                {
                  RowBox[{\(for\ \(\(any\)\(:\)\)\), 
                    RowBox[{
                      StyleBox["x",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox[\(x\&_\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox["y",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox[\(y\&_\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}]}]}
                },
              ColumnAlignments->{Left}], "\n", 
            
            RowBox[{\(\((1)\)\t\(\[LeftAngleBracket]\[RightAngleBracket] \
\[TildeTilde] \[LeftAngleBracket]\[RightAngleBracket]\)\), "\n", 
              RowBox[{\((2)\), "\t", 
                
                RowBox[{\(\[LeftAngleBracket]\[RightAngleBracket]\), 
                  "\[NotTildeTilde]", 
                  RowBox[{"\[LeftAngleBracket]", 
                    RowBox[{
                      StyleBox["y",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox[\(y\&_\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "\[RightAngleBracket]"}]}]}], 
              "\n", 
              RowBox[{\((3)\), "\t", 
                RowBox[{
                  RowBox[{
                    RowBox[{"\[LeftAngleBracket]", 
                      StyleBox[\(y\&_\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "\[RightAngleBracket]"}], 
                    "\[TildeTilde]", 
                    RowBox[{"\[LeftAngleBracket]", 
                      RowBox[{
                        StyleBox["x",
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], ",", 
                        StyleBox[\(x\&_\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], "\[RightAngleBracket]"}]}], 
                  "\[DoubleLeftRightArrow]", 
                  RowBox[{
                    RowBox[{
                      StyleBox["x",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "\[Element]", 
                      RowBox[{"\[LeftAngleBracket]", 
                        StyleBox[\(y\&_\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], "\[RightAngleBracket]"}]}], 
                    "\[And]", 
                    RowBox[{
                      RowBox[{"dfo", "[", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], ",", 
                          RowBox[{"\[LeftAngleBracket]", 
                            StyleBox[\(y\&_\),
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "\[RightAngleBracket]"}]}], 
                        "]"}], "\[TildeTilde]", 
                      RowBox[{"\[LeftAngleBracket]", 
                        StyleBox[\(x\&_\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], 
                        "\[RightAngleBracket]"}]}]}]}]}]}]}], "\n", 
          RowBox[{
          "Definition", \(\(\ \)\((\)\), \(is\ sorted\ version\), \
\(\()\)\(:\)\(\n\)\), GridBox[{
                {
                  RowBox[{\(for\ \(\(any\)\(:\)\)\), 
                    RowBox[{
                      StyleBox["X",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox["Y",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}]}]}
                },
              ColumnAlignments->{Left}], "\n", 
            RowBox[{
              RowBox[{"is\[Dash]sorted\[Dash]version", "[", 
                RowBox[{
                  StyleBox["X",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], ",", 
                  StyleBox["Y",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None]}], "]"}], "\[DoubleLeftRightArrow]", 
              RowBox[{
                RowBox[{"is\[Dash]tuple", "[", 
                  StyleBox["Y",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], "]"}], "\[And]", 
                RowBox[{
                  StyleBox["X",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], "\[TildeTilde]", 
                  StyleBox["Y",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None]}], "\[And]", 
                RowBox[{"is\[Dash]sorted", "[", 
                  StyleBox["Y",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], "]"}]}]}]}], "\n", 
          RowBox[{
          "Proposition", \(\(\ \)\((\)\), \(is\ tuple\ tuple\), \
\(\()\)\(:\)\(\n\)\), GridBox[{
                {
                  RowBox[{\(for\ \(\(any\)\(:\)\)\), 
                    RowBox[{
                      StyleBox[\(x\&_\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " "}]}]}
                },
              ColumnAlignments->{Left}], "\n", 
            RowBox[{"is\[Dash]tuple", "[", 
              RowBox[{"\[LeftAngleBracket]", 
                StyleBox[\(x\&_\),
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], "\[RightAngleBracket]"}], "]"}]}], "\n", 
          
          RowBox[{
          "Definition", \(\(\ \)\((\)\), "prepend", \(\()\)\(:\)\(\n\)\), 
            GridBox[{
                {
                  RowBox[{\(for\ \(\(any\)\(:\)\)\), 
                    RowBox[{
                      StyleBox["x",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox[\(y\&_\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}]}]}
                },
              ColumnAlignments->{Left}], "\n", 
            RowBox[{\((\[Cup])\), "\t", 
              RowBox[{
                RowBox[{
                  StyleBox["x",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], "\[Cup]", 
                  RowBox[{"\[LeftAngleBracket]", 
                    StyleBox[\(y\&_\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], "\[RightAngleBracket]"}]}], "=", 
                RowBox[{"\[LeftAngleBracket]", 
                  RowBox[{
                    StyleBox["x",
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], ",", 
                    StyleBox[\(y\&_\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "\[RightAngleBracket]"}]}]}]}], 
          "\n", 
          RowBox[{
          "Proposition", \(\(\ \)\((\)\), \(singleton\ tuple\ is\ singleton\ \
tuple\), \(\()\)\(:\)\(\n\)\), GridBox[{
                {
                  RowBox[{\(for\ \(\(any\)\(:\)\)\), 
                    RowBox[{
                      StyleBox["x",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " "}]}]}
                },
              ColumnAlignments->{Left}], "\n", 
            RowBox[{"is\[Dash]singleton\[Dash]tuple", "[", 
              RowBox[{"\[LeftAngleBracket]", 
                StyleBox["x",
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], "\[RightAngleBracket]"}], "]"}]}], "\n", 
          
          RowBox[{
          "Definition", \(\(\ \)\((\)\), \(is\ trivial\ tuple\), \(\()\)\(:\)\
\(\n\)\), GridBox[{
                {
                  RowBox[{\(for\ \(\(any\)\(:\)\)\), 
                    RowBox[{"is\[Dash]tuple", "[", 
                      StyleBox["X",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "]"}]}]}
                },
              ColumnAlignments->{Left}], "\n", 
            RowBox[{
              RowBox[{"is\[Dash]trivial\[Dash]tuple", "[", 
                StyleBox["X",
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], "]"}], "\[DoubleLeftRightArrow]", 
              RowBox[{
                RowBox[{"is\[Dash]empty\[Dash]tuple", "[", 
                  StyleBox["X",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], "]"}], "\[Or]", 
                RowBox[{"is\[Dash]singleton\[Dash]tuple", "[", 
                  StyleBox["X",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], "]"}]}]}]}], "\n", 
          RowBox[{
          "Definition", \(\(\ \)\((\)\), \(is\ element\), \(\()\)\(:\)\(\n\
\)\), GridBox[{
                {
                  RowBox[{\(for\ \(\(any\)\(:\)\)\), 
                    RowBox[{
                      StyleBox["x",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox["y",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox[\(y\&_\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}]}]}
                },
              ColumnAlignments->{Left}], "\n", 
            RowBox[{
              RowBox[{\((1)\), "\t", 
                RowBox[{
                  StyleBox["x",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], 
                  "\[NotElement]", \
\(\[LeftAngleBracket]\[RightAngleBracket]\)}]}], "\n", 
              RowBox[{\((2)\), "\t", 
                RowBox[{
                  RowBox[{
                    StyleBox["x",
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], "\[Element]", 
                    RowBox[{"\[LeftAngleBracket]", 
                      RowBox[{
                        StyleBox["y",
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], ",", 
                        StyleBox[\(y\&_\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], "\[RightAngleBracket]"}]}], 
                  "\[DoubleLeftRightArrow]", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox["x",
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], "=", 
                        StyleBox["y",
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], ")"}], "\[Or]", 
                    RowBox[{
                      StyleBox["x",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "\[Element]", 
                      RowBox[{"\[LeftAngleBracket]", 
                        StyleBox[\(y\&_\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], 
                        "\[RightAngleBracket]"}]}]}]}]}]}]}], "\n", 
          RowBox[{
          "Definition", \(\(\ \)\((\)\), \(deletion\ of\ the\ first\ \
occurrence\), \(\()\)\(:\)\(\n\)\), GridBox[{
                {
                  RowBox[{\(for\ \(\(any\)\(:\)\)\), 
                    RowBox[{
                      StyleBox["a",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox["x",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox[\(x\&_\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}]}]}
                },
              ColumnAlignments->{Left}], "\n", 
            RowBox[{
              RowBox[{\((1)\), "\t", 
                RowBox[{
                  RowBox[{"dfo", "[", 
                    RowBox[{
                      StyleBox["a",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], 
                      ",", \(\[LeftAngleBracket]\[RightAngleBracket]\)}], 
                    "]"}], "=", \
\(\[LeftAngleBracket]\[RightAngleBracket]\)}]}], "\n", 
              RowBox[{\((2)\), "\t", 
                RowBox[{
                  RowBox[{"dfo", "[", 
                    RowBox[{
                      StyleBox["a",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      RowBox[{"\[LeftAngleBracket]", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], ",", 
                          StyleBox[\(x\&_\),
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None]}], "\[RightAngleBracket]"}]}], 
                    "]"}], "=", 
                  RowBox[{"\[LeftDoubleBracketingBar]", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"\[LeftAngleBracket]", 
                          StyleBox[\(x\&_\),
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], "\[RightAngleBracket]"}], 
                        "\[DoubleLeftArrow]", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], "=", 
                          StyleBox["a",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None]}]}], ",", 
                      RowBox[{
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], "\[Cup]", 
                          RowBox[{"dfo", "[", 
                            RowBox[{
                              StyleBox["a",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], ",", 
                              RowBox[{"\[LeftAngleBracket]", 
                                StyleBox[\(x\&_\),
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], 
                                "\[RightAngleBracket]"}]}], "]"}]}], 
                        "\[DoubleLeftArrow]", "otherwise"}]}], 
                    "\[RightDoubleBracketingBar]"}]}]}]}]}], "\n", 
          RowBox[{
          "Definition", \(\(\ \)\((\)\), \(is\ longer\ than\), \(\()\)\(:\)\(\
\n\)\), GridBox[{
                {
                  RowBox[{\(for\ \(\(any\)\(:\)\)\), 
                    RowBox[{
                      StyleBox["x",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox[\(x\&_\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox["y",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox[\(y\&_\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}]}]}
                },
              ColumnAlignments->{Left}], "\n", 
            RowBox[{
              RowBox[{\((1)\), "\t", 
                
                RowBox[{\(\[LeftAngleBracket]\[RightAngleBracket]\), 
                  "\[NotSucceeds]", 
                  RowBox[{"\[LeftAngleBracket]", 
                    StyleBox[\(y\&_\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], "\[RightAngleBracket]"}]}]}], "\n", 
              RowBox[{\((2)\), "\t", 
                RowBox[{
                  RowBox[{"\[LeftAngleBracket]", 
                    RowBox[{
                      StyleBox["x",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox[\(x\&_\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "\[RightAngleBracket]"}], 
                  "\[Succeeds]", \
\(\[LeftAngleBracket]\[RightAngleBracket]\)}]}], "\n", 
              RowBox[{\((3)\), "\t", 
                RowBox[{
                  RowBox[{
                    RowBox[{"\[LeftAngleBracket]", 
                      RowBox[{
                        StyleBox["x",
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], ",", 
                        StyleBox[\(x\&_\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], "\[RightAngleBracket]"}], 
                    "\[Succeeds]", 
                    RowBox[{"\[LeftAngleBracket]", 
                      RowBox[{
                        StyleBox["y",
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], ",", 
                        StyleBox[\(y\&_\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], "\[RightAngleBracket]"}]}], 
                  "\[DoubleLeftRightArrow]", 
                  RowBox[{
                    RowBox[{"\[LeftAngleBracket]", 
                      StyleBox[\(x\&_\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "\[RightAngleBracket]"}], 
                    "\[Succeeds]", 
                    RowBox[{"\[LeftAngleBracket]", 
                      StyleBox[\(y\&_\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "\[RightAngleBracket]"}]}]}]}]}]}],
           "\n", 
          RowBox[{
          "Proposition", \(\(\ \)\((\)\), \(trivial\ tuples\ are\ sorted\), \
\(\()\)\(:\)\(\n\)\), GridBox[{
                {
                  RowBox[{\(for\ \(\(any\)\(:\)\)\), 
                    RowBox[{
                      StyleBox[\(x\&_\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " "}]}]}
                },
              ColumnAlignments->{Left}], "\n", 
            RowBox[{
              RowBox[{"is\[Dash]trivial\[Dash]tuple", "[", 
                RowBox[{"\[LeftAngleBracket]", 
                  StyleBox[\(x\&_\),
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], "\[RightAngleBracket]"}], "]"}], "*", 
              RowBox[{"is\[Dash]sorted", "[", 
                RowBox[{"\[LeftAngleBracket]", 
                  StyleBox[\(x\&_\),
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], "\[RightAngleBracket]"}], "]"}]}]}], 
          "\n", 
          RowBox[{
          "Proposition", \(\(\ \)\((\)\), \(only\ trivial\ tuple\ permuted\ \
version\ of\ itself\), \(\()\)\(:\)\(\n\)\), GridBox[{
                {
                  RowBox[{\(for\ \(\(any\)\(:\)\)\), 
                    RowBox[{
                      StyleBox[\(x\&_\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox["Y",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}]}]},
                {
                  RowBox[{\(\(with\)\(:\)\), 
                    RowBox[{"is\[Dash]trivial\[Dash]tuple", "[", 
                      RowBox[{"\[LeftAngleBracket]", 
                        StyleBox[\(x\&_\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], "\[RightAngleBracket]"}], 
                      "]"}]}]}
                },
              ColumnAlignments->{Left}], "\n", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["Y",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], "=", 
                  RowBox[{"\[LeftAngleBracket]", 
                    StyleBox[\(x\&_\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], "\[RightAngleBracket]"}]}], ")"}], 
              "\[Implies]", 
              RowBox[{
                StyleBox["Y",
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], "\[TildeTilde]", 
                RowBox[{"\[LeftAngleBracket]", 
                  StyleBox[\(x\&_\),
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], "\[RightAngleBracket]"}]}]}]}]}]}], 
      TraditionalForm]], "Output",
  CellLabel->"TS_Out[103]//TraditionalForm="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Proof Techniques Available", "Section"],

Cell[TextData[{
  "The proof techniques for sequence variables/tuples represented in terms of \
sequence variables are implemented in the frame of the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " sequence prover."
}], "Text"],

Cell[CellGroupData[{

Cell["Theorema basic prover for sequences: Sqns", "Subsubsection"],

Cell[BoxData[
    \(\(?Sqns\)\)], "Input",
  CellLabel->"TS_In[130]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[Sqns]\)], "Input"],

Cell[BoxData[
    \({SqnsWFOrdering \[Rule] None, 
      SqnsProofTechniques \[Rule] {"ABF", "CDLeft", "IndLeft"}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?SqnsProofTechniques\)\)], "Input"],

Cell[BoxData["\<\"Option of the Sqns Prover.\\n SqnsProofTechniques\[Rule] \
<\!\(\* StyleBox[\\\"list\\\",\\nFontSlant->\\\"Italic\\\"]\)\!\(\* StyleBox[\
\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\)\!\(\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\)\!\(\* StyleBox[\\\" \\\",\
\\nFontSlant->\\\"Italic\\\"]\)\!\(\* StyleBox[\\\"proof\\\",\\nFontSlant->\\\
\"Italic\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\)\!\(\* \
StyleBox[\\\"techniques\\\",\\nFontSlant->\\\"Italic\\\"]\)\!\(\* StyleBox[\\\
\" \\\",\\nFontSlant->\\\"Italic\\\"]\)>. \\n  Proof Techniques: \\n t     \
ABFTupl - arbitrary but fixed for tuple variables (use only when working with \
tuple variables under the universal quantifier)\\n \t ABF - arbitrary but \
fixed for sequences\\n \t CDLeft - Case Distinction,  from the left\\n \t \
CDExtLeft - Case Distinction,  from the left, with 2 base cases \\n \t \
IndLeft - Structural Sequence Induction, from the left\\n \t WFInd - \
WellFounded induction (user also has to provide the well\[Dash]founded \
relation, through the SqnsWFOrdering option)\\n \t CDRight - Case \
Distinction,  from the right\\n \t IndRight - Structural Sequence Induction, \
from the right\\n\\n  Default value: {ABF, CDLeft, IndLeft} \"\>"], "Print",
  CellTags->"Info3263021048-3712034"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?SqnsWFOrdering\)\)], "Input"],

Cell[BoxData["\<\"Option of the Sqns Prover.\\n SqnsWFOrdering \[Rule] \
<\!\(\* StyleBox[\\\"Order\\\",\\nFontSlant->\\\"Italic\\\"]\)\!\(\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\)\!\(\* \
StyleBox[\\\"Symbol\\\",\\nFontSlant->\\\"Italic\\\"]\)\!\(\* \
StyleBox[\\\">\\\",\\nFontSlant->\\\"Italic\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\)\!\(\* StyleBox[\\\"is\\\",\\nFontSlant->\
\\\"Plain\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* StyleBox[\\\"the\\\",\\nFontSlant->\
\\\"Plain\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* \
StyleBox[\\\"well\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* \
StyleBox[\\\"founded\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* \
StyleBox[\\\"relation\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* \
StyleBox[\\\"that\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* StyleBox[\\\"the\\\",\\nFontSlant->\
\\\"Plain\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* \
StyleBox[\\\"user\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* \
StyleBox[\\\"wants\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* \
StyleBox[\\\"to\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* StyleBox[\\\"use\\\",\\nFontSlant->\
\\\"Plain\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* \
StyleBox[\\\"with\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* StyleBox[\\\"the\\\",\\nFontSlant->\
\\\"Plain\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* \
StyleBox[\\\"Well\[Dash]Founded\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* \
StyleBox[\\\"induction\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* \
StyleBox[\\\".\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* StyleBox[\\\"The\\\",\\nFontSlant->\
\\\"Plain\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* \
StyleBox[\\\"properties\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* StyleBox[\\\"the\\\",\\nFontSlant->\
\\\"Plain\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* \
StyleBox[\\\"ordering\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* \
StyleBox[\\\"have\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* \
StyleBox[\\\"to\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* \
StyleBox[\\\"be\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* \
StyleBox[\\\"in\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* StyleBox[\\\"the\\\",\\nFontSlant->\
\\\"Plain\\\"]\)\!\(\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\* \
StyleBox[\\\"knowledge\\\",\\nFontSlant->\\\"Plain\\\"]\) base and the \
ordering has to be well founded.\\n  Default value: None. \"\>"], "Print",
  CellTags->"Info3262768099-1747451"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["User Provers that involve the basic prover for sequences:", \
"Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?*Sqns*\)\)], "Input"],

Cell[BoxData[GridBox[{
        {
          StyleBox["Theorema`Provers`Sqns`Common`",
            FontFamily->"Helvetica",
            FontSize->12,
            FontWeight->"Bold"]},
        {GridBox[{
              {
                ButtonBox[
                  StyleBox["\[Cent]SqnsArbitraryButFixed",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3262768228-8434665", 
                    "Theorema`Provers`Sqns`Common`\[Cent]\
SqnsArbitraryButFixed"},
                  ButtonFrame->"None",
                  ButtonNote->"Theorema`Provers`Sqns`Common`"], 
                ButtonBox[
                  StyleBox["\[Cent]SqnsCaseDistinctionLeft",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3262768228-8434665", 
                    "Theorema`Provers`Sqns`Common`\[Cent]\
SqnsCaseDistinctionLeft"},
                  ButtonFrame->"None",
                  ButtonNote->"Theorema`Provers`Sqns`Common`"], 
                ButtonBox[
                  StyleBox["\[Cent]SqnsChooseMethod",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3262768228-8434665", 
                    "Theorema`Provers`Sqns`Common`\[Cent]SqnsChooseMethod"},
                  ButtonFrame->"None",
                  ButtonNote->"Theorema`Provers`Sqns`Common`"], 
                ButtonBox[
                  StyleBox["\[Cent]SqnsInductionRight",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3262768228-8434665", 
                    "Theorema`Provers`Sqns`Common`\[Cent]SqnsInductionRight"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"Theorema`Provers`Sqns`Common`"]},
              {
                ButtonBox[
                  StyleBox["\[Cent]SqnsCaseDistinctionExtLeft",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3262768228-8434665", 
                    "Theorema`Provers`Sqns`Common`\[Cent]\
SqnsCaseDistinctionExtLeft"},
                  ButtonFrame->"None",
                  ButtonNote->"Theorema`Provers`Sqns`Common`"], 
                ButtonBox[
                  StyleBox["\[Cent]SqnsCaseDistinctionRight",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3262768228-8434665", 
                    "Theorema`Provers`Sqns`Common`\[Cent]\
SqnsCaseDistinctionRight"},
                  ButtonFrame->"None",
                  ButtonNote->"Theorema`Provers`Sqns`Common`"], 
                ButtonBox[
                  StyleBox["\[Cent]SqnsInductionLeft",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3262768228-8434665", 
                    "Theorema`Provers`Sqns`Common`\[Cent]SqnsInductionLeft"},
                  ButtonFrame->"None",
                  ButtonNote->"Theorema`Provers`Sqns`Common`"], 
                ButtonBox[
                  StyleBox["\[Cent]SqnsWFInduction",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3262768228-8434665", 
                    "Theorema`Provers`Sqns`Common`\[Cent]SqnsWFInduction"},
                  ButtonFrame->"None",
                  ButtonNote->"Theorema`Provers`Sqns`Common`"]}
              },
            RowMinHeight->{1, 1.05}]},
        {
          StyleBox["Theorema`Provers`Sqns`Prover`",
            FontFamily->"Helvetica",
            FontSize->12,
            FontWeight->"Bold"]},
        {GridBox[{
              {
                ButtonBox[
                  StyleBox["Sqns",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3262768228-8434665", 
                    "Theorema`Provers`Sqns`Prover`Sqns"},
                  ButtonFrame->"None",
                  ButtonNote->"Theorema`Provers`Sqns`Prover`"], 
                ButtonBox[
                  StyleBox["SqnsProofTechniques",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3262768228-8434665", 
                    "Theorema`Provers`Sqns`Prover`SqnsProofTechniques"},
                  ButtonFrame->"None",
                  ButtonNote->"Theorema`Provers`Sqns`Prover`"], 
                ButtonBox[
                  StyleBox["SqnsWFOrdering",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3262768228-8434665", 
                    "Theorema`Provers`Sqns`Prover`SqnsWFOrdering"},
                  ButtonFrame->"None",
                  ButtonNote->"Theorema`Provers`Sqns`Prover`"], "", "", ""}
              },
            RowMinHeight->1.05]},
        {
          StyleBox["Theorema`Provers`UserProvers`Sqns`",
            FontFamily->"Helvetica",
            FontSize->12,
            FontWeight->"Bold"]},
        {GridBox[{
              {
                ButtonBox[
                  StyleBox["SqnsCasePC",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3262768228-8434665", 
                    "Theorema`Provers`UserProvers`Sqns`SqnsCasePC"},
                  ButtonFrame->"None",
                  ButtonNote->"Theorema`Provers`UserProvers`Sqns`"], 
                ButtonBox[
                  StyleBox["SqnsEqProver",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3262768228-8434665", 
                    "Theorema`Provers`UserProvers`Sqns`SqnsEqProver"},
                  ButtonFrame->"None",
                  ButtonNote->"Theorema`Provers`UserProvers`Sqns`"], 
                ButtonBox[
                  StyleBox["SqnsPredCaseProver",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3262768228-8434665", 
                    "Theorema`Provers`UserProvers`Sqns`SqnsPredCaseProver"},
                  ButtonFrame->"None",
                  ButtonNote->"Theorema`Provers`UserProvers`Sqns`"], 
                ButtonBox[
                  StyleBox["SqnsPredProver",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3262768228-8434665", 
                    "Theorema`Provers`UserProvers`Sqns`SqnsPredProver"},
                  ButtonFrame->"None",
                  ButtonNote->"Theorema`Provers`UserProvers`Sqns`"], 
                ButtonBox[
                  StyleBox["SqnsTHEqCasePC",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3262768228-8434665", 
                    "Theorema`Provers`UserProvers`Sqns`SqnsTHEqCasePC"},
                  ButtonFrame->"None",
                  ButtonNote->"Theorema`Provers`UserProvers`Sqns`"], "", ""},
              {
                ButtonBox[
                  StyleBox["SqnsEqCasePC",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3262768228-8434665", 
                    "Theorema`Provers`UserProvers`Sqns`SqnsEqCasePC"},
                  ButtonFrame->"None",
                  ButtonNote->"Theorema`Provers`UserProvers`Sqns`"], 
                ButtonBox[
                  StyleBox["SqnsGenEqCasePC",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3262768228-8434665", 
                    "Theorema`Provers`UserProvers`Sqns`SqnsGenEqCasePC"},
                  ButtonFrame->"None",
                  ButtonNote->"Theorema`Provers`UserProvers`Sqns`"], 
                ButtonBox[
                  StyleBox["SqnsPredEqCasePC",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3262768228-8434665", 
                    "Theorema`Provers`UserProvers`Sqns`SqnsPredEqCasePC"},
                  ButtonFrame->"None",
                  ButtonNote->"Theorema`Provers`UserProvers`Sqns`"], 
                ButtonBox[
                  StyleBox["SqnsProver",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3262768228-8434665", 
                    "Theorema`Provers`UserProvers`Sqns`SqnsProver"},
                  ButtonFrame->"None",
                  ButtonNote->"Theorema`Provers`UserProvers`Sqns`"], "", "", 
                ""}
              },
            RowMinHeight->{1, 1.05}]}
        },
      RowSpacings->{2, 3, 2, 3, 2, 3},
      ColumnAlignments->{Left},
      ColumnsEqual->True]], "Print",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->GrayLevel[0.930022],
  ButtonBoxOptions->{Active->True}],

Cell[BoxData[
    \("The prover combining proof techniques on sequences with \
simplification, predicate logic, case distinction and natural deduction."\)], \
"Print",
  CellTags->"Info3262768228-8434665"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Algorithm Type: Divide and Conquer for Tuples", "Section"],

Cell[BoxData[
    RowBox[{
      StyleBox["Algorithm",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<sorted\>\"", ",", \(any[is\[Dash]tuple[X]]\), ",", 
        "\[IndentingNewLine]", 
        RowBox[{\(sorted[X]\), "=", 
          RowBox[{
            StyleBox["{",
              SpanMaxSize->Infinity], GridBox[{
                {
                  RowBox[{
                    StyleBox["special",
                      FontColor->RGBColor[1, 0, 0]], "[", "X", "]"}], 
                  "\[DoubleLeftArrow]", \(is\[Dash]trivial\[Dash]tuple[X]\)},
                {
                  RowBox[{
                    StyleBox["merged",
                      FontColor->RGBColor[1, 0, 0]], "[", 
                    RowBox[{
                      RowBox[{"sorted", "[", 
                        RowBox[{
                          StyleBox["left\[Dash]split",
                            FontColor->RGBColor[1, 0, 0]], "[", "X", "]"}], 
                        "]"}], ",", 
                      RowBox[{"sorted", "[", 
                        RowBox[{
                          StyleBox["right\[Dash]split",
                            FontColor->RGBColor[1, 0, 0]], "[", "X", "]"}], 
                        "]"}]}], "]"}], "\[DoubleLeftArrow]", "otherwise"}
                },
              ColumnAlignments->{Left}], 
            StyleBox["}",
              ShowContents->False]}]}]}], "  ", "]"}]], "Input",
  CellLabel->"TS_In[87]:=",
  InitializationCell->True,
  CellTags->"Algorithm (sorted)"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Knowledge attached to the algorithm type: \
requirements for the auxiliary functions:", "Subsection"]], "Subsection"],

Cell[BoxData[
    \(Lemma["\<closure of special\>", \ any[X], \ 
      with[\[InvisibleSpace]is\[Dash]tuple[X] \[And] 
          is\[Dash]trivial\[Dash]tuple[
            X]], \ \[IndentingNewLine]is\[Dash]tuple[special[X]]]\)], "Input",\

  CellLabel->"TS_In[88]:=",
  InitializationCell->True,
  CellTags->"Lemma (closure of special)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Lemma",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<splits are tuples\>\"", ",", \(any[X]\), 
        ",", \(with[
          is\[Dash]tuple[X] \[And] \[Not] is\[Dash]trivial\[Dash]tuple[X]]\), 
        ",", "\[IndentingNewLine]", GridBox[{
            {\(is\[Dash]tuple[left\[Dash]split[X]]\)},
            {\(is\[Dash]tuple[right\[Dash]split[X]]\)}
            },
          ColumnAlignments->{Left}]}], "  ", "]"}]], "Input",
  CellLabel->"TS_In[89]:=",
  InitializationCell->True,
  CellTags->"Lemma (splits are tuples)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Lemma",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<splits are shorter\>\"", ",", \(any[is\[Dash]tuple[X]]\), 
        ",", \(with[\[Not] is\[Dash]trivial\[Dash]tuple[X]]\), ",", 
        "\[IndentingNewLine]", GridBox[{
            {\(X \[Succeeds] left\[Dash]split[X]\)},
            {\(X \[Succeeds] right\[Dash]split[X]\)}
            },
          ColumnAlignments->{Left}]}], "  ", "]"}]], "Input",
  CellLabel->"TS_In[90]:=",
  InitializationCell->True,
  CellTags->"Lemma (splits are shorter)"],

Cell[BoxData[
    \(Lemma["\<closure of merge\>", \ 
      any[is\[Dash]tuple[X, \ Y]], \ \[IndentingNewLine]is\[Dash]tuple[
        merged[X, \ Y]]]\)], "Input",
  CellLabel->"TS_In[91]:=",
  InitializationCell->True,
  CellTags->"Lemma (closure of merge)"],

Cell[BoxData[
    RowBox[{"Theory", "[", 
      RowBox[{
      "\"\<algorithm type knowledge\>\"", ",", " ", "\[IndentingNewLine]", 
        GridBox[{
            {\(Lemma["\<closure of special\>"]\)},
            {\(Lemma["\<splits are tuples\>"]\)},
            {\(Lemma["\<splits are shorter\>"]\)},
            {\(Lemma["\<closure of merge\>"]\)}
            }]}], "\[IndentingNewLine]", "]"}]], "Input",
  CellLabel->"TS_In[92]:=",
  InitializationCell->True,
  CellTags->"Theory (algorithm type knowledge)"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fill up the knowledge needed by the Cascade", "Section"],

Cell[CellGroupData[{

Cell["The symbol denoting the new notion", "Subsubsection"],

Cell[BoxData[
    \(\(nS = \[Bullet][sorted];\)\)], "Input",
  CellLabel->"TS_In[93]:=",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["The symbols denoting the auxiliary notions", "Subsubsection"],

Cell[BoxData[
    \(\(aNS = {\[Bullet][special], \ \[Bullet][merged], \ \[Bullet][
            left\[Dash]split], \ \[Bullet][right\[Dash]split]};\)\)], "Input",\

  CellLabel->"TS_In[94]:=",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The list of conjectures containing only known symbols: empty (may be updated \
by the Cascade)\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(kConjectures = \[Bullet]asml[];\)\)], "Input",
  CellLabel->"TS_In[95]:=",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The list of conjectures containing the auxiliary symbols (requirements for \
auxiliary notions): properties from the Algorithm Type,(to  be updated by the \
Cascade)\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(nConjectures = Theory["\<algorithm type knowledge\>"];\)\)], "Input",
  CellLabel->"TS_In[96]:=",
  InitializationCell->True],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(nConjectures\)\" is \
similar to existing symbol \"\!\(kConjectures\)\"."\)], "Message",
  CellLabel->"From TS_In[96]:="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The knowledge available", "Subsubsection"],

Cell[BoxData[
    RowBox[{"Theory", "[", 
      RowBox[{
      "\"\<lazy thinking correctness of sort\>\"", ",", " ", 
        "\[IndentingNewLine]", GridBox[{
            {\(Theory["\<knowledge: is sorted version\>"]\)},
            {\(Algorithm["\<sorted\>"]\)},
            {\(Theory["\<algorithm type knowledge\>"]\)}
            }]}], "]"}]], "Input",
  CellLabel->"TS_In[97]:=",
  InitializationCell->True,
  CellTags->"Theory (lazy thinking correctness of sort)"],

Cell[BoxData[
    \(\(kb = Theory["\<lazy thinking correctness of sort\>"];\)\)], "Input",
  CellLabel->"TS_In[98]:=",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Other initializations", "Subsubsection"],

Cell["\<\
This is a variable used by the conjecture generator (GenerateConjectures) to \
eliminate from the lhs of the implication of the conjectures  (if they are in \
this form) the terms that are just syntactic sugar and are rewritten \
immediately, by the respective definitions, in the respective proofs. \
\>", "Text"],

Cell[BoxData[
    \(\($ExplorationSyntacticSugar = {\[Bullet][
            is\[Dash]sorted\[Dash]version]};\)\)], "Input",
  CellLabel->"TS_In[99]:=",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cascade", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Prove", "[", 
        RowBox[{\(Theorem["\<correctness of sort\>"]\), ",", 
          " ", \(using \[Rule] 
            Theory["\<lazy thinking correctness of sort\>"]\), ",", 
          " ", \(by \[Rule] 
            CascadeLT[SqnsEqCasePC, \ GenerateConjectures, \ nS, \ aNS, \ 
              kConjectures, \ nConjectures]\), ",", " ", 
          
          StyleBox[\(built\[Dash]in \[Rule] {Property[\(\[TildeTilde]\)\(\(\
\[Rule]\)\({Commutative}\)\)]}\),
            FontSize->9], 
          StyleBox[",",
            FontSize->9], 
          StyleBox[" ",
            FontSize->9], 
          
          StyleBox[\(ProverOptions \[Rule] {SqnsProofTechniques \[Rule] \
{"\<WFInd\>"}, \ SqnsWFOrdering \[Rule] \[Bullet][ \[Succeeds] ], \ 
                GRWTarget \[Rule] {"\<kb\>", \ "\<goal\>"}, \ 
                AllowIntroduceQuantifiers \[Rule] True}\),
            FontSize->9], 
          StyleBox[",",
            FontSize->9], 
          StyleBox[" ",
            FontSize->9], 
          StyleBox[\(SearchDepth \[Rule] 50\),
            FontSize->9]}], "]"}], "//", "Timing"}]], "Input",
  CellLabel->"TS_In[105]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LAZY THINKING::::: The proof fails.  \\n After analysing \
the failing proof, the following conjecture is added to the knowledge base: \
\\n \"\>", "\[InvisibleSpace]", 
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\<\"Lemma (conjecture15): conjecture15\"\>", ",", 
            RowBox[{
              UnderscriptBox[
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["X1",
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " "}]], 
                RowBox[{"is\[Dash]tuple", "[", 
                  StyleBox["X1",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], "]"}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"is\[Dash]trivial\[Dash]tuple", "[", 
                      StyleBox["X1",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "]"}], "\[And]", 
                    RowBox[{"is\[Dash]sorted", "[", 
                      StyleBox["X1",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "]"}]}], "\[Implies]", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"special", "[", 
                        StyleBox["X1",
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], "]"}], "=", 
                      StyleBox["X1",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], ")"}]}], ")"}]}], 
            ",", \(\[Bullet]finfo[]\)}], "]"}], 
        "\[InvisibleSpace]", "\<\"\\n Now attempt the proof with the updated \
knowledge base. \"\>"}],
      SequenceForm[ 
      "LAZY THINKING::::: The proof fails.  \n After analysing the failing \
proof, the following conjecture is added to the knowledge base: \n ", 
        \[Bullet]lf[ "Lemma (conjecture15): conjecture15", 
          \[Trademark]ForAll[ 
            \[Bullet]range[ 
              \[Bullet]simpleRange[ 
                \[Bullet]var[ X1]]], 
            \[Trademark]IsTuple[ 
              \[Bullet]var[ X1]], 
            \[Trademark]Implies[ 
              \[Trademark]And[ 
                is\[Dash]trivial\[Dash]tuple[ 
                  \[Bullet]var[ X1]], 
                is\[Dash]sorted[ 
                  \[Bullet]var[ X1]]], 
              \[Trademark]Equal[ 
                special[ 
                  \[Bullet]var[ X1]], 
                \[Bullet]var[ X1]]]], 
          \[Bullet]finfo[ ]], 
        "\n Now attempt the proof with the updated knowledge base. "],
      Editable->False]], "Print",
  CellLabel->"From TS_In[105]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LAZY THINKING::::: The proof fails.  \\n After analysing \
the failing proof, the following conjecture is added to the knowledge base: \
\\n \"\>", "\[InvisibleSpace]", 
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\<\"Lemma (conjecture44): conjecture44\"\>", ",", 
            RowBox[{
              UnderscriptBox[
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["X2",
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], ",", 
                    StyleBox["X3",
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], ",", 
                    StyleBox["X4",
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}]], 
                RowBox[{"is\[Dash]tuple", "[", 
                  StyleBox["X4",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], "]"}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"is\[Dash]tuple", "[", 
                      StyleBox["X2",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "]"}], "\[And]", 
                    RowBox[{
                      RowBox[{"left\[Dash]split", "[", 
                        StyleBox["X4",
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], "]"}], "\[TildeTilde]", 
                      StyleBox["X2",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "\[And]", 
                    RowBox[{"is\[Dash]sorted", "[", 
                      StyleBox["X2",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "]"}], "\[And]", 
                    RowBox[{"is\[Dash]tuple", "[", 
                      StyleBox["X3",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "]"}], "\[And]", 
                    RowBox[{
                      RowBox[{"right\[Dash]split", "[", 
                        StyleBox["X4",
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], "]"}], "\[TildeTilde]", 
                      StyleBox["X3",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "\[And]", 
                    RowBox[{"is\[Dash]sorted", "[", 
                      StyleBox["X3",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "]"}], "\[And]", 
                    RowBox[{"\[Not]", 
                      RowBox[{"is\[Dash]trivial\[Dash]tuple", "[", 
                        StyleBox["X4",
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], "]"}]}]}], "\[Implies]", 
                  RowBox[{
                    RowBox[{"merged", "[", 
                      RowBox[{
                        StyleBox["X2",
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], ",", 
                        StyleBox["X3",
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], "]"}], "\[TildeTilde]", 
                    StyleBox["X4",
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}]}], ")"}]}], 
            ",", \(\[Bullet]finfo[]\)}], "]"}], 
        "\[InvisibleSpace]", "\<\"\\n Now attempt the proof with the updated \
knowledge base. \"\>"}],
      SequenceForm[ 
      "LAZY THINKING::::: The proof fails.  \n After analysing the failing \
proof, the following conjecture is added to the knowledge base: \n ", 
        \[Bullet]lf[ "Lemma (conjecture44): conjecture44", 
          \[Trademark]ForAll[ 
            \[Bullet]range[ 
              \[Bullet]simpleRange[ 
                \[Bullet]var[ X2]], 
              \[Bullet]simpleRange[ 
                \[Bullet]var[ X3]], 
              \[Bullet]simpleRange[ 
                \[Bullet]var[ X4]]], 
            \[Trademark]IsTuple[ 
              \[Bullet]var[ X4]], 
            \[Trademark]Implies[ 
              \[Trademark]And[ 
                \[Trademark]IsTuple[ 
                  \[Bullet]var[ X2]], 
                \[Trademark]TildeTilde[ 
                  left\[Dash]split[ 
                    \[Bullet]var[ X4]], 
                  \[Bullet]var[ X2]], 
                is\[Dash]sorted[ 
                  \[Bullet]var[ X2]], 
                \[Trademark]IsTuple[ 
                  \[Bullet]var[ X3]], 
                \[Trademark]TildeTilde[ 
                  right\[Dash]split[ 
                    \[Bullet]var[ X4]], 
                  \[Bullet]var[ X3]], 
                is\[Dash]sorted[ 
                  \[Bullet]var[ X3]], 
                \[Trademark]Not[ 
                  is\[Dash]trivial\[Dash]tuple[ 
                    \[Bullet]var[ X4]]]], 
              \[Trademark]TildeTilde[ 
                merged[ 
                  \[Bullet]var[ X2], 
                  \[Bullet]var[ X3]], 
                \[Bullet]var[ X4]]]], 
          \[Bullet]finfo[ ]], 
        "\n Now attempt the proof with the updated knowledge base. "],
      Editable->False]], "Print",
  CellLabel->"From TS_In[105]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LAZY THINKING::::: The proof fails.  \\n After analysing \
the failing proof, the following conjecture is added to the knowledge base: \
\\n \"\>", "\[InvisibleSpace]", 
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\<\"Lemma (conjecture46): conjecture46\"\>", ",", 
            RowBox[{
              UnderscriptBox[
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["X5",
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], ",", 
                    StyleBox["X6",
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], ",", 
                    StyleBox["X7",
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}]], 
                RowBox[{"is\[Dash]tuple", "[", 
                  StyleBox["X7",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], "]"}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"is\[Dash]tuple", "[", 
                      StyleBox["X5",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "]"}], "\[And]", 
                    RowBox[{
                      RowBox[{"left\[Dash]split", "[", 
                        StyleBox["X7",
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], "]"}], "\[TildeTilde]", 
                      StyleBox["X5",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "\[And]", 
                    RowBox[{"is\[Dash]sorted", "[", 
                      StyleBox["X5",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "]"}], "\[And]", 
                    RowBox[{"is\[Dash]tuple", "[", 
                      StyleBox["X6",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "]"}], "\[And]", 
                    RowBox[{
                      RowBox[{"right\[Dash]split", "[", 
                        StyleBox["X7",
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], "]"}], "\[TildeTilde]", 
                      StyleBox["X6",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "\[And]", 
                    RowBox[{"is\[Dash]sorted", "[", 
                      StyleBox["X6",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "]"}], "\[And]", 
                    RowBox[{"\[Not]", 
                      RowBox[{"is\[Dash]trivial\[Dash]tuple", "[", 
                        StyleBox["X7",
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], "]"}]}]}], "\[Implies]", 
                  RowBox[{"is\[Dash]sorted", "[", 
                    RowBox[{"merged", "[", 
                      RowBox[{
                        StyleBox["X5",
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], ",", 
                        StyleBox["X6",
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], "]"}], "]"}]}], ")"}]}], 
            ",", \(\[Bullet]finfo[]\)}], "]"}], 
        "\[InvisibleSpace]", "\<\"\\n Now attempt the proof with the updated \
knowledge base. \"\>"}],
      SequenceForm[ 
      "LAZY THINKING::::: The proof fails.  \n After analysing the failing \
proof, the following conjecture is added to the knowledge base: \n ", 
        \[Bullet]lf[ "Lemma (conjecture46): conjecture46", 
          \[Trademark]ForAll[ 
            \[Bullet]range[ 
              \[Bullet]simpleRange[ 
                \[Bullet]var[ X5]], 
              \[Bullet]simpleRange[ 
                \[Bullet]var[ X6]], 
              \[Bullet]simpleRange[ 
                \[Bullet]var[ X7]]], 
            \[Trademark]IsTuple[ 
              \[Bullet]var[ X7]], 
            \[Trademark]Implies[ 
              \[Trademark]And[ 
                \[Trademark]IsTuple[ 
                  \[Bullet]var[ X5]], 
                \[Trademark]TildeTilde[ 
                  left\[Dash]split[ 
                    \[Bullet]var[ X7]], 
                  \[Bullet]var[ X5]], 
                is\[Dash]sorted[ 
                  \[Bullet]var[ X5]], 
                \[Trademark]IsTuple[ 
                  \[Bullet]var[ X6]], 
                \[Trademark]TildeTilde[ 
                  right\[Dash]split[ 
                    \[Bullet]var[ X7]], 
                  \[Bullet]var[ X6]], 
                is\[Dash]sorted[ 
                  \[Bullet]var[ X6]], 
                \[Trademark]Not[ 
                  is\[Dash]trivial\[Dash]tuple[ 
                    \[Bullet]var[ X7]]]], 
              is\[Dash]sorted[ 
                merged[ 
                  \[Bullet]var[ X5], 
                  \[Bullet]var[ X6]]]]], 
          \[Bullet]finfo[ ]], 
        "\n Now attempt the proof with the updated knowledge base. "],
      Editable->False]], "Print",
  CellLabel->"From TS_In[105]:="],

Cell[BoxData[
    \("\n LAZY THINKING ::::: The proof is completed!!!!"\)], "Print",
  CellLabel->"From TS_In[105]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(692.556`\ Second\), ",", 
        RowBox[{"{", 
          RowBox[{"\<\"proved\"\>", ",", 
            RowBox[{"\[Bullet]asml", "[", 
              
              RowBox[{\(\[Bullet]lf["Definition (is sorted): 1", 
                  is\[Dash]sorted[\[LeftAngleBracket]\[RightAngleBracket]], \
\[Bullet]finfo[\*"\<\"\"\>", "lazy thinking correctness of sort", 
                    "knowledge: is sorted version"]]\), ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Definition (is sorted): 2\"\>", ",", 
                    RowBox[{
                      UnderscriptBox["\[ForAll]", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], " "}]], 
                      RowBox[{"is\[Dash]sorted", "[", 
                        RowBox[{"\[LeftAngleBracket]", 
                          StyleBox["x",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], "\[RightAngleBracket]"}], 
                        "]"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "lazy thinking correctness of sort", 
                      "knowledge: is sorted version"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Definition (is sorted): 3\"\>", ",", 
                    RowBox[{
                      UnderscriptBox["\[ForAll]", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], ",", 
                          StyleBox["y",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], ",", 
                          StyleBox[\(z\&_\),
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None]}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{"is\[Dash]sorted", "[", 
                            RowBox[{"\[LeftAngleBracket]", 
                              RowBox[{
                                StyleBox["x",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], ",", 
                                StyleBox["y",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], ",", 
                                StyleBox[\(z\&_\),
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None]}], 
                              "\[RightAngleBracket]"}], "]"}], 
                          "\[DoubleLeftRightArrow]", 
                          RowBox[{
                            RowBox[{
                              StyleBox["x",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "\[GreaterEqual]", 
                              StyleBox["y",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None]}], "\[And]", 
                            RowBox[{"is\[Dash]sorted", "[", 
                              RowBox[{"\[LeftAngleBracket]", 
                                RowBox[{
                                  StyleBox["y",
                                    FontWeight->"Bold",
                                    FontSlant->"Italic",
                                    FontColor->RGBColor[0, 0, 1],
                                    Background->None], ",", 
                                  StyleBox[\(z\&_\),
                                    FontWeight->"Bold",
                                    FontSlant->"Italic",
                                    FontColor->RGBColor[0, 0, 1],
                                    Background->None]}], 
                                "\[RightAngleBracket]"}], "]"}]}]}], ")"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "lazy thinking correctness of sort", 
                      "knowledge: is sorted version"]\)}], "]"}], 
                ",", \(\[Bullet]lf[
                  "Definition (is permuted version): 1", \[LeftAngleBracket]\
\[RightAngleBracket] \[TildeTilde] \[LeftAngleBracket]\[RightAngleBracket], \
\[Bullet]finfo[\*"\<\"\"\>", "lazy thinking correctness of sort", 
                    "knowledge: is sorted version"]]\), ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  
                  RowBox[{"\<\"Definition (is permuted version): 2\"\>", ",", 
                    
                    RowBox[{
                      UnderscriptBox["\[ForAll]", 
                        RowBox[{
                          StyleBox["y",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], ",", 
                          StyleBox[\(y\&_\),
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None]}]], 
                      RowBox[{"(", 
                        
                        RowBox[{\(\[LeftAngleBracket]\[RightAngleBracket]\), 
                          "\[NotTildeTilde]", 
                          RowBox[{"\[LeftAngleBracket]", 
                            RowBox[{
                              StyleBox["y",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], ",", 
                              StyleBox[\(y\&_\),
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None]}], 
                            "\[RightAngleBracket]"}]}], ")"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "lazy thinking correctness of sort", 
                      "knowledge: is sorted version"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  
                  RowBox[{"\<\"Definition (is permuted version): 3\"\>", ",", 
                    
                    RowBox[{
                      UnderscriptBox["\[ForAll]", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], ",", 
                          StyleBox[\(x\&_\),
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], ",", 
                          StyleBox[\(y\&_\),
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None]}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            RowBox[{"\[LeftAngleBracket]", 
                              StyleBox[\(y\&_\),
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "\[RightAngleBracket]"}], 
                            "\[TildeTilde]", 
                            RowBox[{"\[LeftAngleBracket]", 
                              RowBox[{
                                StyleBox["x",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], ",", 
                                StyleBox[\(x\&_\),
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None]}], 
                              "\[RightAngleBracket]"}]}], 
                          "\[DoubleLeftRightArrow]", 
                          RowBox[{
                            RowBox[{
                              StyleBox["x",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "\[Element]", 
                              RowBox[{"\[LeftAngleBracket]", 
                                StyleBox[\(y\&_\),
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], 
                                "\[RightAngleBracket]"}]}], "\[And]", 
                            RowBox[{
                              RowBox[{"dfo", "[", 
                                RowBox[{
                                  StyleBox["x",
                                    FontWeight->"Bold",
                                    FontSlant->"Italic",
                                    FontColor->RGBColor[0, 0, 1],
                                    Background->None], ",", 
                                  RowBox[{"\[LeftAngleBracket]", 
                                    StyleBox[\(y\&_\),
                                      FontWeight->"Bold",
                                      FontSlant->"Italic",
                                      FontColor->RGBColor[0, 0, 1],
                                      Background->None], 
                                    "\[RightAngleBracket]"}]}], "]"}], 
                              "\[TildeTilde]", 
                              RowBox[{"\[LeftAngleBracket]", 
                                StyleBox[\(x\&_\),
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], 
                                "\[RightAngleBracket]"}]}]}]}], ")"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "lazy thinking correctness of sort", 
                      "knowledge: is sorted version"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Definition (is sorted version)\"\>", ",", 
                    RowBox[{
                      UnderscriptBox[
                        UnderscriptBox["\[ForAll]", 
                          RowBox[{
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], ",", 
                            StyleBox["Y",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None]}]], 
                        RowBox[{"is\[Dash]tuple", "[", 
                          StyleBox["X",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], "]"}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{"is\[Dash]sorted\[Dash]version", "[", 
                            RowBox[{
                              StyleBox["X",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], ",", 
                              StyleBox["Y",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None]}], "]"}], 
                          "\[DoubleLeftRightArrow]", 
                          RowBox[{
                            RowBox[{"is\[Dash]tuple", "[", 
                              StyleBox["Y",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "]"}], "\[And]", 
                            RowBox[{
                              StyleBox["X",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "\[TildeTilde]", 
                              StyleBox["Y",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None]}], "\[And]", 
                            RowBox[{"is\[Dash]sorted", "[", 
                              StyleBox["Y",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "]"}]}]}], ")"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "lazy thinking correctness of sort", 
                      "knowledge: is sorted version"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Proposition (is tuple tuple)\"\>", ",", 
                    RowBox[{
                      UnderscriptBox["\[ForAll]", 
                        RowBox[{
                          StyleBox[\(x\&_\),
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], " "}]], 
                      RowBox[{"is\[Dash]tuple", "[", 
                        RowBox[{"\[LeftAngleBracket]", 
                          StyleBox[\(x\&_\),
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], "\[RightAngleBracket]"}], 
                        "]"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "lazy thinking correctness of sort", 
                      "knowledge: is sorted version"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Definition (prepend): \[Cup]\"\>", ",", 
                    RowBox[{
                      UnderscriptBox["\[ForAll]", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], ",", 
                          StyleBox[\(y\&_\),
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None]}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "\[Cup]", 
                            RowBox[{"\[LeftAngleBracket]", 
                              StyleBox[\(y\&_\),
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "\[RightAngleBracket]"}]}],
                           "=", 
                          RowBox[{"\[LeftAngleBracket]", 
                            RowBox[{
                              StyleBox["x",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], ",", 
                              StyleBox[\(y\&_\),
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None]}], 
                            "\[RightAngleBracket]"}]}], ")"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "lazy thinking correctness of sort", 
                      "knowledge: is sorted version"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  
                  RowBox[{"\<\"Proposition (singleton tuple is singleton \
tuple)\"\>", ",", 
                    RowBox[{
                      UnderscriptBox["\[ForAll]", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], " "}]], 
                      RowBox[{"is\[Dash]singleton\[Dash]tuple", "[", 
                        RowBox[{"\[LeftAngleBracket]", 
                          StyleBox["x",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], "\[RightAngleBracket]"}], 
                        "]"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "lazy thinking correctness of sort", 
                      "knowledge: is sorted version"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Definition (is trivial tuple)\"\>", ",", 
                    RowBox[{
                      UnderscriptBox["\[ForAll]", 
                        RowBox[{"is\[Dash]tuple", "[", 
                          StyleBox["X",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], "]"}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{"is\[Dash]trivial\[Dash]tuple", "[", 
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "]"}], 
                          "\[DoubleLeftRightArrow]", 
                          RowBox[{
                            RowBox[{"is\[Dash]empty\[Dash]tuple", "[", 
                              StyleBox["X",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "]"}], "\[Or]", 
                            RowBox[{"is\[Dash]singleton\[Dash]tuple", "[", 
                              StyleBox["X",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "]"}]}]}], ")"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "lazy thinking correctness of sort", 
                      "knowledge: is sorted version"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Definition (is element): 1\"\>", ",", 
                    RowBox[{
                      UnderscriptBox["\[ForAll]", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], " "}]], 
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], 
                          "\[NotElement]", \(\[LeftAngleBracket]\
\[RightAngleBracket]\)}], ")"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "lazy thinking correctness of sort", 
                      "knowledge: is sorted version"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Definition (is element): 2\"\>", ",", 
                    RowBox[{
                      UnderscriptBox["\[ForAll]", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], ",", 
                          StyleBox["y",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], ",", 
                          StyleBox[\(y\&_\),
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None]}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "\[Element]", 
                            RowBox[{"\[LeftAngleBracket]", 
                              RowBox[{
                                StyleBox["y",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], ",", 
                                StyleBox[\(y\&_\),
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None]}], 
                              "\[RightAngleBracket]"}]}], 
                          "\[DoubleLeftRightArrow]", 
                          RowBox[{
                            RowBox[{"(", 
                              RowBox[{
                                StyleBox["x",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], "=", 
                                StyleBox["y",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None]}], ")"}], "\[Or]", 
                            RowBox[{
                              StyleBox["x",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "\[Element]", 
                              RowBox[{"\[LeftAngleBracket]", 
                                StyleBox[\(y\&_\),
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], 
                                "\[RightAngleBracket]"}]}]}]}], ")"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "lazy thinking correctness of sort", 
                      "knowledge: is sorted version"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  
                  RowBox[{"\<\"Definition (deletion of the first occurrence): \
1\"\>", ",", 
                    RowBox[{
                      UnderscriptBox["\[ForAll]", 
                        RowBox[{
                          StyleBox["a",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], " "}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{"dfo", "[", 
                            RowBox[{
                              StyleBox["a",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], 
                              ",", \(\[LeftAngleBracket]\[RightAngleBracket]\)\
}], "]"}], "=", \(\[LeftAngleBracket]\[RightAngleBracket]\)}], ")"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "lazy thinking correctness of sort", 
                      "knowledge: is sorted version"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  
                  RowBox[{"\<\"Definition (deletion of the first occurrence): \
2\"\>", ",", 
                    RowBox[{
                      UnderscriptBox["\[ForAll]", 
                        RowBox[{
                          StyleBox["a",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], ",", 
                          StyleBox["x",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], ",", 
                          StyleBox[\(x\&_\),
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None]}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{"dfo", "[", 
                            RowBox[{
                              StyleBox["a",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], ",", 
                              RowBox[{"\[LeftAngleBracket]", 
                                RowBox[{
                                  StyleBox["x",
                                    FontWeight->"Bold",
                                    FontSlant->"Italic",
                                    FontColor->RGBColor[0, 0, 1],
                                    Background->None], ",", 
                                  StyleBox[\(x\&_\),
                                    FontWeight->"Bold",
                                    FontSlant->"Italic",
                                    FontColor->RGBColor[0, 0, 1],
                                    Background->None]}], 
                                "\[RightAngleBracket]"}]}], "]"}], "=", 
                          RowBox[{"\[LeftDoubleBracketingBar]", 
                            RowBox[{
                              RowBox[{
                                RowBox[{"\[LeftAngleBracket]", 
                                  StyleBox[\(x\&_\),
                                    FontWeight->"Bold",
                                    FontSlant->"Italic",
                                    FontColor->RGBColor[0, 0, 1],
                                    Background->None], 
                                  "\[RightAngleBracket]"}], 
                                "\[DoubleLeftArrow]", 
                                RowBox[{
                                  StyleBox["x",
                                    FontWeight->"Bold",
                                    FontSlant->"Italic",
                                    FontColor->RGBColor[0, 0, 1],
                                    Background->None], "=", 
                                  StyleBox["a",
                                    FontWeight->"Bold",
                                    FontSlant->"Italic",
                                    FontColor->RGBColor[0, 0, 1],
                                    Background->None]}]}], ",", 
                              RowBox[{
                                RowBox[{
                                  StyleBox["x",
                                    FontWeight->"Bold",
                                    FontSlant->"Italic",
                                    FontColor->RGBColor[0, 0, 1],
                                    Background->None], "\[Cup]", 
                                  RowBox[{"dfo", "[", 
                                    RowBox[{
                                      StyleBox["a",
                                        FontWeight->"Bold",
                                        FontSlant->"Italic",
                                        FontColor->RGBColor[0, 0, 1],
                                        Background->None], ",", 
                                      RowBox[{"\[LeftAngleBracket]", 
                                        StyleBox[\(x\&_\),
                                        FontWeight->"Bold",
                                        FontSlant->"Italic",
                                        FontColor->RGBColor[0, 0, 1],
                                        Background->None], 
                                        "\[RightAngleBracket]"}]}], "]"}]}], 
                                "\[DoubleLeftArrow]", "otherwise"}]}], 
                            "\[RightDoubleBracketingBar]"}]}], ")"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "lazy thinking correctness of sort", 
                      "knowledge: is sorted version"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Definition (is longer than): 1\"\>", ",", 
                    RowBox[{
                      UnderscriptBox["\[ForAll]", 
                        RowBox[{
                          StyleBox[\(y\&_\),
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], " "}]], 
                      RowBox[{"(", 
                        
                        RowBox[{\(\[LeftAngleBracket]\[RightAngleBracket]\), 
                          "\[NotSucceeds]", 
                          RowBox[{"\[LeftAngleBracket]", 
                            StyleBox[\(y\&_\),
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "\[RightAngleBracket]"}]}], 
                        ")"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "lazy thinking correctness of sort", 
                      "knowledge: is sorted version"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Definition (is longer than): 2\"\>", ",", 
                    RowBox[{
                      UnderscriptBox["\[ForAll]", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], ",", 
                          StyleBox[\(x\&_\),
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None]}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{"\[LeftAngleBracket]", 
                            RowBox[{
                              StyleBox["x",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], ",", 
                              StyleBox[\(x\&_\),
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None]}], "\[RightAngleBracket]"}],
                           "\[Succeeds]", \(\[LeftAngleBracket]\
\[RightAngleBracket]\)}], ")"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "lazy thinking correctness of sort", 
                      "knowledge: is sorted version"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Definition (is longer than): 3\"\>", ",", 
                    RowBox[{
                      UnderscriptBox["\[ForAll]", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], ",", 
                          StyleBox[\(x\&_\),
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], ",", 
                          StyleBox["y",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], ",", 
                          StyleBox[\(y\&_\),
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None]}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            RowBox[{"\[LeftAngleBracket]", 
                              RowBox[{
                                StyleBox["x",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], ",", 
                                StyleBox[\(x\&_\),
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None]}], 
                              "\[RightAngleBracket]"}], "\[Succeeds]", 
                            RowBox[{"\[LeftAngleBracket]", 
                              RowBox[{
                                StyleBox["y",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], ",", 
                                StyleBox[\(y\&_\),
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None]}], 
                              "\[RightAngleBracket]"}]}], 
                          "\[DoubleLeftRightArrow]", 
                          RowBox[{
                            RowBox[{"\[LeftAngleBracket]", 
                              StyleBox[\(x\&_\),
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "\[RightAngleBracket]"}], 
                            "\[Succeeds]", 
                            RowBox[{"\[LeftAngleBracket]", 
                              StyleBox[\(y\&_\),
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], 
                              "\[RightAngleBracket]"}]}]}], ")"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "lazy thinking correctness of sort", 
                      "knowledge: is sorted version"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  
                  RowBox[{"\<\"Proposition (trivial tuples are sorted)\"\>", 
                    ",", 
                    RowBox[{
                      UnderscriptBox[
                        UnderscriptBox["\[ForAll]", 
                          RowBox[{
                            StyleBox[\(x\&_\),
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], " "}]], 
                        RowBox[{"is\[Dash]trivial\[Dash]tuple", "[", 
                          RowBox[{"\[LeftAngleBracket]", 
                            StyleBox[\(x\&_\),
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "\[RightAngleBracket]"}], 
                          "]"}]], 
                      RowBox[{"is\[Dash]sorted", "[", 
                        RowBox[{"\[LeftAngleBracket]", 
                          StyleBox[\(x\&_\),
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], "\[RightAngleBracket]"}], 
                        "]"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "lazy thinking correctness of sort", 
                      "knowledge: is sorted version"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  
                  RowBox[{"\<\"Proposition (only trivial tuple permuted \
version of itself)\"\>", ",", 
                    RowBox[{
                      UnderscriptBox[
                        UnderscriptBox["\[ForAll]", 
                          RowBox[{
                            StyleBox[\(x\&_\),
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], ",", 
                            StyleBox["Y",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None]}]], 
                        RowBox[{"is\[Dash]trivial\[Dash]tuple", "[", 
                          RowBox[{"\[LeftAngleBracket]", 
                            StyleBox[\(x\&_\),
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "\[RightAngleBracket]"}], 
                          "]"}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{"(", 
                            RowBox[{
                              StyleBox["Y",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "=", 
                              RowBox[{"\[LeftAngleBracket]", 
                                StyleBox[\(x\&_\),
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], 
                                "\[RightAngleBracket]"}]}], ")"}], 
                          "\[Implies]", 
                          RowBox[{
                            StyleBox["Y",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "\[TildeTilde]", 
                            RowBox[{"\[LeftAngleBracket]", 
                              StyleBox[\(x\&_\),
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], 
                              "\[RightAngleBracket]"}]}]}], ")"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "lazy thinking correctness of sort", 
                      "knowledge: is sorted version"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  
                  RowBox[{"\<\"Proposition (reflexivity of permuted \
version)\"\>", ",", 
                    RowBox[{
                      UnderscriptBox["\[ForAll]", 
                        RowBox[{
                          StyleBox[\(x\&_\),
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], " "}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{"\[LeftAngleBracket]", 
                            StyleBox[\(x\&_\),
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "\[RightAngleBracket]"}], 
                          "\[TildeTilde]", 
                          RowBox[{"\[LeftAngleBracket]", 
                            StyleBox[\(x\&_\),
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "\[RightAngleBracket]"}]}], 
                        ")"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "lazy thinking correctness of sort", 
                      "knowledge: is sorted version"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Algorithm (sorted)\"\>", ",", 
                    RowBox[{
                      UnderscriptBox["\[ForAll]", 
                        RowBox[{"is\[Dash]tuple", "[", 
                          StyleBox["X",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], "]"}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{"sorted", "[", 
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "]"}], "=", 
                          RowBox[{"\[LeftDoubleBracketingBar]", 
                            RowBox[{
                              RowBox[{
                                RowBox[{"special", "[", 
                                  StyleBox["X",
                                    FontWeight->"Bold",
                                    FontSlant->"Italic",
                                    FontColor->RGBColor[0, 0, 1],
                                    Background->None], "]"}], 
                                "\[DoubleLeftArrow]", 
                                RowBox[{"is\[Dash]trivial\[Dash]tuple", "[", 
                                  StyleBox["X",
                                    FontWeight->"Bold",
                                    FontSlant->"Italic",
                                    FontColor->RGBColor[0, 0, 1],
                                    Background->None], "]"}]}], ",", 
                              RowBox[{
                                RowBox[{"merged", "[", 
                                  RowBox[{
                                    RowBox[{"sorted", "[", 
                                      RowBox[{"left\[Dash]split", "[", 
                                        StyleBox["X",
                                        FontWeight->"Bold",
                                        FontSlant->"Italic",
                                        FontColor->RGBColor[0, 0, 1],
                                        Background->None], "]"}], "]"}], ",", 
                                    
                                    RowBox[{"sorted", "[", 
                                      RowBox[{"right\[Dash]split", "[", 
                                        StyleBox["X",
                                        FontWeight->"Bold",
                                        FontSlant->"Italic",
                                        FontColor->RGBColor[0, 0, 1],
                                        Background->None], "]"}], "]"}]}], 
                                  "]"}], "\[DoubleLeftArrow]", 
                                "otherwise"}]}], 
                            "\[RightDoubleBracketingBar]"}]}], ")"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "lazy thinking correctness of sort"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Lemma (closure of special)\"\>", ",", 
                    RowBox[{
                      UnderscriptBox[
                        UnderscriptBox["\[ForAll]", 
                          RowBox[{
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], " "}]], 
                        RowBox[{
                          RowBox[{"is\[Dash]tuple", "[", 
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "]"}], "\[And]", 
                          RowBox[{"is\[Dash]trivial\[Dash]tuple", "[", 
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "]"}]}]], 
                      RowBox[{"is\[Dash]tuple", "[", 
                        RowBox[{"special", "[", 
                          StyleBox["X",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], "]"}], "]"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "lazy thinking correctness of sort", 
                      "algorithm type knowledge"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Lemma (splits are tuples): 1\"\>", ",", 
                    RowBox[{
                      UnderscriptBox[
                        UnderscriptBox["\[ForAll]", 
                          RowBox[{
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], " "}]], 
                        RowBox[{
                          RowBox[{"is\[Dash]tuple", "[", 
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "]"}], "\[And]", 
                          RowBox[{"\[Not]", 
                            RowBox[{"is\[Dash]trivial\[Dash]tuple", "[", 
                              StyleBox["X",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "]"}]}]}]], 
                      RowBox[{"is\[Dash]tuple", "[", 
                        RowBox[{"left\[Dash]split", "[", 
                          StyleBox["X",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], "]"}], "]"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "lazy thinking correctness of sort", 
                      "algorithm type knowledge"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Lemma (splits are tuples): 2\"\>", ",", 
                    RowBox[{
                      UnderscriptBox[
                        UnderscriptBox["\[ForAll]", 
                          RowBox[{
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], " "}]], 
                        RowBox[{
                          RowBox[{"is\[Dash]tuple", "[", 
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "]"}], "\[And]", 
                          RowBox[{"\[Not]", 
                            RowBox[{"is\[Dash]trivial\[Dash]tuple", "[", 
                              StyleBox["X",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "]"}]}]}]], 
                      RowBox[{"is\[Dash]tuple", "[", 
                        RowBox[{"right\[Dash]split", "[", 
                          StyleBox["X",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], "]"}], "]"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "lazy thinking correctness of sort", 
                      "algorithm type knowledge"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Lemma (splits are shorter): 1\"\>", ",", 
                    RowBox[{
                      UnderscriptBox[
                        UnderscriptBox["\[ForAll]", 
                          RowBox[{"is\[Dash]tuple", "[", 
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "]"}]], 
                        RowBox[{"\[Not]", 
                          RowBox[{"is\[Dash]trivial\[Dash]tuple", "[", 
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "]"}]}]], 
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox["X",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], "\[Succeeds]", 
                          RowBox[{"left\[Dash]split", "[", 
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "]"}]}], ")"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "lazy thinking correctness of sort", 
                      "algorithm type knowledge"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Lemma (splits are shorter): 2\"\>", ",", 
                    RowBox[{
                      UnderscriptBox[
                        UnderscriptBox["\[ForAll]", 
                          RowBox[{"is\[Dash]tuple", "[", 
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "]"}]], 
                        RowBox[{"\[Not]", 
                          RowBox[{"is\[Dash]trivial\[Dash]tuple", "[", 
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "]"}]}]], 
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox["X",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], "\[Succeeds]", 
                          RowBox[{"right\[Dash]split", "[", 
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "]"}]}], ")"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "lazy thinking correctness of sort", 
                      "algorithm type knowledge"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Lemma (closure of merge)\"\>", ",", 
                    RowBox[{
                      UnderscriptBox["\[ForAll]", GridBox[{
                            {
                              RowBox[{"is\[Dash]tuple", "[", 
                                StyleBox["X",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], "]"}]},
                            {
                              RowBox[{"is\[Dash]tuple", "[", 
                                StyleBox["Y",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], "]"}]}
                            }]], 
                      RowBox[{"is\[Dash]tuple", "[", 
                        RowBox[{"merged", "[", 
                          RowBox[{
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], ",", 
                            StyleBox["Y",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None]}], "]"}], "]"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "lazy thinking correctness of sort", 
                      "algorithm type knowledge"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Lemma (conjecture15): conjecture15\"\>", ",", 
                    RowBox[{
                      UnderscriptBox[
                        UnderscriptBox["\[ForAll]", 
                          RowBox[{
                            StyleBox["X1",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], " "}]], 
                        RowBox[{"is\[Dash]tuple", "[", 
                          StyleBox["X1",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], "]"}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            RowBox[{"is\[Dash]trivial\[Dash]tuple", "[", 
                              StyleBox["X1",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "]"}], "\[And]", 
                            RowBox[{"is\[Dash]sorted", "[", 
                              StyleBox["X1",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "]"}]}], "\[Implies]", 
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{"special", "[", 
                                StyleBox["X1",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], "]"}], "=", 
                              StyleBox["X1",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None]}], ")"}]}], ")"}]}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Lemma (conjecture44): conjecture44\"\>", ",", 
                    RowBox[{
                      UnderscriptBox[
                        UnderscriptBox["\[ForAll]", 
                          RowBox[{
                            StyleBox["X2",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], ",", 
                            StyleBox["X3",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], ",", 
                            StyleBox["X4",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None]}]], 
                        RowBox[{"is\[Dash]tuple", "[", 
                          StyleBox["X4",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], "]"}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            RowBox[{"is\[Dash]tuple", "[", 
                              StyleBox["X2",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "]"}], "\[And]", 
                            RowBox[{
                              RowBox[{"left\[Dash]split", "[", 
                                StyleBox["X4",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], "]"}], "\[TildeTilde]", 
                              StyleBox["X2",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None]}], "\[And]", 
                            RowBox[{"is\[Dash]sorted", "[", 
                              StyleBox["X2",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "]"}], "\[And]", 
                            RowBox[{"is\[Dash]tuple", "[", 
                              StyleBox["X3",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "]"}], "\[And]", 
                            RowBox[{
                              RowBox[{"right\[Dash]split", "[", 
                                StyleBox["X4",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], "]"}], "\[TildeTilde]", 
                              StyleBox["X3",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None]}], "\[And]", 
                            RowBox[{"is\[Dash]sorted", "[", 
                              StyleBox["X3",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "]"}], "\[And]", 
                            RowBox[{"\[Not]", 
                              RowBox[{"is\[Dash]trivial\[Dash]tuple", "[", 
                                StyleBox["X4",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], "]"}]}]}], "\[Implies]", 
                          
                          RowBox[{
                            RowBox[{"merged", "[", 
                              RowBox[{
                                StyleBox["X2",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], ",", 
                                StyleBox["X3",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None]}], "]"}], "\[TildeTilde]",
                             
                            StyleBox["X4",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None]}]}], ")"}]}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Lemma (conjecture46): conjecture46\"\>", ",", 
                    RowBox[{
                      UnderscriptBox[
                        UnderscriptBox["\[ForAll]", 
                          RowBox[{
                            StyleBox["X5",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], ",", 
                            StyleBox["X6",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], ",", 
                            StyleBox["X7",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None]}]], 
                        RowBox[{"is\[Dash]tuple", "[", 
                          StyleBox["X7",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], "]"}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            RowBox[{"is\[Dash]tuple", "[", 
                              StyleBox["X5",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "]"}], "\[And]", 
                            RowBox[{
                              RowBox[{"left\[Dash]split", "[", 
                                StyleBox["X7",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], "]"}], "\[TildeTilde]", 
                              StyleBox["X5",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None]}], "\[And]", 
                            RowBox[{"is\[Dash]sorted", "[", 
                              StyleBox["X5",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "]"}], "\[And]", 
                            RowBox[{"is\[Dash]tuple", "[", 
                              StyleBox["X6",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "]"}], "\[And]", 
                            RowBox[{
                              RowBox[{"right\[Dash]split", "[", 
                                StyleBox["X7",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], "]"}], "\[TildeTilde]", 
                              StyleBox["X6",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None]}], "\[And]", 
                            RowBox[{"is\[Dash]sorted", "[", 
                              StyleBox["X6",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "]"}], "\[And]", 
                            RowBox[{"\[Not]", 
                              RowBox[{"is\[Dash]trivial\[Dash]tuple", "[", 
                                StyleBox["X7",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], "]"}]}]}], "\[Implies]", 
                          
                          RowBox[{"is\[Dash]sorted", "[", 
                            RowBox[{"merged", "[", 
                              RowBox[{
                                StyleBox["X5",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], ",", 
                                StyleBox["X6",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None]}], "]"}], "]"}]}], 
                        ")"}]}], ",", \(\[Bullet]finfo[]\)}], "]"}]}], "]"}], 
            ",", "sorted", 
            ",", \({special, merged, left\[Dash]split, right\[Dash]split}\), 
            ",", \(\[Bullet]asml[]\), ",", 
            RowBox[{"\[Bullet]asml", "[", 
              RowBox[{
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Lemma (closure of special)\"\>", ",", 
                    RowBox[{
                      UnderscriptBox[
                        UnderscriptBox["\[ForAll]", 
                          RowBox[{
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], " "}]], 
                        RowBox[{
                          RowBox[{"is\[Dash]tuple", "[", 
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "]"}], "\[And]", 
                          RowBox[{"is\[Dash]trivial\[Dash]tuple", "[", 
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "]"}]}]], 
                      RowBox[{"is\[Dash]tuple", "[", 
                        RowBox[{"special", "[", 
                          StyleBox["X",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], "]"}], "]"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "algorithm type knowledge"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Lemma (splits are tuples): 1\"\>", ",", 
                    RowBox[{
                      UnderscriptBox[
                        UnderscriptBox["\[ForAll]", 
                          RowBox[{
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], " "}]], 
                        RowBox[{
                          RowBox[{"is\[Dash]tuple", "[", 
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "]"}], "\[And]", 
                          RowBox[{"\[Not]", 
                            RowBox[{"is\[Dash]trivial\[Dash]tuple", "[", 
                              StyleBox["X",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "]"}]}]}]], 
                      RowBox[{"is\[Dash]tuple", "[", 
                        RowBox[{"left\[Dash]split", "[", 
                          StyleBox["X",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], "]"}], "]"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "algorithm type knowledge"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Lemma (splits are tuples): 2\"\>", ",", 
                    RowBox[{
                      UnderscriptBox[
                        UnderscriptBox["\[ForAll]", 
                          RowBox[{
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], " "}]], 
                        RowBox[{
                          RowBox[{"is\[Dash]tuple", "[", 
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "]"}], "\[And]", 
                          RowBox[{"\[Not]", 
                            RowBox[{"is\[Dash]trivial\[Dash]tuple", "[", 
                              StyleBox["X",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "]"}]}]}]], 
                      RowBox[{"is\[Dash]tuple", "[", 
                        RowBox[{"right\[Dash]split", "[", 
                          StyleBox["X",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], "]"}], "]"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "algorithm type knowledge"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Lemma (splits are shorter): 1\"\>", ",", 
                    RowBox[{
                      UnderscriptBox[
                        UnderscriptBox["\[ForAll]", 
                          RowBox[{"is\[Dash]tuple", "[", 
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "]"}]], 
                        RowBox[{"\[Not]", 
                          RowBox[{"is\[Dash]trivial\[Dash]tuple", "[", 
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "]"}]}]], 
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox["X",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], "\[Succeeds]", 
                          RowBox[{"left\[Dash]split", "[", 
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "]"}]}], ")"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "algorithm type knowledge"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Lemma (splits are shorter): 2\"\>", ",", 
                    RowBox[{
                      UnderscriptBox[
                        UnderscriptBox["\[ForAll]", 
                          RowBox[{"is\[Dash]tuple", "[", 
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "]"}]], 
                        RowBox[{"\[Not]", 
                          RowBox[{"is\[Dash]trivial\[Dash]tuple", "[", 
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "]"}]}]], 
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox["X",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], "\[Succeeds]", 
                          RowBox[{"right\[Dash]split", "[", 
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], "]"}]}], ")"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "algorithm type knowledge"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Lemma (closure of merge)\"\>", ",", 
                    RowBox[{
                      UnderscriptBox["\[ForAll]", GridBox[{
                            {
                              RowBox[{"is\[Dash]tuple", "[", 
                                StyleBox["X",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], "]"}]},
                            {
                              RowBox[{"is\[Dash]tuple", "[", 
                                StyleBox["Y",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], "]"}]}
                            }]], 
                      RowBox[{"is\[Dash]tuple", "[", 
                        RowBox[{"merged", "[", 
                          RowBox[{
                            StyleBox["X",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], ",", 
                            StyleBox["Y",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None]}], "]"}], "]"}]}], 
                    ",", \(\[Bullet]finfo[\*"\<\"\"\>", 
                      "algorithm type knowledge"]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Lemma (conjecture15): conjecture15\"\>", ",", 
                    RowBox[{
                      UnderscriptBox[
                        UnderscriptBox["\[ForAll]", 
                          RowBox[{
                            StyleBox["X1",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], " "}]], 
                        RowBox[{"is\[Dash]tuple", "[", 
                          StyleBox["X1",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], "]"}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            RowBox[{"is\[Dash]trivial\[Dash]tuple", "[", 
                              StyleBox["X1",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "]"}], "\[And]", 
                            RowBox[{"is\[Dash]sorted", "[", 
                              StyleBox["X1",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "]"}]}], "\[Implies]", 
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{"special", "[", 
                                StyleBox["X1",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], "]"}], "=", 
                              StyleBox["X1",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None]}], ")"}]}], ")"}]}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Lemma (conjecture44): conjecture44\"\>", ",", 
                    RowBox[{
                      UnderscriptBox[
                        UnderscriptBox["\[ForAll]", 
                          RowBox[{
                            StyleBox["X2",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], ",", 
                            StyleBox["X3",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], ",", 
                            StyleBox["X4",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None]}]], 
                        RowBox[{"is\[Dash]tuple", "[", 
                          StyleBox["X4",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], "]"}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            RowBox[{"is\[Dash]tuple", "[", 
                              StyleBox["X2",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "]"}], "\[And]", 
                            RowBox[{
                              RowBox[{"left\[Dash]split", "[", 
                                StyleBox["X4",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], "]"}], "\[TildeTilde]", 
                              StyleBox["X2",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None]}], "\[And]", 
                            RowBox[{"is\[Dash]sorted", "[", 
                              StyleBox["X2",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "]"}], "\[And]", 
                            RowBox[{"is\[Dash]tuple", "[", 
                              StyleBox["X3",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "]"}], "\[And]", 
                            RowBox[{
                              RowBox[{"right\[Dash]split", "[", 
                                StyleBox["X4",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], "]"}], "\[TildeTilde]", 
                              StyleBox["X3",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None]}], "\[And]", 
                            RowBox[{"is\[Dash]sorted", "[", 
                              StyleBox["X3",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "]"}], "\[And]", 
                            RowBox[{"\[Not]", 
                              RowBox[{"is\[Dash]trivial\[Dash]tuple", "[", 
                                StyleBox["X4",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], "]"}]}]}], "\[Implies]", 
                          
                          RowBox[{
                            RowBox[{"merged", "[", 
                              RowBox[{
                                StyleBox["X2",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], ",", 
                                StyleBox["X3",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None]}], "]"}], "\[TildeTilde]",
                             
                            StyleBox["X4",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None]}]}], ")"}]}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"Lemma (conjecture46): conjecture46\"\>", ",", 
                    RowBox[{
                      UnderscriptBox[
                        UnderscriptBox["\[ForAll]", 
                          RowBox[{
                            StyleBox["X5",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], ",", 
                            StyleBox["X6",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], ",", 
                            StyleBox["X7",
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None]}]], 
                        RowBox[{"is\[Dash]tuple", "[", 
                          StyleBox["X7",
                            FontWeight->"Bold",
                            FontSlant->"Italic",
                            FontColor->RGBColor[0, 0, 1],
                            Background->None], "]"}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            RowBox[{"is\[Dash]tuple", "[", 
                              StyleBox["X5",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "]"}], "\[And]", 
                            RowBox[{
                              RowBox[{"left\[Dash]split", "[", 
                                StyleBox["X7",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], "]"}], "\[TildeTilde]", 
                              StyleBox["X5",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None]}], "\[And]", 
                            RowBox[{"is\[Dash]sorted", "[", 
                              StyleBox["X5",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "]"}], "\[And]", 
                            RowBox[{"is\[Dash]tuple", "[", 
                              StyleBox["X6",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "]"}], "\[And]", 
                            RowBox[{
                              RowBox[{"right\[Dash]split", "[", 
                                StyleBox["X7",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], "]"}], "\[TildeTilde]", 
                              StyleBox["X6",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None]}], "\[And]", 
                            RowBox[{"is\[Dash]sorted", "[", 
                              StyleBox["X6",
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None], "]"}], "\[And]", 
                            RowBox[{"\[Not]", 
                              RowBox[{"is\[Dash]trivial\[Dash]tuple", "[", 
                                StyleBox["X7",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], "]"}]}]}], "\[Implies]", 
                          
                          RowBox[{"is\[Dash]sorted", "[", 
                            RowBox[{"merged", "[", 
                              RowBox[{
                                StyleBox["X5",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None], ",", 
                                StyleBox["X6",
                                  FontWeight->"Bold",
                                  FontSlant->"Italic",
                                  FontColor->RGBColor[0, 0, 1],
                                  Background->None]}], "]"}], "]"}]}], 
                        ")"}]}], ",", \(\[Bullet]finfo[]\)}], "]"}]}], 
              "]"}]}], "}"}]}], "}"}]], "Output",
  CellLabel->"TS_Out[105]="]
}, Closed]],

Cell[CellGroupData[{

Cell["Call in Big Font", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Prove[Theorem["\<correctness of sort\>"], \ 
        using \[Rule] Theory["\<lazy thinking correctness of sort\>"], \ 
        by \[Rule] 
          CascadeLT[SqnsEqCasePC, \ GenerateConjectures, \ nS, \ aNS, \ 
            kConjectures, \ nConjectures], \ 
        built\[Dash]in \[Rule] \
{Property[\(\[TildeTilde]\)\(\(\[Rule]\)\({Commutative}\)\)]}, \ 
        ProverOptions \[Rule] {SqnsProofTechniques \[Rule] {"\<WFInd\>"}, \ 
            SqnsWFOrdering \[Rule] \[Bullet][ \[Succeeds] ], \ 
            GRWTarget \[Rule] {"\<kb\>", \ "\<goal\>"}, \ 
            AllowIntroduceQuantifiers \[Rule] True}, \ 
        SearchDepth \[Rule] 50] // Timing\)], "Input",
  CellLabel->"TS_In[92]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LAZY THINKING::::: The proof fails.  \\n After analysing \
the failing proof, the following conjecture is added to the knowledge base: \
\\n \"\>", "\[InvisibleSpace]", 
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\<\"Lemma (conjecture15): conjecture15\"\>", ",", 
            RowBox[{
              UnderscriptBox[
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["X1",
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " "}]], 
                RowBox[{"is\[Dash]tuple", "[", 
                  StyleBox["X1",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], "]"}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"is\[Dash]trivial\[Dash]tuple", "[", 
                      StyleBox["X1",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "]"}], "\[And]", 
                    RowBox[{"is\[Dash]sorted", "[", 
                      StyleBox["X1",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "]"}]}], "\[Implies]", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"special", "[", 
                        StyleBox["X1",
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], "]"}], "=", 
                      StyleBox["X1",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], ")"}]}], ")"}]}], 
            ",", \(\[Bullet]finfo[]\)}], "]"}], 
        "\[InvisibleSpace]", "\<\"\\n Now attempt the proof with the updated \
knowledge base. \"\>"}],
      SequenceForm[ 
      "LAZY THINKING::::: The proof fails.  \n After analysing the failing \
proof, the following conjecture is added to the knowledge base: \n ", 
        \[Bullet]lf[ "Lemma (conjecture15): conjecture15", 
          \[Trademark]ForAll[ 
            \[Bullet]range[ 
              \[Bullet]simpleRange[ 
                \[Bullet]var[ X1]]], 
            \[Trademark]IsTuple[ 
              \[Bullet]var[ X1]], 
            \[Trademark]Implies[ 
              \[Trademark]And[ 
                is\[Dash]trivial\[Dash]tuple[ 
                  \[Bullet]var[ X1]], 
                is\[Dash]sorted[ 
                  \[Bullet]var[ X1]]], 
              \[Trademark]Equal[ 
                special[ 
                  \[Bullet]var[ X1]], 
                \[Bullet]var[ X1]]]], 
          \[Bullet]finfo[ ]], 
        "\n Now attempt the proof with the updated knowledge base. "],
      Editable->False]], "Print",
  CellLabel->"From TS_In[92]:="],

Cell[BoxData[
    \(Append::"normal" \(\(:\)\(\ \)\) 
      "Nonatomic expression expected at position \!\(1\) in \
\!\(Append[\(\(Theorema`Provers`PCS`BasicPND`Private`inf, \(\(\[Bullet]stain[\
\(\(\"used in UMP\", \"2\"\)\)]\)\)\)\)]\)."\)], "Message",
  CellLabel->"From TS_In[92]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"LAZY THINKING::::: The proof fails.  \\n After analysing \
the failing proof, the following conjecture is added to the knowledge base: \
\\n \"\>", "\[InvisibleSpace]", 
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\<\"Lemma (conjecture44): conjecture44\"\>", ",", 
            RowBox[{
              UnderscriptBox[
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["X2",
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], ",", 
                    StyleBox["X3",
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], ",", 
                    StyleBox["X4",
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}]], 
                RowBox[{"is\[Dash]tuple", "[", 
                  StyleBox["X4",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], "]"}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"is\[Dash]tuple", "[", 
                      StyleBox["X2",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "]"}], "\[And]", 
                    RowBox[{
                      RowBox[{"left\[Dash]split", "[", 
                        StyleBox["X4",
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], "]"}], "\[TildeTilde]", 
                      StyleBox["X2",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "\[And]", 
                    RowBox[{"is\[Dash]sorted", "[", 
                      StyleBox["X2",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "]"}], "\[And]", 
                    RowBox[{"is\[Dash]tuple", "[", 
                      StyleBox["X3",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "]"}], "\[And]", 
                    RowBox[{
                      RowBox[{"right\[Dash]split", "[", 
                        StyleBox["X4",
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], "]"}], "\[TildeTilde]", 
                      StyleBox["X3",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "\[And]", 
                    RowBox[{"is\[Dash]sorted", "[", 
                      StyleBox["X3",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "]"}], "\[And]", 
                    RowBox[{"\[Not]", 
                      RowBox[{"is\[Dash]trivial\[Dash]tuple", "[", 
                        StyleBox["X4",
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], "]"}]}]}], "\[Implies]", 
                  RowBox[{
                    RowBox[{"merged", "[", 
                      RowBox[{
                        StyleBox["X2",
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], ",", 
                        StyleBox["X3",
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], "]"}], "\[TildeTilde]", 
                    StyleBox["X4",
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}]}], ")"}]}], 
            ",", \(\[Bullet]finfo[]\)}], "]"}], 
        "\[InvisibleSpace]", "\<\"\\n Now attempt the proof with the updated \
knowledge base. \"\>"}],
      SequenceForm[ 
      "LAZY THINKING::::: The proof fails.  \n After analysing the failing \
proof, the following conjecture is added to the knowledge base: \n ", 
        \[Bullet]lf[ "Lemma (conjecture44): conjecture44", 
          \[Trademark]ForAll[ 
            \[Bullet]range[ 
              \[Bullet]simpleRange[ 
                \[Bullet]var[ X2]], 
              \[Bullet]simpleRange[ 
                \[Bullet]var[ X3]], 
              \[Bullet]simpleRange[ 
                \[Bullet]var[ X4]]], 
            \[Trademark]IsTuple[ 
              \[Bullet]var[ X4]], 
            \[Trademark]Implies[ 
              \[Trademark]And[ 
                \[Trademark]IsTuple[ 
                  \[Bullet]var[ X2]], 
                \[Trademark]TildeTilde[ 
                  left\[Dash]split[ 
                    \[Bullet]var[ X4]], 
                  \[Bullet]var[ X2]], 
                is\[Dash]sorted[ 
                  \[Bullet]var[ X2]], 
                \[Trademark]IsTuple[ 
                  \[Bullet]var[ X3]], 
                \[Trademark]TildeTilde[ 
                  right\[Dash]split[ 
                    \[Bullet]var[ X4]], 
                  \[Bullet]var[ X3]], 
                is\[Dash]sorted[ 
                  \[Bullet]var[ X3]], 
                \[Trademark]Not[ 
                  is\[Dash]trivial\[Dash]tuple[ 
                    \[Bullet]var[ X4]]]], 
              \[Trademark]TildeTilde[ 
                merged[ 
                  \[Bullet]var[ X2], 
                  \[Bullet]var[ X3]], 
                \[Bullet]var[ X4]]]], 
          \[Bullet]finfo[ ]], 
        "\n Now attempt the proof with the updated knowledge base. "],
      Editable->False]], "Print",
  CellLabel->"From TS_In[92]:="]
}, Closed]]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 723}},
AutoGeneratedPackage->None,
WindowSize->{750, 696},
WindowMargins->{{Automatic, 0}, {Automatic, 0}},
ShowSelection->True,
Magnification->1,
StyleDefinitions -> "TutorialBook.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Theory (knowledge: is sorted version)"->{
    Cell[2282, 70, 1235, 28, 335, "Input",
      InitializationCell->True,
      CellTags->"Theory (knowledge: is sorted version)"]},
  "Info3263021048-3712034"->{
    Cell[37281, 885, 1313, 18, 294, "Print",
      CellTags->"Info3263021048-3712034"]},
  "Info3262768099-1747451"->{
    Cell[38686, 911, 3621, 59, 104, "Print",
      CellTags->"Info3262768099-1747451"]},
  "Info3262768228-8434665"->{
    Cell[55940, 1287, 205, 4, 47, "Print",
      CellTags->"Info3262768228-8434665"]},
  "Algorithm (sorted)"->{
    Cell[56273, 1300, 1512, 37, 138, "Input",
      InitializationCell->True,
      CellTags->"Algorithm (sorted)"]},
  "Lemma (closure of special)"->{
    Cell[57954, 1344, 337, 8, 91, "Input",
      InitializationCell->True,
      CellTags->"Lemma (closure of special)"]},
  "Lemma (splits are tuples)"->{
    Cell[58294, 1354, 583, 15, 110, "Input",
      InitializationCell->True,
      CellTags->"Lemma (splits are tuples)"]},
  "Lemma (splits are shorter)"->{
    Cell[58880, 1371, 561, 14, 110, "Input",
      InitializationCell->True,
      CellTags->"Lemma (splits are shorter)"]},
  "Lemma (closure of merge)"->{
    Cell[59444, 1387, 258, 6, 68, "Input",
      InitializationCell->True,
      CellTags->"Lemma (closure of merge)"]},
  "Theory (algorithm type knowledge)"->{
    Cell[59705, 1395, 513, 12, 166, "Input",
      InitializationCell->True,
      CellTags->"Theory (algorithm type knowledge)"]},
  "Theory (lazy thinking correctness of sort)"->{
    Cell[61889, 1477, 470, 11, 110, "Input",
      InitializationCell->True,
      CellTags->"Theory (lazy thinking correctness of sort)"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Theory (knowledge: is sorted version)", 191458, 4087},
  {"Info3263021048-3712034", 191622, 4091},
  {"Info3262768099-1747451", 191741, 4094},
  {"Info3262768228-8434665", 191860, 4097},
  {"Algorithm (sorted)", 191973, 4100},
  {"Lemma (closure of special)", 192125, 4104},
  {"Lemma (splits are tuples)", 192281, 4108},
  {"Lemma (splits are shorter)", 192439, 4112},
  {"Lemma (closure of merge)", 192596, 4116},
  {"Theory (algorithm type knowledge)", 192758, 4120},
  {"Theory (lazy thinking correctness of sort)", 192940, 4124}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 48, 0, 73, "Title"],
Cell[1778, 54, 130, 3, 32, "Subsubtitle"],

Cell[CellGroupData[{
Cell[1933, 61, 58, 0, 92, "Section"],
Cell[1994, 63, 285, 5, 68, "Text"],
Cell[2282, 70, 1235, 28, 335, "Input",
  InitializationCell->True,
  CellTags->"Theory (knowledge: is sorted version)"],

Cell[CellGroupData[{
Cell[3542, 102, 226, 6, 45, "Input"],
Cell[3771, 110, 32713, 736, 964, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[36533, 852, 45, 0, 60, "Section"],
Cell[36581, 854, 236, 6, 48, "Text"],

Cell[CellGroupData[{
Cell[36842, 864, 66, 0, 37, "Subsubsection"],
Cell[36911, 866, 71, 2, 45, "Input"],

Cell[CellGroupData[{
Cell[37007, 872, 46, 1, 31, "Input"],
Cell[37056, 875, 128, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37221, 882, 57, 1, 31, "Input"],
Cell[37281, 885, 1313, 18, 294, "Print",
  CellTags->"Info3263021048-3712034"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38631, 908, 52, 1, 31, "Input"],
Cell[38686, 911, 3621, 59, 104, "Print",
  CellTags->"Info3262768099-1747451"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[42356, 976, 84, 1, 37, "Subsubsection"],

Cell[CellGroupData[{
Cell[42465, 981, 44, 1, 31, "Input"],
Cell[42512, 984, 13425, 301, 214, "Print"],
Cell[55940, 1287, 205, 4, 47, "Print",
  CellTags->"Info3262768228-8434665"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[56206, 1298, 64, 0, 92, "Section"],
Cell[56273, 1300, 1512, 37, 138, "Input",
  InitializationCell->True,
  CellTags->"Algorithm (sorted)"],

Cell[CellGroupData[{
Cell[57810, 1341, 141, 1, 44, "Subsection"],
Cell[57954, 1344, 337, 8, 91, "Input",
  InitializationCell->True,
  CellTags->"Lemma (closure of special)"],
Cell[58294, 1354, 583, 15, 110, "Input",
  InitializationCell->True,
  CellTags->"Lemma (splits are tuples)"],
Cell[58880, 1371, 561, 14, 110, "Input",
  InitializationCell->True,
  CellTags->"Lemma (splits are shorter)"],
Cell[59444, 1387, 258, 6, 68, "Input",
  InitializationCell->True,
  CellTags->"Lemma (closure of merge)"],
Cell[59705, 1395, 513, 12, 166, "Input",
  InitializationCell->True,
  CellTags->"Theory (algorithm type knowledge)"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[60267, 1413, 62, 0, 92, "Section"],

Cell[CellGroupData[{
Cell[60354, 1417, 59, 0, 37, "Subsubsection"],
Cell[60416, 1419, 116, 3, 45, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[60569, 1427, 67, 0, 37, "Subsubsection"],
Cell[60639, 1429, 219, 5, 45, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[60895, 1439, 127, 3, 37, "Subsubsection"],
Cell[61025, 1444, 124, 3, 45, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[61186, 1452, 198, 4, 54, "Subsubsection"],

Cell[CellGroupData[{
Cell[61409, 1460, 147, 3, 45, "Input",
  InitializationCell->True],
Cell[61559, 1465, 230, 4, 47, "Message"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[61838, 1475, 48, 0, 37, "Subsubsection"],
Cell[61889, 1477, 470, 11, 110, "Input",
  InitializationCell->True,
  CellTags->"Theory (lazy thinking correctness of sort)"],
Cell[62362, 1490, 146, 3, 45, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[62545, 1498, 46, 0, 37, "Subsubsection"],
Cell[62594, 1500, 324, 5, 68, "Text"],
Cell[62921, 1507, 178, 4, 45, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[63148, 1517, 26, 0, 92, "Section"],

Cell[CellGroupData[{
Cell[63199, 1521, 1175, 29, 160, "Input"],
Cell[64377, 1552, 3342, 76, 109, "Print"],
Cell[67722, 1630, 6870, 154, 157, "Print"],
Cell[74595, 1786, 6625, 148, 157, "Print"],
Cell[81223, 1936, 118, 2, 47, "Print"],
Cell[81344, 1940, 98014, 1859, 2430, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[179395, 3804, 38, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[179458, 3808, 715, 13, 183, "Input"],
Cell[180176, 3823, 3341, 76, 109, "Print"],
Cell[183520, 3901, 287, 5, 47, "Message"],
Cell[183810, 3908, 6869, 154, 157, "Print"]
}, Closed]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

