(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)



(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     69627,       2161]*)
(*NotebookOutlinePosition[     80044,       2401]*)
(*  CellTagsIndexPosition[     77378,       2344]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[" Predicate Logic Prover", "Title"],

Cell[CellGroupData[{

Cell["Starting the System", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(<< Theorema`\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \("You can specify your personal preferences in a file `Setup.m` in the \
directory (folder) \"Theorema -> User\" in your private Theorema \
directory!"\)], "Print"]
}, Open  ]],

Cell[TextData[{
  "The following command sets the PredicateProver as the default prover to be \
used in the command ",
  StyleBox["Prove",
    FontWeight->"Bold"],
  StyleBox[" and the ProofSimplifier as the default transformer",
    FontVariations->{"CompatibilityType"->0}],
  "."
}], "Text"],

Cell[BoxData[
    \(SetGlobals[Prover \[Rule] PredicateProver]\)], "Input"],

Cell[BoxData[
    \(\(SetOptions[Prove, transformBy \[Rule] ProofSimplifier];\)\)], "Input"],

Cell["Some of the proofs in this demo require a higher value:", "Text"],

Cell[BoxData[
    \(\($RecursionLimit = 1024;\)\)], "Input"],

Cell["\<\
Each of the following commands controls the appearance of the \
labels in the generated proofs.\
\>", "Text"],

Cell[BoxData[
    \(SetGlobals[LabelStyle \[Rule] "\<Alphanumeric\>"]\)], "Input"],

Cell[BoxData[
    \(SetGlobals[LabelStyle \[Rule] "\<Numeric\>"]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Options of the Predicate Logic Prover", "Section"],

Cell["\<\
All the options of the propositional prover are also available for \
the predicate logic prover:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[PredicateProver]\)], "Input"],

Cell[BoxData[
    \({TryAlternatives \[Rule] False, BackChaining \[Rule] False, 
      BackChainingDisjunction \[Rule] False, 
      BackChainingImplication \[Rule] False, 
      BackChainingEquivalence \[Rule] False, 
      TrySubgoalDisjunction \[Rule] False, 
      TrySubgoalImplication \[Rule] False, 
      TrySubgoalEquivalence \[Rule] False, TrySubgoal \[Rule] False, 
      PNDLevel \[Rule] 1}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[SetPNDGlobals]\)], "Input"],

Cell[BoxData[
    \({TryAlternatives \[Rule] False, BackChaining \[Rule] False, 
      BackChainingDisjunction \[Rule] False, 
      BackChainingImplication \[Rule] False, 
      BackChainingEquivalence \[Rule] False, 
      TrySubgoalDisjunction \[Rule] False, 
      TrySubgoalImplication \[Rule] False, 
      TrySubgoalEquivalence \[Rule] False, TrySubgoal \[Rule] False, 
      PNDLevel \[Rule] 1}\)], "Output"]
}, Closed]],

Cell["\<\
The additional options specific to predicate proving are described \
below.\
\>", "Text"],

Cell[CellGroupData[{

Cell["PND Level", "Subsection"],

Cell["PND stands for \"Prove by Natural Deduction\".", "Text"],

Cell["\<\
PNDLevel controls the \"cleverness\" of the predicate logic prover. \
When the level is higher, more sofisticated rules are applied. The default \
value is 1.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?PNDLevel\)\)], "Input"],

Cell[BoxData[
    \("Option of PND (PredicateProver), if set to more than 0 it will trigger \
the use of more clever rules in the prover. Default is 1."\)], "Print"]
}, Open  ]],

Cell[BoxData[
    RowBox[{"Theorem", "[", 
      RowBox[{"\"\<D\>\"", ",", GridBox[{
            {\(\((\((\[ForAll] \+x P[x])\) \[Implies] 
                    Q)\)\[DoubleLongRightArrow]\((\[Exists] \+y\((P[
                          y] \[Implies] Q)\))\)\), "\"\<d\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Theorem (D)"],

Cell[BoxData[
    \(\(Prove[Theorem["\<D\>"]];\)\)], "Input"],

Cell[BoxData[
    \(\(Prove[Theorem["\<D\>"], 
        ProverOptions \[Rule] {PNDLevel -> 0}];\)\)], "Input"],

Cell["\<\
Currently the effect of the PNDLevel option is the following:\
\>", \
"Text"],

Cell["PNDLevel  >  0: ", "Text"],

Cell["\<\
- in universal assumptions of of type disjunction, implication, and \
equivalence, check whether the quantified variables occur in all operands and \
move the universal quantifier inside the formula when possible;\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
 - transform existential goal which is an implication or an \
equivalence into a disjunction.\
\>", "Text"],

Cell["PNDLevel  >  1: ", "Text"],

Cell[TextData[{
  "- transform existential goal of type ",
  StyleBox["\[Exists] (f \[DoubleLeftRightArrow] g)",
    FontWeight->"Bold"],
  " into ",
  StyleBox["\[ForAll]f \[Implies] \[Exists]g",
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  "- transform existential goal of type ",
  StyleBox["\[Exists] (f \[Implies] g)",
    FontWeight->"Bold"],
  " into ",
  StyleBox["\[ForAll]f \[Implies] \[Exists]g",
    FontWeight->"Bold"]
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Options for Proof Simplification", "Section"],

Cell["\<\
These options are not specifically related to a particular prover, \
however we give a brief introduction here because they are useful for some \
proofs in this demo.\
\>", "Text"],

Cell["\<\
Before a proof is displayed, it can be simplified in various ways. \
We present first an example:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Proposition",
          FontWeight->"Bold"], "[", 
        RowBox[{"\"\<ForAll Distributivity\>\"", ",", "\n", "\t", GridBox[{
              {\(\((\[ForAll] \+x\((P[x]\[DoubleLongRightArrow]
                          Q)\))\)\[DoubleLongLeftRightArrow]\((\((\[Exists] \
\+y P[y])\)\[DoubleLongRightArrow]Q)\)\), "\"\<\[ForAll]d\>\""}
              },
            ColumnAlignments->{Left}]}], "]"}], ";"}]], "Input",
  CellTags->"Proposition (ForAll Distributivity)"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], 
        "[", \(Proposition["\<ForAll Distributivity\>"]\), "]"}], 
      ";"}]], "Input"],

Cell[TextData[{
  "In the previous proof, at a certain moment the goal (Q) coincides with the \
right-hand side of an assumed implication (",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          UnderscriptBox["\[Exists]", 
            RowBox[{
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], " "}]], 
          RowBox[{"P", "[", 
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "]"}]}], "\[Implies]", "Q"}]],
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  "). The prover transforms the latter by retaining only the negation of the \
left-hand side of the implication. A more natural proof is obtained if the \
prover first tries to prove the left-hand side of the implication. This can \
be done by using the appropriate option:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], 
        "[", \(Proposition["\<ForAll Distributivity\>"], 
        ProverOptions \[Rule] {BackChaining \[Rule] True}\), "]"}], 
      ";"}]], "Input"],

Cell["\<\
Now one obtains a proof which has an alternative branch. This is \
necessary because the prover does not know in advance which of the \
alternatives will succeed. If we want to see only the successful branch of \
the proof, then we have to set some options:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], 
        "[", \(Proposition["\<ForAll Distributivity\>"], 
        ProverOptions \[Rule] {BackChaining \[Rule] True}, 
        transformBy \[Rule] ProofSimplifier, 
        TransformerOptions \[Rule] {branches \[Rule] Proved}\), "]"}], 
      ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?transformBy\)\)], "Input"],

Cell[BoxData[
    \("An option for Prove/Compute/Simplify/Solve that specifies the \
transformation method to be used."\)], "Print"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?ProofSimplifier\)\)], "Input"],

Cell[BoxData[
    \("[proof-object, options] returns a simplified proof-object according to \
options."\)], "Print"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[ProofSimplifier]\)], "Input"],

Cell[BoxData[
    \({branches \[Rule] All, steps \[Rule] All, 
      substitutions \[Rule] All}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?branches\)\)], "Input"],

Cell[BoxData[
    \("Option of ProofSimplifier with possible values: Proved, Pending, \
Failed, Disproved and list combinations of these. All (default) means list of \
all."\)], "Print"]
}, Closed]],

Cell[BoxData[
    \(\(SetOptions[Prove, transformBy \[Rule] ProofSimplifier];\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], 
        "[", \(Proposition["\<ForAll Distributivity\>"], 
        ProverOptions \[Rule] {BackChaining \[Rule] True}, 
        TransformerOptions \[Rule] {branches -> Proved}\), "]"}], 
      ";"}]], "Input"],

Cell["\<\
Note that the internal proof object constructed by the prover is \
not modified: only the version which is displayed is transformed by the \
ProofSimplifier. One can allways display the full version of the last proof \
object or any simplified version of it, whithout having to call the prover \
again.\
\>", "Text"],

Cell[BoxData[
    \(ProofShow[]\)], "Input"],

Cell[BoxData[
    \(\(Transform[$TmaProofObject, by -> ProofSimplifier, 
        TransformerOptions \[Rule] {branches -> Proved}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?Transform\)\)], "Input"],

Cell[BoxData[
    \("Transform[po, by \[Rule] T, TransformerOptions \[Rule] {to}, show\
\[Dash]by \[Rule] S, ShowOptions \[Rule] {so}, opts] transforms (e.g. \
simplifies) the proof object `po` by the transformation function `T`. `po` \
can be a single proof object or a collection of proof objects (list, \
tuple,etc.). The list `{to}` contains options for `T`. In fact, `T[po,to]` is \
called.\n\nFinally, the resulting proof object is displayed by `S`. The list \
`{so}` contains options for `S`. In fact, `S[#,so]&` is called on the result \
returned by the transformation `T`.\n\nDefault values for all options are \
provided."\)], "Print"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Using Definitions by Equality and Definitions by Equivalence", "Section"],

Cell[CellGroupData[{

Cell["Definitions by Equality", "Subsection"],

Cell[TextData[{
  "In the current version of the predicate logic prover, \
equalities-by-definition  ( ",
  StyleBox[":=",
    FontWeight->"Bold"],
  " ) are used for rewriting left\[Dash]to\[Dash]right the [sub]terms \
occuring ",
  StyleBox["in the goal",
    FontWeight->"Bold"],
  " (but not in the assumptions). The user should be aware that [ab]using \
equalities may lead to infinite loops! Note that the normal equality ( ",
  StyleBox["=",
    FontWeight->"Bold"],
  " ) is not interpreted in any special way."
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theorem",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Sum of functions is commutative\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(f, g, x\)\((\((f\[CirclePlus]g)\)[
                      x] = \((g\[CirclePlus]f)\)[x])\)\), "\"\<fg\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Theorem (Sum of functions is commutative)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Sum\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(f, g, x\)\((\((f\[CirclePlus]g)\)[
                      x] := \((f[x] + g[x])\))\)\), "\"\<d+\>\""},
            {\(\[ForAll] \+\(x, y\)\((x + y = y + x)\)\), "\"\<c+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Theory (Sum)"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", 
        RowBox[{
          RowBox[{
            StyleBox["Theorem",
              FontWeight->"Bold"], "[", 
            "\"\<Sum of functions is commutative\>\"", "]"}], ",", 
          RowBox[{"using", "\[Rule]", 
            RowBox[{
              StyleBox["Theory",
                FontWeight->"Bold"], "[", "\"\<Sum\>\"", "]"}]}]}], "]"}], 
      ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Definitions by Equivalence", "Subsection"],

Cell[TextData[{
  "For defining formulae, we recommend the use of equivalent-by-definition ( \
:\[DoubleLeftRightArrow] ). The prover expands these definitions both in the \
goal and in the assumptions, but only when the respective formula occurs ",
  StyleBox["at the top level",
    FontWeight->"Bold"],
  " of the expression."
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<symmetric difference\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(x, y\)\((\((x\[CircleMinus]y)\) : \(\(\
\[DoubleLeftRightArrow]\)\((\((x \[And] \((\[Not] y)\))\) \[Or] \((\((\[Not] \
x)\) \[And] y)\))\)\))\)\), "\"\<\[CircleMinus]:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Definition (symmetric difference)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<associativity of symmetric difference right\>\"", ",", "\n", "\t", 
        GridBox[{
            {\(\((\((A\[CircleMinus]B)\)\[CircleMinus]C)\)\
\[DoubleLongRightArrow]\((A\[CircleMinus]\((B\[CircleMinus]C)\))\)\), 
              "\"\<\[DoubleLongRightArrow]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (associativity of symmetric difference right)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", 
      RowBox[{\(Proposition["\<associativity of symmetric difference \
right\>"]\), ",", 
        RowBox[{"using", "\[Rule]", 
          RowBox[{
            StyleBox["Definition",
              FontWeight->"Bold"], "[", "\"\<symmetric difference\>\"", 
            "]"}]}], ",", \(SearchDepth -> 35\)}], "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Closed]],

Cell[BoxData[
    ButtonBox[\(Proofs/symmetric - dif - right . nb\),
      ButtonData:>{
        FrontEnd`FileName[ {"Proofs"}, "symmetric-dif-right.nb", 
          CharacterEncoding -> "ISO8859-1"], None},
      ButtonStyle->"Hyperlink"]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<associativity of symmetric difference left\>\"", ",", "\n", "\t", 
        GridBox[{
            {\(\((\((A\[CircleMinus]B)\)\[CircleMinus]C)\)\
\[DoubleLongLeftArrow]\((A\[CircleMinus]\((B\[CircleMinus]C)\))\)\), 
              "\"\<\[DoubleLongLeftArrow]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (associativity of symmetric difference left)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", 
      RowBox[{\(Proposition["\<associativity of symmetric difference left\>"]\
\), ",", 
        RowBox[{"using", "\[Rule]", 
          RowBox[{
            StyleBox["Definition",
              FontWeight->"Bold"], "[", "\"\<symmetric difference\>\"", 
            "]"}]}], ",", \(SearchDepth -> 40\)}], "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Closed]],

Cell[BoxData[
    ButtonBox[\(Proofs/symmetric - dif - left . nb\),
      ButtonData:>{
        FrontEnd`FileName[ {"Proofs"}, "symmetric-dif-left.nb", 
          CharacterEncoding -> "ISO8859-1"], None},
      ButtonStyle->"Hyperlink"]], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Propositional Proving ", "Section"],

Cell[BoxData[
    RowBox[{"See", "  ", 
      ButtonBox[\(Propositional - Logic - Prover . nb\),
        ButtonData:>{"Propositional-Logic-Prover.nb", None},
        ButtonStyle->"Hyperlink"]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Quantified Theorems on Implication", "Section"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<ForAll Distributivity\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\[ForAll] \+x\((P[x]\[DoubleLongRightArrow]
                        Q)\))\)\[DoubleLongLeftRightArrow]\((\((\[Exists] \+y 
                          P[y])\)\[DoubleLongRightArrow]Q)\)\), 
              "\"\<\[ForAll]d\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (ForAll Distributivity)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], 
      "[", \(Proposition["\<ForAll Distributivity\>"]\), "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<ForAll Distributivity\>"], 
      ProverOptions \[Rule] {BackChaining \[Rule] True}\), "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<ForAll Distributivity\>"], 
      ProverOptions \[Rule] {BackChaining \[Rule] True}, 
      transformBy \[Rule] ProofSimplifier, 
      TransformerOptions \[Rule] {branches \[Rule] Proved}\), "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?ProofSimplifier\)\)], "Input"],

Cell[BoxData[
    \("[proof-object, options] returns a simplified proof-object according to \
options."\)], "Print"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[ProofSimplifier]\)], "Input"],

Cell[BoxData[
    \({branches \[Rule] All, steps \[Rule] All, 
      substitutions \[Rule] All}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?branches\)\)], "Input"],

Cell[BoxData[
    \("Option of ProofSimplifier with possible values: Proved, Pending, \
Failed, Disproved and list combinations of these. All (default) means list of \
all."\)], "Print"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetOptions[Prove, transformBy \[Rule] ProofSimplifier]\)], "Input"],

Cell[BoxData[
    \({using \[Rule] \[Bullet]kb["None", \[Bullet]range[], 
          True, \[Bullet]flist[]], 
      built\[Dash]in \[Rule] \[Bullet]bui["None", \[Bullet]range[], 
          True, \[Bullet]flist[]], by \[RuleDelayed] $TmaDefaultProver, 
      ProverOptions \[RuleDelayed] {}, transformBy \[Rule] ProofSimplifier, 
      TransformerOptions \[Rule] {}, showBy \[Rule] StaticWriter, 
      ShowOptions \[Rule] {}, SearchDepth \[Rule] Default, 
      formal\[Dash]object \[RuleDelayed] $TmaDefaultProofObject, 
      SearchMethod \[Rule] Default, ExpandKnowledge \[Rule] False, 
      LabelStyle \[RuleDelayed] $TmaDefaultLabelStyle}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<ForAll Distributivity\>"], 
      ProverOptions \[Rule] {BackChaining \[Rule] True}, 
      TransformerOptions \[Rule] {branches -> Proved}\), "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<ForAll Distributivity\>"], 
      ProverOptions \[Rule] {PNDLevel \[Rule] 0}\), "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Closed]],

Cell[BoxData[
    RowBox[{"Theorem", "[", 
      RowBox[{"\"\<Exists Distributivity\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\((\[ForAll] \+x P[x])\) \[Implies] 
                    Q)\) \[DoubleLeftRightArrow] \((\[Exists] \+y\((P[
                          y] \[Implies] Q)\))\)\), "\"\<\[Exists]d\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Theorem (Exists Distributivity)"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Prove[Theorem["\<Exists Distributivity\>"]]\)], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Prove[Theorem["\<Exists Distributivity\>"], 
      ProverOptions \[Rule] {PNDLevel \[Rule] 0, BackChaining \[Rule] True}, 
      TransformerOptions \[Rule] {branches \[Rule] Proved}]\)], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Prove[Theorem["\<Exists Distributivity\>"], 
      ProverOptions \[Rule] {PNDLevel \[Rule] 2, BackChaining \[Rule] True}, 
      TransformerOptions \[Rule] {branches \[Rule] Proved}]\)], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p1\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\[Exists] \+x\((P[x]\[DoubleLongRightArrow]
                        Q[x])\))\)\[DoubleLongLeftRightArrow]\((\((\[ForAll] \
\+y P[y])\)\[DoubleLongRightArrow]\((\[Exists] \+z Q[z])\))\)\), "\"\<p\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (p1)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p1\>"]\), "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p1\>"], 
      ProverOptions \[Rule] {PNDLevel \[Rule] 0}\), "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p2\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\[ForAll] \+\(x, y\)\((P[x]\[DoubleLongRightArrow]
                        Q[y])\))\)\[DoubleLongLeftRightArrow]\((\((\[Exists] \
\+z P[z])\)\[DoubleLongRightArrow]\((\[ForAll] \+t Q[t])\))\)\), "\"\<p\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (p2)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p2\>"]\), "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p2\>"], 
      ProverOptions \[Rule] {BackChaining \[Rule] True}\), "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p3\>\"", ",", "\n", "\t    ", GridBox[{
            {\(\((\[ForAll] \+x\((\[Not] \((P[x]\[DoubleLongLeftRightArrow]
                            Q[x])\))\))\)\[DoubleLongLeftRightArrow]\((\
\[ForAll] \+y\((\((\[Not] P[y])\)\[DoubleLongLeftRightArrow]Q[y])\))\)\), 
              "\"\<p\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (p3)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p3\>"]\), "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p3\>"], 
      ProverOptions \[Rule] {PNDLevel \[Rule] 0}\), "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p4\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\[Exists] \+x\((P[x]\[DoubleLongLeftRightArrow]
                        Q[x])\))\)\[DoubleLongLeftRightArrow]\((\((\[ForAll] \
\+y\((P[y] \[Or] Q[y])\))\)\[DoubleLongRightArrow]\((\[Exists] \+z\((P[
                              z] \[And] Q[z])\))\))\)\), "\"\<p\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (p4)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p4\>"]\), "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p4\>"], 
      ProverOptions \[Rule] {PNDLevel \[Rule] 0}\), "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p5\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\[ForAll] \+y\((P[y]\[DoubleLongLeftRightArrow]
                        Q[y])\))\)\[DoubleLongLeftRightArrow]\((\[ForAll] \+x\
\((\((P[x] \[And] Q[x])\) \[Or] \((\((\[Not] P[x])\) \[And] \((\[Not] Q[
                                  x])\))\))\))\)\), "\"\<p\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (p5)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p5\>"]\), "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p6\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\[ForAll] \+y\((P[y]\[DoubleLongLeftRightArrow]
                        Q[y])\))\)\[DoubleLongLeftRightArrow]\((\((\[ForAll] \
\+x\((P[x] \[Or] \((\[Not] Q[
                                  x])\))\))\) \[And] \((\[ForAll] \+x\((\((\
\[Not] P[x])\) \[Or] Q[x])\))\))\)\), "\"\<p\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (p6)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p6\>"]\), "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Equality, Order, Congruence", "Section"],

Cell[CellGroupData[{

Cell["Equal", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Equal Reflexivity\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+x\((x = x)\)\), "\"\<=\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (Equal Reflexivity)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Equal Symmetry\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(x, y\)\((\((x = 
                        y)\)\[DoubleLongRightArrow]\((y = x)\))\)\), 
              "\"\<=\[Implies]=\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (Equal Symmetry)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Equal Transitivity\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(x, y, z\)\((\((\((x = y)\)\  \[And] \ \((y = 
                            z)\))\)\[DoubleLongRightArrow]\ \((x = z)\))\)\), 
              "\"\<==\[Implies]=\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (Equal Transitivity)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Equal Transitivity \[ForAll]\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(x, y\)\((\((x = 
                        y)\)\ \[DoubleLongRightArrow]\((\[ForAll] \+z\((\ \
\((y = z)\)\[DoubleLongRightArrow]\ \((x = z)\))\))\))\)\), 
              "\"\<=\[Implies]\[ForAll]=\[Implies]=\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (Equal Transitivity \[ForAll])"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Prove", "[", 
        RowBox[{
          RowBox[{
            StyleBox["Proposition",
              FontWeight->"Bold"], "[", "\"\<Equal Transitivity\>\"", "]"}], 
          ",", 
          RowBox[{"using", "\[Rule]", 
            RowBox[{
              StyleBox["Proposition",
                FontWeight->"Bold"], "[", 
              "\"\<Equal Transitivity \[ForAll]\>\"", "]"}]}]}], "]"}], 
      ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Prove", "[", 
        RowBox[{
          RowBox[{
            StyleBox["Proposition",
              FontWeight->"Bold"], "[", "\"\<Equal Transitivity\>\"", "]"}], 
          ",", 
          RowBox[{"using", "\[Rule]", 
            RowBox[{
              StyleBox["Proposition",
                FontWeight->"Bold"], "[", 
              "\"\<Equal Transitivity \[ForAll]\>\"", "]"}]}], 
          ",", \(TransformerOptions \[Rule] {steps \[Rule] Useful}\)}], "]"}],
       ";"}]], "Input"],

Cell[BoxData[
    InterpretationBox[\("doing DisplayProofCell interactive mode:"\
\[InvisibleSpace]$TmaInteractiveMode\),
      SequenceForm[ 
      "doing DisplayProofCell interactive mode:", $TmaInteractiveMode],
      Editable->False]], "Print"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Prove[Proposition["\<Equal Transitivity\>"], 
      using \[Rule] Proposition["\<Equal Transitivity \[ForAll]\>"], 
      TransformerOptions \[Rule] {steps \[Rule] {Useful, 
              Combined}}]\)], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Prove[Proposition["\<Equal Transitivity\>"], 
      using \[Rule] Proposition["\<Equal Transitivity \[ForAll]\>"], 
      TransformerOptions \[Rule] {steps \[Rule] Combined}]\)], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Equal\>\"", ",", "\n", "\t", GridBox[{
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Equal Reflexivity\>\"", 
                "]"}]},
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Equal Symmetry\>\"", "]"}]},
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Equal Transitivity\>\"", 
                "]"}]}
            }]}], "]"}]], "Input",
  CellTags->"Theory (Equal)"]
}, Closed]],

Cell[CellGroupData[{

Cell["Less", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Less Irreflexivity\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+x\(\[Not] \((x\  < \ x)\)\)\), "\"\<\[Not]<\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (Less Irreflexivity)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Less Antisymmetry\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(x, y\)\((\((x\  < 
                        y)\)\[DoubleLongRightArrow]\(\[Not] \((y\  < \ 
                          x)\)\))\)\), "\"\<<\[Implies]\[Not]<\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (Less Antisymmetry)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<Less Irreflexivity\>\"", "]"}], 
        ",", 
        RowBox[{"using", "\[Rule]", 
          RowBox[{
            StyleBox["Proposition",
              FontWeight->"Bold"], "[", "\"\<Less Antisymmetry\>\"", 
            "]"}]}]}], "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Less Transitivity\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(x, y, z\)\((\((\((x\  < \ y)\) \[And] \((y < 
                            z)\))\)\[DoubleLongRightArrow]\((x\  < \ 
                        z)\))\)\), "\"\<<<\[Implies]<\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (Less Transitivity)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<Less Antisymmetry\>\"", "]"}], ",",
         
        RowBox[{"using", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Less Transitivity\>\"", 
                "]"}], ",", 
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Less Irreflexivity\>\"", 
                "]"}]}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<Less Antisymmetry\>\"", "]"}], ",",
         
        RowBox[{"using", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Less Transitivity\>\"", 
                "]"}], ",", 
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Less Irreflexivity\>\"", 
                "]"}]}], "}"}]}], 
        ",", \(TransformerOptions \[Rule] {steps \[Rule] Essential}\)}], 
      "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Less\>\"", ",", "\n", "\t", GridBox[{
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Less Irreflexivity\>\"", 
                "]"}]},
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Less Antisymmetry\>\"", 
                "]"}]},
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Less Transitivity\>\"", 
                "]"}]}
            }]}], "]"}]], "Input",
  CellTags->"Theory (Less)"]
}, Closed]],

Cell[CellGroupData[{

Cell["Equal and Less", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Equal not Less\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(x, y\)\((\((x = 
                        y)\)\[DoubleLongRightArrow]\(\[Not] \((x\  < \ 
                          y)\)\))\)\), "\"\<=\[Implies]\[Not]<\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (Equal not Less)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Equal not Greater\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(x, y\)\((\((x = 
                        y)\)\[DoubleLongRightArrow]\(\[Not] \((y\  < \ 
                          x)\)\))\)\), "\"\<=\[Implies]\[Not]>\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (Equal not Greater)"],

Cell[BoxData[
    \(\(SetOptions[Prove, 
        TransformerOptions \[Rule] {steps \[Rule] Essential}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<Equal not Greater\>\"", "]"}], ",",
         
        RowBox[{"using", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Equal Symmetry\>\"", "]"}], 
              ",", 
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Equal not Less\>\"", "]"}]}],
             "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Less and Equal Totality\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(x, y\)\((\((x < y)\) \[Or] \((\ 
                      x = y)\) \[Or] \((y < x)\))\)\), 
              "\"\<<\[Or]=\[Or]>\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (Less and Equal Totality)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Equal versus Less\>\"", ",", "\n", "\t", GridBox[{
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Equal not Less\>\"", "]"}]},
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Equal not Greater\>\"", 
                "]"}]},
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Less and Equal Totality\>\"",
                 "]"}]}
            }]}], "]"}]], "Input",
  CellTags->"Theory (Equal versus Less)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Equal and Less\>\"", ",", "\n", "\t", GridBox[{
            {
              RowBox[{
                StyleBox["Theory",
                  FontWeight->"Bold"], "[", "\"\<Equal\>\"", "]"}]},
            {
              RowBox[{
                StyleBox["Theory",
                  FontWeight->"Bold"], "[", "\"\<Less\>\"", "]"}]},
            {
              RowBox[{
                StyleBox["Theory",
                  FontWeight->"Bold"], "[", "\"\<Equal versus Less\>\"", 
                "]"}]}
            }]}], "]"}]], "Input",
  CellTags->"Theory (Equal and Less)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Less and Equal Transitivity\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(x, y, z\)\((\((\((x\  < \ y)\) \[And] \((y = 
                            z)\))\)\[DoubleLongRightArrow]\((x\  < \ 
                        z)\))\)\), "\"\<<=\[Implies]<\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (Less and Equal Transitivity)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Prove", "[", 
        RowBox[{
          RowBox[{
            StyleBox["Proposition",
              FontWeight->"Bold"], "[", "\"\<Less and Equal Transitivity\>\"",
             "]"}], ",", 
          RowBox[{"using", "\[Rule]", 
            RowBox[{
              StyleBox["Theory",
                FontWeight->"Bold"], "[", "\"\<Equal and Less\>\"", "]"}]}], 
          ",", \(SearchDepth \[Rule] 101\)}], "]"}], "//", 
      "Timing"}]], "Input"],

Cell[BoxData[
    InterpretationBox[\("Not used: "\[InvisibleSpace]{"Proposition (Equal \
Reflexivity): =", "Proposition (Equal Symmetry): =\[Implies]=", 
          "Proposition (Less Irreflexivity): \[Not]<", 
          "Proposition (Less Antisymmetry): <\[Implies]\[Not]<", 
          "Proposition (Equal not Less): =\[Implies]\[Not]<"}\),
      SequenceForm[ 
      "Not used: ", {"Proposition (Equal Reflexivity): =", 
        "Proposition (Equal Symmetry): =\[Implies]=", 
        "Proposition (Less Irreflexivity): \[Not]<", 
        "Proposition (Less Antisymmetry): <\[Implies]\[Not]<", 
        "Proposition (Equal not Less): =\[Implies]\[Not]<"}],
      Editable->False]], "Print"],

Cell[BoxData[
    \({24.95599999999999`\ Second, \[SkeletonIndicator]\ ProofObject\ \
\[SkeletonIndicator]}\)], "Output"]
}, Open  ]],

Cell[RawData["\<\
Cell[TextData[ButtonBox[\"Proof\",
  ButtonData:>{
    FrontEnd`FileName[ {\"Proofs\"}, \
\"Less-and-Equal-Transitivity-essential.nb\", CharacterEncoding -> \
\"ISO8859-1\"], None},
  ButtonStyle->\"Hyperlink\"]], \"Text\"]\
\>"], "Text"],

Cell[TextData[{
  ButtonBox["Unsimplified",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs"}, "Less-and-Equal-Transitivity-full.nb", 
        CharacterEncoding -> "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  ButtonBox[" ",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs"}, "Less-and-Equal-Transitivity-full.nb", 
        CharacterEncoding -> "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  ButtonBox["proof",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs"}, "Less-and-Equal-Transitivity-full.nb", 
        CharacterEncoding -> "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell[BoxData[
    \(ProofShow[]\)], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Equal and Less Transitivity\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(x, y, z\)\((\((\((x = y)\) \[And] \((y < 
                            z)\))\)\[DoubleLongRightArrow]\((x\  < \ 
                        z)\))\)\), "\"\<=<\[Implies]<\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (Equal and Less Transitivity)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Prove", "[", 
        RowBox[{
          RowBox[{
            StyleBox["Proposition",
              FontWeight->"Bold"], "[", "\"\<Equal and Less Transitivity\>\"",
             "]"}], ",", 
          RowBox[{"using", "\[Rule]", 
            RowBox[{
              StyleBox["Theory",
                FontWeight->"Bold"], "[", "\"\<Equal and Less\>\"", "]"}]}], 
          ",", \(SearchDepth \[Rule] 101\)}], "]"}], "//", 
      "Timing"}]], "Input"],

Cell[BoxData[
    InterpretationBox[\("Not used: "\[InvisibleSpace]{"Proposition (Equal \
Reflexivity): =", "Proposition (Equal Symmetry): =\[Implies]=", 
          "Proposition (Less Irreflexivity): \[Not]<", 
          "Proposition (Less Antisymmetry): <\[Implies]\[Not]<", 
          "Proposition (Equal not Less): =\[Implies]\[Not]<"}\),
      SequenceForm[ 
      "Not used: ", {"Proposition (Equal Reflexivity): =", 
        "Proposition (Equal Symmetry): =\[Implies]=", 
        "Proposition (Less Irreflexivity): \[Not]<", 
        "Proposition (Less Antisymmetry): <\[Implies]\[Not]<", 
        "Proposition (Equal not Less): =\[Implies]\[Not]<"}],
      Editable->False]], "Print"],

Cell[BoxData[
    \({23.552999999999997`\ Second, \[SkeletonIndicator]\ ProofObject\ \
\[SkeletonIndicator]}\)], "Output"]
}, Closed]],

Cell[TextData[ButtonBox["Proof",
  ButtonData:>{
    FrontEnd`FileName[ {"Proofs"}, "Equal-and-Less-Transitivity-essential.nb",
       CharacterEncoding -> "ISO8859-1"], None},
  ButtonStyle->"Hyperlink"]], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["LessOrEqual", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<LessOrEqual Def\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(x, y\)\((\((x\  \[LessEqual] \ 
                        y)\) : \(\(\[DoubleLeftRightArrow]\)\(\ \)\((\((x\  = 
                              y)\) \[Or] \((\ x\  < \ y)\))\)\))\)\), 
              "\"\<\[LessEqual]:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Definition (LessOrEqual Def)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<LessOrEqual Reflexivity\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+x\((x\  \[LessEqual] \ x)\)\), 
              "\"\<\[LessEqual]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (LessOrEqual Reflexivity)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<LessOrEqual Reflexivity\>\"", 
          "]"}], ",", 
        RowBox[{"using", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                StyleBox["Definition",
                  FontWeight->"Bold"], "[", "\"\<LessOrEqual Def\>\"", "]"}], 
              ",", 
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Equal Reflexivity\>\"", 
                "]"}]}], "}"}]}], 
        ",", \(ProverOptions \[Rule] {TryAlternatives \[Rule] True}\)}], 
      "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<LessOrEqual Antisymmetry\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(x, y\)\((\((\((x\  \[LessEqual] \ 
                            y)\) \[And] \((y \[LessEqual] 
                            x)\))\)\[DoubleLongRightArrow]\((x = y)\))\)\), 
              "\"\<\[LessEqual]\[GreaterEqual]\[Implies]=\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (LessOrEqual Antisymmetry)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<LessOrEqual Antisymmetry\>\"", 
          "]"}], ",", 
        RowBox[{"using", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                StyleBox["Definition",
                  FontWeight->"Bold"], "[", "\"\<LessOrEqual Def\>\"", "]"}], 
              ",", 
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Equal Symmetry\>\"", "]"}], 
              ",", 
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Less Antisymmetry\>\"", 
                "]"}]}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<LessOrEqual Transitivity\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(x, y, z\)\((\((\((x\  \[LessEqual] \ 
                            y)\) \[And] \((y \[LessEqual] 
                            z)\))\)\[DoubleLongRightArrow]\((x\  \[LessEqual] \
\ z)\))\)\), "\"\<\[LessEqual]\[LessEqual]\[Implies]\[LessEqual]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (LessOrEqual Transitivity)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Prove", "[", 
        RowBox[{
          RowBox[{
            StyleBox["Proposition",
              FontWeight->"Bold"], "[", "\"\<LessOrEqual Transitivity\>\"", 
            "]"}], ",", 
          RowBox[{"using", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  StyleBox["Definition",
                    FontWeight->"Bold"], "[", "\"\<LessOrEqual Def\>\"", 
                  "]"}], ",", 
                RowBox[{
                  StyleBox["Theory",
                    FontWeight->"Bold"], "[", "\"\<Equal and Less\>\"", 
                  "]"}]}], "}"}]}], ",", \(SearchDepth \[Rule] 100\)}], "]"}],
       "//", "Timing"}]], "Input"],

Cell[BoxData[
    InterpretationBox[\("Not used: "\[InvisibleSpace]{"Proposition (Equal \
Reflexivity): =", "Proposition (Less Irreflexivity): \[Not]<", 
          "Proposition (Less Antisymmetry): <\[Implies]\[Not]<"}\),
      SequenceForm[ 
      "Not used: ", {"Proposition (Equal Reflexivity): =", 
        "Proposition (Less Irreflexivity): \[Not]<", 
        "Proposition (Less Antisymmetry): <\[Implies]\[Not]<"}],
      Editable->False]], "Print"],

Cell[BoxData[
    \({50.863`\ Second, \[SkeletonIndicator]\ ProofObject\ \
\[SkeletonIndicator]}\)], "Output"]
}, Open  ]],

Cell[TextData[ButtonBox["Proof",
  ButtonData:>{
    FrontEnd`FileName[ {"Proofs"}, "LessOrEqual-Transitivity.nb", 
      CharacterEncoding -> "ISO8859-1"], None},
  ButtonStyle->"Hyperlink"]], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Transitivity of Equal and of Less\>\"", ",", "\n", "\t", GridBox[{
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Equal Transitivity\>\"", 
                "]"}]},
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<Less Transitivity\>\"", 
                "]"}]},
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", 
                "\"\<Equal and Less Transitivity\>\"", "]"}]},
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", 
                "\"\<Less and Equal Transitivity\>\"", "]"}]}
            }]}], "]"}]], "Input",
  CellTags->"Theory (Transitivity of Equal and of Less)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Prove", "[", 
        RowBox[{
          RowBox[{
            StyleBox["Proposition",
              FontWeight->"Bold"], "[", "\"\<LessOrEqual Transitivity\>\"", 
            "]"}], ",", 
          RowBox[{"using", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  StyleBox["Definition",
                    FontWeight->"Bold"], "[", "\"\<LessOrEqual Def\>\"", 
                  "]"}], ",", 
                RowBox[{
                  StyleBox["Theory",
                    FontWeight->"Bold"], "[", 
                  "\"\<Transitivity of Equal and of Less\>\"", "]"}]}], 
              "}"}]}], ",", \(SearchDepth \[Rule] 50\)}], "]"}], "//", 
      "Timing"}]], "Input"],

Cell[BoxData[
    \({13.468999999999994`\ Second, \[SkeletonIndicator]\ ProofObject\ \
\[SkeletonIndicator]}\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Congruence", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Congruence Def by LessOrEqual\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(x, y\)\((\((x\  \[Tilde] \ 
                        y)\) : \(\(\[DoubleLeftRightArrow]\)\(\ \)\((\((x\  \
\[LessEqual] \ y)\) \[And] \((y\  \[LessEqual] \ x)\))\)\))\)\), 
              "\"\<\[Tilde]:\[LessEqual]\[LessEqual]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Definition (Congruence Def by LessOrEqual)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Congruence Reflexivity\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+x\((x\  \[Tilde] \ x)\)\), "\"\<\[Tilde]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (Congruence Reflexivity)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<Congruence Reflexivity\>\"", "]"}],
         ",", 
        RowBox[{"using", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                StyleBox["Definition",
                  FontWeight->"Bold"], "[", 
                "\"\<Congruence Def by LessOrEqual\>\"", "]"}], ",", 
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<LessOrEqual Reflexivity\>\"",
                 "]"}]}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Congruence Symmetry\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(x, y\)\((\((x\  \[Tilde] 
                        y)\)\[DoubleLongRightArrow]\((y\  \[Tilde] \ 
                        x)\))\)\), "\"\<\[Tilde]\[Implies]\[Tilde]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (Congruence Symmetry)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<Congruence Symmetry\>\"", "]"}], 
        ",", 
        RowBox[{"using", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              StyleBox["Definition",
                FontWeight->"Bold"], "[", 
              "\"\<Congruence Def by LessOrEqual\>\"", "]"}], "}"}]}]}], 
      "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Congruence Transitivity\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(x, y, z\)\((\((\((x\  \[Tilde] \ 
                            y)\) \[And] \((y \[Tilde] 
                            z)\))\)\[DoubleLongRightArrow]\((x\  \[Tilde] \ 
                        z)\))\)\), 
              "\"\<\[Tilde]\[Tilde]\[Implies]\[Tilde]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (Congruence Transitivity)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Timing", "[", 
      RowBox[{"Prove", "[", 
        RowBox[{
          RowBox[{
            StyleBox["Proposition",
              FontWeight->"Bold"], "[", "\"\<Congruence Transitivity\>\"", 
            "]"}], ",", 
          RowBox[{"using", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  StyleBox["Definition",
                    FontWeight->"Bold"], "[", 
                  "\"\<Congruence Def by LessOrEqual\>\"", "]"}], ",", 
                RowBox[{
                  StyleBox["Proposition",
                    FontWeight->"Bold"], "[", 
                  "\"\<LessOrEqual Transitivity\>\"", "]"}]}], "}"}]}]}], 
        "]"}], "]"}]], "Input"],

Cell[BoxData[
    \({6.889999999999986`\ Second, \[SkeletonIndicator]\ ProofObject\ \
\[SkeletonIndicator]}\)], "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["The Limit of a Sum", "Section"],

Cell[CellGroupData[{

Cell["Initializations", "Subsubsection"],

Cell["\<\
In the spirit of \"structured programming\", we build the \
definition of limit up in a hierarchy of definitions, one quantifier at a \
time:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<2-ary limit\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(f, a\)\((\((limit[f, 
                        a])\)\  : \(\(\[DoubleLeftRightArrow]\)\((\ \[ForAll] \
\+\[Epsilon] limit[f, a, \[Epsilon]])\)\))\)\), "\"\<l2:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Definition (2-ary limit)"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(limit\)\" is similar to \
existing symbol \"\!\(Limit\)\"."\)], "Message"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<3-ary limit\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(f, a, \[Epsilon]\)\((\((limit[f, 
                        a, \[Epsilon]])\) : \(\(\[DoubleLeftRightArrow]\)\(\ \
\)\(\[Exists] \+N limit[f, a, \[Epsilon], N]\)\))\)\), "\"\<l3:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Definition (3-ary limit)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<4-ary limit\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(f, a, \[Epsilon], N\)\((\((limit[f, 
                        a, \[Epsilon], 
                        N])\) : \(\(\[DoubleLeftRightArrow]\)\((\(\(\(\ \)\(\
\[ForAll]\)\)\+n\) \((n \[GreaterEqual] 
                                N)\)\[DoubleLongRightArrow]\((\
\[LeftBracketingBar]f[n] - a\[RightBracketingBar] < \[Epsilon])\))\)\))\)\), 
              "\"\<l4:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Definition (4-ary limit)"],

Cell["Auxiliary knowledge:", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<sum of sequences\>\"", ",", \(any[f, g, x]\), ",", "\n", "\t", 
        GridBox[{
            {\(\((\((f\[CirclePlus]g)\)[x])\) := \((f[x] + g[x])\)\), 
              "\"\<\[CirclePlus]:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Definition (sum of sequences)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<distance of sum\>\"", 
        ",", \(any[x, y, a, b, \[Delta], \[Epsilon]]\), ",", "\n", "\t", 
        GridBox[{
            {\(\((\[LeftBracketingBar]x - 
                          a\[RightBracketingBar] < \[Delta] \[And] \
\[LeftBracketingBar]y - 
                          b\[RightBracketingBar] < \[Epsilon])\)\
\[DoubleLongRightArrow]\((\[LeftBracketingBar]\((x + y)\) - \((a + 
                            b)\)\[RightBracketingBar] < \[Delta] + \
\[Epsilon])\)\), "\"\<\[LeftBracketingBar]++\[RightBracketingBar]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (distance of sum)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<max\>\"", ",", \(any[M, m, n]\), ",", "\n", "\t", GridBox[{
            {\(\((M \[GreaterEqual] 
                    max[m, n])\)\[DoubleLongRightArrow]\((M \[GreaterEqual] 
                      m \[And] M \[GreaterEqual] n)\)\), "\"\<max:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (max)"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(max\)\" is similar to \
existing symbol \"\!\(Max\)\"."\)], "Message"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Limit4", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<4-ary limit\>\"", ",", "\n", "\t", GridBox[{
            {\(Definition["\<4-ary limit\>"]\)},
            {\(Definition["\<sum of sequences\>"]\)},
            {\(Proposition["\<distance of sum\>"]\)},
            {\(Proposition["\<max\>"]\)}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Theory (4-ary limit)"],

Cell["Ultimately, we want to prove", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<2-ary limit of sum\>\"", ",", \(any[f, a, g, b]\), ",", "\n", "\t",
         GridBox[{
            {\(\((limit[f, a] \[And] limit[g, b])\)\n\t\[DoubleLongRightArrow]
                limit[f\[CirclePlus]g, a + b]\), "\"\<l2+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (2-ary limit of sum)"],

Cell["\<\
The decomposition of the limit definition suggests building up the \
proposition (and its proof)  in a hierarchy of propositions (and \
proofs):\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<4-ary limit of sum\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(f, a, \[Delta], M, g, b, \[Epsilon], \
N\)\((\((limit[f, a, \[Delta], M] \[And] 
                        limit[g, b, \[Epsilon], 
                          N])\)\n\t\[DoubleLongRightArrow]
                    limit[f\[CirclePlus]g, a + b, \[Delta] + \[Epsilon], 
                      max[M, N]])\)\), "\"\<l4+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (4-ary limit of sum)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Timing", "[", 
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", \(Proposition["\<4-ary limit of sum\>"], 
        using \[Rule] Theory["\<4-ary limit\>"], SearchDepth \[Rule] 50\), 
        "]"}], "]"}]], "Input"],

Cell[BoxData[
    \({9.283000000000015`\ Second, \[SkeletonIndicator]\ ProofObject\ \
\[SkeletonIndicator]}\)], "Output"]
}, Open  ]],

Cell[TextData[ButtonBox["Proofs/limit-4.nb",
  ButtonData:>{
    FrontEnd`FileName[ {"Proofs"}, "limit-4.nb", CharacterEncoding -> 
      "ISO8859-1"], None},
  ButtonStyle->"Hyperlink"]], "Text"],

Cell["\<\
In case the ProofSimplifier was not set as the default transformer \
of the system then evaluate the following cell:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetOptions[Transform, by \[Rule] ProofSimplifier]\)], "Input"],

Cell[BoxData[
    \({by \[Rule] ProofSimplifier, TransformerOptions \[Rule] {}, 
      showBy \[Rule] StaticWriter, ShowOptions \[Rule] {}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transform[$TmaProofObject, 
      TransformerOptions \[Rule] {steps \[Rule] Useful}]\)], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?steps\)\)], "Input"],

Cell[BoxData[
    \("Option of ProofSimplifier with possible values: All, Essential, \
Combined, Useful, SequentialCombined, DistributedCombined, LiftedParallel and \
list combinations of these."\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transform[$TmaProofObject, 
      TransformerOptions \[Rule] {steps \[Rule] \ Essential}]\)], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Limit3", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<3-ary limit\>\"", ",", "\n", "\t", GridBox[{
            {\(Definition["\<3-ary limit\>"]\)},
            {\(Proposition["\<4-ary limit of sum\>"]\)}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Theory (3-ary limit)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<3-ary limit of sum\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(f, a, \[Delta], g, b, \[Epsilon]\)\((\((limit[f, 
                          a, \[Delta]] \[And] 
                        limit[g, b, \[Epsilon]])\)\n\t\[DoubleLongRightArrow]
                    limit[f\[CirclePlus]g, 
                      a + b, \[Delta] + \[Epsilon]])\)\), "\"\<l3+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (3-ary limit of sum)"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Timing", "[", 
        RowBox[{
          StyleBox["Prove",
            FontWeight->"Bold"], 
          "[", \(Proposition["\<3-ary limit of sum\>"], 
          using \[Rule] Theory["\<3-ary limit\>"]\), "]"}], "]"}], 
      ";"}]], "Input"],

Cell[BoxData[
    \(ProofShow[]\)], "Input"],

Cell[TextData[ButtonBox["Proofs/limit-3.nb",
  ButtonData:>{
    FrontEnd`FileName[ {"Proofs"}, "limit-3.nb", CharacterEncoding -> 
      "ISO8859-1"], None},
  ButtonStyle->"Hyperlink"]], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Limit2", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<3-ary limit of sum: variant\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(f, a, g, b, \[Epsilon]\)\((\((limit[f, 
                          a, \[Epsilon]/2] \[And] 
                        limit[g, 
                          b, \[Epsilon]/2])\)\n\t\[DoubleLongRightArrow]
                    limit[f\[CirclePlus]g, a + b, \[Epsilon]])\)\), 
              "\"\<l3+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (3-ary limit of sum: variant)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<2-ary limit\>\"", ",", "\n", "\t", GridBox[{
            {\(Definition["\<2-ary limit\>"]\)},
            {\(Proposition["\<3-ary limit of sum: variant\>"]\)}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Theory (2-ary limit)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<2-ary limit of sum\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(f, a, g, b\)\((\((limit[f, a] \[And] 
                        limit[g, b])\)\n\t\[DoubleLongRightArrow]
                    limit[f\[CirclePlus]g, a + b])\)\), "\"\<l2+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Proposition (2-ary limit of sum)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Timing", "[", 
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", \(Proposition["\<2-ary limit of sum\>"], 
        using \[Rule] Theory["\<2-ary limit\>"], 
        ProverOptions \[Rule] {BackChaining \[Rule] True}\), "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    \({3.605000000000018`\ Second, \[SkeletonIndicator]\ ProofObject\ \
\[SkeletonIndicator]}\)], "Output"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 951}},
WindowSize->{1032, 921},
WindowMargins->{{75, Automatic}, {1, Automatic}},
Magnification->1,
StyleDefinitions -> "PastelColor.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Theorem (D)"->{
    Cell[4920, 169, 370, 8, 47, "Input",
      CellTags->"Theorem (D)"]},
  "Proposition (ForAll Distributivity)"->{
    Cell[6910, 243, 525, 11, 83, "Input",
      CellTags->"Proposition (ForAll Distributivity)"],
    Cell[18069, 587, 529, 11, 83, "Input",
      CellTags->"Proposition (ForAll Distributivity)"]},
  "Theorem (Sum of functions is commutative)"->{
    Cell[12767, 426, 442, 10, 78, "Input",
      CellTags->"Theorem (Sum of functions is commutative)"]},
  "Theory (Sum)"->{
    Cell[13212, 438, 444, 10, 107, "Input",
      CellTags->"Theory (Sum)"]},
  "Definition (symmetric difference)"->{
    Cell[14564, 480, 486, 10, 78, "Input",
      CellTags->"Definition (symmetric difference)"]},
  "Proposition (associativity of symmetric difference right)"->{
    Cell[15053, 492, 527, 12, 72, "Input",
      CellTags->
      "Proposition (associativity of symmetric difference right)"]},
  "Proposition (associativity of symmetric difference left)"->{
    Cell[16371, 531, 523, 12, 72, "Input",
      CellTags->"Proposition (associativity of symmetric difference left)"]},
  "Theorem (Exists Distributivity)"->{
    Cell[21846, 712, 433, 8, 83, "Input",
      CellTags->"Theorem (Exists Distributivity)"]},
  "Proposition (p1)"->{
    Cell[23175, 753, 468, 10, 83, "Input",
      CellTags->"Proposition (p1)"]},
  "Proposition (p2)"->{
    Cell[24211, 788, 475, 10, 83, "Input",
      CellTags->"Proposition (p2)"]},
  "Proposition (p3)"->{
    Cell[25261, 823, 504, 11, 83, "Input",
      CellTags->"Proposition (p3)"]},
  "Proposition (p4)"->{
    Cell[26333, 859, 536, 11, 83, "Input",
      CellTags->"Proposition (p4)"]},
  "Proposition (p5)"->{
    Cell[27437, 895, 532, 11, 83, "Input",
      CellTags->"Proposition (p5)"]},
  "Proposition (p6)"->{
    Cell[28229, 919, 552, 12, 83, "Input",
      CellTags->"Proposition (p6)"]},
  "Proposition (Equal Reflexivity)"->{
    Cell[29179, 953, 335, 8, 62, "Input",
      CellTags->"Proposition (Equal Reflexivity)"]},
  "Proposition (Equal Symmetry)"->{
    Cell[29517, 963, 427, 10, 64, "Input",
      CellTags->"Proposition (Equal Symmetry)"]},
  "Proposition (Equal Transitivity)"->{
    Cell[29947, 975, 474, 10, 64, "Input",
      CellTags->"Proposition (Equal Transitivity)"]},
  "Proposition (Equal Transitivity \[ForAll])"->{
    Cell[30424, 987, 549, 12, 69, "Input",
      CellTags->"Proposition (Equal Transitivity \[ForAll])"]},
  "Theory (Equal)"->{
    Cell[32951, 1065, 714, 20, 89, "Input",
      CellTags->"Theory (Equal)"]},
  "Proposition (Less Irreflexivity)"->{
    Cell[33734, 1092, 358, 8, 62, "Input",
      CellTags->"Proposition (Less Irreflexivity)"]},
  "Proposition (Less Antisymmetry)"->{
    Cell[34095, 1102, 468, 10, 64, "Input",
      CellTags->"Proposition (Less Antisymmetry)"]},
  "Proposition (Less Transitivity)"->{
    Cell[35093, 1133, 484, 10, 64, "Input",
      CellTags->"Proposition (Less Transitivity)"]},
  "Theory (Less)"->{
    Cell[37185, 1197, 732, 21, 89, "Input",
      CellTags->"Theory (Less)"]},
  "Proposition (Equal not Less)"->{
    Cell[37996, 1225, 460, 10, 64, "Input",
      CellTags->"Proposition (Equal not Less)"]},
  "Proposition (Equal not Greater)"->{
    Cell[38459, 1237, 466, 10, 64, "Input",
      CellTags->"Proposition (Equal not Greater)"]},
  "Proposition (Less and Equal Totality)"->{
    Cell[39799, 1278, 448, 10, 64, "Input",
      CellTags->"Proposition (Less and Equal Totality)"]},
  "Theory (Equal versus Less)"->{
    Cell[40250, 1290, 743, 20, 89, "Input",
      CellTags->"Theory (Equal versus Less)"]},
  "Theory (Equal and Less)"->{
    Cell[40996, 1312, 677, 19, 89, "Input",
      CellTags->"Theory (Equal and Less)"]},
  "Proposition (Less and Equal Transitivity)"->{
    Cell[41676, 1333, 511, 11, 64, "Input",
      CellTags->"Proposition (Less and Equal Transitivity)"]},
  "Proposition (Equal and Less Transitivity)"->{
    Cell[44465, 1412, 507, 11, 64, "Input",
      CellTags->"Proposition (Equal and Less Transitivity)"]},
  "Definition (LessOrEqual Def)"->{
    Cell[46612, 1472, 523, 11, 64, "Input",
      CellTags->"Definition (LessOrEqual Def)"]},
  "Proposition (LessOrEqual Reflexivity)"->{
    Cell[47138, 1485, 388, 9, 62, "Input",
      CellTags->"Proposition (LessOrEqual Reflexivity)"]},
  "Proposition (LessOrEqual Antisymmetry)"->{
    Cell[48373, 1523, 557, 11, 64, "Input",
      CellTags->"Proposition (LessOrEqual Antisymmetry)"]},
  "Proposition (LessOrEqual Transitivity)"->{
    Cell[49860, 1565, 570, 11, 64, "Input",
      CellTags->"Proposition (LessOrEqual Transitivity)"]},
  "Theory (Transitivity of Equal and of Less)"->{
    Cell[51982, 1622, 992, 27, 107, "Input",
      CellTags->"Theory (Transitivity of Equal and of Less)"]},
  "Definition (Congruence Def by LessOrEqual)"->{
    Cell[53981, 1685, 568, 12, 64, "Input",
      CellTags->"Definition (Congruence Def by LessOrEqual)"]},
  "Proposition (Congruence Reflexivity)"->{
    Cell[54552, 1699, 363, 8, 62, "Input",
      CellTags->"Proposition (Congruence Reflexivity)"]},
  "Proposition (Congruence Symmetry)"->{
    Cell[55702, 1734, 481, 10, 64, "Input",
      CellTags->"Proposition (Congruence Symmetry)"]},
  "Proposition (Congruence Transitivity)"->{
    Cell[56771, 1767, 582, 12, 64, "Input",
      CellTags->"Proposition (Congruence Transitivity)"]},
  "Definition (2-ary limit)"->{
    Cell[58595, 1827, 459, 10, 69, "Input",
      CellTags->"Definition (2-ary limit)"]},
  "Definition (3-ary limit)"->{
    Cell[59255, 1845, 477, 10, 69, "Input",
      CellTags->"Definition (3-ary limit)"]},
  "Definition (4-ary limit)"->{
    Cell[59735, 1857, 661, 14, 69, "Input",
      CellTags->"Definition (4-ary limit)"]},
  "Definition (sum of sequences)"->{
    Cell[60438, 1875, 425, 11, 58, "Input",
      CellTags->"Definition (sum of sequences)"]},
  "Proposition (distance of sum)"->{
    Cell[60866, 1888, 760, 17, 58, "Input",
      CellTags->"Proposition (distance of sum)"]},
  "Proposition (max)"->{
    Cell[61651, 1909, 468, 11, 58, "Input",
      CellTags->"Proposition (max)"]},
  "Theory (4-ary limit)"->{
    Cell[62384, 1933, 455, 11, 107, "Input",
      CellTags->"Theory (4-ary limit)"]},
  "Proposition (2-ary limit of sum)"->{
    Cell[62889, 1948, 466, 11, 82, "Input",
      CellTags->"Proposition (2-ary limit of sum)"],
    Cell[68639, 2130, 485, 10, 91, "Input",
      CellTags->"Proposition (2-ary limit of sum)"]},
  "Proposition (4-ary limit of sum)"->{
    Cell[63529, 1967, 627, 13, 91, "Input",
      CellTags->"Proposition (4-ary limit of sum)"]},
  "Theory (3-ary limit)"->{
    Cell[66061, 2054, 362, 9, 71, "Input",
      CellTags->"Theory (3-ary limit)"]},
  "Proposition (3-ary limit of sum)"->{
    Cell[66426, 2065, 602, 12, 91, "Input",
      CellTags->"Proposition (3-ary limit of sum)"]},
  "Proposition (3-ary limit of sum: variant)"->{
    Cell[67631, 2103, 631, 14, 91, "Input",
      CellTags->"Proposition (3-ary limit of sum: variant)"]},
  "Theory (2-ary limit)"->{
    Cell[68265, 2119, 371, 9, 71, "Input",
      CellTags->"Theory (2-ary limit)"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Theorem (D)", 70290, 2179},
  {"Proposition (ForAll Distributivity)", 70407, 2182},
  {"Theorem (Sum of functions is commutative)", 70654, 2187},
  {"Theory (Sum)", 70780, 2190},
  {"Definition (symmetric difference)", 70899, 2193},
  {"Proposition (associativity of symmetric difference right)", 71062, 2196},
  {"Proposition (associativity of symmetric difference left)", 71255, 2200},
  {"Theorem (Exists Distributivity)", 71415, 2203},
  {"Proposition (p1)", 71534, 2206},
  {"Proposition (p2)", 71639, 2209},
  {"Proposition (p3)", 71744, 2212},
  {"Proposition (p4)", 71849, 2215},
  {"Proposition (p5)", 71954, 2218},
  {"Proposition (p6)", 72059, 2221},
  {"Proposition (Equal Reflexivity)", 72179, 2224},
  {"Proposition (Equal Symmetry)", 72310, 2227},
  {"Proposition (Equal Transitivity)", 72443, 2230},
  {"Proposition (Equal Transitivity \[ForAll])", 72590, 2233},
  {"Theory (Equal)", 72719, 2236},
  {"Proposition (Less Irreflexivity)", 72839, 2239},
  {"Proposition (Less Antisymmetry)", 72975, 2242},
  {"Proposition (Less Transitivity)", 73111, 2245},
  {"Theory (Less)", 73229, 2248},
  {"Proposition (Equal not Less)", 73344, 2251},
  {"Proposition (Equal not Greater)", 73477, 2254},
  {"Proposition (Less and Equal Totality)", 73619, 2257},
  {"Theory (Equal versus Less)", 73756, 2260},
  {"Theory (Equal and Less)", 73879, 2263},
  {"Proposition (Less and Equal Transitivity)", 74017, 2266},
  {"Proposition (Equal and Less Transitivity)", 74173, 2269},
  {"Definition (LessOrEqual Def)", 74316, 2272},
  {"Proposition (LessOrEqual Reflexivity)", 74455, 2275},
  {"Proposition (LessOrEqual Antisymmetry)", 74603, 2278},
  {"Proposition (LessOrEqual Transitivity)", 74753, 2281},
  {"Theory (Transitivity of Equal and of Less)", 74907, 2284},
  {"Definition (Congruence Def by LessOrEqual)", 75066, 2287},
  {"Proposition (Congruence Reflexivity)", 75218, 2290},
  {"Proposition (Congruence Symmetry)", 75360, 2293},
  {"Proposition (Congruence Transitivity)", 75504, 2296},
  {"Definition (2-ary limit)", 75639, 2299},
  {"Definition (3-ary limit)", 75761, 2302},
  {"Definition (4-ary limit)", 75883, 2305},
  {"Definition (sum of sequences)", 76010, 2308},
  {"Proposition (distance of sum)", 76142, 2311},
  {"Proposition (max)", 76262, 2314},
  {"Theory (4-ary limit)", 76373, 2317},
  {"Proposition (2-ary limit of sum)", 76500, 2320},
  {"Proposition (4-ary limit of sum)", 76735, 2325},
  {"Theory (3-ary limit)", 76861, 2328},
  {"Proposition (3-ary limit of sum)", 76986, 2331},
  {"Proposition (3-ary limit of sum: variant)", 77133, 2334},
  {"Theory (2-ary limit)", 77268, 2337}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 40, 0, 76, "Title"],

Cell[CellGroupData[{
Cell[1804, 55, 38, 0, 51, "Section"],

Cell[CellGroupData[{
Cell[1867, 59, 59, 1, 38, "Input"],
Cell[1929, 62, 183, 3, 58, "Print"]
}, Open  ]],
Cell[2127, 68, 294, 8, 29, "Text"],
Cell[2424, 78, 75, 1, 38, "Input"],
Cell[2502, 81, 92, 1, 38, "Input"],
Cell[2597, 84, 71, 0, 29, "Text"],
Cell[2671, 86, 60, 1, 38, "Input"],
Cell[2734, 89, 119, 3, 29, "Text"],
Cell[2856, 94, 82, 1, 38, "Input"],
Cell[2941, 97, 77, 1, 38, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3055, 103, 56, 0, 35, "Section"],
Cell[3114, 105, 120, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[3259, 112, 57, 1, 38, "Input"],
Cell[3319, 115, 416, 8, 75, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[3772, 128, 55, 1, 38, "Input"],
Cell[3830, 131, 416, 8, 75, "Output"]
}, Closed]],
Cell[4261, 142, 99, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[4385, 149, 31, 0, 39, "Subsection"],
Cell[4419, 151, 62, 0, 29, "Text"],
Cell[4484, 153, 182, 4, 29, "Text"],

Cell[CellGroupData[{
Cell[4691, 161, 46, 1, 38, "Input"],
Cell[4740, 164, 165, 2, 39, "Print"]
}, Open  ]],
Cell[4920, 169, 370, 8, 47, "Input",
  CellTags->"Theorem (D)"],
Cell[5293, 179, 61, 1, 52, "Input"],
Cell[5357, 182, 109, 2, 52, "Input"],
Cell[5469, 186, 87, 3, 29, "Text"],
Cell[5559, 191, 32, 0, 29, "Text"],
Cell[5594, 193, 284, 6, 50, "Text"],
Cell[5881, 201, 117, 3, 29, "Text"],
Cell[6001, 206, 32, 0, 29, "Text"],
Cell[6036, 208, 232, 7, 29, "Text"],
Cell[6271, 217, 219, 7, 29, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[6539, 230, 51, 0, 35, "Section"],
Cell[6593, 232, 190, 4, 29, "Text"],
Cell[6786, 238, 121, 3, 29, "Text"],
Cell[6910, 243, 525, 11, 83, "Input",
  CellTags->"Proposition (ForAll Distributivity)"],
Cell[7438, 256, 189, 6, 52, "Input"],
Cell[7630, 264, 948, 22, 75, "Text"],
Cell[8581, 288, 249, 7, 52, "Input"],
Cell[8833, 297, 281, 5, 50, "Text"],
Cell[9117, 304, 358, 9, 72, "Input"],

Cell[CellGroupData[{
Cell[9500, 317, 49, 1, 52, "Input"],
Cell[9552, 320, 132, 2, 39, "Print"]
}, Closed]],

Cell[CellGroupData[{
Cell[9721, 327, 53, 1, 52, "Input"],
Cell[9777, 330, 116, 2, 39, "Print"]
}, Closed]],

Cell[CellGroupData[{
Cell[9930, 337, 57, 1, 52, "Input"],
Cell[9990, 340, 109, 2, 51, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[10136, 347, 46, 1, 52, "Input"],
Cell[10185, 350, 186, 3, 58, "Print"]
}, Closed]],
Cell[10386, 356, 92, 1, 52, "Input"],
Cell[10481, 359, 307, 8, 52, "Input"],
Cell[10791, 369, 326, 6, 50, "Text"],
Cell[11120, 377, 44, 1, 38, "Input"],
Cell[11167, 380, 145, 2, 52, "Input"],

Cell[CellGroupData[{
Cell[11337, 386, 47, 1, 52, "Input"],
Cell[11387, 389, 645, 9, 172, "Print"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[12081, 404, 79, 0, 35, "Section"],

Cell[CellGroupData[{
Cell[12185, 408, 45, 0, 39, "Subsection"],
Cell[12233, 410, 531, 14, 50, "Text"],
Cell[12767, 426, 442, 10, 78, "Input",
  CellTags->"Theorem (Sum of functions is commutative)"],
Cell[13212, 438, 444, 10, 107, "Input",
  CellTags->"Theory (Sum)"],
Cell[13659, 450, 473, 14, 52, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[14169, 469, 48, 0, 25, "Subsection"],
Cell[14220, 471, 341, 7, 50, "Text"],
Cell[14564, 480, 486, 10, 78, "Input",
  CellTags->"Definition (symmetric difference)"],
Cell[15053, 492, 527, 12, 72, "Input",
  CellTags->"Proposition (associativity of symmetric difference right)"],

Cell[CellGroupData[{
Cell[15605, 508, 407, 10, 72, "Input"],
Cell[16015, 520, 89, 1, 51, "Output"]
}, Closed]],
Cell[16119, 524, 249, 5, 41, "Input"],
Cell[16371, 531, 523, 12, 72, "Input",
  CellTags->"Proposition (associativity of symmetric difference left)"],

Cell[CellGroupData[{
Cell[16919, 547, 406, 10, 72, "Input"],
Cell[17328, 559, 89, 1, 51, "Output"]
}, Closed]],
Cell[17432, 563, 247, 5, 41, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[17728, 574, 41, 0, 35, "Section"],
Cell[17772, 576, 204, 4, 41, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[18013, 585, 53, 0, 35, "Section"],
Cell[18069, 587, 529, 11, 83, "Input",
  CellTags->"Proposition (ForAll Distributivity)"],

Cell[CellGroupData[{
Cell[18623, 602, 154, 4, 52, "Input"],
Cell[18780, 608, 89, 1, 51, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[18906, 614, 205, 4, 52, "Input"],
Cell[19114, 620, 89, 1, 51, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[19240, 626, 310, 6, 58, "Input"],
Cell[19553, 634, 89, 1, 51, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[19679, 640, 53, 1, 52, "Input"],
Cell[19735, 643, 116, 2, 39, "Print"]
}, Closed]],

Cell[CellGroupData[{
Cell[19888, 650, 57, 1, 52, "Input"],
Cell[19948, 653, 109, 2, 51, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[20094, 660, 46, 1, 52, "Input"],
Cell[20143, 663, 186, 3, 58, "Print"]
}, Closed]],

Cell[CellGroupData[{
Cell[20366, 671, 87, 1, 52, "Input"],
Cell[20456, 674, 658, 10, 89, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[21151, 689, 261, 5, 52, "Input"],
Cell[21415, 696, 89, 1, 51, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[21541, 702, 198, 4, 52, "Input"],
Cell[21742, 708, 89, 1, 51, "Output"]
}, Closed]],
Cell[21846, 712, 433, 8, 83, "Input",
  CellTags->"Theorem (Exists Distributivity)"],

Cell[CellGroupData[{
Cell[22304, 724, 76, 1, 52, "Input"],
Cell[22383, 727, 89, 1, 51, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[22509, 733, 215, 3, 52, "Input"],
Cell[22727, 738, 89, 1, 51, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[22853, 744, 215, 3, 38, "Input"],
Cell[23071, 749, 89, 1, 51, "Output"]
}, Closed]],
Cell[23175, 753, 468, 10, 83, "Input",
  CellTags->"Proposition (p1)"],

Cell[CellGroupData[{
Cell[23668, 767, 128, 3, 52, "Input"],
Cell[23799, 772, 89, 1, 51, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[23925, 778, 179, 4, 52, "Input"],
Cell[24107, 784, 89, 1, 51, "Output"]
}, Closed]],
Cell[24211, 788, 475, 10, 83, "Input",
  CellTags->"Proposition (p2)"],

Cell[CellGroupData[{
Cell[24711, 802, 128, 3, 52, "Input"],
Cell[24842, 807, 89, 1, 51, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[24968, 813, 186, 4, 52, "Input"],
Cell[25157, 819, 89, 1, 51, "Output"]
}, Closed]],
Cell[25261, 823, 504, 11, 83, "Input",
  CellTags->"Proposition (p3)"],

Cell[CellGroupData[{
Cell[25790, 838, 128, 3, 52, "Input"],
Cell[25921, 843, 89, 1, 51, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[26047, 849, 179, 4, 38, "Input"],
Cell[26229, 855, 89, 1, 51, "Output"]
}, Closed]],
Cell[26333, 859, 536, 11, 83, "Input",
  CellTags->"Proposition (p4)"],

Cell[CellGroupData[{
Cell[26894, 874, 128, 3, 52, "Input"],
Cell[27025, 879, 89, 1, 51, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[27151, 885, 179, 4, 38, "Input"],
Cell[27333, 891, 89, 1, 51, "Output"]
}, Closed]],
Cell[27437, 895, 532, 11, 83, "Input",
  CellTags->"Proposition (p5)"],

Cell[CellGroupData[{
Cell[27994, 910, 128, 3, 52, "Input"],
Cell[28125, 915, 89, 1, 51, "Output"]
}, Closed]],
Cell[28229, 919, 552, 12, 83, "Input",
  CellTags->"Proposition (p6)"],

Cell[CellGroupData[{
Cell[28806, 935, 128, 3, 52, "Input"],
Cell[28937, 940, 89, 1, 51, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[29075, 947, 46, 0, 35, "Section"],

Cell[CellGroupData[{
Cell[29146, 951, 30, 0, 31, "Subsubsection"],
Cell[29179, 953, 335, 8, 62, "Input",
  CellTags->"Proposition (Equal Reflexivity)"],
Cell[29517, 963, 427, 10, 64, "Input",
  CellTags->"Proposition (Equal Symmetry)"],
Cell[29947, 975, 474, 10, 64, "Input",
  CellTags->"Proposition (Equal Transitivity)"],
Cell[30424, 987, 549, 12, 69, "Input",
  CellTags->"Proposition (Equal Transitivity \[ForAll])"],
Cell[30976, 1001, 458, 13, 38, "Input"],

Cell[CellGroupData[{
Cell[31459, 1018, 529, 14, 38, "Input"],
Cell[31991, 1034, 248, 5, 39, "Print"]
}, Closed]],

Cell[CellGroupData[{
Cell[32276, 1044, 232, 4, 58, "Input"],
Cell[32511, 1050, 89, 1, 51, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[32637, 1056, 207, 3, 38, "Input"],
Cell[32847, 1061, 89, 1, 51, "Output"]
}, Closed]],
Cell[32951, 1065, 714, 20, 89, "Input",
  CellTags->"Theory (Equal)"]
}, Closed]],

Cell[CellGroupData[{
Cell[33702, 1090, 29, 0, 23, "Subsubsection"],
Cell[33734, 1092, 358, 8, 62, "Input",
  CellTags->"Proposition (Less Irreflexivity)"],
Cell[34095, 1102, 468, 10, 64, "Input",
  CellTags->"Proposition (Less Antisymmetry)"],

Cell[CellGroupData[{
Cell[34588, 1116, 398, 11, 38, "Input"],
Cell[34989, 1129, 89, 1, 37, "Output"]
}, Open  ]],
Cell[35093, 1133, 484, 10, 64, "Input",
  CellTags->"Proposition (Less Transitivity)"],

Cell[CellGroupData[{
Cell[35602, 1147, 634, 17, 38, "Input"],
Cell[36239, 1166, 89, 1, 37, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36365, 1172, 713, 19, 58, "Input"],
Cell[37081, 1193, 89, 1, 37, "Output"]
}, Open  ]],
Cell[37185, 1197, 732, 21, 89, "Input",
  CellTags->"Theory (Less)"]
}, Closed]],

Cell[CellGroupData[{
Cell[37954, 1223, 39, 0, 23, "Subsubsection"],
Cell[37996, 1225, 460, 10, 64, "Input",
  CellTags->"Proposition (Equal not Less)"],
Cell[38459, 1237, 466, 10, 64, "Input",
  CellTags->"Proposition (Equal not Greater)"],
Cell[38928, 1249, 118, 2, 38, "Input"],

Cell[CellGroupData[{
Cell[39071, 1255, 621, 17, 38, "Input"],
Cell[39695, 1274, 89, 1, 37, "Output"]
}, Open  ]],
Cell[39799, 1278, 448, 10, 64, "Input",
  CellTags->"Proposition (Less and Equal Totality)"],
Cell[40250, 1290, 743, 20, 89, "Input",
  CellTags->"Theory (Equal versus Less)"],
Cell[40996, 1312, 677, 19, 89, "Input",
  CellTags->"Theory (Equal and Less)"],
Cell[41676, 1333, 511, 11, 64, "Input",
  CellTags->"Proposition (Less and Equal Transitivity)"],

Cell[CellGroupData[{
Cell[42212, 1348, 491, 13, 38, "Input"],
Cell[42706, 1363, 691, 12, 58, "Print"],
Cell[43400, 1377, 121, 2, 37, "Output"]
}, Open  ]],
Cell[43536, 1382, 256, 7, 92, "Text"],
Cell[43795, 1391, 620, 16, 29, "Text"],
Cell[44418, 1409, 44, 1, 38, "Input"],
Cell[44465, 1412, 507, 11, 64, "Input",
  CellTags->"Proposition (Equal and Less Transitivity)"],

Cell[CellGroupData[{
Cell[44997, 1427, 491, 13, 38, "Input"],
Cell[45491, 1442, 691, 12, 58, "Print"],
Cell[46185, 1456, 122, 2, 51, "Output"]
}, Closed]],
Cell[46322, 1461, 214, 4, 29, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[46573, 1470, 36, 0, 23, "Subsubsection"],
Cell[46612, 1472, 523, 11, 64, "Input",
  CellTags->"Definition (LessOrEqual Def)"],
Cell[47138, 1485, 388, 9, 62, "Input",
  CellTags->"Proposition (LessOrEqual Reflexivity)"],

Cell[CellGroupData[{
Cell[47551, 1498, 715, 19, 58, "Input"],
Cell[48269, 1519, 89, 1, 37, "Output"]
}, Open  ]],
Cell[48373, 1523, 557, 11, 64, "Input",
  CellTags->"Proposition (LessOrEqual Antisymmetry)"],

Cell[CellGroupData[{
Cell[48955, 1538, 798, 21, 58, "Input"],
Cell[49756, 1561, 89, 1, 37, "Output"]
}, Open  ]],
Cell[49860, 1565, 570, 11, 64, "Input",
  CellTags->"Proposition (LessOrEqual Transitivity)"],

Cell[CellGroupData[{
Cell[50455, 1580, 737, 19, 58, "Input"],
Cell[51195, 1601, 455, 8, 39, "Print"],
Cell[51653, 1611, 110, 2, 37, "Output"]
}, Open  ]],
Cell[51778, 1616, 201, 4, 29, "Text"],
Cell[51982, 1622, 992, 27, 107, "Input",
  CellTags->"Theory (Transitivity of Equal and of Less)"],

Cell[CellGroupData[{
Cell[52999, 1653, 770, 20, 58, "Input"],
Cell[53772, 1675, 122, 2, 37, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[53943, 1683, 35, 0, 23, "Subsubsection"],
Cell[53981, 1685, 568, 12, 64, "Input",
  CellTags->"Definition (Congruence Def by LessOrEqual)"],
Cell[54552, 1699, 363, 8, 62, "Input",
  CellTags->"Proposition (Congruence Reflexivity)"],

Cell[CellGroupData[{
Cell[54940, 1711, 655, 17, 58, "Input"],
Cell[55598, 1730, 89, 1, 37, "Output"]
}, Open  ]],
Cell[55702, 1734, 481, 10, 64, "Input",
  CellTags->"Proposition (Congruence Symmetry)"],

Cell[CellGroupData[{
Cell[56208, 1748, 456, 13, 38, "Input"],
Cell[56667, 1763, 89, 1, 37, "Output"]
}, Open  ]],
Cell[56771, 1767, 582, 12, 64, "Input",
  CellTags->"Proposition (Congruence Transitivity)"],

Cell[CellGroupData[{
Cell[57378, 1783, 737, 19, 58, "Input"],
Cell[58118, 1804, 121, 2, 37, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[58300, 1813, 37, 0, 35, "Section"],

Cell[CellGroupData[{
Cell[58362, 1817, 40, 0, 31, "Subsubsection"],
Cell[58405, 1819, 165, 4, 29, "Text"],

Cell[CellGroupData[{
Cell[58595, 1827, 459, 10, 69, "Input",
  CellTags->"Definition (2-ary limit)"],
Cell[59057, 1839, 183, 3, 22, "Message"]
}, Open  ]],
Cell[59255, 1845, 477, 10, 69, "Input",
  CellTags->"Definition (3-ary limit)"],
Cell[59735, 1857, 661, 14, 69, "Input",
  CellTags->"Definition (4-ary limit)"],
Cell[60399, 1873, 36, 0, 29, "Text"],
Cell[60438, 1875, 425, 11, 58, "Input",
  CellTags->"Definition (sum of sequences)"],
Cell[60866, 1888, 760, 17, 58, "Input",
  CellTags->"Proposition (distance of sum)"],

Cell[CellGroupData[{
Cell[61651, 1909, 468, 11, 58, "Input",
  CellTags->"Proposition (max)"],
Cell[62122, 1922, 179, 3, 22, "Message"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[62350, 1931, 31, 0, 23, "Subsubsection"],
Cell[62384, 1933, 455, 11, 107, "Input",
  CellTags->"Theory (4-ary limit)"],
Cell[62842, 1946, 44, 0, 29, "Text"],
Cell[62889, 1948, 466, 11, 82, "Input",
  CellTags->"Proposition (2-ary limit of sum)"],
Cell[63358, 1961, 168, 4, 29, "Text"],
Cell[63529, 1967, 627, 13, 91, "Input",
  CellTags->"Proposition (4-ary limit of sum)"],

Cell[CellGroupData[{
Cell[64181, 1984, 268, 6, 38, "Input"],
Cell[64452, 1992, 121, 2, 37, "Output"]
}, Open  ]],
Cell[64588, 1997, 196, 4, 29, "Text"],
Cell[64787, 2003, 140, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[64952, 2010, 82, 1, 38, "Input"],
Cell[65037, 2013, 153, 2, 37, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[65227, 2020, 117, 2, 38, "Input"],
Cell[65347, 2024, 89, 1, 37, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[65473, 2030, 43, 1, 38, "Input"],
Cell[65519, 2033, 208, 3, 58, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[65764, 2041, 122, 2, 38, "Input"],
Cell[65889, 2045, 89, 1, 37, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[66027, 2052, 31, 0, 23, "Subsubsection"],
Cell[66061, 2054, 362, 9, 71, "Input",
  CellTags->"Theory (3-ary limit)"],
Cell[66426, 2065, 602, 12, 91, "Input",
  CellTags->"Proposition (3-ary limit of sum)"],
Cell[67031, 2079, 283, 8, 38, "Input"],
Cell[67317, 2089, 44, 1, 38, "Input"],
Cell[67364, 2092, 196, 4, 29, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[67597, 2101, 31, 0, 23, "Subsubsection"],
Cell[67631, 2103, 631, 14, 91, "Input",
  CellTags->"Proposition (3-ary limit of sum: variant)"],
Cell[68265, 2119, 371, 9, 71, "Input",
  CellTags->"Theory (2-ary limit)"],
Cell[68639, 2130, 485, 10, 91, "Input",
  CellTags->"Proposition (2-ary limit of sum)"],

Cell[CellGroupData[{
Cell[69149, 2144, 302, 7, 38, "Input"],
Cell[69454, 2153, 121, 2, 51, "Output"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

