(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    114759,       3378]*)
(*NotebookOutlinePosition[    153924,       4293]*)
(*  CellTagsIndexPosition[    150678,       4202]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Demo: Propositional Proving", "Title"],

Cell["\<\
(Double-click on the vertical bars in order to open/close the \
sections)\
\>", "Text"],

Cell[CellGroupData[{

Cell["Starting the System", "Section"],

Cell[TextData[{
  "The following command will load the Theorema system. (Click on the command \
and press ",
  StyleBox["\[LeftAngleBracket]Shift\[RightAngleBracket]\[LeftAngleBracket]\
Enter\[RightAngleBracket]",
    FontWeight->"Bold"],
  " in order to execute it.)"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(<< Theorema`\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \("You can specify your personal preferences in a file `Setup.m` in the \
directory (folder) \"Theorema -> User\" in your private Theorema \
directory!"\)], "Print"]
}, Open  ]],

Cell[TextData[{
  "The following command sets the PropositionalProver as the default prover \
to be used in the command ",
  StyleBox["Prove",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[
    \(SetGlobals[Prover \[Rule] PropositionalProver]\)], "Input"],

Cell["\<\
Each of the following commands controls the appearance of the \
labels in the generated proofs.\
\>", "Text"],

Cell[BoxData[
    \(SetGlobals[LabelStyle \[Rule] "\<Alphanumeric\>"]\)], "Input"],

Cell[BoxData[
    \(SetGlobals[LabelStyle \[Rule] "\<Numeric\>"]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Using the Prover and its Options", "Section"],

Cell[CellGroupData[{

Cell["Using the Prover", "Subsection"],

Cell[TextData[{
  "By using the palette ",
  StyleBox["FormalTextLanguage",
    FontSlant->"Italic"],
  " (menu ",
  StyleBox["File/Palettes",
    FontSlant->"Italic"],
  "), you can define new propositions as follows:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<conclusion\>\"", ",", "\n", "\t", GridBox[{
            {\(\((A \[And] B \[And] C)\)\[DoubleLongLeftRightArrow]A\), 
              "\"\<abc\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->"Proposition (conclusion)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<assumptions\>\"", ",", "\n", "\t", GridBox[{
            {\(A\[DoubleLongRightArrow]B\), "\"\<ab\>\""},
            {"C", "\"\<c\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->"Proposition (assumptions)"],

Cell[TextData[{
  "(The logical connectives can be typed using the palette ",
  StyleBox["CompleteCharacters/Operators",
    FontSlant->"Italic"],
  " or using the ",
  StyleBox["Escape",
    FontSlant->"Italic"],
  " key: ",
  StyleBox["\[LeftAngleBracket]ESC\[RightAngleBracket]not\[LeftAngleBracket]\
ESC\[RightAngleBracket]",
    FontWeight->"Bold"],
  ", ",
  StyleBox["\[LeftAngleBracket]ESC\[RightAngleBracket]and\[LeftAngleBracket]\
ESC\[RightAngleBracket]",
    FontWeight->"Bold"],
  ", ",
  StyleBox["\[LeftAngleBracket]ESC\[RightAngleBracket]or\[LeftAngleBracket]\
ESC\[RightAngleBracket]",
    FontWeight->"Bold"],
  ", ",
  StyleBox["\[LeftAngleBracket]ESC\[RightAngleBracket]==>\[LeftAngleBracket]\
ESC\[RightAngleBracket]",
    FontWeight->"Bold"],
  ", ",
  StyleBox["\[LeftAngleBracket]ESC\[RightAngleBracket]<==>\[LeftAngleBracket]\
ESC\[RightAngleBracket]",
    FontWeight->"Bold"],
  ".)"
}], "Text"],

Cell["The following command generates the proof:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Prove[Proposition["\<conclusion\>"], 
      using \[Rule] Proposition["\<assumptions\>"], 
      by \[Rule] PropositionalProver]\)], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Open  ]],

Cell[BoxData[
    ButtonBox[\(\(\[LongRightArrow]\)\(\ \)\(proof\)\),
      ButtonData:>{
        FrontEnd`FileName[ {"PropositionalProofs"}, "01-simple-example.nb", 
          CharacterEncoding -> "ISO8859-1"], None},
      ButtonStyle->"Hyperlink"]], "Input"],

Cell[TextData[{
  "(The arrow \"\[Rule]\" can be  typed as ",
  StyleBox["\[LeftAngleBracket]ESC\[RightAngleBracket]->\[LeftAngleBracket]\
ESC\[RightAngleBracket]",
    FontWeight->"Bold"],
  ".)"
}], "Text"],

Cell[TextData[{
  "The proof is presented in a separate notebook and the structure of the \
proof is represented by the nesting of the cells indicated by the vertical \
bars on the right-hand side. By double-click on such a bar you can open/close \
the respective group of cells. Select the topmost cell by single-click on the \
rightmost vertical bar, then press ",
  StyleBox["\[LeftAngleBracket]Alt\[RightAngleBracket] } ",
    FontWeight->"Bold"],
  "(on Windows ",
  StyleBox["\[LeftAngleBracket]Ctrl\[RightAngleBracket] }",
    FontWeight->"Bold"],
  ") in order to close all  the subcells, then open various groups of cells \
for studying the proof at the desired level of detail."
}], "Text"],

Cell["\<\
If the following command has already been executed in this session:\
\
\>", "Text"],

Cell[BoxData[
    \(SetGlobals[Prover \[Rule] PropositionalProver]\)], "Input"],

Cell[TextData[{
  "then the prover does not have to be specified in the ",
  StyleBox["Prove",
    FontWeight->"Bold"],
  " command:"
}], "Text"],

Cell[BoxData[
    \(Prove[Proposition["\<conclusion\>"], 
      using \[Rule] Proposition["\<assumptions\>"]]\)], "Input"],

Cell["\<\
The option \"using\[Rule] \[Ellipsis]\" may also be missing if no \
assumptions are needed for the proof:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<independent\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\((A\[DoubleLongRightArrow]B)\) \[And] 
                    C)\)\[DoubleLongRightArrow]\((\((A \[And] B \[And] 
                        C)\)\[DoubleLongLeftRightArrow]A)\)\), "\"\<abc\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->"Proposition (independent)"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Prove[Proposition["\<independent\>"]]\)], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Open  ]],

Cell[BoxData[
    ButtonBox[\(\(\[LongRightArrow]\)\(\ \)\(proof\)\),
      ButtonData:>{
        FrontEnd`FileName[ {"PropositionalProofs"}, "02-independent.nb", 
          CharacterEncoding -> "ISO8859-1"], None},
      ButtonStyle->"Hyperlink"]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options of the Propositional Prover", "Subsection"],

Cell["\<\
The behavior of the propositional prover can be controlled by \
options, which are listed by the  command:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[PropositionalProver]\)], "Input"],

Cell[OutputFormData["\<\
{TryAlternatives -> False, BackChaining -> False, 
 BackChainingDisjunction -> False, BackChainingImplication -> False, 
 BackChainingEquivalence -> False, TrySubgoalDisjunction -> False, 
 TrySubgoalImplication -> False, TrySubgoalEquivalence -> False, 
 TrySubgoal -> False}\
\>", "\<\
{TryAlternatives -> False, BackChaining -> \
False, 
 
  BackChainingDisjunction -> False, BackChainingImplication -> False, 
 
  BackChainingEquivalence -> False, TrySubgoalDisjunction -> False, 
 
  TrySubgoalImplication -> False, TrySubgoalEquivalence -> False, 
 
  TrySubgoal -> False}\
\>"], "Output"]
}, Open  ]],

Cell["\<\
The meaning of the options can be found out by commands like:\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?BackChaining\)\)], "Input"],

Cell["\<\
Option of PPND (PropositionalProver, PredicateProvers), if set to \
True the
   prover will try to back chain on goal for assumed disjunctions,
\t\timplications, and equivalences. One can also use BackChainingDisjunction,
   BackChainingImplication, and BackChainingEquivalence.\
\>", "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?TrySubgoalImplication\)\)], "Input"],

Cell["\<\
Option of PPND (PropositionalProver, PredicateProvers), if set to \
True the
   prover will try to back chain on assumed implications.\
\>", "Print"]
}, Open  ]],

Cell[TextData[{
  "All the options are set to ",
  StyleBox["False",
    FontWeight->"Bold"],
  " by default. Setting such an option to ",
  StyleBox["True",
    FontWeight->"Bold"],
  " will  create  several proof alternatives: some of them may fail, but when \
they succeed they may lead to more natural proofs. Example:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<disjunction\>\"", ",", "\n", "\t", GridBox[{
            {\(\((P \[And] 
                    Q \[And] \((P \[And] Q)\)\[DoubleLongRightArrow]
                      R)\)\[DoubleLongRightArrow]\((A \[Or] R \[Or] B)\)\), 
              "\"\<p\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->"Proposition (disjunction)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<disjunction\>"]\), 
      "]"}]], "Input",
  CellTags->{"disjunction", "p"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<disjunction\>"], 
      ProverOptions \[Rule] {TryAlternatives \[Rule] True, 
          BackChaining \[Rule] True}\), "]"}]], "Input",
  CellTags->{"disjunction", "p"}],

Cell["\<\
The proof generated by the previous command has failed branches and \
pending branches. One can display only the successful branches using the \
options for the simplification of proofs - see below.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options for the Simplification of Proofs", "Subsection"],

Cell["\<\
The proof presented in the previous paragraph contains branches \
which are not necessary for the success. The following command results in a \
proof whithout unnecessary branches.\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<disjunction\>\"", ",", "\n", "\t", GridBox[{
            {\(\((P \[And] 
                    Q \[And] \((P \[And] Q)\)\[DoubleLongRightArrow]
                      R)\)\[DoubleLongRightArrow]\((A \[Or] R \[Or] B)\)\), 
              "\"\<p\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"disjunction", "Iterated Implication", "p"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<disjunction\>"], 
      transformBy -> ProofSimplifier, 
      TransformerOptions \[Rule] {branches -> Proved}, 
      ProverOptions \[Rule] {TryAlternatives \[Rule] True, 
          BackChaining \[Rule] True}\), "]"}]], "Input",
  CellTags->"p"],

Cell[TextData[{
  "The option ",
  StyleBox["transformBy", "Input"],
  " indicates which operation is performed on the resulting proof-object."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"?", 
      StyleBox["transformBy",
        "Input"]}]], "Input"],

Cell["\<\
An option for Prove/Compute/Simplify/Solve that specifies the \
transformation
   method to be used.\
\>", "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[Prove]\)], "Input"],

Cell[OutputFormData["\<\
{using -> \[Bullet]kb[\"None\", \[Bullet]range[], \
True, \[Bullet]flist[]], 
 built\[Dash]in -> \[Bullet]bui[\"None\", \[Bullet]range[], True, \
\[Bullet]flist[]], 
 by :> $TmaDefaultProver, ProverOptions :> {}, transformBy -> Identity, 
 TransformerOptions -> {}, showBy -> StaticWriter, ShowOptions -> {}, 
 SearchDepth -> Default, formal\[Dash]object :> $TmaDefaultProofObject, 
 SearchMethod -> Default, ExpandKnowledge -> False, 
 LabelStyle :> $TmaDefaultLabelStyle}\
\>", "\<\
{using -> \[Bullet]kb[None, \
\[Bullet]range[], True, \[Bullet]flist[]], 
 
  built\[Dash]in -> \[Bullet]bui[None, \[Bullet]range[], True, \
\[Bullet]flist[]], by :> $TmaDefaultProver, 
 
  ProverOptions :> {}, transformBy -> Identity, TransformerOptions -> {}, 
 
  showBy -> StaticWriter, ShowOptions -> {}, SearchDepth -> Default, 
 
  formal\[Dash]object :> $TmaDefaultProofObject, SearchMethod -> Default, 
 
  ExpandKnowledge -> False, LabelStyle :> $TmaDefaultLabelStyle}\
\>"], \
"Output"]
}, Open  ]],

Cell[TextData[{
  "Setting ",
  StyleBox["transformBy->ProofSimplifier", "Input"],
  "  results in simplifying the proof-object before display."
}], "Text"],

Cell[TextData[{
  "The option ",
  StyleBox["transformBy", "Input"],
  " indicates which operation is done on the resulting proof-object. \
Furthermore the option ",
  StyleBox["TransformerOptions", "Input"],
  " of the command ",
  StyleBox["Prove", "Input"],
  " will be passed to  ",
  StyleBox["ProofSimplifier", "Input"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[ProofSimplifier]\)], "Input"],

Cell[OutputFormData["\<\
{branches -> All, steps -> All, substitutions -> \
All}\
\>", "\<\
{branches -> All, steps -> All, substitutions -> All}\
\>"], \
"Output"]
}, Open  ]],

Cell["\<\
For instance, branches controls the number of branches which are \
displayed.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?branches\)\)], "Input"],

Cell["\<\
Option of ProofSimplifier with possible values: Proved, Pending, \
Failed,
   Disproved and list combinations of these. All (default) means list of all.\
\
\>", "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?steps\)\)], "Input"],

Cell["\<\
Option of ProofSimplifier with possible values: All, Essential, \
Combined,
   Useful, SequentialCombined, DistributedCombined, LiftedParallel and list
   combinations of these.\
\>", "Print"]
}, Open  ]],

Cell["In order to simplify proofs by all available methods use:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetOptions[Prove, transformBy -> ProofSimplifier, 
      TransformerOptions \[Rule] {steps -> Essential}]\)], "Input"],

Cell[OutputFormData["\<\
{using -> \[Bullet]kb[\"None\", \[Bullet]range[], \
True, \[Bullet]flist[]], 
 built\[Dash]in -> \[Bullet]bui[\"None\", \[Bullet]range[], True, \
\[Bullet]flist[]], 
 by :> $TmaDefaultProver, ProverOptions :> {}, 
 transformBy -> ProofSimplifier, TransformerOptions -> {steps -> Essential}, 
 showBy -> StaticWriter, ShowOptions -> {}, SearchDepth -> Default, 
 formal\[Dash]object :> $TmaDefaultProofObject, SearchMethod -> Default, 
 ExpandKnowledge -> False, LabelStyle :> $TmaDefaultLabelStyle}\
\>", \
"\<\
{using -> \[Bullet]kb[None, \[Bullet]range[], True, \[Bullet]flist[]], 
 
  built\[Dash]in -> \[Bullet]bui[None, \[Bullet]range[], True, \
\[Bullet]flist[]], by :> $TmaDefaultProver, 
 
  ProverOptions :> {}, transformBy -> ProofSimplifier, 
 
  TransformerOptions -> {steps -> Essential}, showBy -> StaticWriter, 
 
  ShowOptions -> {}, SearchDepth -> Default, 
 
  formal\[Dash]object :> $TmaDefaultProofObject, SearchMethod -> Default, 
 
  ExpandKnowledge -> False, LabelStyle :> $TmaDefaultLabelStyle}\
\>"], \
"Output"]
}, Closed]],

Cell[TextData[{
  "In fact one does not need to repeat the ",
  StyleBox["Prove", "Input"],
  " command in order to see varios versions of the simplified proof. After a \
",
  StyleBox["Prove", "Input"],
  " is executed, the proof-object is returned as the result of the command, \
and also stored in the global variable ",
  StyleBox["$TmaProofObject", "Input"],
  ". The proof-object can be shown as proof-notebook using ",
  StyleBox["ProofShow", "Input"],
  " and can be simplified using ",
  StyleBox["ProofSimplifier", "Input"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \($TmaProofObject\)], "Input"],

Cell[OutputFormData["\<\
Theorema`Provers`Common`ProofObject`Private`AndNode[
 Theorema`Provers`Common`ProofObject`Private`ProofInfo[
  \"InitialProofSituation\", \[Bullet]lf[\"Proposition (disjunction): p\", 
   \[Trademark]Implies[\[Trademark]And[P, Q, \
\[Trademark]Implies[\[Trademark]And[P, Q], R]], \[Trademark]Or[A, R, B]], 
   \[Bullet]finfo[]], \[Bullet]asml[]], 
 Theorema`Provers`Common`ProofObject`Private`Subgoals[
  Theorema`Provers`Common`ProofObject`Private`AndNode[
   Theorema`Provers`Common`ProofObject`Private`ProofInfo[\"ProveImplication\",\
 
    \[Bullet]usedFormulae[\"Proposition (disjunction): p\"], 
    \[Bullet]generatedFormulae[\[Bullet]lf[\"1\", \[Trademark]And[P, Q, \
\[Trademark]Implies[\[Trademark]And[P, Q], 
        R]], \[Bullet]finfo[]], \[Bullet]lf[\"2\", \[Trademark]Or[A, R, B], \
\[Bullet]finfo[]]]], 
   Theorema`Provers`Common`ProofObject`Private`Subgoals[
    Theorema`Provers`Common`ProofObject`Private`AndNode[
     Theorema`Provers`Common`ProofObject`Private`ProofInfo[
      \"AssumptionIsConjunction\", \[Bullet]usedFormulae[\"1\"], 
      \[Bullet]generatedFormulae[\[Bullet]lf[\"1.1\", P, \[Bullet]finfo[]], 
       \[Bullet]lf[\"1.2\", Q, \[Bullet]finfo[]], \[Bullet]lf[\"1.3\", \
\[Trademark]Implies[\[Trademark]And[P, Q], R], 
        \[Bullet]finfo[]]]], \
Theorema`Provers`Common`ProofObject`Private`Subgoals[
      Theorema`Provers`Common`ProofObject`Private`OrNode[
       Theorema`Provers`Common`ProofObject`Private`ProofInfo[
        \"ProveDisjunctionAlternatives\", \[Bullet]usedFormulae[\"2\"], 
        \[Bullet]generatedFormulae[]], 
       Theorema`Provers`Common`ProofObject`Private`Subgoals[
        Theorema`Provers`Common`ProofObject`Private`AndNode[
         Theorema`Provers`Common`ProofObject`Private`ProofInfo[
          \"TryDisjunctionOperand\", \[Bullet]usedFormulae[\"2\"], \
\[Bullet]generatedFormulae[
           \[Bullet]lf[\"4\", A, \[Bullet]finfo[]]]], 
         Theorema`Provers`Common`ProofObject`Private`Subgoals[
          Theorema`Provers`Common`ProofObject`Private`AndNode[
           Theorema`Provers`Common`ProofObject`Private`ProofInfo[
            \"TransformImplication\", \[Bullet]usedFormulae[\"1.3\"], 
            \[Bullet]generatedFormulae[\[Bullet]lf[\"9\", \[Trademark]Or[\
\[Trademark]Not[\[Trademark]And[P, Q]], R], 
              \[Bullet]finfo[]]]], 
           Theorema`Provers`Common`ProofObject`Private`Subgoals[
            Theorema`Provers`Common`ProofObject`Private`AndNode[
             Theorema`Provers`Common`ProofObject`Private`ProofInfo[
              \"CaseDistinction\", \[Bullet]usedFormulae[\"4\", \"9\"], 
              \[Bullet]generatedFormulae[\[Bullet]lf[\"9.1\", \
\[Trademark]Not[\[Trademark]And[P, Q]], 
                \[Bullet]finfo[]], \[Bullet]lf[\"9.2\", R, \
\[Bullet]finfo[]]]], 
             Theorema`Provers`Common`ProofObject`Private`Subgoals[
              Theorema`Provers`Common`ProofObject`Private`AndNode[
               Theorema`Provers`Common`ProofObject`Private`ProofInfo[
                \"AssumptionIsNegatedConjunction\", \
\[Bullet]usedFormulae[\"9.1\"], 
                \[Bullet]generatedFormulae[\[Bullet]lf[\"10\", \
\[Trademark]Or[\[Trademark]Not[P], \[Trademark]Not[Q]], 
                  \[Bullet]finfo[]]]], 
               Theorema`Provers`Common`ProofObject`Private`Subgoals[
                Theorema`Provers`Common`ProofObject`Private`AndNode[
                 Theorema`Provers`Common`ProofObject`Private`ProofInfo[
                  \"Resolution\", \[Bullet]usedFormulae[\"1.1\", \"10\"], 
                  \[Bullet]generatedFormulae[\[Bullet]lf[\"11\", \
\[Trademark]Not[Q], \[Bullet]finfo[]]]], 
                 Theorema`Provers`Common`ProofObject`Private`Subgoals[
                  Theorema`Provers`Common`ProofObject`Private`AndNode[
                   Theorema`Provers`Common`ProofObject`Private`ProofInfo[
                    \"ContradictoryAssumptions\", \[Bullet]usedFormulae[\"1.2\
\", \"11\"], 
                    \[Bullet]generatedFormulae[], \"4\"], 
                   Theorema`Provers`Common`ProofObject`Private`Subgoals[], 
                   Theorema`Provers`Common`ProofObject`Private`Constraints[], \

                   \"proved\"]], 
                 Theorema`Provers`Common`ProofObject`Private`Constraints[], 
                 \"proved\"]], 
               Theorema`Provers`Common`ProofObject`Private`Constraints[], 
               \"proved\"], \
Theorema`Provers`Common`ProofObject`Private`AndNode[
               Theorema`Provers`Common`ProofObject`Private`ProofInfo[
                \"NoApplicableProver\", \"4\"], 
               Theorema`Provers`Common`ProofObject`Private`Subgoals[], 
               Theorema`Provers`Common`ProofObject`Private`MainProofSituation[\

                \[Bullet]lf[\"4\", A, \[Bullet]finfo[]], \[Bullet]asml[\
\[Bullet]lf[\"1.1\", P, 
                  \[Bullet]finfo[]], \[Bullet]lf[\"1.2\", Q, \
\[Bullet]finfo[]], \[Bullet]lf[\"9.2\", R, 
                  \[Bullet]finfo[]]], \[Bullet]lkTab[{{\"PPND\", \
\[Bullet]lkTab[{}]}, 
                  {\"ProversHistory\", {PPND, PPND, PPND, PPND, PPND}}}]], 
               Theorema`Provers`Common`ProofObject`Private`Constraints[], 
               \"failed\"]], 
             Theorema`Provers`Common`ProofObject`Private`Constraints[], 
             \"failed\"]], 
           Theorema`Provers`Common`ProofObject`Private`Constraints[], 
           \"failed\"]], 
         Theorema`Provers`Common`ProofObject`Private`Constraints[], 
         \"failed\"], Theorema`Provers`Common`ProofObject`Private`AndNode[
         Theorema`Provers`Common`ProofObject`Private`ProofInfo[
          \"TryDisjunctionOperand\", \[Bullet]usedFormulae[\"2\"], \
\[Bullet]generatedFormulae[
           \[Bullet]lf[\"5\", R, \[Bullet]finfo[]]]], 
         Theorema`Provers`Common`ProofObject`Private`Subgoals[
          Theorema`Provers`Common`ProofObject`Private`OrNode[
           Theorema`Provers`Common`ProofObject`Private`ProofInfo[
            \"GoalIsRHSofImplication\", \[Bullet]usedFormulae[\"5\", \
\"1.3\"], 
            \[Bullet]generatedFormulae[]], 
           Theorema`Provers`Common`ProofObject`Private`Subgoals[
            Theorema`Provers`Common`ProofObject`Private`AndNode[
             Theorema`Provers`Common`ProofObject`Private`ProofInfo[
              \"BackChainingImplication\", \[Bullet]usedFormulae[\"5\", \"1.3\
\"], 
              \[Bullet]generatedFormulae[\[Bullet]lf[\"13\", \
\[Trademark]And[P, Q], \[Bullet]finfo[]]]], 
             Theorema`Provers`Common`ProofObject`Private`Subgoals[
              Theorema`Provers`Common`ProofObject`Private`AndNode[
               Theorema`Provers`Common`ProofObject`Private`ProofInfo[
                \"ProveConjunction\", \[Bullet]usedFormulae[\"13\"], 
                \[Bullet]generatedFormulae[\[Bullet]lf[\"13.1\", P, \
\[Bullet]finfo[]], 
                 \[Bullet]lf[\"13.2\", Q, \[Bullet]finfo[]]]], 
               Theorema`Provers`Common`ProofObject`Private`Subgoals[
                Theorema`Provers`Common`ProofObject`Private`AndNode[
                 Theorema`Provers`Common`ProofObject`Private`ProofInfo[
                  \"ConclusionIsAssumption\", \[Bullet]usedFormulae[\"13.1\", \
\"1.1\"], 
                  \[Bullet]generatedFormulae[]], 
                 Theorema`Provers`Common`ProofObject`Private`Subgoals[], 
                 Theorema`Provers`Common`ProofObject`Private`Constraints[], 
                 \"proved\"], 
                Theorema`Provers`Common`ProofObject`Private`AndNode[
                 Theorema`Provers`Common`ProofObject`Private`ProofInfo[
                  \"ConclusionIsAssumption\", \[Bullet]usedFormulae[\"13.2\", \
\"1.2\"], 
                  \[Bullet]generatedFormulae[]], 
                 Theorema`Provers`Common`ProofObject`Private`Subgoals[], 
                 Theorema`Provers`Common`ProofObject`Private`Constraints[], 
                 \"proved\"]], 
               Theorema`Provers`Common`ProofObject`Private`Constraints[
                \[Bullet]sl[]], \"proved\"]], 
             Theorema`Provers`Common`ProofObject`Private`Constraints[
              \[Bullet]sl[]], \"proved\"], 
            Theorema`Provers`Common`ProofObject`Private`AndNode[
             Theorema`Provers`Common`ProofObject`Private`ProofInfo[
              \"SimplifyImplicationLHS\", \[Bullet]usedFormulae[\"5\", \
\"1.3\"], 
              \[Bullet]generatedFormulae[\[Bullet]lf[\"12\", \[Trademark]Not[\
\[Trademark]And[P, Q]], 
                \[Bullet]finfo[]]]], 
             Theorema`Provers`Common`ProofObject`Private`Subgoals[
              Theorema`Provers`Common`ProofObject`Private`ProofSituation[
               \[Bullet]lf[\"5\", R, \[Bullet]finfo[]], \[Bullet]asml[\
\[Bullet]lf[\"1.1\", P, 
                 \[Bullet]finfo[]], \[Bullet]lf[\"1.2\", Q, \
\[Bullet]finfo[]], \[Bullet]lf[\"12\", 
                 \[Trademark]Not[\[Trademark]And[P, Q]], \[Bullet]finfo[]]], \
\[Bullet]lkTab[
                {{\"PPND\", \[Bullet]lkTab[{}]}, {\"ProversHistory\", {PPND, \
PPND, 
                   PPND}}, {\"LastProver\", PPND}}], \"pending\"]], 
             Theorema`Provers`Common`ProofObject`Private`Constraints[], 
             \"pending\"]], 
           Theorema`Provers`Common`ProofObject`Private`Constraints[
            \[Bullet]sl[\[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, \
1, 2, 1, 2, 2, 2, 1, 2, 
                2}], \[Bullet]rstrs[]]]], \"proved\"]], 
         Theorema`Provers`Common`ProofObject`Private`Constraints[
          \[Bullet]sl[\[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, \
1, 2, 1, 2, 2, 2, 1, 2, 
              2}], \[Bullet]rstrs[]]]], \"proved\"], 
        Theorema`Provers`Common`ProofObject`Private`AndNode[
         Theorema`Provers`Common`ProofObject`Private`ProofInfo[
          \"TryDisjunctionOperand\", \[Bullet]usedFormulae[\"2\"], \
\[Bullet]generatedFormulae[
           \[Bullet]lf[\"7\", B, \[Bullet]finfo[]]]], 
         Theorema`Provers`Common`ProofObject`Private`Subgoals[
          Theorema`Provers`Common`ProofObject`Private`ProofSituation[
           \[Bullet]lf[\"7\", B, \[Bullet]finfo[]], \
\[Bullet]asml[\[Bullet]lf[\"1.1\", P, \[Bullet]finfo[]], 
            \[Bullet]lf[\"1.2\", Q, \[Bullet]finfo[]], \[Bullet]lf[\"1.3\", \
\[Trademark]Implies[
              \[Trademark]And[P, Q], R], \[Bullet]finfo[]]], \[Bullet]lkTab[
            {{\"PPND\", \[Bullet]lkTab[{}]}, {\"ProversHistory\", {PPND, \
PPND}}, 
             {\"LastProver\", PPND}}], \"pending\"]], 
         Theorema`Provers`Common`ProofObject`Private`Constraints[], 
         \"pending\"], Theorema`Provers`Common`ProofObject`Private`AndNode[
         Theorema`Provers`Common`ProofObject`Private`ProofInfo[
          \"ProveDisjunction\", \[Bullet]usedFormulae[\"2\"], \
\[Bullet]generatedFormulae[
           \[Bullet]lf[\"3\", A, \[Bullet]finfo[]], \[Bullet]lf[\"6\", \
\[Trademark]Not[R], \[Bullet]finfo[]], 
           \[Bullet]lf[\"8\", \[Trademark]Not[B], \[Bullet]finfo[]]]], 
         Theorema`Provers`Common`ProofObject`Private`Subgoals[
          Theorema`Provers`Common`ProofObject`Private`ProofSituation[
           \[Bullet]lf[\"3\", A, \[Bullet]finfo[]], \
\[Bullet]asml[\[Bullet]lf[\"6\", \[Trademark]Not[R], 
             \[Bullet]finfo[]], \[Bullet]lf[\"8\", \[Trademark]Not[B], \
\[Bullet]finfo[]], 
            \[Bullet]lf[\"1.1\", P, \[Bullet]finfo[]], \[Bullet]lf[\"1.2\", \
Q, \[Bullet]finfo[]], 
            \[Bullet]lf[\"1.3\", \[Trademark]Implies[\[Trademark]And[P, Q], \
R], \[Bullet]finfo[]]], 
           \[Bullet]lkTab[{{\"PPND\", \[Bullet]lkTab[{}]}, \
{\"ProversHistory\", 
              {PPND, PPND}}, {\"LastProver\", PPND}}], \"pending\"]], 
         Theorema`Provers`Common`ProofObject`Private`Constraints[], 
         \"pending\"]], \
Theorema`Provers`Common`ProofObject`Private`Constraints[
        \[Bullet]sl[\[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, 1, \
2, 1, 2, 2, 2, 1, 2, 
            2}], \[Bullet]rstrs[]], \[Bullet]syst[\[Bullet]sub[], \
\[Bullet]refs[{2, 1, 2, 1, 2, 1, 2, 
            3}], \[Bullet]rstrs[]], \[Bullet]syst[\[Bullet]sub[], \
\[Bullet]refs[{2, 1, 2, 1, 2, 1, 2, 
            4}], \[Bullet]rstrs[]]]], \"proved\"]], 
     Theorema`Provers`Common`ProofObject`Private`Constraints[
      \[Bullet]sl[\[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, 1, 2, \
1, 2, 2, 2, 1, 2, 2}], 
        \[Bullet]rstrs[]], \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, \
2, 1, 2, 1, 2, 3}], 
        \[Bullet]rstrs[]], \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, \
2, 1, 2, 1, 2, 4}], 
        \[Bullet]rstrs[]]]], \"proved\"]], 
   Theorema`Provers`Common`ProofObject`Private`Constraints[
    \[Bullet]sl[\[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, 1, 2, \
1, 2, 2, 2, 1, 2, 2}], 
      \[Bullet]rstrs[]], \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, \
2, 1, 2, 1, 2, 3}], 
      \[Bullet]rstrs[]], \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, \
2, 1, 2, 1, 2, 4}], 
      \[Bullet]rstrs[]]]], \"proved\"]], 
 Theorema`Provers`Common`ProofObject`Private`Constraints[
  \[Bullet]sl[\[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, 1, 2, 1, \
2, 2, 2, 1, 2, 2}], 
    \[Bullet]rstrs[]], \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, \
1, 2, 1, 2, 3}], 
    \[Bullet]rstrs[]], \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, \
1, 2, 1, 2, 4}], 
    \[Bullet]rstrs[]]]], \"proved\"]\
\>", \
"\<\
Theorema`Provers`Common`ProofObject`Private`AndNode[Theorema`Provers`\
Common`P\\
 
    roofObject`Private`ProofInfo[InitialProofSituation, 
 
   \[Bullet]lf[Proposition (disjunction): p, 
 
    \[Trademark]Implies[\[Trademark]And[P, Q, \
\[Trademark]Implies[\[Trademark]And[P, Q], R]], \[Trademark]Or[A, R, B]], \
\[Bullet]finfo[]], 
 
   \[Bullet]asml[]], Theorema`Provers`Common`ProofObject`Private`Subgoals[
 
   Theorema`Provers`Common`ProofObject`Private`AndNode[Theorema`Provers`Commo\
\\
 
      n`ProofObject`Private`ProofInfo[ProveImplication, 
 
     \[Bullet]usedFormulae[Proposition (disjunction): p], 
 
     \[Bullet]generatedFormulae[\[Bullet]lf[1, \[Trademark]And[P, Q, \
\[Trademark]Implies[\[Trademark]And[P, Q], R]], 
 
       \[Bullet]finfo[]], \[Bullet]lf[2, \[Trademark]Or[A, R, B], \
\[Bullet]finfo[]]]], 
 
    Theorema`Provers`Common`ProofObject`Private`Subgoals[Theorema`Provers`Com\
\\
 
       mon`ProofObject`Private`AndNode[Theorema`Provers`Common`ProofObject`Pr\
\\
 
        ivate`ProofInfo[AssumptionIsConjunction, \[Bullet]usedFormulae[1], 
 
       \[Bullet]generatedFormulae[\[Bullet]lf[1.1, P, \[Bullet]finfo[]], \
\[Bullet]lf[1.2, Q, \[Bullet]finfo[]], 
 
        \[Bullet]lf[1.3, \[Trademark]Implies[\[Trademark]And[P, Q], R], \
\[Bullet]finfo[]]]], 
 
      Theorema`Provers`Common`ProofObject`Private`Subgoals[Theorema`Provers`C\
\\
 
         ommon`ProofObject`Private`OrNode[Theorema`Provers`Common`ProofObject\
\\
 
          `Private`ProofInfo[ProveDisjunctionAlternatives, \
\[Bullet]usedFormulae[2], 
 
         \[Bullet]generatedFormulae[]], 
 
        Theorema`Provers`Common`ProofObject`Private`Subgoals[Theorema`Provers\
\\
 
           `Common`ProofObject`Private`AndNode[Theorema`Provers`Common`ProofO\
\\
 
            bject`Private`ProofInfo[TryDisjunctionOperand, \
\[Bullet]usedFormulae[2], 
 
           \[Bullet]generatedFormulae[\[Bullet]lf[4, A, \[Bullet]finfo[]]]], 
 
          Theorema`Provers`Common`ProofObject`Private`Subgoals[
 
           Theorema`Provers`Common`ProofObject`Private`AndNode[
 
            Theorema`Provers`Common`ProofObject`Private`ProofInfo[
 
             TransformImplication, \[Bullet]usedFormulae[1.3], 
 
             \[Bullet]generatedFormulae[\[Bullet]lf[9, \[Trademark]Or[\
\[Trademark]Not[\[Trademark]And[P, Q]], R], \[Bullet]finfo[]]]], 
 
            Theorema`Provers`Common`ProofObject`Private`Subgoals[
 
             Theorema`Provers`Common`ProofObject`Private`AndNode[
 
              Theorema`Provers`Common`ProofObject`Private`ProofInfo[
 
               CaseDistinction, \[Bullet]usedFormulae[4, 9], 
 
               \[Bullet]generatedFormulae[\[Bullet]lf[9.1, \[Trademark]Not[\
\[Trademark]And[P, Q]], \[Bullet]finfo[]], 
 
                \[Bullet]lf[9.2, R, \[Bullet]finfo[]]]], 
 
              Theorema`Provers`Common`ProofObject`Private`Subgoals[
 
               Theorema`Provers`Common`ProofObject`Private`AndNode[
 
                Theorema`Provers`Common`ProofObject`Private`ProofInfo[
 
                 AssumptionIsNegatedConjunction, \[Bullet]usedFormulae[9.1], 
 
                 \[Bullet]generatedFormulae[\[Bullet]lf[10, \[Trademark]Or[\
\[Trademark]Not[P], \[Trademark]Not[Q]], \[Bullet]finfo[]]]]
 
                 , Theorema`Provers`Common`ProofObject`Private`Subgoals[
 
                 Theorema`Provers`Common`ProofObject`Private`AndNode[
 
                  Theorema`Provers`Common`ProofObject`Private`ProofInfo[
 
                   Resolution, \[Bullet]usedFormulae[1.1, 10], 
 
                   \[Bullet]generatedFormulae[\[Bullet]lf[11, \
\[Trademark]Not[Q], \[Bullet]finfo[]]]], 
 
                  Theorema`Provers`Common`ProofObject`Private`Subgoals[
 
                   Theorema`Provers`Common`ProofObject`Private`AndNode[
 
                    Theorema`Provers`Common`ProofObject`Private`ProofInfo[
 
                     ContradictoryAssumptions, \[Bullet]usedFormulae[1.2, \
11], 
 
                     \[Bullet]generatedFormulae[], 4], 
 
                    Theorema`Provers`Common`ProofObject`Private`Subgoals[], 
 
                    Theorema`Provers`Common`ProofObject`Private`Constrain\\
 
                      ts[], proved]], 
 
                  Theorema`Provers`Common`ProofObject`Private`Constraints[], 
 
                  proved]], Theorema`Provers`Common`ProofObject`Private`Const\
\\
 
                  raints[], proved], 
 
               Theorema`Provers`Common`ProofObject`Private`AndNode[
 
                Theorema`Provers`Common`ProofObject`Private`ProofInfo[
 
                 NoApplicableProver, 4], 
 
                Theorema`Provers`Common`ProofObject`Private`Subgoals[], 
 
                Theorema`Provers`Common`ProofObject`Private`MainProofSituati\\\

 
                  on[\[Bullet]lf[4, A, \[Bullet]finfo[]], 
 
                 \[Bullet]asml[\[Bullet]lf[1.1, P, \[Bullet]finfo[]], \
\[Bullet]lf[1.2, Q, \[Bullet]finfo[]], 
 
                  \[Bullet]lf[9.2, R, \[Bullet]finfo[]]], 
 
                 \[Bullet]lkTab[{{PPND, \[Bullet]lkTab[{}]}, 
 
                   {ProversHistory, {PPND, PPND, PPND, PPND, PPND}}}]], 
 
                Theorema`Provers`Common`ProofObject`Private`Constraints[], 
 
                failed]], Theorema`Provers`Common`ProofObject`Private`Constra\
\\
 
                ints[], failed]], 
 
            Theorema`Provers`Common`ProofObject`Private`Constraints[], \
failed]
 
            ], Theorema`Provers`Common`ProofObject`Private`Constraints[], 
 
          failed], Theorema`Provers`Common`ProofObject`Private`AndNode[
 
          Theorema`Provers`Common`ProofObject`Private`ProofInfo[
 
           TryDisjunctionOperand, \[Bullet]usedFormulae[2], 
 
           \[Bullet]generatedFormulae[\[Bullet]lf[5, R, \[Bullet]finfo[]]]], 
 
          Theorema`Provers`Common`ProofObject`Private`Subgoals[
 
           Theorema`Provers`Common`ProofObject`Private`OrNode[Theorema`Prover\
\\
 
              s`Common`ProofObject`Private`ProofInfo[GoalIsRHSofImplication, 
 
             \[Bullet]usedFormulae[5, 1.3], \[Bullet]generatedFormulae[]], 
 
            Theorema`Provers`Common`ProofObject`Private`Subgoals[
 
             Theorema`Provers`Common`ProofObject`Private`AndNode[
 
              Theorema`Provers`Common`ProofObject`Private`ProofInfo[
 
               BackChainingImplication, \[Bullet]usedFormulae[5, 1.3], 
 
               \[Bullet]generatedFormulae[\[Bullet]lf[13, \[Trademark]And[P, \
Q], \[Bullet]finfo[]]]], 
 
              Theorema`Provers`Common`ProofObject`Private`Subgoals[
 
               Theorema`Provers`Common`ProofObject`Private`AndNode[
 
                Theorema`Provers`Common`ProofObject`Private`ProofInfo[
 
                 ProveConjunction, \[Bullet]usedFormulae[13], 
 
                 \[Bullet]generatedFormulae[\[Bullet]lf[13.1, P, \
\[Bullet]finfo[]], 
 
                  \[Bullet]lf[13.2, Q, \[Bullet]finfo[]]]], 
 
                Theorema`Provers`Common`ProofObject`Private`Subgoals[
 
                 Theorema`Provers`Common`ProofObject`Private`AndNode[
 
                  Theorema`Provers`Common`ProofObject`Private`ProofInfo[
 
                   ConclusionIsAssumption, \[Bullet]usedFormulae[13.1, 1.1], 
 
                   \[Bullet]generatedFormulae[]], 
 
                  Theorema`Provers`Common`ProofObject`Private`Subgoals[], 
 
                  Theorema`Provers`Common`ProofObject`Private`Constraints[], 
 
                  proved], \
Theorema`Provers`Common`ProofObject`Private`AndNo\\
 
                   de[Theorema`Provers`Common`ProofObject`Private`ProofInfo[
 
                   ConclusionIsAssumption, \[Bullet]usedFormulae[13.2, 1.2], 
 
                   \[Bullet]generatedFormulae[]], 
 
                  Theorema`Provers`Common`ProofObject`Private`Subgoals[], 
 
                  Theorema`Provers`Common`ProofObject`Private`Constraints[], 
 
                  proved]], Theorema`Provers`Common`ProofObject`Private`Const\
\\
 
                  raints[\[Bullet]sl[]], proved]], 
 
              Theorema`Provers`Common`ProofObject`Private`Constraints[\
\[Bullet]sl[]], 
 
              proved], Theorema`Provers`Common`ProofObject`Private`AndNode[
 
              Theorema`Provers`Common`ProofObject`Private`ProofInfo[
 
               SimplifyImplicationLHS, \[Bullet]usedFormulae[5, 1.3], 
 
               \[Bullet]generatedFormulae[\[Bullet]lf[12, \[Trademark]Not[\
\[Trademark]And[P, Q]], \[Bullet]finfo[]]]], 
 
              Theorema`Provers`Common`ProofObject`Private`Subgoals[
 
               Theorema`Provers`Common`ProofObject`Private`ProofSituation[
 
                \[Bullet]lf[5, R, \[Bullet]finfo[]], 
 
                \[Bullet]asml[\[Bullet]lf[1.1, P, \[Bullet]finfo[]], \
\[Bullet]lf[1.2, Q, \[Bullet]finfo[]], 
 
                 \[Bullet]lf[12, \[Trademark]Not[\[Trademark]And[P, Q]], \
\[Bullet]finfo[]]], 
 
                \[Bullet]lkTab[{{PPND, \[Bullet]lkTab[{}]}, 
 
                  {ProversHistory, {PPND, PPND, PPND}}, {LastProver, PPND}}], \

 
                pending]], Theorema`Provers`Common`ProofObject`Private`Constr\
\\
 
                aints[], pending]], 
 
            Theorema`Provers`Common`ProofObject`Private`Constraints[
 
             \[Bullet]sl[\[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, \
2, 1, 2, 1, 2, 2, 2, 1, 2, 2}], 
 
               \[Bullet]rstrs[]]]], proved]], 
 
          Theorema`Provers`Common`ProofObject`Private`Constraints[
 
           \[Bullet]sl[\[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, \
1, 2, 1, 2, 2, 2, 1, 2, 2}], 
 
             \[Bullet]rstrs[]]]], proved], 
 
         Theorema`Provers`Common`ProofObject`Private`AndNode[Theorema`Provers\
\\
 
            `Common`ProofObject`Private`ProofInfo[TryDisjunctionOperand, 
 
           \[Bullet]usedFormulae[2], \
\[Bullet]generatedFormulae[\[Bullet]lf[7, B, \[Bullet]finfo[]]]], 
 
          Theorema`Provers`Common`ProofObject`Private`Subgoals[
 
           Theorema`Provers`Common`ProofObject`Private`ProofSituation[
 
            \[Bullet]lf[7, B, \[Bullet]finfo[]], 
 
            \[Bullet]asml[\[Bullet]lf[1.1, P, \[Bullet]finfo[]], \
\[Bullet]lf[1.2, Q, \[Bullet]finfo[]], 
 
             \[Bullet]lf[1.3, \[Trademark]Implies[\[Trademark]And[P, Q], R], \
\[Bullet]finfo[]]], 
 
            \[Bullet]lkTab[{{PPND, \[Bullet]lkTab[{}]}, {ProversHistory, \
{PPND, PPND}}, 
 
              {LastProver, PPND}}], pending]], 
 
          Theorema`Provers`Common`ProofObject`Private`Constraints[], pending]\
\\
 
          , Theorema`Provers`Common`ProofObject`Private`AndNode[
 
          Theorema`Provers`Common`ProofObject`Private`ProofInfo[
 
           ProveDisjunction, \[Bullet]usedFormulae[2], 
 
           \[Bullet]generatedFormulae[\[Bullet]lf[3, A, \[Bullet]finfo[]], \
\[Bullet]lf[6, \[Trademark]Not[R], \[Bullet]finfo[]], 
 
            \[Bullet]lf[8, \[Trademark]Not[B], \[Bullet]finfo[]]]], 
 
          Theorema`Provers`Common`ProofObject`Private`Subgoals[
 
           Theorema`Provers`Common`ProofObject`Private`ProofSituation[
 
            \[Bullet]lf[3, A, \[Bullet]finfo[]], 
 
            \[Bullet]asml[\[Bullet]lf[6, \[Trademark]Not[R], \
\[Bullet]finfo[]], \[Bullet]lf[8, \[Trademark]Not[B], \[Bullet]finfo[]], 
 
             \[Bullet]lf[1.1, P, \[Bullet]finfo[]], \[Bullet]lf[1.2, Q, \
\[Bullet]finfo[]], 
 
             \[Bullet]lf[1.3, \[Trademark]Implies[\[Trademark]And[P, Q], R], \
\[Bullet]finfo[]]], 
 
            \[Bullet]lkTab[{{PPND, \[Bullet]lkTab[{}]}, {ProversHistory, \
{PPND, PPND}}, 
 
              {LastProver, PPND}}], pending]], 
 
          Theorema`Provers`Common`ProofObject`Private`Constraints[], \
pending]]
 
         , Theorema`Provers`Common`ProofObject`Private`Constraints[
 
         \[Bullet]sl[\[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, 1, \
2, 1, 2, 2, 2, 1, 2, 2}], 
 
           \[Bullet]rstrs[]], \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, \
1, 2, 1, 2, 1, 2, 3}], 
 
           \[Bullet]rstrs[]], \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, \
1, 2, 1, 2, 1, 2, 4}], 
 
           \[Bullet]rstrs[]]]], proved]], 
 
      Theorema`Provers`Common`ProofObject`Private`Constraints[\[Bullet]sl[
 
        \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, 1, 2, 1, 2, 2, \
2, 1, 2, 2}], \[Bullet]rstrs[]], 
 
        \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, 1, 2, 1, 2, \
3}], \[Bullet]rstrs[]], 
 
        \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, 1, 2, 1, 2, \
4}], \[Bullet]rstrs[]]]], proved]], 
 
    Theorema`Provers`Common`ProofObject`Private`Constraints[\[Bullet]sl[
 
      \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, 1, 2, 1, 2, 2, 2, \
1, 2, 2}], \[Bullet]rstrs[]], 
 
      \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, 1, 2, 1, 2, 3}], \
\[Bullet]rstrs[]], 
 
      \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, 1, 2, 1, 2, 4}], \
\[Bullet]rstrs[]]]], proved]], 
 
  Theorema`Provers`Common`ProofObject`Private`Constraints[\[Bullet]sl[\
\[Bullet]syst[\[Bullet]sub[], 
 
     \[Bullet]refs[{2, 1, 2, 1, 2, 1, 2, 2, 2, 1, 2, 2}], \[Bullet]rstrs[]], 
 
    \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, 1, 2, 1, 2, 3}], \
\[Bullet]rstrs[]], 
 
    \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, 1, 2, 1, 2, 4}], \
\[Bullet]rstrs[]]]], proved]\
\>"], "Output"]
}, Closed]],

Cell[BoxData[
    \(ProofShow[$TmaProofObject]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ProofSimplifier[$TmaProofObject, steps -> Essential]\)], "Input"],

Cell[OutputFormData["\<\
Theorema`Provers`Common`ProofObject`Private`AndNode[
 Theorema`Provers`Common`ProofObject`Private`ProofInfo[
  \"InitialProofSituation\", \[Bullet]lf[\"Proposition (disjunction): p\", 
   \[Trademark]Implies[\[Trademark]And[P, Q, \
\[Trademark]Implies[\[Trademark]And[P, Q], R]], \[Trademark]Or[A, R, B]], 
   \[Bullet]finfo[]], \[Bullet]asml[]], 
 Theorema`Provers`Common`ProofObject`Private`Subgoals[
  Theorema`Provers`Common`ProofObject`Private`AndNode[
   Theorema`Provers`Common`ProofObject`Private`ProofInfo[\"ProveImplication\",\
 
    \[Bullet]usedFormulae[\"Proposition (disjunction): p\"], 
    \[Bullet]generatedFormulae[\[Bullet]lf[\"1\", \[Trademark]And[P, Q, \
\[Trademark]Implies[\[Trademark]And[P, Q], 
        R]], \[Bullet]finfo[]], \[Bullet]lf[\"2\", \[Trademark]Or[A, R, B], \
\[Bullet]finfo[]]]], 
   Theorema`Provers`Common`ProofObject`Private`Subgoals[
    Theorema`Provers`Common`ProofObject`Private`AndNode[
     Theorema`Provers`Common`ProofObject`Private`ProofInfo[
      \"AssumptionIsConjunction\", \[Bullet]usedFormulae[\"1\"], 
      \[Bullet]generatedFormulae[\[Bullet]lf[\"1.1\", P, \[Bullet]finfo[]], 
       \[Bullet]lf[\"1.2\", Q, \[Bullet]finfo[]], \[Bullet]lf[\"1.3\", \
\[Trademark]Implies[\[Trademark]And[P, Q], R], 
        \[Bullet]finfo[]]]], \
Theorema`Provers`Common`ProofObject`Private`Subgoals[
      Theorema`Provers`Common`ProofObject`Private`AndNode[
       Theorema`Provers`Common`ProofObject`Private`ProofInfo[
        \"TryDisjunctionOperand\", \[Bullet]usedFormulae[\"2\"], \
\[Bullet]generatedFormulae[
         \[Bullet]lf[\"5\", R, \[Bullet]finfo[]]]], 
       Theorema`Provers`Common`ProofObject`Private`Subgoals[
        Theorema`Provers`Common`ProofObject`Private`AndNode[
         Theorema`Provers`Common`ProofObject`Private`ProofInfo[
          \"BackChainingImplication\", \[Bullet]usedFormulae[\"5\", \"1.3\"], \

          \[Bullet]generatedFormulae[\[Bullet]lf[\"13\", \[Trademark]And[P, \
Q], \[Bullet]finfo[]]]], 
         Theorema`Provers`Common`ProofObject`Private`Subgoals[
          Theorema`Provers`Common`ProofObject`Private`AndNode[
           Theorema`Provers`Common`ProofObject`Private`ProofInfo[
            \"ProveConjunction\", \[Bullet]usedFormulae[\"13\"], \
\[Bullet]generatedFormulae[
             \[Bullet]lf[\"13.1\", P, \[Bullet]finfo[]], \
\[Bullet]lf[\"13.2\", Q, \[Bullet]finfo[]]]], 
           Theorema`Provers`Common`ProofObject`Private`Subgoals[
            Theorema`Provers`Common`ProofObject`Private`AndNode[
             Theorema`Provers`Common`ProofObject`Private`ProofInfo[
              \"ConclusionIsAssumption\", \[Bullet]usedFormulae[\"13.1\", \
\"1.1\"], 
              \[Bullet]generatedFormulae[]], 
             Theorema`Provers`Common`ProofObject`Private`Subgoals[], 
             Theorema`Provers`Common`ProofObject`Private`Constraints[], 
             \"proved\"], \
Theorema`Provers`Common`ProofObject`Private`AndNode[
             Theorema`Provers`Common`ProofObject`Private`ProofInfo[
              \"ConclusionIsAssumption\", \[Bullet]usedFormulae[\"13.2\", \
\"1.2\"], 
              \[Bullet]generatedFormulae[]], 
             Theorema`Provers`Common`ProofObject`Private`Subgoals[], 
             Theorema`Provers`Common`ProofObject`Private`Constraints[], 
             \"proved\"]], 
           Theorema`Provers`Common`ProofObject`Private`Constraints[\[Bullet]\
sl[]], 
           \"proved\"]], 
         Theorema`Provers`Common`ProofObject`Private`Constraints[\[Bullet]sl[]\
], 
         \"proved\"]], \
Theorema`Provers`Common`ProofObject`Private`Constraints[
        \[Bullet]sl[\[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, 1, \
2, 1, 2, 2, 2, 1, 2, 
            2}], \[Bullet]rstrs[]]]], \"proved\"]], 
     Theorema`Provers`Common`ProofObject`Private`Constraints[
      \[Bullet]sl[\[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, 1, 2, \
1, 2, 2, 2, 1, 2, 2}], 
        \[Bullet]rstrs[]], \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, \
2, 1, 2, 1, 2, 3}], 
        \[Bullet]rstrs[]], \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, \
2, 1, 2, 1, 2, 4}], 
        \[Bullet]rstrs[]]]], \"proved\"]], 
   Theorema`Provers`Common`ProofObject`Private`Constraints[
    \[Bullet]sl[\[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, 1, 2, \
1, 2, 2, 2, 1, 2, 2}], 
      \[Bullet]rstrs[]], \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, \
2, 1, 2, 1, 2, 3}], 
      \[Bullet]rstrs[]], \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, \
2, 1, 2, 1, 2, 4}], 
      \[Bullet]rstrs[]]]], \"proved\"]], 
 Theorema`Provers`Common`ProofObject`Private`Constraints[
  \[Bullet]sl[\[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, 1, 2, 1, \
2, 2, 2, 1, 2, 2}], 
    \[Bullet]rstrs[]], \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, \
1, 2, 1, 2, 3}], 
    \[Bullet]rstrs[]], \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, \
1, 2, 1, 2, 4}], 
    \[Bullet]rstrs[]]]], \"proved\"]\
\>", \
"\<\
Theorema`Provers`Common`ProofObject`Private`AndNode[Theorema`Provers`\
Common`P\\
 
    roofObject`Private`ProofInfo[InitialProofSituation, 
 
   \[Bullet]lf[Proposition (disjunction): p, 
 
    \[Trademark]Implies[\[Trademark]And[P, Q, \
\[Trademark]Implies[\[Trademark]And[P, Q], R]], \[Trademark]Or[A, R, B]], \
\[Bullet]finfo[]], 
 
   \[Bullet]asml[]], Theorema`Provers`Common`ProofObject`Private`Subgoals[
 
   Theorema`Provers`Common`ProofObject`Private`AndNode[Theorema`Provers`Commo\
\\
 
      n`ProofObject`Private`ProofInfo[ProveImplication, 
 
     \[Bullet]usedFormulae[Proposition (disjunction): p], 
 
     \[Bullet]generatedFormulae[\[Bullet]lf[1, \[Trademark]And[P, Q, \
\[Trademark]Implies[\[Trademark]And[P, Q], R]], 
 
       \[Bullet]finfo[]], \[Bullet]lf[2, \[Trademark]Or[A, R, B], \
\[Bullet]finfo[]]]], 
 
    Theorema`Provers`Common`ProofObject`Private`Subgoals[Theorema`Provers`Com\
\\
 
       mon`ProofObject`Private`AndNode[Theorema`Provers`Common`ProofObject`Pr\
\\
 
        ivate`ProofInfo[AssumptionIsConjunction, \[Bullet]usedFormulae[1], 
 
       \[Bullet]generatedFormulae[\[Bullet]lf[1.1, P, \[Bullet]finfo[]], \
\[Bullet]lf[1.2, Q, \[Bullet]finfo[]], 
 
        \[Bullet]lf[1.3, \[Trademark]Implies[\[Trademark]And[P, Q], R], \
\[Bullet]finfo[]]]], 
 
      Theorema`Provers`Common`ProofObject`Private`Subgoals[Theorema`Provers`C\
\\
 
         ommon`ProofObject`Private`AndNode[Theorema`Provers`Common`ProofObjec\
\\
 
          t`Private`ProofInfo[TryDisjunctionOperand, \
\[Bullet]usedFormulae[2], 
 
         \[Bullet]generatedFormulae[\[Bullet]lf[5, R, \[Bullet]finfo[]]]], 
 
        Theorema`Provers`Common`ProofObject`Private`Subgoals[Theorema`Provers\
\\
 
           `Common`ProofObject`Private`AndNode[Theorema`Provers`Common`ProofO\
\\
 
            bject`Private`ProofInfo[BackChainingImplication, 
 
           \[Bullet]usedFormulae[5, 1.3], 
 
           \[Bullet]generatedFormulae[\[Bullet]lf[13, \[Trademark]And[P, Q], \
\[Bullet]finfo[]]]], 
 
          Theorema`Provers`Common`ProofObject`Private`Subgoals[
 
           Theorema`Provers`Common`ProofObject`Private`AndNode[
 
            Theorema`Provers`Common`ProofObject`Private`ProofInfo[
 
             ProveConjunction, \[Bullet]usedFormulae[13], 
 
             \[Bullet]generatedFormulae[\[Bullet]lf[13.1, P, \
\[Bullet]finfo[]], 
 
              \[Bullet]lf[13.2, Q, \[Bullet]finfo[]]]], 
 
            Theorema`Provers`Common`ProofObject`Private`Subgoals[
 
             Theorema`Provers`Common`ProofObject`Private`AndNode[
 
              Theorema`Provers`Common`ProofObject`Private`ProofInfo[
 
               ConclusionIsAssumption, \[Bullet]usedFormulae[13.1, 1.1], 
 
               \[Bullet]generatedFormulae[]], 
 
              Theorema`Provers`Common`ProofObject`Private`Subgoals[], 
 
              Theorema`Provers`Common`ProofObject`Private`Constraints[], 
 
              proved], Theorema`Provers`Common`ProofObject`Private`AndNode[
 
              Theorema`Provers`Common`ProofObject`Private`ProofInfo[
 
               ConclusionIsAssumption, \[Bullet]usedFormulae[13.2, 1.2], 
 
               \[Bullet]generatedFormulae[]], 
 
              Theorema`Provers`Common`ProofObject`Private`Subgoals[], 
 
              Theorema`Provers`Common`ProofObject`Private`Constraints[], 
 
              proved]], Theorema`Provers`Common`ProofObject`Private`Constrain\
\\
 
              ts[\[Bullet]sl[]], proved]], 
 
          Theorema`Provers`Common`ProofObject`Private`Constraints[\[Bullet]sl[\
]], 
 
          proved]], Theorema`Provers`Common`ProofObject`Private`Constraints[
 
         \[Bullet]sl[\[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, 1, \
2, 1, 2, 2, 2, 1, 2, 2}], 
 
           \[Bullet]rstrs[]]]], proved]], 
 
      Theorema`Provers`Common`ProofObject`Private`Constraints[\[Bullet]sl[
 
        \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, 1, 2, 1, 2, 2, \
2, 1, 2, 2}], \[Bullet]rstrs[]], 
 
        \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, 1, 2, 1, 2, \
3}], \[Bullet]rstrs[]], 
 
        \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, 1, 2, 1, 2, \
4}], \[Bullet]rstrs[]]]], proved]], 
 
    Theorema`Provers`Common`ProofObject`Private`Constraints[\[Bullet]sl[
 
      \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, 1, 2, 1, 2, 2, 2, \
1, 2, 2}], \[Bullet]rstrs[]], 
 
      \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, 1, 2, 1, 2, 3}], \
\[Bullet]rstrs[]], 
 
      \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, 1, 2, 1, 2, 4}], \
\[Bullet]rstrs[]]]], proved]], 
 
  Theorema`Provers`Common`ProofObject`Private`Constraints[\[Bullet]sl[\
\[Bullet]syst[\[Bullet]sub[], 
 
     \[Bullet]refs[{2, 1, 2, 1, 2, 1, 2, 2, 2, 1, 2, 2}], \[Bullet]rstrs[]], 
 
    \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, 1, 2, 1, 2, 3}], \
\[Bullet]rstrs[]], 
 
    \[Bullet]syst[\[Bullet]sub[], \[Bullet]refs[{2, 1, 2, 1, 2, 1, 2, 4}], \
\[Bullet]rstrs[]]]], proved]\
\>"], "Output"]
}, Closed]],

Cell[BoxData[
    \(ProofShow[%]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Other Options for Proving: Search Depth", "Subsection"],

Cell[TextData[{
  "The behavior of any prover in ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " can be controlled by additional options, which are listed by the  \
command:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[Prove]\)], "Input"],

Cell[OutputFormData["\<\
{using -> \[Bullet]kb[\"None\", \[Bullet]range[], \
True, \[Bullet]flist[]], 
 built\[Dash]in -> \[Bullet]bui[\"None\", \[Bullet]range[], True, \
\[Bullet]flist[]], by :> $TmaDefaultProver, ProverOptions :> {}, 
 transformBy -> Identity, TransformerOptions -> {}, showBy -> StaticWriter, \
ShowOptions -> {}, 
 SearchDepth -> Default, formal\[Dash]object :> $TmaDefaultProofObject, \
SearchMethod -> Default, 
 ExpandKnowledge -> False, LabelStyle :> $TmaDefaultLabelStyle}\
\>", \
"\<\
{using -> \[Bullet]kb[None, \[Bullet]range[], True, \[Bullet]flist[]], \
built\[Dash]in -> \[Bullet]bui[None, \[Bullet]range[], True, \
\[Bullet]flist[]], 
 
  by :> $TmaDefaultProver, ProverOptions :> {}, transformBy -> Identity, \
TransformerOptions -> {}, 
 
  showBy -> StaticWriter, ShowOptions -> {}, SearchDepth -> Default, 
 
  formal\[Dash]object :> $TmaDefaultProofObject, SearchMethod -> Default, \
ExpandKnowledge -> False, 
 
  LabelStyle :> $TmaDefaultLabelStyle}\
\>"], "Output"]
}, Open  ]],

Cell[TextData[{
  "Of particular interest is the option ",
  StyleBox["SearchDepth",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<assoc left\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\((AB \[And] \[Not] C)\) \[Or] \((\((\[Not] AB)\) \[And] 
                        C)\))\)\[DoubleLongRightArrow]\((\((A \[And] \[Not] \
BC)\) \[Or] \((\((\[Not] A)\) \[And] BC)\))\)\), "\"\<abc\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"assoc", "assoc left", "Iterated Implication", "p1"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<assoc right\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\((AB \[And] \[Not] C)\) \[Or] \((\((\[Not] AB)\) \[And] 
                        C)\))\)\[DoubleLongLeftArrow]\((\((A \[And] \[Not] \
BC)\) \[Or] \((\((\[Not] A)\) \[And] BC)\))\)\), "\"\<abc\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"assoc", "assoc right", "Iterated Implication", "p1"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<asm\>\"", ",", "\n", "\t", GridBox[{
            {\(AB\[DoubleLongLeftRightArrow]\((\((A \[And] \[Not] B)\) \[Or] \
\((\((\[Not] A)\) \[And] B)\))\)\), "\"\<ab\>\""},
            {\(BC\[DoubleLongLeftRightArrow]\((\((B \[And] \[Not] C)\) \[Or] \
\((\((\[Not] B)\) \[And] C)\))\)\), "\"\<bc\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"asm", "Iterated Implication", "p1"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Timing", "[", 
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", \(Proposition["\<assoc left\>"], 
        using \[Rule] Proposition["\<asm\>"], SearchDepth \[Rule] 50\), "]"}],
       "]"}]], "Input"],

Cell[BoxData[
    \({110.819999999999985`\ Second, \[SkeletonIndicator]\ ProofObject\ \
\[SkeletonIndicator]}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Timing", "[", 
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", \(Proposition["\<assoc right\>"], 
        using \[Rule] Proposition["\<asm\>"], SearchDepth \[Rule] 50\), "]"}],
       "]"}]], "Input"],

Cell[BoxData[
    \({121.059999999999967`\ Second, \[SkeletonIndicator]\ ProofObject\ \
\[SkeletonIndicator]}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "When you are out of patience with a long proof and you use the menu ",
  StyleBox["Kernel/AbortEvaluation",
    FontSlant->"Italic"],
  ", then you can still see the part of the proof which was produced using:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ProofShow[$TmaProofObject]\)], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Propositions Involving Truth Constants", "Section"],

Cell[CellGroupData[{

Cell["Truth Constants As Goals and As Assumptions ", "Subsection"],

Cell[CellGroupData[{

Cell["Definitions which are Necessary for the Other Subsections", \
"Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<True\>\"", ",", "\n", "\t", GridBox[{
            {"True", "\"\<t\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{
  "Iterated Implication", "Negated True", "Tertium non datur", "True"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<False\>\"", ",", "\n", "\t", GridBox[{
            {"False", "\"\<f\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{
  "False", "Iterated Implication", "Negated True", "Tertium non datur", 
    "True"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Negated True\>\"", ",", "\n", "\t", GridBox[{
            {\(\[Not] True\), "\"\<nt\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{
  "Iterated Implication", "Negated True", "Tertium non datur", "True"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Negated False\>\"", ",", "\n", "\t", GridBox[{
            {\(\[Not] False\), "\"\<nf\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{
  "Iterated Implication", "Negated False", "Negated True", 
    "Tertium non datur"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Any\>\"", ",", "\n", "\t", GridBox[{
            {"X", "\"\<x\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{
  "Any", "Any Proposition", "Iterated Implication", "Negated True", 
    "Tertium non datur", "True"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Truth Constants as Goals without Assumptions", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<True\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<False\>"]\), 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<Negated True\>"]\), 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<Negated False\>"]\), 
      "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Truth Constants as Goals with Arbitrary Assumptions", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<True\>"], 
      using \[Rule] Proposition["\<Any\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<False\>"], 
      using \[Rule] Proposition["\<Any\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<Negated True\>"], 
      using \[Rule] Proposition["\<Any\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<Negated False\>"], 
      using \[Rule] Proposition["\<Any\>"]\), "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Truth Constants as Assumptions with Arbitrary Goals", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<Any\>"], 
      using \[Rule] Proposition["\<True\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<Any\>"], 
      using \[Rule] Proposition["\<False\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<Any\>"], 
      using \[Rule] Proposition["\<Negated True\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<Any\>"], 
      using \[Rule] Proposition["\<Negated False\>"]\), "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Truth Constants as Assumptions and Goals", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<True\>"], 
      using \[Rule] Proposition["\<False\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<True\>"], 
      using \[Rule] Proposition["\<Negated True\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<True\>"], 
      using \[Rule] Proposition["\<Negated False\>"]\), "]"}]], "Input"],

Cell[BoxData[
    \(\ \)], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<False\>"], 
      using \[Rule] Proposition["\<True\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<False\>"], 
      using \[Rule] Proposition["\<Negated True\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<False\>"], 
      using \[Rule] Proposition["\<Negated False\>"]\), "]"}]], "Input"],

Cell[BoxData[
    \(\ \)], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<Negated True\>"], 
      using \[Rule] Proposition["\<True\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<Negated True\>"], 
      using \[Rule] Proposition["\<False\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<Negated True\>"], 
      using \[Rule] Proposition["\<Negated False\>"]\), "]"}]], "Input"],

Cell[BoxData[
    \(\ \)], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<Negated False\>"], 
      using \[Rule] Proposition["\<True\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<Negated False\>"], 
      using \[Rule] Proposition["\<False\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<Negated False\>"], 
      using \[Rule] Proposition["\<Negated True\>"]\), "]"}]], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Simplification of Formulae Containing Truth Constants", "Subsection"],

Cell[CellGroupData[{

Cell["Negation", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Negated True\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\[Not] True)\)\[DoubleLongLeftRightArrow]False\), 
              "\"\<nt\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated Implication", "Negated True", "Tertium non datur"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<Negated True\>"]\), 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Negated False\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\[Not] False)\)\[DoubleLongLeftRightArrow]True\), 
              "\"\<nf\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{
  "Iterated Implication", "Negated False", "Negated True", 
    "Tertium non datur"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<Negated False\>"]\), 
      "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Conjunction", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<True Conjunct\>\"", ",", "\n", "\t", GridBox[{
            {\(\((A \[And] True)\)\[DoubleLongLeftRightArrow]A\), 
              "\"\<tc\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{
  "Iterated Implication", "Negated True", "Tertium non datur", 
    "True Conjunct"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<True Conjunct\>\"", ",", "\n", "\t", GridBox[{
            {\(\((A \[And] \[Not] False)\)\[DoubleLongLeftRightArrow]A\), 
              "\"\<tc\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{
  "Iterated Implication", "Negated True", "Tertium non datur", 
    "True Conjunct"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<True Conjunct\>"]\), 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<False Conjunct\>\"", ",", "\n", "\t", GridBox[{
            {\(\((A \[And] False)\)\[DoubleLongLeftRightArrow]False\), 
              "\"\<fc\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{
  "False Conjunct", "Iterated Implication", "Negated True", 
    "Tertium non datur"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<False Conjunct\>\"", ",", "\n", "\t", GridBox[{
            {\(\((A \[And] \[Not] True)\)\[DoubleLongLeftRightArrow]False\), 
              "\"\<fc\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{
  "False Conjunct", "Iterated Implication", "Negated True", 
    "Tertium non datur"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<False Conjunct\>"]\), 
      "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Disjunction", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<True Alternative\>\"", ",", "\n", "\t", GridBox[{
            {\(\((A \[Or] True)\)\[DoubleLongLeftRightArrow]True\), 
              "\"\<ta\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{
  "Iterated Implication", "Negated True", "Tertium non datur", 
    "True Alternative"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<True Alternative\>\"", ",", "\n", "\t", GridBox[{
            {\(\((A \[Or] \[Not] False)\)\[DoubleLongLeftRightArrow]True\), 
              "\"\<ta\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{
  "Iterated Implication", "Negated True", "Tertium non datur", 
    "True Alternative"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<True Alternative\>"]\), 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<False Alternative\>\"", ",", "\n", "\t", GridBox[{
            {\(\((A \[Or] False)\)\[DoubleLongLeftRightArrow]A\), 
              "\"\<fa\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{
  "False Alternative", "Iterated Implication", "Negated True", 
    "Tertium non datur"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<False Alternative\>\"", ",", "\n", "\t", GridBox[{
            {\(\((A \[Or] \[Not] True)\)\[DoubleLongLeftRightArrow]A\), 
              "\"\<fa\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{
  "False Alternative", "Iterated Implication", "Negated True", 
    "Tertium non datur"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<False Alternative\>"], 
      ProverOptions \[Rule] {BackChaining \[Rule] True}\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<test\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\((A \[Or] \[Not] True)\) \[And] \((A\[DoubleLongRightArrow]
                        B)\))\)\[DoubleLongRightArrow]B\), "\"\<fa\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{
  "False Alternative", "Iterated Implication", "Negated True", 
    "Tertium non datur", "test"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<test\>"], 
      ProverOptions \[Rule] {BackChaining \[Rule] True}\), "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Implication", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<True Implicand\>\"", ",", "\n", "\t", GridBox[{
            {\(\((True\[DoubleLongRightArrow]A)\)\[DoubleLongLeftRightArrow]
                A\), "\"\<tid\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{
  "Iterated Implication", "Negated True", "Tertium non datur", 
    "True Conjunct", "True Implicand"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<True Implicand\>"], 
      ProverOptions \[Rule] {BackChaining \[Rule] True}\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<False Implicand\>\"", ",", "\n", "\t", GridBox[{
            {\(\((False\[DoubleLongRightArrow]A)\)\[DoubleLongLeftRightArrow]
                True\), "\"\<fid\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{
  "False Conjunct", "False Implicand", "Iterated Implication", "Negated True",
     "Tertium non datur"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<False Implicand\>"]\), 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<True Implicatum\>\"", ",", "\n", "\t", GridBox[{
            {\(\((A\[DoubleLongRightArrow]True)\)\[DoubleLongLeftRightArrow]
                True\), "\"\<tim\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{
  "Iterated Implication", "Negated True", "Tertium non datur", 
    "True Conjunct", "True Implicatum"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<True Implicatum\>"]\), 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<False Implicatum\>\"", ",", "\n", "\t", GridBox[{
            {\(\((A\[DoubleLongRightArrow]
                    False)\)\[DoubleLongLeftRightArrow]\(\[Not] A\)\), 
              "\"\<fim\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{
  "False Conjunct", "False Implicatum", "Iterated Implication", 
    "Negated True", "Tertium non datur"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<False Implicatum\>"], 
      ProverOptions \[Rule] {BackChaining \[Rule] True}\), "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Equivalence", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<True Left Side\>\"", ",", "\n", "\t", GridBox[{
            {\(\((True\[DoubleLongLeftRightArrow]
                    A)\)\[DoubleLongLeftRightArrow]A\), "\"\<tls\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{
  "Iterated Implication", "Negated True", "Tertium non datur", 
    "True Conjunct", "True Implicand", "True Left Side"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<True Left Side\>"], 
      ProverOptions \[Rule] {BackChaining \[Rule] True}\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<True Right Side\>\"", ",", "\n", "\t", GridBox[{
            {\(\((True\[DoubleLongLeftRightArrow]
                    A)\)\[DoubleLongLeftRightArrow]A\), "\"\<trs\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{
  "Iterated Implication", "Negated True", "Tertium non datur", 
    "True Conjunct", "True Implicatum", "True Right Side"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<True Right Side\>"], 
      ProverOptions \[Rule] {BackChaining \[Rule] True}\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<False Left Side\>\"", ",", "\n", "\t", GridBox[{
            {\(\((False\[DoubleLongLeftRightArrow]
                    A)\)\[DoubleLongLeftRightArrow]\(\[Not] A\)\), 
              "\"\<fls\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{
  "False Left Side", "Iterated Implication", "Negated True", 
    "Tertium non datur", "True Conjunct", "True Implicand"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<False Left Side\>"], 
      ProverOptions \[Rule] {BackChaining \[Rule] True}\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<False Right Side\>\"", ",", "\n", "\t", GridBox[{
            {\(\((False\[DoubleLongLeftRightArrow]
                    A)\)\[DoubleLongLeftRightArrow]\(\[Not] A\)\), 
              "\"\<frs\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{
  "False Right Side", "Iterated Implication", "Negated True", 
    "Tertium non datur", "True Conjunct", "True Implicatum"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<False Right Side\>"], 
      ProverOptions \[Rule] {BackChaining \[Rule] True}\), "]"}]], "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Propositional Logic is Boolean Algebra", "Section"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Tertium non datur\>\"", ",", "\n", "\t", GridBox[{
            {\(A \[Or] \((\[Not] A)\)\), "\"\<tnd\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated Implication", "Tertium non datur"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<Tertium non datur\>"]\), 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<No contradiction\>\"", ",", "\n", "\t", GridBox[{
            {\(\[Not] \((A \[And] \((\[Not] A)\))\)\), "\"\<nc\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated Implication", "No contradiction"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<No contradiction\>"]\), 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<True alternative\>\"", ",", "\n", "\t", GridBox[{
            {\(A \[Or] True\), "\"\<ta\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated Implication", "True alternative"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<True alternative\>"]\), 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<True conjunctive fails\>\"", ",", "\n", "\t", GridBox[{
            {\(A \[And] True\), "\"\<tcf\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated Implication", "True conjunctive fails"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], 
      "[", \(Proposition["\<True conjunctive fails\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<True conjunctive\>\"", ",", "\n", "\t", GridBox[{
            {\(\((A \[And] True)\)\[DoubleLongLeftRightArrow]A\), 
              "\"\<tc\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated Implication", "True conjunctive"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<True conjunctive\>"]\), 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<False conjunctive\>\"", ",", "\n", "\t", GridBox[{
            {\(\((A \[And] False)\)\[DoubleLongLeftRightArrow]False\), 
              "\"\<fc\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"False conjunctive", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<False conjunctive\>"]\), 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<False alternative fails\>\"", ",", "\n", "\t", GridBox[{
            {\(A \[Or] False\), "\"\<fcf\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"False alternative fails", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], 
      "[", \(Proposition["\<False alternative fails\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<False alternative\>\"", ",", "\n", "\t", GridBox[{
            {\(\((A \[Or] False)\)\[DoubleLongLeftRightArrow]A\), 
              "\"\<fa\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"False alternative", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<False alternative\>"]\), 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<False alternative\>"], 
      ProverOptions \[Rule] {BackChaining \[Rule] True}\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Commutativity of \[And]\>\"", ",", "\n", "\t", GridBox[{
            {\(\((A \[And] B)\)\[DoubleLongLeftRightArrow]\((B \[And] A)\)\), 
              "\"\<ca\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Commutativity of \[And]", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], 
      "[", \(Proposition["\<Commutativity of \[And]\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Commutativity of \[Or]\>\"", ",", "\n", "\t", GridBox[{
            {\(\((A \[Or] B)\)\[DoubleLongLeftRightArrow]\((B \[Or] A)\)\), 
              "\"\<co\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Commutativity of \[Or]", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], 
      "[", \(Proposition["\<Commutativity of \[Or]\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Idempotency of \[And]\>\"", ",", "\n", "\t", GridBox[{
            {\(\((A \[And] A)\)\[DoubleLongLeftRightArrow]A\), "\"\<ia\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Idempotency of \[And]", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], 
      "[", \(Proposition["\<Idempotency of \[And]\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Idempotency of \[Or]\>\"", ",", "\n", "\t", GridBox[{
            {\(\((A \[Or] A)\)\[DoubleLongLeftRightArrow]A\), "\"\<io\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Idempotency of \[Or]", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<Idempotency of \[Or]\>"]\),
       "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Associativity of \[And]\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\((\ A\  \[And] \ B)\)\  \[And] \ 
                    C)\)\[DoubleLongLeftRightArrow]\ \((\ 
                  A\  \[And] \ \((B\  \[And] \ C)\))\)\), "\"\<aa\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Associativity of \[And]", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], 
      "[", \(Proposition["\<Associativity of \[And]\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Associativity of \[Or]\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\((\ A\  \[Or] \ B)\)\  \[Or] \ 
                    C)\)\[DoubleLongLeftRightArrow]\ \((\ 
                  A\  \[Or] \ \((B\  \[Or] \ C)\))\)\), "\"\<ao\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Associativity of \[Or]", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], 
      "[", \(Proposition["\<Associativity of \[Or]\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Distributivity of \[Or]\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\((\ A\  \[And] \ B)\)\  \[Or] \ 
                    C)\)\[DoubleLongLeftRightArrow]\ \((\((\ 
                      A \[Or] \ C)\) \[And] \ \((B\  \[Or] \ C)\))\)\), 
              "\"\<do\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Distributivity of \[Or]", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], 
      "[", \(Proposition["\<Distributivity of \[Or]\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Distributivity of \[And]\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\((\ A\  \[Or] \ B)\)\  \[And] \ 
                    C)\)\[DoubleLongLeftRightArrow]\ \((\((\ 
                      A \[And] \ C)\) \[Or] \ \((B\  \[And] \ C)\))\)\), 
              "\"\<da\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Distributivity of \[And]", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], 
      "[", \(Proposition["\<Distributivity of \[And]\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Absorption of \[And] over \[Or]\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\((\ A\  \[And] \ B)\)\  \[Or] \ 
                    A)\) \[DoubleLeftRightArrow] \ A\), "\"\<aao\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Absorption of \[And] over \[Or]", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], 
      "[", \(Proposition["\<Absorption of \[And] over \[Or]\>"]\), 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Absorption of \[Or] over \[And]\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\((\ A\  \[Or] \ B)\)\  \[And] \ 
                    A)\) \[DoubleLeftRightArrow] \ A\), "\"\<aoa\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Absorption of \[Or] over \[And]", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], 
      "[", \(Proposition["\<Absorption of \[Or] over \[And]\>"]\), 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Double Negation\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\[Not] \(\[Not] A\))\)\[DoubleLongLeftRightArrow]A\), 
              "\"\<dn\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Double Negation", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<Double Negation\>"]\), 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<De Morgan for \[And]\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\[Not] \ \((A\  \[And] \ 
                        B)\)\ )\) \[DoubleLeftRightArrow] \ \((\ \((\[Not] A)\
\) \[Or] \((\[Not] B)\))\)\), "\"\<ma\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"De Morgan for \[And]", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<De Morgan for \[And]\>"]\),
       "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Switched De Morgan for \[And]\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\[Not] \ \((A\  \[And] \ 
                        B)\)\ )\) \[DoubleLeftRightArrow] \ \((\ \((\[Not] B)\
\) \[Or] \((\[Not] A)\))\)\), "\"\<ma\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{
  "De Morgan for \[And]", "Iterated Implication", 
    "Switched De Morgan for \[And]"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], 
      "[", \(Proposition["\<Switched De Morgan for \[And]\>"]\), 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<De Morgan for \[Or]\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\[Not] \ \((A\  \[Or] \ 
                        B)\)\ )\) \[DoubleLeftRightArrow] \ \((\ \((\[Not] A)\
\) \[And] \((\[Not] B)\))\)\), "\"\<mo\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"De Morgan for \[Or]", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<De Morgan for \[Or]\>"]\), 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Switched De Morgan for \[Or]\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\[Not] \ \((A\  \[Or] \ 
                        B)\)\ )\) \[DoubleLeftRightArrow] \ \((\ \((\[Not] B)\
\) \[And] \((\[Not] A)\))\)\), "\"\<mo\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{
  "De Morgan for \[Or]", "Iterated Implication", 
    "Switched De Morgan for \[Or]"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], 
      "[", \(Proposition["\<Switched De Morgan for \[Or]\>"]\), 
      "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Propositional Theorems on Implication", "Section"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Implication by disjunction\>\"", ",", "\n", "\t", GridBox[{
            {\(\((A\[DoubleLongRightArrow]
                    B)\)\[DoubleLongLeftRightArrow]\((\((\[Not] A)\) \[Or] 
                    B)\)\), "\"\<id\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Implication by disjunction", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], 
      "[", \(Proposition["\<Implication by disjunction\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Negated implication\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\[Not] \((A\[DoubleLongRightArrow]
                        B)\))\)\[DoubleLongLeftRightArrow]\((A \[And] \((\
\[Not] B)\))\)\), "\"\<ni\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated Implication", "Negated implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<Negated implication\>"]\), 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Contraposition\>\"", ",", "\n", "\t", GridBox[{
            {\(\((A\[DoubleLongLeftRightArrow]
                    B)\)\[DoubleLongLeftRightArrow]\((\((\[Not] A)\)\
\[DoubleLongLeftRightArrow]\((\[Not] B)\))\)\), "\"\<cp\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Contraposition", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<Contraposition\>"]\), 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Iterated implication\>\"", ",", "\n", "\t", GridBox[{
            {\(\((A1\[DoubleLongRightArrow]\((A2\[DoubleLongRightArrow]
                        B)\))\)\[DoubleLongLeftRightArrow]\((\((A1 \[And] 
                        A2)\)\[DoubleLongRightArrow]B)\)\), "\"\<ii\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated implication", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<Iterated implication\>"], 
      ProverOptions \[Rule] {BackChaining \[Rule] True}\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Distributivity over disjunction\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\((A1 \[Or] A2)\)\[DoubleLongRightArrow]
                    B)\)\[DoubleLongLeftRightArrow]\((\((A1\
\[DoubleLongRightArrow]B)\) \[And] \((A2\[DoubleLongRightArrow]B)\))\)\), 
              "\"\<dd\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Distributivity over disjunction", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], 
      "[", \(Proposition["\<Distributivity over disjunction\>"]\), 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Distributivity over conjunction\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\((A1 \[And] A2)\)\[DoubleLongRightArrow]
                    B)\)\[DoubleLongLeftRightArrow]\((\((A1\
\[DoubleLongRightArrow]B)\) \[Or] \((A2\[DoubleLongRightArrow]B)\))\)\), 
              "\"\<dc\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Distributivity over conjunction", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], 
      "[", \(Proposition["\<Distributivity over conjunction\>"]\), 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Multiple implication\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\((\((A1 \[And] A2)\)\[DoubleLongRightArrow]
                        B)\) \[And] \((C\[DoubleLongRightArrow]
                        A1)\) \[And] \((C\[DoubleLongRightArrow]
                        A2)\))\)\[DoubleLongRightArrow]\((C\
\[DoubleLongRightArrow]B)\)\), "\"\<mi\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated Implication", "Multiple implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<Multiple implication\>"], 
      ProverOptions \[Rule] {BackChaining \[Rule] True}\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Multiple conjunction\>\"", ",", "\n", "\t", GridBox[{
            {\(\((A1 \[And] 
                    A2)\)\[DoubleLongRightArrow]\((A3\[DoubleLongRightArrow]\(\
(A1 \[And] A2 \[And] A3)\))\)\), "\"\<mc\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated Implication", "Multiple conjunction"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<Multiple conjunction\>"]\),
       "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Redundant implication\>\"", ",", "\n", "\t", GridBox[{
            {\(\((A\[DoubleLongRightArrow]\((A\[DoubleLongRightArrow]
                        B)\))\)\[DoubleLongLeftRightArrow]\((A\
\[DoubleLongRightArrow]B)\)\), "\"\<ri\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated Implication", "Redundant implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], 
      "[", \(Proposition["\<Redundant implication\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Peirce implication\>\"", ",", "\n", "\t    ", GridBox[{
            {\(\((\((A\[DoubleLongRightArrow]B)\)\[DoubleLongRightArrow]
                    A)\)\[DoubleLongRightArrow]A\), "\"\<pi\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Peirce implication", "Peirce Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<Peirce implication\>"]\), 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Equivalence by implication\>\"", ",", "\n", "\t", GridBox[{
            {\(\((A\[DoubleLongLeftRightArrow]
                    B)\)\[DoubleLongLeftRightArrow]\((\((A\
\[DoubleLongRightArrow]B)\) \[And] \((B\[DoubleLongRightArrow]A)\))\)\), 
              "\"\<ei\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Equivalence by implication", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], 
      "[", \(Proposition["\<Equivalence by implication\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Equivalence by disjunction\>\"", ",", "\n", "\t", GridBox[{
            {\(\((A\[DoubleLongLeftRightArrow]
                    B)\)\[DoubleLongLeftRightArrow]\((\((A \[And] 
                        B)\) \[Or] \((\((\[Not] A)\) \[And] \((\[Not] \
B)\))\))\)\), "\"\<ed\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Equivalence by disjunction", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], 
      "[", \(Proposition["\<Equivalence by disjunction\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Equivalence by conjunction\>\"", ",", "\n", "\t", GridBox[{
            {\(\((A\[DoubleLongLeftRightArrow]
                    B)\)\[DoubleLongLeftRightArrow]\((\((A \[Or] \((\[Not] B)\
\))\) \[And] \((\((\[Not] A)\) \[Or] B)\))\)\), "\"\<ec\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Equivalence by conjunction", "Iterated Implication"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], 
      "[", \(Proposition["\<Equivalence by conjunction\>"]\), "]"}]], "Input"],

Cell["\<\
This proof is simpler because the rule for proof by cases is used \
before the rule for transforming implications and equivalences into \
disjunctions.\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Negated equivalence\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\[Not] \((A\[DoubleLongLeftRightArrow]
                        B)\))\)\[DoubleLongLeftRightArrow]\((\((\[Not] A)\)\
\[DoubleLongLeftRightArrow]B)\)\), "\"\<ne\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated Implication", "Negated equivalence"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<Negated equivalence\>"]\), 
      "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Pelletier Collection ", "Section"],

Cell["\<\
From: F. J. Pelletier, \"Seventy-Five Problems for Testing \
Automatic Theorem Provers\", J. of Automated Reasoning, 1986, pp. \
191-216\
\>", "Text"],

Cell["(Only the propositional examples are listed here.)", "Text"],

Cell["Problem 1.", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p1\>\"", ",", "\n", "\t", GridBox[{
            {\(\((P\[DoubleLongRightArrow]
                    Q)\)\[DoubleLongLeftRightArrow]\((\((\[Not] Q)\)\
\[DoubleLongRightArrow]\((\[Not] P)\))\)\), "\"\<p1\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated Implication", "p1"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p1\>"]\), "]"}]], "Input"],

Cell["Problem 2.", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p2\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\[Not] \(\[Not] P\))\)\[DoubleLongLeftRightArrow]P\), 
              "\"\<p2\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated Implication", "p2"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p2\>"]\), "]"}]], "Input"],

Cell["Problem 3.", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p3\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\[Not] \((P\[DoubleLongRightArrow]
                        Q)\))\)\[DoubleLongRightArrow]\((Q\
\[DoubleLongRightArrow]P)\)\), "\"\<p3\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated Implication", "p3"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p3\>"]\), "]"}]], "Input"],

Cell["Problem 4.", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p4\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\((\[Not] P)\)\[DoubleLongRightArrow]
                    Q)\)\[DoubleLongLeftRightArrow]\((\((\[Not] Q)\)\
\[DoubleLongRightArrow]P)\)\), "\"\<p4\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated Implication", "p4"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p4\>"]\), "]"}]], "Input"],

Cell["Problem 5.", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p5\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\((P \[Or] Q)\)\[DoubleLongRightArrow]\((P \[Or] 
                        R)\))\)\[DoubleLongRightArrow]\((P \[Or] \((Q\
\[DoubleLongRightArrow]R)\))\)\), "\"\<p5\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated Implication", "p5"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p5\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p5\>"], 
      ProverOptions \[Rule] {TrySubgoal \[Rule] True}\), "]"}]], "Input"],

Cell["Problem 6. Law of Excluded Middle", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p6\>\"", ",", "\n", "\t", GridBox[{
            {\(P \[Or] \((\[Not] P)\)\), "\"\<p6\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated Implication", "p6"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p6\>"]\), "]"}]], "Input"],

Cell["Problem 7. Extended Law of Excluded Middle", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p7\>\"", ",", "\n", "\t", GridBox[{
            {\(P \[Or] \((\[Not] \(\[Not] \(\[Not] P\)\))\)\), "\"\<p7\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated Implication", "p7"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p7\>"]\), "]"}]], "Input"],

Cell["Problem 8. Pierce", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p8\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\((P\[DoubleLongRightArrow]Q)\)\[DoubleLongRightArrow]
                    P)\)\[DoubleLongRightArrow]P\), "\"\<p8\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated Implication", "p8"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p8\>"]\), "]"}]], "Input"],

Cell["Problem 9.", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p9\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\((P \[Or] Q)\) \[And] \((\((\[Not] P)\) \[Or] 
                        Q)\) \[And] \((P \[Or] \((\[Not] Q)\))\))\)\
\[DoubleLongRightArrow]\((\[Not] \((\((\[Not] P)\) \[Or] \((\[Not] Q)\))\))\)\
\), "\"\<p9\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated Implication", "p9"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p9\>"]\), "]"}]], "Input"],

Cell["Problem 10.", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p10 conclusion\>\"", ",", "\n", "\t", GridBox[{
            {\(P\[DoubleLongLeftRightArrow]Q\), "\"\<p10c\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated Implication", "p10 conclusion"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p10 assumptions\>\"", ",", "\n", "\t", GridBox[{
            {\(Q\[DoubleLongRightArrow]R\), "\"\<p10a1\>\""},
            {\(R\[DoubleLongRightArrow]\((P \[And] Q)\)\), "\"\<p10a2\>\""},
            {\(P\[DoubleLongRightArrow]\((Q \[Or] R)\)\), "\"\<p10a3\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated Implication", "p10 assumptions"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p10 conclusion\>"], 
      using \[Rule] Proposition["\<p10 assumptions\>"]\), "]"}]], "Input"],

Cell["Problem 11.", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p11\>\"", ",", "\n", "\t", GridBox[{
            {\(P\[DoubleLongLeftRightArrow]P\), "\"\<p11\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated Implication", "p11"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p11\>"]\), "]"}]], "Input"],

Cell["Problem 12.", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p12\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\((P\[DoubleLongLeftRightArrow]
                        Q)\)\[DoubleLongLeftRightArrow]
                    R)\)\[DoubleLongLeftRightArrow]\((P\
\[DoubleLongLeftRightArrow]\((Q\[DoubleLongLeftRightArrow]R)\))\)\), 
              "\"\<p12\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->"Proposition (p12)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p12\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p12\>"], 
      ProverOptions \[Rule] {BackChaining \[Rule] True}\), "]"}]], "Input"],

Cell[BoxData[
    \(The\ next\ proof\ was\ nicer\ if\ the\ rule\ "\<prove by cases\>"\ was\ \
applied\ \(\(earlier\)\(.\)\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p13\>\"", ",", "\n", "\t", GridBox[{
            {\(\((P \[Or] \((Q \[And] 
                        R)\))\)\[DoubleLongLeftRightArrow]\((\((P \[Or] 
                        Q)\) \[And] \((P \[Or] R)\))\)\), "\"\<p13\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated Implication", "p13"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p13\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p14\>\"", ",", "\n", "\t", GridBox[{
            {\(\((P\[DoubleLongLeftRightArrow]
                    Q)\)\[DoubleLongLeftRightArrow]\((\((Q \[Or] \((\[Not] P)\
\))\) \[And] \((\((\[Not] Q)\) \[Or] P)\))\)\), "\"\<p14\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated Implication", "p14"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p14\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p15\>\"", ",", "\n", "\t", GridBox[{
            {\(\((P\[DoubleLongRightArrow]
                    Q)\)\[DoubleLongLeftRightArrow]\((\((\[Not] P)\) \[Or] 
                    Q)\)\), "\"\<p15\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated Implication", "p15"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p15\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p16\>\"", ",", "\n", "\t", GridBox[{
            {\(\((P\[DoubleLongRightArrow]
                    Q)\) \[Or] \((Q\[DoubleLongRightArrow]P)\)\), 
              "\"\<p16\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated Implication", "p16"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p16\>"]\), "]"}]], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<p17\>\"", ",", "\n", "\t", GridBox[{
            {\(\((\((P \[And] \((Q\[DoubleLongRightArrow]
                            R)\))\)\[DoubleLongRightArrow]
                    S)\)\[DoubleLongLeftRightArrow]\((\((\((\[Not] P)\) \[Or] 
                        Q \[Or] 
                        S)\) \[And] \((\((\[Not] P)\) \[Or] \((\[Not] R)\) \
\[Or] S)\))\)\), "\"\<p17\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"Iterated Implication", "p17"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<p17\>"]\), "]"}]], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{649, 768},
WindowMargins->{{38, Automatic}, {Automatic, 0}},
Magnification->1,
StyleDefinitions -> "PastelColor.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Proposition (conclusion)"->{
    Cell[3444, 124, 398, 10, 52, "Input",
      CellTags->"Proposition (conclusion)"]},
  "Proposition (assumptions)"->{
    Cell[3845, 136, 388, 10, 73, "Input",
      CellTags->"Proposition (assumptions)"]},
  "Proposition (independent)"->{
    Cell[7272, 245, 506, 11, 52, "Input",
      CellTags->"Proposition (independent)"]},
  "Proposition (disjunction)"->{
    Cell[10268, 351, 499, 12, 52, "Input",
      CellTags->"Proposition (disjunction)"]},
  "disjunction"->{
    Cell[10770, 365, 178, 5, 35, "Input",
      CellTags->{"disjunction", "p"}],
    Cell[10951, 372, 270, 6, 51, "Input",
      CellTags->{"disjunction", "p"}],
    Cell[11755, 397, 516, 12, 52, "Input",
      CellTags->{"disjunction", "Iterated Implication", "p"}]},
  "p"->{
    Cell[10770, 365, 178, 5, 35, "Input",
      CellTags->{"disjunction", "p"}],
    Cell[10951, 372, 270, 6, 51, "Input",
      CellTags->{"disjunction", "p"}],
    Cell[11755, 397, 516, 12, 52, "Input",
      CellTags->{"disjunction", "Iterated Implication", "p"}],
    Cell[12274, 411, 348, 8, 67, "Input",
      CellTags->"p"]},
  "Iterated Implication"->{
    Cell[11755, 397, 516, 12, 52, "Input",
      CellTags->{"disjunction", "Iterated Implication", "p"}],
    Cell[55896, 1552, 541, 11, 52, "Input",
      CellTags->{"assoc", "assoc left", "Iterated Implication", "p1"}],
    Cell[56440, 1565, 542, 11, 52, "Input",
      CellTags->{"assoc", "assoc right", "Iterated Implication", "p1"}],
    Cell[56985, 1578, 559, 12, 73, "Input",
      CellTags->{"asm", "Iterated Implication", "p1"}],
    Cell[59122, 1653, 370, 10, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", "True"}],
    Cell[59495, 1665, 386, 11, 70, "Input",
      CellTags->{
      "False", "Iterated Implication", "Negated True", "Tertium non datur", 
        "True"}],
    Cell[59884, 1678, 388, 10, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", "True"}],
    Cell[60275, 1690, 404, 11, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated False", "Negated True", 
        "Tertium non datur"}],
    Cell[60682, 1703, 397, 11, 70, "Input",
      CellTags->{
      "Any", "Any Proposition", "Iterated Implication", "Negated True", 
        "Tertium non datur", "True"}],
    Cell[66099, 1898, 430, 10, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur"}],
    Cell[66680, 1916, 456, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated False", "Negated True", 
        "Tertium non datur"}],
    Cell[67361, 1941, 454, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct"}],
    Cell[67818, 1955, 462, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct"}],
    Cell[68432, 1975, 461, 12, 70, "Input",
      CellTags->{
      "False Conjunct", "Iterated Implication", "Negated True", 
        "Tertium non datur"}],
    Cell[68896, 1989, 467, 12, 70, "Input",
      CellTags->{
      "False Conjunct", "Iterated Implication", "Negated True", 
        "Tertium non datur"}],
    Cell[69589, 2014, 462, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Alternative"}],
    Cell[70054, 2028, 470, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Alternative"}],
    Cell[70679, 2048, 462, 12, 70, "Input",
      CellTags->{
      "False Alternative", "Iterated Implication", "Negated True", 
        "Tertium non datur"}],
    Cell[71144, 2062, 468, 12, 70, "Input",
      CellTags->{
      "False Alternative", "Iterated Implication", "Negated True", 
        "Tertium non datur"}],
    Cell[71819, 2082, 514, 12, 70, "Input",
      CellTags->{
      "False Alternative", "Iterated Implication", "Negated True", 
        "Tertium non datur", "test"}],
    Cell[72600, 2107, 491, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct", "True Implicand"}],
    Cell[73295, 2127, 498, 12, 70, "Input",
      CellTags->{
      "False Conjunct", "False Implicand", "Iterated Implication", 
        "Negated True", "Tertium non datur"}],
    Cell[73947, 2147, 496, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct", "True Implicatum"}],
    Cell[74597, 2167, 527, 13, 70, "Input",
      CellTags->{
      "False Conjunct", "False Implicatum", "Iterated Implication", 
        "Negated True", "Tertium non datur"}],
    Cell[75403, 2193, 517, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct", "True Implicand", "True Left Side"}],
    Cell[76124, 2213, 520, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct", "True Implicatum", "True Right Side"}],
    Cell[76849, 2233, 546, 13, 70, "Input",
      CellTags->{
      "False Left Side", "Iterated Implication", "Negated True", 
        "Tertium non datur", "True Conjunct", "True Implicand"}],
    Cell[77600, 2254, 549, 13, 70, "Input",
      CellTags->{
      "False Right Side", "Iterated Implication", "Negated True", 
        "Tertium non datur", "True Conjunct", "True Implicatum"}],
    Cell[78473, 2282, 378, 9, 70, "Input",
      CellTags->{"Iterated Implication", "Tertium non datur"}],
    Cell[79007, 2299, 389, 9, 70, "Input",
      CellTags->{"Iterated Implication", "No contradiction"}],
    Cell[79551, 2316, 365, 9, 70, "Input",
      CellTags->{"Iterated Implication", "True alternative"}],
    Cell[80071, 2333, 379, 9, 70, "Input",
      CellTags->{"Iterated Implication", "True conjunctive fails"}],
    Cell[80611, 2350, 415, 10, 70, "Input",
      CellTags->{"Iterated Implication", "True conjunctive"}],
    Cell[81181, 2368, 422, 10, 70, "Input",
      CellTags->{"False conjunctive", "Iterated Implication"}],
    Cell[81759, 2386, 381, 9, 70, "Input",
      CellTags->{"False alternative fails", "Iterated Implication"}],
    Cell[82302, 2403, 417, 10, 70, "Input",
      CellTags->{"False alternative", "Iterated Implication"}],
    Cell[83079, 2427, 441, 10, 70, "Input",
      CellTags->{"Commutativity of \[And]", "Iterated Implication"}],
    Cell[83682, 2445, 437, 10, 70, "Input",
      CellTags->{"Commutativity of \[Or]", "Iterated Implication"}],
    Cell[84280, 2463, 407, 9, 70, "Input",
      CellTags->{"Idempotency of \[And]", "Iterated Implication"}],
    Cell[84847, 2480, 404, 9, 70, "Input",
      CellTags->{"Idempotency of \[Or]", "Iterated Implication"}],
    Cell[85410, 2497, 518, 11, 70, "Input",
      CellTags->{"Associativity of \[And]", "Iterated Implication"}],
    Cell[86090, 2516, 512, 11, 70, "Input",
      CellTags->{"Associativity of \[Or]", "Iterated Implication"}],
    Cell[86763, 2535, 549, 12, 70, "Input",
      CellTags->{"Distributivity of \[Or]", "Iterated Implication"}],
    Cell[87474, 2555, 552, 12, 70, "Input",
      CellTags->{"Distributivity of \[And]", "Iterated Implication"}],
    Cell[88189, 2575, 480, 11, 70, "Input",
      CellTags->{"Absorption of \[And] over \[Or]", "Iterated Implication"}],
    Cell[88846, 2595, 480, 11, 70, "Input",
      CellTags->{"Absorption of \[Or] over \[And]", "Iterated Implication"}],
    Cell[89503, 2615, 419, 10, 70, "Input",
      CellTags->{"Double Negation", "Iterated Implication"}],
    Cell[90076, 2633, 495, 11, 70, "Input",
      CellTags->{"De Morgan for \[And]", "Iterated Implication"}],
    Cell[90730, 2652, 552, 14, 70, "Input",
      CellTags->{
      "De Morgan for \[And]", "Iterated Implication", 
        "Switched De Morgan for \[And]"}],
    Cell[91457, 2675, 493, 11, 70, "Input",
      CellTags->{"De Morgan for \[Or]", "Iterated Implication"}],
    Cell[92108, 2694, 549, 14, 70, "Input",
      CellTags->{
      "De Morgan for \[Or]", "Iterated Implication", 
        "Switched De Morgan for \[Or]"}],
    Cell[92924, 2722, 508, 12, 70, "Input",
      CellTags->{"Implication by disjunction", "Iterated Implication"}],
    Cell[93597, 2742, 486, 11, 70, "Input",
      CellTags->{"Iterated Implication", "Negated implication"}],
    Cell[94241, 2761, 495, 11, 70, "Input",
      CellTags->{"Contraposition", "Iterated Implication"}],
    Cell[94889, 2780, 549, 11, 70, "Input",
      CellTags->{"Iterated implication", "Iterated Implication"}],
    Cell[95648, 2799, 580, 13, 70, "Input",
      CellTags->{"Distributivity over disjunction", "Iterated Implication"}],
    Cell[96405, 2821, 580, 13, 70, "Input",
      CellTags->{"Distributivity over conjunction", "Iterated Implication"}],
    Cell[97162, 2843, 626, 13, 70, "Input",
      CellTags->{"Iterated Implication", "Multiple implication"}],
    Cell[97998, 2864, 484, 11, 70, "Input",
      CellTags->{"Iterated Implication", "Multiple conjunction"}],
    Cell[98641, 2883, 509, 11, 70, "Input",
      CellTags->{"Iterated Implication", "Redundant implication"}],
    Cell[99932, 2920, 556, 13, 70, "Input",
      CellTags->{"Equivalence by implication", "Iterated Implication"}],
    Cell[100653, 2941, 561, 13, 70, "Input",
      CellTags->{"Equivalence by disjunction", "Iterated Implication"}],
    Cell[101379, 2962, 535, 12, 70, "Input",
      CellTags->{"Equivalence by conjunction", "Iterated Implication"}],
    Cell[102257, 2988, 509, 11, 70, "Input",
      CellTags->{"Iterated Implication", "Negated equivalence"}],
    Cell[103262, 3022, 463, 11, 52, "Input",
      CellTags->{"Iterated Implication", "p1"}],
    Cell[103888, 3042, 393, 10, 52, "Input",
      CellTags->{"Iterated Implication", "p2"}],
    Cell[104444, 3061, 450, 11, 52, "Input",
      CellTags->{"Iterated Implication", "p3"}],
    Cell[105057, 3081, 463, 11, 52, "Input",
      CellTags->{"Iterated Implication", "p4"}],
    Cell[105683, 3101, 479, 11, 52, "Input",
      CellTags->{"Iterated Implication", "p5"}],
    Cell[106535, 3127, 347, 9, 52, "Input",
      CellTags->{"Iterated Implication", "p6"}],
    Cell[107077, 3145, 369, 9, 52, "Input",
      CellTags->{"Iterated Implication", "p7"}],
    Cell[107616, 3163, 431, 10, 52, "Input",
      CellTags->{"Iterated Implication", "p8"}],
    Cell[108210, 3182, 524, 12, 52, "Input",
      CellTags->{"Iterated Implication", "p9"}],
    Cell[108898, 3203, 380, 9, 52, "Input",
      CellTags->{"Iterated Implication", "p10 conclusion"}],
    Cell[109281, 3214, 532, 11, 93, "Input",
      CellTags->{"Iterated Implication", "p10 assumptions"}],
    Cell[110046, 3235, 357, 9, 52, "Input",
      CellTags->{"Iterated Implication", "p11"}],
    Cell[111576, 3283, 479, 11, 52, "Input",
      CellTags->{"Iterated Implication", "p13"}],
    Cell[112190, 3301, 483, 11, 52, "Input",
      CellTags->{"Iterated Implication", "p14"}],
    Cell[112808, 3319, 456, 11, 52, "Input",
      CellTags->{"Iterated Implication", "p15"}],
    Cell[113399, 3337, 433, 11, 52, "Input",
      CellTags->{"Iterated Implication", "p16"}],
    Cell[113967, 3355, 632, 14, 52, "Input",
      CellTags->{"Iterated Implication", "p17"}]},
  "assoc"->{
    Cell[55896, 1552, 541, 11, 52, "Input",
      CellTags->{"assoc", "assoc left", "Iterated Implication", "p1"}],
    Cell[56440, 1565, 542, 11, 52, "Input",
      CellTags->{"assoc", "assoc right", "Iterated Implication", "p1"}]},
  "assoc left"->{
    Cell[55896, 1552, 541, 11, 52, "Input",
      CellTags->{"assoc", "assoc left", "Iterated Implication", "p1"}]},
  "p1"->{
    Cell[55896, 1552, 541, 11, 52, "Input",
      CellTags->{"assoc", "assoc left", "Iterated Implication", "p1"}],
    Cell[56440, 1565, 542, 11, 52, "Input",
      CellTags->{"assoc", "assoc right", "Iterated Implication", "p1"}],
    Cell[56985, 1578, 559, 12, 73, "Input",
      CellTags->{"asm", "Iterated Implication", "p1"}],
    Cell[103262, 3022, 463, 11, 52, "Input",
      CellTags->{"Iterated Implication", "p1"}]},
  "assoc right"->{
    Cell[56440, 1565, 542, 11, 52, "Input",
      CellTags->{"assoc", "assoc right", "Iterated Implication", "p1"}]},
  "asm"->{
    Cell[56985, 1578, 559, 12, 73, "Input",
      CellTags->{"asm", "Iterated Implication", "p1"}]},
  "Negated True"->{
    Cell[59122, 1653, 370, 10, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", "True"}],
    Cell[59495, 1665, 386, 11, 70, "Input",
      CellTags->{
      "False", "Iterated Implication", "Negated True", "Tertium non datur", 
        "True"}],
    Cell[59884, 1678, 388, 10, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", "True"}],
    Cell[60275, 1690, 404, 11, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated False", "Negated True", 
        "Tertium non datur"}],
    Cell[60682, 1703, 397, 11, 70, "Input",
      CellTags->{
      "Any", "Any Proposition", "Iterated Implication", "Negated True", 
        "Tertium non datur", "True"}],
    Cell[66099, 1898, 430, 10, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur"}],
    Cell[66680, 1916, 456, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated False", "Negated True", 
        "Tertium non datur"}],
    Cell[67361, 1941, 454, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct"}],
    Cell[67818, 1955, 462, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct"}],
    Cell[68432, 1975, 461, 12, 70, "Input",
      CellTags->{
      "False Conjunct", "Iterated Implication", "Negated True", 
        "Tertium non datur"}],
    Cell[68896, 1989, 467, 12, 70, "Input",
      CellTags->{
      "False Conjunct", "Iterated Implication", "Negated True", 
        "Tertium non datur"}],
    Cell[69589, 2014, 462, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Alternative"}],
    Cell[70054, 2028, 470, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Alternative"}],
    Cell[70679, 2048, 462, 12, 70, "Input",
      CellTags->{
      "False Alternative", "Iterated Implication", "Negated True", 
        "Tertium non datur"}],
    Cell[71144, 2062, 468, 12, 70, "Input",
      CellTags->{
      "False Alternative", "Iterated Implication", "Negated True", 
        "Tertium non datur"}],
    Cell[71819, 2082, 514, 12, 70, "Input",
      CellTags->{
      "False Alternative", "Iterated Implication", "Negated True", 
        "Tertium non datur", "test"}],
    Cell[72600, 2107, 491, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct", "True Implicand"}],
    Cell[73295, 2127, 498, 12, 70, "Input",
      CellTags->{
      "False Conjunct", "False Implicand", "Iterated Implication", 
        "Negated True", "Tertium non datur"}],
    Cell[73947, 2147, 496, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct", "True Implicatum"}],
    Cell[74597, 2167, 527, 13, 70, "Input",
      CellTags->{
      "False Conjunct", "False Implicatum", "Iterated Implication", 
        "Negated True", "Tertium non datur"}],
    Cell[75403, 2193, 517, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct", "True Implicand", "True Left Side"}],
    Cell[76124, 2213, 520, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct", "True Implicatum", "True Right Side"}],
    Cell[76849, 2233, 546, 13, 70, "Input",
      CellTags->{
      "False Left Side", "Iterated Implication", "Negated True", 
        "Tertium non datur", "True Conjunct", "True Implicand"}],
    Cell[77600, 2254, 549, 13, 70, "Input",
      CellTags->{
      "False Right Side", "Iterated Implication", "Negated True", 
        "Tertium non datur", "True Conjunct", "True Implicatum"}]},
  "Tertium non datur"->{
    Cell[59122, 1653, 370, 10, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", "True"}],
    Cell[59495, 1665, 386, 11, 70, "Input",
      CellTags->{
      "False", "Iterated Implication", "Negated True", "Tertium non datur", 
        "True"}],
    Cell[59884, 1678, 388, 10, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", "True"}],
    Cell[60275, 1690, 404, 11, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated False", "Negated True", 
        "Tertium non datur"}],
    Cell[60682, 1703, 397, 11, 70, "Input",
      CellTags->{
      "Any", "Any Proposition", "Iterated Implication", "Negated True", 
        "Tertium non datur", "True"}],
    Cell[66099, 1898, 430, 10, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur"}],
    Cell[66680, 1916, 456, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated False", "Negated True", 
        "Tertium non datur"}],
    Cell[67361, 1941, 454, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct"}],
    Cell[67818, 1955, 462, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct"}],
    Cell[68432, 1975, 461, 12, 70, "Input",
      CellTags->{
      "False Conjunct", "Iterated Implication", "Negated True", 
        "Tertium non datur"}],
    Cell[68896, 1989, 467, 12, 70, "Input",
      CellTags->{
      "False Conjunct", "Iterated Implication", "Negated True", 
        "Tertium non datur"}],
    Cell[69589, 2014, 462, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Alternative"}],
    Cell[70054, 2028, 470, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Alternative"}],
    Cell[70679, 2048, 462, 12, 70, "Input",
      CellTags->{
      "False Alternative", "Iterated Implication", "Negated True", 
        "Tertium non datur"}],
    Cell[71144, 2062, 468, 12, 70, "Input",
      CellTags->{
      "False Alternative", "Iterated Implication", "Negated True", 
        "Tertium non datur"}],
    Cell[71819, 2082, 514, 12, 70, "Input",
      CellTags->{
      "False Alternative", "Iterated Implication", "Negated True", 
        "Tertium non datur", "test"}],
    Cell[72600, 2107, 491, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct", "True Implicand"}],
    Cell[73295, 2127, 498, 12, 70, "Input",
      CellTags->{
      "False Conjunct", "False Implicand", "Iterated Implication", 
        "Negated True", "Tertium non datur"}],
    Cell[73947, 2147, 496, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct", "True Implicatum"}],
    Cell[74597, 2167, 527, 13, 70, "Input",
      CellTags->{
      "False Conjunct", "False Implicatum", "Iterated Implication", 
        "Negated True", "Tertium non datur"}],
    Cell[75403, 2193, 517, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct", "True Implicand", "True Left Side"}],
    Cell[76124, 2213, 520, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct", "True Implicatum", "True Right Side"}],
    Cell[76849, 2233, 546, 13, 70, "Input",
      CellTags->{
      "False Left Side", "Iterated Implication", "Negated True", 
        "Tertium non datur", "True Conjunct", "True Implicand"}],
    Cell[77600, 2254, 549, 13, 70, "Input",
      CellTags->{
      "False Right Side", "Iterated Implication", "Negated True", 
        "Tertium non datur", "True Conjunct", "True Implicatum"}],
    Cell[78473, 2282, 378, 9, 70, "Input",
      CellTags->{"Iterated Implication", "Tertium non datur"}]},
  "True"->{
    Cell[59122, 1653, 370, 10, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", "True"}],
    Cell[59495, 1665, 386, 11, 70, "Input",
      CellTags->{
      "False", "Iterated Implication", "Negated True", "Tertium non datur", 
        "True"}],
    Cell[59884, 1678, 388, 10, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", "True"}],
    Cell[60682, 1703, 397, 11, 70, "Input",
      CellTags->{
      "Any", "Any Proposition", "Iterated Implication", "Negated True", 
        "Tertium non datur", "True"}]},
  "False"->{
    Cell[59495, 1665, 386, 11, 70, "Input",
      CellTags->{
      "False", "Iterated Implication", "Negated True", "Tertium non datur", 
        "True"}]},
  "Negated False"->{
    Cell[60275, 1690, 404, 11, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated False", "Negated True", 
        "Tertium non datur"}],
    Cell[66680, 1916, 456, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated False", "Negated True", 
        "Tertium non datur"}]},
  "Any"->{
    Cell[60682, 1703, 397, 11, 70, "Input",
      CellTags->{
      "Any", "Any Proposition", "Iterated Implication", "Negated True", 
        "Tertium non datur", "True"}]},
  "Any Proposition"->{
    Cell[60682, 1703, 397, 11, 70, "Input",
      CellTags->{
      "Any", "Any Proposition", "Iterated Implication", "Negated True", 
        "Tertium non datur", "True"}]},
  "True Conjunct"->{
    Cell[67361, 1941, 454, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct"}],
    Cell[67818, 1955, 462, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct"}],
    Cell[72600, 2107, 491, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct", "True Implicand"}],
    Cell[73947, 2147, 496, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct", "True Implicatum"}],
    Cell[75403, 2193, 517, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct", "True Implicand", "True Left Side"}],
    Cell[76124, 2213, 520, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct", "True Implicatum", "True Right Side"}],
    Cell[76849, 2233, 546, 13, 70, "Input",
      CellTags->{
      "False Left Side", "Iterated Implication", "Negated True", 
        "Tertium non datur", "True Conjunct", "True Implicand"}],
    Cell[77600, 2254, 549, 13, 70, "Input",
      CellTags->{
      "False Right Side", "Iterated Implication", "Negated True", 
        "Tertium non datur", "True Conjunct", "True Implicatum"}]},
  "False Conjunct"->{
    Cell[68432, 1975, 461, 12, 70, "Input",
      CellTags->{
      "False Conjunct", "Iterated Implication", "Negated True", 
        "Tertium non datur"}],
    Cell[68896, 1989, 467, 12, 70, "Input",
      CellTags->{
      "False Conjunct", "Iterated Implication", "Negated True", 
        "Tertium non datur"}],
    Cell[73295, 2127, 498, 12, 70, "Input",
      CellTags->{
      "False Conjunct", "False Implicand", "Iterated Implication", 
        "Negated True", "Tertium non datur"}],
    Cell[74597, 2167, 527, 13, 70, "Input",
      CellTags->{
      "False Conjunct", "False Implicatum", "Iterated Implication", 
        "Negated True", "Tertium non datur"}]},
  "True Alternative"->{
    Cell[69589, 2014, 462, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Alternative"}],
    Cell[70054, 2028, 470, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Alternative"}]},
  "False Alternative"->{
    Cell[70679, 2048, 462, 12, 70, "Input",
      CellTags->{
      "False Alternative", "Iterated Implication", "Negated True", 
        "Tertium non datur"}],
    Cell[71144, 2062, 468, 12, 70, "Input",
      CellTags->{
      "False Alternative", "Iterated Implication", "Negated True", 
        "Tertium non datur"}],
    Cell[71819, 2082, 514, 12, 70, "Input",
      CellTags->{
      "False Alternative", "Iterated Implication", "Negated True", 
        "Tertium non datur", "test"}]},
  "test"->{
    Cell[71819, 2082, 514, 12, 70, "Input",
      CellTags->{
      "False Alternative", "Iterated Implication", "Negated True", 
        "Tertium non datur", "test"}]},
  "True Implicand"->{
    Cell[72600, 2107, 491, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct", "True Implicand"}],
    Cell[75403, 2193, 517, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct", "True Implicand", "True Left Side"}],
    Cell[76849, 2233, 546, 13, 70, "Input",
      CellTags->{
      "False Left Side", "Iterated Implication", "Negated True", 
        "Tertium non datur", "True Conjunct", "True Implicand"}]},
  "False Implicand"->{
    Cell[73295, 2127, 498, 12, 70, "Input",
      CellTags->{
      "False Conjunct", "False Implicand", "Iterated Implication", 
        "Negated True", "Tertium non datur"}]},
  "True Implicatum"->{
    Cell[73947, 2147, 496, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct", "True Implicatum"}],
    Cell[76124, 2213, 520, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct", "True Implicatum", "True Right Side"}],
    Cell[77600, 2254, 549, 13, 70, "Input",
      CellTags->{
      "False Right Side", "Iterated Implication", "Negated True", 
        "Tertium non datur", "True Conjunct", "True Implicatum"}]},
  "False Implicatum"->{
    Cell[74597, 2167, 527, 13, 70, "Input",
      CellTags->{
      "False Conjunct", "False Implicatum", "Iterated Implication", 
        "Negated True", "Tertium non datur"}]},
  "True Left Side"->{
    Cell[75403, 2193, 517, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct", "True Implicand", "True Left Side"}]},
  "True Right Side"->{
    Cell[76124, 2213, 520, 12, 70, "Input",
      CellTags->{
      "Iterated Implication", "Negated True", "Tertium non datur", 
        "True Conjunct", "True Implicatum", "True Right Side"}]},
  "False Left Side"->{
    Cell[76849, 2233, 546, 13, 70, "Input",
      CellTags->{
      "False Left Side", "Iterated Implication", "Negated True", 
        "Tertium non datur", "True Conjunct", "True Implicand"}]},
  "False Right Side"->{
    Cell[77600, 2254, 549, 13, 70, "Input",
      CellTags->{
      "False Right Side", "Iterated Implication", "Negated True", 
        "Tertium non datur", "True Conjunct", "True Implicatum"}]},
  "No contradiction"->{
    Cell[79007, 2299, 389, 9, 70, "Input",
      CellTags->{"Iterated Implication", "No contradiction"}]},
  "True alternative"->{
    Cell[79551, 2316, 365, 9, 70, "Input",
      CellTags->{"Iterated Implication", "True alternative"}]},
  "True conjunctive fails"->{
    Cell[80071, 2333, 379, 9, 70, "Input",
      CellTags->{"Iterated Implication", "True conjunctive fails"}]},
  "True conjunctive"->{
    Cell[80611, 2350, 415, 10, 70, "Input",
      CellTags->{"Iterated Implication", "True conjunctive"}]},
  "False conjunctive"->{
    Cell[81181, 2368, 422, 10, 70, "Input",
      CellTags->{"False conjunctive", "Iterated Implication"}]},
  "False alternative fails"->{
    Cell[81759, 2386, 381, 9, 70, "Input",
      CellTags->{"False alternative fails", "Iterated Implication"}]},
  "False alternative"->{
    Cell[82302, 2403, 417, 10, 70, "Input",
      CellTags->{"False alternative", "Iterated Implication"}]},
  "Commutativity of \[And]"->{
    Cell[83079, 2427, 441, 10, 70, "Input",
      CellTags->{"Commutativity of \[And]", "Iterated Implication"}]},
  "Commutativity of \[Or]"->{
    Cell[83682, 2445, 437, 10, 70, "Input",
      CellTags->{"Commutativity of \[Or]", "Iterated Implication"}]},
  "Idempotency of \[And]"->{
    Cell[84280, 2463, 407, 9, 70, "Input",
      CellTags->{"Idempotency of \[And]", "Iterated Implication"}]},
  "Idempotency of \[Or]"->{
    Cell[84847, 2480, 404, 9, 70, "Input",
      CellTags->{"Idempotency of \[Or]", "Iterated Implication"}]},
  "Associativity of \[And]"->{
    Cell[85410, 2497, 518, 11, 70, "Input",
      CellTags->{"Associativity of \[And]", "Iterated Implication"}]},
  "Associativity of \[Or]"->{
    Cell[86090, 2516, 512, 11, 70, "Input",
      CellTags->{"Associativity of \[Or]", "Iterated Implication"}]},
  "Distributivity of \[Or]"->{
    Cell[86763, 2535, 549, 12, 70, "Input",
      CellTags->{"Distributivity of \[Or]", "Iterated Implication"}]},
  "Distributivity of \[And]"->{
    Cell[87474, 2555, 552, 12, 70, "Input",
      CellTags->{"Distributivity of \[And]", "Iterated Implication"}]},
  "Absorption of \[And] over \[Or]"->{
    Cell[88189, 2575, 480, 11, 70, "Input",
      CellTags->{
      "Absorption of \[And] over \[Or]", "Iterated Implication"}]},
  "Absorption of \[Or] over \[And]"->{
    Cell[88846, 2595, 480, 11, 70, "Input",
      CellTags->{
      "Absorption of \[Or] over \[And]", "Iterated Implication"}]},
  "Double Negation"->{
    Cell[89503, 2615, 419, 10, 70, "Input",
      CellTags->{"Double Negation", "Iterated Implication"}]},
  "De Morgan for \[And]"->{
    Cell[90076, 2633, 495, 11, 70, "Input",
      CellTags->{"De Morgan for \[And]", "Iterated Implication"}],
    Cell[90730, 2652, 552, 14, 70, "Input",
      CellTags->{
      "De Morgan for \[And]", "Iterated Implication", 
        "Switched De Morgan for \[And]"}]},
  "Switched De Morgan for \[And]"->{
    Cell[90730, 2652, 552, 14, 70, "Input",
      CellTags->{
      "De Morgan for \[And]", "Iterated Implication", 
        "Switched De Morgan for \[And]"}]},
  "De Morgan for \[Or]"->{
    Cell[91457, 2675, 493, 11, 70, "Input",
      CellTags->{"De Morgan for \[Or]", "Iterated Implication"}],
    Cell[92108, 2694, 549, 14, 70, "Input",
      CellTags->{
      "De Morgan for \[Or]", "Iterated Implication", 
        "Switched De Morgan for \[Or]"}]},
  "Switched De Morgan for \[Or]"->{
    Cell[92108, 2694, 549, 14, 70, "Input",
      CellTags->{
      "De Morgan for \[Or]", "Iterated Implication", 
        "Switched De Morgan for \[Or]"}]},
  "Implication by disjunction"->{
    Cell[92924, 2722, 508, 12, 70, "Input",
      CellTags->{"Implication by disjunction", "Iterated Implication"}]},
  "Negated implication"->{
    Cell[93597, 2742, 486, 11, 70, "Input",
      CellTags->{"Iterated Implication", "Negated implication"}]},
  "Contraposition"->{
    Cell[94241, 2761, 495, 11, 70, "Input",
      CellTags->{"Contraposition", "Iterated Implication"}]},
  "Iterated implication"->{
    Cell[94889, 2780, 549, 11, 70, "Input",
      CellTags->{"Iterated implication", "Iterated Implication"}]},
  "Distributivity over disjunction"->{
    Cell[95648, 2799, 580, 13, 70, "Input",
      CellTags->{
      "Distributivity over disjunction", "Iterated Implication"}]},
  "Distributivity over conjunction"->{
    Cell[96405, 2821, 580, 13, 70, "Input",
      CellTags->{
      "Distributivity over conjunction", "Iterated Implication"}]},
  "Multiple implication"->{
    Cell[97162, 2843, 626, 13, 70, "Input",
      CellTags->{"Iterated Implication", "Multiple implication"}]},
  "Multiple conjunction"->{
    Cell[97998, 2864, 484, 11, 70, "Input",
      CellTags->{"Iterated Implication", "Multiple conjunction"}]},
  "Redundant implication"->{
    Cell[98641, 2883, 509, 11, 70, "Input",
      CellTags->{"Iterated Implication", "Redundant implication"}]},
  "Peirce implication"->{
    Cell[99310, 2902, 465, 10, 70, "Input",
      CellTags->{"Peirce implication", "Peirce Implication"}]},
  "Peirce Implication"->{
    Cell[99310, 2902, 465, 10, 70, "Input",
      CellTags->{"Peirce implication", "Peirce Implication"}]},
  "Equivalence by implication"->{
    Cell[99932, 2920, 556, 13, 70, "Input",
      CellTags->{"Equivalence by implication", "Iterated Implication"}]},
  "Equivalence by disjunction"->{
    Cell[100653, 2941, 561, 13, 70, "Input",
      CellTags->{"Equivalence by disjunction", "Iterated Implication"}]},
  "Equivalence by conjunction"->{
    Cell[101379, 2962, 535, 12, 70, "Input",
      CellTags->{"Equivalence by conjunction", "Iterated Implication"}]},
  "Negated equivalence"->{
    Cell[102257, 2988, 509, 11, 70, "Input",
      CellTags->{"Iterated Implication", "Negated equivalence"}]},
  "p2"->{
    Cell[103888, 3042, 393, 10, 52, "Input",
      CellTags->{"Iterated Implication", "p2"}]},
  "p3"->{
    Cell[104444, 3061, 450, 11, 52, "Input",
      CellTags->{"Iterated Implication", "p3"}]},
  "p4"->{
    Cell[105057, 3081, 463, 11, 52, "Input",
      CellTags->{"Iterated Implication", "p4"}]},
  "p5"->{
    Cell[105683, 3101, 479, 11, 52, "Input",
      CellTags->{"Iterated Implication", "p5"}]},
  "p6"->{
    Cell[106535, 3127, 347, 9, 52, "Input",
      CellTags->{"Iterated Implication", "p6"}]},
  "p7"->{
    Cell[107077, 3145, 369, 9, 52, "Input",
      CellTags->{"Iterated Implication", "p7"}]},
  "p8"->{
    Cell[107616, 3163, 431, 10, 52, "Input",
      CellTags->{"Iterated Implication", "p8"}]},
  "p9"->{
    Cell[108210, 3182, 524, 12, 52, "Input",
      CellTags->{"Iterated Implication", "p9"}]},
  "p10 conclusion"->{
    Cell[108898, 3203, 380, 9, 52, "Input",
      CellTags->{"Iterated Implication", "p10 conclusion"}]},
  "p10 assumptions"->{
    Cell[109281, 3214, 532, 11, 93, "Input",
      CellTags->{"Iterated Implication", "p10 assumptions"}]},
  "p11"->{
    Cell[110046, 3235, 357, 9, 52, "Input",
      CellTags->{"Iterated Implication", "p11"}]},
  "Proposition (p12)"->{
    Cell[110568, 3253, 544, 13, 52, "Input",
      CellTags->"Proposition (p12)"]},
  "p13"->{
    Cell[111576, 3283, 479, 11, 52, "Input",
      CellTags->{"Iterated Implication", "p13"}]},
  "p14"->{
    Cell[112190, 3301, 483, 11, 52, "Input",
      CellTags->{"Iterated Implication", "p14"}]},
  "p15"->{
    Cell[112808, 3319, 456, 11, 52, "Input",
      CellTags->{"Iterated Implication", "p15"}]},
  "p16"->{
    Cell[113399, 3337, 433, 11, 52, "Input",
      CellTags->{"Iterated Implication", "p16"}]},
  "p17"->{
    Cell[113967, 3355, 632, 14, 52, "Input",
      CellTags->{"Iterated Implication", "p17"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Proposition (conclusion)", 115409, 3395},
  {"Proposition (assumptions)", 115530, 3398},
  {"Proposition (independent)", 115652, 3401},
  {"Proposition (disjunction)", 115774, 3404},
  {"disjunction", 115883, 3407},
  {"p", 116161, 3414},
  {"Iterated Implication", 116522, 3423},
  {"assoc", 126724, 3635},
  {"assoc left", 126976, 3640},
  {"p1", 127103, 3643},
  {"assoc right", 127550, 3652},
  {"asm", 127679, 3655},
  {"Negated True", 127800, 3658},
  {"Tertium non datur", 131805, 3752},
  {"True", 135904, 3848},
  {"False", 136527, 3863},
  {"Negated False", 136706, 3868},
  {"Any", 137032, 3877},
  {"Any Proposition", 137230, 3882},
  {"True Conjunct", 137426, 3887},
  {"False Conjunct", 138892, 3920},
  {"True Alternative", 139588, 3937},
  {"False Alternative", 139934, 3946},
  {"test", 140438, 3959},
  {"True Implicand", 140630, 3964},
  {"False Implicand", 141216, 3977},
  {"True Implicatum", 141417, 3982},
  {"False Implicatum", 142009, 3995},
  {"True Left Side", 142210, 4000},
  {"True Right Side", 142427, 4005},
  {"False Left Side", 142646, 4010},
  {"False Right Side", 142865, 4015},
  {"No contradiction", 143086, 4020},
  {"True alternative", 143217, 4023},
  {"True conjunctive fails", 143354, 4026},
  {"True conjunctive", 143491, 4029},
  {"False conjunctive", 143624, 4032},
  {"False alternative fails", 143764, 4035},
  {"False alternative", 143903, 4038},
  {"Commutativity of \[And]", 144043, 4041},
  {"Commutativity of \[Or]", 144188, 4044},
  {"Idempotency of \[And]", 144331, 4047},
  {"Idempotency of \[Or]", 144471, 4050},
  {"Associativity of \[And]", 144613, 4053},
  {"Associativity of \[Or]", 144758, 4056},
  {"Distributivity of \[Or]", 144903, 4059},
  {"Distributivity of \[And]", 145050, 4062},
  {"Absorption of \[And] over \[Or]", 145205, 4065},
  {"Absorption of \[Or] over \[And]", 145374, 4069},
  {"Double Negation", 145527, 4073},
  {"De Morgan for \[And]", 145662, 4076},
  {"Switched De Morgan for \[And]", 145971, 4083},
  {"De Morgan for \[Or]", 146159, 4088},
  {"Switched De Morgan for \[Or]", 146464, 4095},
  {"Implication by disjunction", 146657, 4100},
  {"Negated implication", 146802, 4103},
  {"Contraposition", 146935, 4106},
  {"Iterated implication", 147069, 4109},
  {"Distributivity over disjunction", 147220, 4112},
  {"Distributivity over conjunction", 147389, 4116},
  {"Multiple implication", 147547, 4120},
  {"Multiple conjunction", 147687, 4123},
  {"Redundant implication", 147828, 4126},
  {"Peirce implication", 147967, 4129},
  {"Peirce Implication", 148101, 4132},
  {"Equivalence by implication", 148243, 4135},
  {"Equivalence by disjunction", 148395, 4138},
  {"Equivalence by conjunction", 148548, 4141},
  {"Negated equivalence", 148694, 4144},
  {"p2", 148816, 4147},
  {"p3", 148921, 4150},
  {"p4", 149026, 4153},
  {"p5", 149131, 4156},
  {"p6", 149236, 4159},
  {"p7", 149340, 4162},
  {"p8", 149444, 4165},
  {"p9", 149549, 4168},
  {"p10 conclusion", 149666, 4171},
  {"p10 assumptions", 149795, 4174},
  {"p11", 149914, 4177},
  {"Proposition (p12)", 150034, 4180},
  {"p13", 150129, 4183},
  {"p14", 150236, 4186},
  {"p15", 150343, 4189},
  {"p16", 150450, 4192},
  {"p17", 150557, 4195}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 44, 0, 174, "Title"],
Cell[1774, 54, 97, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[1896, 61, 38, 0, 49, "Section"],
Cell[1937, 63, 280, 7, 48, "Text"],

Cell[CellGroupData[{
Cell[2242, 74, 59, 1, 35, "Input"],
Cell[2304, 77, 183, 3, 53, "Print"]
}, Open  ]],
Cell[2502, 83, 185, 6, 48, "Text"],
Cell[2690, 91, 79, 1, 35, "Input"],
Cell[2772, 94, 119, 3, 28, "Text"],
Cell[2894, 99, 82, 1, 35, "Input"],
Cell[2979, 102, 77, 1, 35, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3093, 108, 51, 0, 49, "Section"],

Cell[CellGroupData[{
Cell[3169, 112, 38, 0, 38, "Subsection"],
Cell[3210, 114, 231, 8, 48, "Text"],
Cell[3444, 124, 398, 10, 52, "Input",
  CellTags->"Proposition (conclusion)"],
Cell[3845, 136, 388, 10, 73, "Input",
  CellTags->"Proposition (assumptions)"],
Cell[4236, 148, 921, 28, 48, "Text"],
Cell[5160, 178, 58, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[5243, 182, 161, 3, 51, "Input"],
Cell[5407, 187, 89, 1, 35, "Output"]
}, Open  ]],
Cell[5511, 191, 261, 5, 44, "Input"],
Cell[5775, 198, 208, 6, 28, "Text"],
Cell[5986, 206, 700, 13, 108, "Text"],
Cell[6689, 221, 93, 3, 28, "Text"],
Cell[6785, 226, 79, 1, 35, "Input"],
Cell[6867, 229, 145, 5, 28, "Text"],
Cell[7015, 236, 122, 2, 35, "Input"],
Cell[7140, 240, 129, 3, 28, "Text"],
Cell[7272, 245, 506, 11, 52, "Input",
  CellTags->"Proposition (independent)"],

Cell[CellGroupData[{
Cell[7803, 260, 70, 1, 35, "Input"],
Cell[7876, 263, 89, 1, 35, "Output"]
}, Open  ]],
Cell[7980, 267, 258, 5, 44, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8275, 277, 57, 0, 38, "Subsection"],
Cell[8335, 279, 130, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[8490, 286, 61, 1, 35, "Input"],
Cell[8554, 289, 620, 17, 103, "Output"]
}, Open  ]],
Cell[9189, 309, 87, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[9301, 316, 50, 1, 35, "Input"],
Cell[9354, 319, 303, 6, 97, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9694, 330, 59, 1, 35, "Input"],
Cell[9756, 333, 159, 4, 52, "Print"]
}, Open  ]],
Cell[9930, 340, 335, 9, 68, "Text"],
Cell[10268, 351, 499, 12, 52, "Input",
  CellTags->"Proposition (disjunction)"],
Cell[10770, 365, 178, 5, 35, "Input",
  CellTags->{"disjunction", "p"}],
Cell[10951, 372, 270, 6, 51, "Input",
  CellTags->{"disjunction", "p"}],
Cell[11224, 380, 222, 4, 48, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11483, 389, 62, 0, 38, "Subsection"],
Cell[11548, 391, 204, 4, 48, "Text"],
Cell[11755, 397, 516, 12, 52, "Input",
  CellTags->{"disjunction", "Iterated Implication", "p"}],
Cell[12274, 411, 348, 8, 67, "Input",
  CellTags->"p"],
Cell[12625, 421, 155, 4, 28, "Text"],

Cell[CellGroupData[{
Cell[12805, 429, 91, 3, 35, "Input"],
Cell[12899, 434, 125, 4, 67, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13061, 443, 47, 1, 35, "Input"],
Cell[13111, 446, 1007, 25, 121, "Output"]
}, Open  ]],
Cell[14133, 474, 156, 4, 28, "Text"],
Cell[14292, 480, 344, 11, 48, "Text"],

Cell[CellGroupData[{
Cell[14661, 495, 57, 1, 35, "Input"],
Cell[14721, 498, 164, 6, 33, "Output"]
}, Open  ]],
Cell[14900, 507, 101, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[15026, 514, 46, 1, 35, "Input"],
Cell[15075, 517, 179, 5, 67, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15291, 527, 43, 1, 35, "Input"],
Cell[15337, 530, 202, 5, 67, "Print"]
}, Open  ]],
Cell[15554, 538, 73, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[15652, 542, 138, 2, 51, "Input"],
Cell[15793, 546, 1062, 27, 70, "Output"]
}, Closed]],
Cell[16870, 576, 552, 14, 88, "Text"],

Cell[CellGroupData[{
Cell[17447, 594, 48, 1, 35, "Input"],
Cell[17498, 597, 26673, 638, 70, "Output"]
}, Closed]],
Cell[44186, 1238, 59, 1, 35, "Input"],

Cell[CellGroupData[{
Cell[44270, 1243, 85, 1, 35, "Input"],
Cell[44358, 1246, 9957, 247, 70, "Output"]
}, Closed]],
Cell[54330, 1496, 45, 1, 35, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54412, 1502, 61, 0, 38, "Subsection"],
Cell[54476, 1504, 194, 6, 48, "Text"],

Cell[CellGroupData[{
Cell[54695, 1514, 47, 1, 35, "Input"],
Cell[54745, 1517, 1006, 25, 103, "Output"]
}, Open  ]],
Cell[55766, 1545, 127, 5, 28, "Text"],
Cell[55896, 1552, 541, 11, 52, "Input",
  CellTags->{"assoc", "assoc left", "Iterated Implication", "p1"}],
Cell[56440, 1565, 542, 11, 52, "Input",
  CellTags->{"assoc", "assoc right", "Iterated Implication", "p1"}],
Cell[56985, 1578, 559, 12, 73, "Input",
  CellTags->{"asm", "Iterated Implication", "p1"}],

Cell[CellGroupData[{
Cell[57569, 1594, 255, 6, 51, "Input"],
Cell[57827, 1602, 123, 2, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[57987, 1609, 256, 6, 51, "Input"],
Cell[58246, 1617, 123, 2, 70, "Output"]
}, Closed]],
Cell[58384, 1622, 241, 5, 48, "Text"],

Cell[CellGroupData[{
Cell[58650, 1631, 59, 1, 35, "Input"],
Cell[58712, 1634, 89, 1, 70, "Output"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[58862, 1642, 57, 0, 49, "Section"],

Cell[CellGroupData[{
Cell[58944, 1646, 66, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[59035, 1650, 84, 1, 70, "Subsubsection"],
Cell[59122, 1653, 370, 10, 70, "Input",
  CellTags->{
  "Iterated Implication", "Negated True", "Tertium non datur", "True"}],
Cell[59495, 1665, 386, 11, 70, "Input",
  CellTags->{
  "False", "Iterated Implication", "Negated True", "Tertium non datur", 
    "True"}],
Cell[59884, 1678, 388, 10, 70, "Input",
  CellTags->{
  "Iterated Implication", "Negated True", "Tertium non datur", "True"}],
Cell[60275, 1690, 404, 11, 70, "Input",
  CellTags->{
  "Iterated Implication", "Negated False", "Negated True", 
    "Tertium non datur"}],
Cell[60682, 1703, 397, 11, 70, "Input",
  CellTags->{
  "Any", "Any Proposition", "Iterated Implication", "Negated True", 
    "Tertium non datur", "True"}]
}, Closed]],

Cell[CellGroupData[{
Cell[61116, 1719, 69, 0, 70, "Subsubsection"],
Cell[61188, 1721, 130, 3, 70, "Input"],
Cell[61321, 1726, 138, 4, 70, "Input"],
Cell[61462, 1732, 145, 4, 70, "Input"],
Cell[61610, 1738, 146, 4, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[61793, 1747, 76, 0, 70, "Subsubsection"],
Cell[61872, 1749, 175, 4, 70, "Input"],
Cell[62050, 1755, 176, 4, 70, "Input"],
Cell[62229, 1761, 183, 4, 70, "Input"],
Cell[62415, 1767, 184, 4, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[62636, 1776, 76, 0, 70, "Subsubsection"],
Cell[62715, 1778, 175, 4, 70, "Input"],
Cell[62893, 1784, 176, 4, 70, "Input"],
Cell[63072, 1790, 183, 4, 70, "Input"],
Cell[63258, 1796, 184, 4, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[63479, 1805, 65, 0, 70, "Subsubsection"],
Cell[63547, 1807, 177, 4, 70, "Input"],
Cell[63727, 1813, 184, 4, 70, "Input"],
Cell[63914, 1819, 185, 4, 70, "Input"],
Cell[64102, 1825, 35, 1, 70, "Input"],
Cell[64140, 1828, 177, 4, 70, "Input"],
Cell[64320, 1834, 185, 4, 70, "Input"],
Cell[64508, 1840, 186, 4, 70, "Input"],
Cell[64697, 1846, 35, 1, 70, "Input"],
Cell[64735, 1849, 184, 4, 70, "Input"],
Cell[64922, 1855, 185, 4, 70, "Input"],
Cell[65110, 1861, 193, 4, 70, "Input"],
Cell[65306, 1867, 35, 1, 70, "Input"],
Cell[65344, 1870, 185, 4, 70, "Input"],
Cell[65532, 1876, 186, 4, 70, "Input"],
Cell[65721, 1882, 193, 4, 70, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[65963, 1892, 75, 0, 24, "Subsection"],

Cell[CellGroupData[{
Cell[66063, 1896, 33, 0, 70, "Subsubsection"],
Cell[66099, 1898, 430, 10, 70, "Input",
  CellTags->{"Iterated Implication", "Negated True", "Tertium non datur"}],
Cell[66532, 1910, 145, 4, 70, "Input"],
Cell[66680, 1916, 456, 12, 70, "Input",
  CellTags->{
  "Iterated Implication", "Negated False", "Negated True", 
    "Tertium non datur"}],
Cell[67139, 1930, 146, 4, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[67322, 1939, 36, 0, 70, "Subsubsection"],
Cell[67361, 1941, 454, 12, 70, "Input",
  CellTags->{
  "Iterated Implication", "Negated True", "Tertium non datur", 
    "True Conjunct"}],
Cell[67818, 1955, 462, 12, 70, "Input",
  CellTags->{
  "Iterated Implication", "Negated True", "Tertium non datur", 
    "True Conjunct"}],
Cell[68283, 1969, 146, 4, 70, "Input"],
Cell[68432, 1975, 461, 12, 70, "Input",
  CellTags->{
  "False Conjunct", "Iterated Implication", "Negated True", 
    "Tertium non datur"}],
Cell[68896, 1989, 467, 12, 70, "Input",
  CellTags->{
  "False Conjunct", "Iterated Implication", "Negated True", 
    "Tertium non datur"}],
Cell[69366, 2003, 147, 4, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[69550, 2012, 36, 0, 70, "Subsubsection"],
Cell[69589, 2014, 462, 12, 70, "Input",
  CellTags->{
  "Iterated Implication", "Negated True", "Tertium non datur", 
    "True Alternative"}],
Cell[70054, 2028, 470, 12, 70, "Input",
  CellTags->{
  "Iterated Implication", "Negated True", "Tertium non datur", 
    "True Alternative"}],
Cell[70527, 2042, 149, 4, 70, "Input"],
Cell[70679, 2048, 462, 12, 70, "Input",
  CellTags->{
  "False Alternative", "Iterated Implication", "Negated True", 
    "Tertium non datur"}],
Cell[71144, 2062, 468, 12, 70, "Input",
  CellTags->{
  "False Alternative", "Iterated Implication", "Negated True", 
    "Tertium non datur"}],
Cell[71615, 2076, 201, 4, 70, "Input"],
Cell[71819, 2082, 514, 12, 70, "Input",
  CellTags->{
  "False Alternative", "Iterated Implication", "Negated True", 
    "Tertium non datur", "test"}],
Cell[72336, 2096, 188, 4, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[72561, 2105, 36, 0, 70, "Subsubsection"],
Cell[72600, 2107, 491, 12, 70, "Input",
  CellTags->{
  "Iterated Implication", "Negated True", "Tertium non datur", 
    "True Conjunct", "True Implicand"}],
Cell[73094, 2121, 198, 4, 70, "Input"],
Cell[73295, 2127, 498, 12, 70, "Input",
  CellTags->{
  "False Conjunct", "False Implicand", "Iterated Implication", "Negated True",
     "Tertium non datur"}],
Cell[73796, 2141, 148, 4, 70, "Input"],
Cell[73947, 2147, 496, 12, 70, "Input",
  CellTags->{
  "Iterated Implication", "Negated True", "Tertium non datur", 
    "True Conjunct", "True Implicatum"}],
Cell[74446, 2161, 148, 4, 70, "Input"],
Cell[74597, 2167, 527, 13, 70, "Input",
  CellTags->{
  "False Conjunct", "False Implicatum", "Iterated Implication", 
    "Negated True", "Tertium non datur"}],
Cell[75127, 2182, 200, 4, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[75364, 2191, 36, 0, 70, "Subsubsection"],
Cell[75403, 2193, 517, 12, 70, "Input",
  CellTags->{
  "Iterated Implication", "Negated True", "Tertium non datur", 
    "True Conjunct", "True Implicand", "True Left Side"}],
Cell[75923, 2207, 198, 4, 70, "Input"],
Cell[76124, 2213, 520, 12, 70, "Input",
  CellTags->{
  "Iterated Implication", "Negated True", "Tertium non datur", 
    "True Conjunct", "True Implicatum", "True Right Side"}],
Cell[76647, 2227, 199, 4, 70, "Input"],
Cell[76849, 2233, 546, 13, 70, "Input",
  CellTags->{
  "False Left Side", "Iterated Implication", "Negated True", 
    "Tertium non datur", "True Conjunct", "True Implicand"}],
Cell[77398, 2248, 199, 4, 70, "Input"],
Cell[77600, 2254, 549, 13, 70, "Input",
  CellTags->{
  "False Right Side", "Iterated Implication", "Negated True", 
    "Tertium non datur", "True Conjunct", "True Implicatum"}],
Cell[78152, 2269, 200, 4, 70, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[78413, 2280, 57, 0, 33, "Section"],
Cell[78473, 2282, 378, 9, 70, "Input",
  CellTags->{"Iterated Implication", "Tertium non datur"}],
Cell[78854, 2293, 150, 4, 70, "Input"],
Cell[79007, 2299, 389, 9, 70, "Input",
  CellTags->{"Iterated Implication", "No contradiction"}],
Cell[79399, 2310, 149, 4, 70, "Input"],
Cell[79551, 2316, 365, 9, 70, "Input",
  CellTags->{"Iterated Implication", "True alternative"}],
Cell[79919, 2327, 149, 4, 70, "Input"],
Cell[80071, 2333, 379, 9, 70, "Input",
  CellTags->{"Iterated Implication", "True conjunctive fails"}],
Cell[80453, 2344, 155, 4, 70, "Input"],
Cell[80611, 2350, 415, 10, 70, "Input",
  CellTags->{"Iterated Implication", "True conjunctive"}],
Cell[81029, 2362, 149, 4, 70, "Input"],
Cell[81181, 2368, 422, 10, 70, "Input",
  CellTags->{"False conjunctive", "Iterated Implication"}],
Cell[81606, 2380, 150, 4, 70, "Input"],
Cell[81759, 2386, 381, 9, 70, "Input",
  CellTags->{"False alternative fails", "Iterated Implication"}],
Cell[82143, 2397, 156, 4, 70, "Input"],
Cell[82302, 2403, 417, 10, 70, "Input",
  CellTags->{"False alternative", "Iterated Implication"}],
Cell[82722, 2415, 150, 4, 70, "Input"],
Cell[82875, 2421, 201, 4, 70, "Input"],
Cell[83079, 2427, 441, 10, 70, "Input",
  CellTags->{"Commutativity of \[And]", "Iterated Implication"}],
Cell[83523, 2439, 156, 4, 70, "Input"],
Cell[83682, 2445, 437, 10, 70, "Input",
  CellTags->{"Commutativity of \[Or]", "Iterated Implication"}],
Cell[84122, 2457, 155, 4, 70, "Input"],
Cell[84280, 2463, 407, 9, 70, "Input",
  CellTags->{"Idempotency of \[And]", "Iterated Implication"}],
Cell[84690, 2474, 154, 4, 70, "Input"],
Cell[84847, 2480, 404, 9, 70, "Input",
  CellTags->{"Idempotency of \[Or]", "Iterated Implication"}],
Cell[85254, 2491, 153, 4, 70, "Input"],
Cell[85410, 2497, 518, 11, 70, "Input",
  CellTags->{"Associativity of \[And]", "Iterated Implication"}],
Cell[85931, 2510, 156, 4, 70, "Input"],
Cell[86090, 2516, 512, 11, 70, "Input",
  CellTags->{"Associativity of \[Or]", "Iterated Implication"}],
Cell[86605, 2529, 155, 4, 70, "Input"],
Cell[86763, 2535, 549, 12, 70, "Input",
  CellTags->{"Distributivity of \[Or]", "Iterated Implication"}],
Cell[87315, 2549, 156, 4, 70, "Input"],
Cell[87474, 2555, 552, 12, 70, "Input",
  CellTags->{"Distributivity of \[And]", "Iterated Implication"}],
Cell[88029, 2569, 157, 4, 70, "Input"],
Cell[88189, 2575, 480, 11, 70, "Input",
  CellTags->{"Absorption of \[And] over \[Or]", "Iterated Implication"}],
Cell[88672, 2588, 171, 5, 70, "Input"],
Cell[88846, 2595, 480, 11, 70, "Input",
  CellTags->{"Absorption of \[Or] over \[And]", "Iterated Implication"}],
Cell[89329, 2608, 171, 5, 70, "Input"],
Cell[89503, 2615, 419, 10, 70, "Input",
  CellTags->{"Double Negation", "Iterated Implication"}],
Cell[89925, 2627, 148, 4, 70, "Input"],
Cell[90076, 2633, 495, 11, 70, "Input",
  CellTags->{"De Morgan for \[And]", "Iterated Implication"}],
Cell[90574, 2646, 153, 4, 70, "Input"],
Cell[90730, 2652, 552, 14, 70, "Input",
  CellTags->{
  "De Morgan for \[And]", "Iterated Implication", 
    "Switched De Morgan for \[And]"}],
Cell[91285, 2668, 169, 5, 70, "Input"],
Cell[91457, 2675, 493, 11, 70, "Input",
  CellTags->{"De Morgan for \[Or]", "Iterated Implication"}],
Cell[91953, 2688, 152, 4, 70, "Input"],
Cell[92108, 2694, 549, 14, 70, "Input",
  CellTags->{
  "De Morgan for \[Or]", "Iterated Implication", 
    "Switched De Morgan for \[Or]"}],
Cell[92660, 2710, 168, 5, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[92865, 2720, 56, 0, 33, "Section"],
Cell[92924, 2722, 508, 12, 70, "Input",
  CellTags->{"Implication by disjunction", "Iterated Implication"}],
Cell[93435, 2736, 159, 4, 70, "Input"],
Cell[93597, 2742, 486, 11, 70, "Input",
  CellTags->{"Iterated Implication", "Negated implication"}],
Cell[94086, 2755, 152, 4, 70, "Input"],
Cell[94241, 2761, 495, 11, 70, "Input",
  CellTags->{"Contraposition", "Iterated Implication"}],
Cell[94739, 2774, 147, 4, 70, "Input"],
Cell[94889, 2780, 549, 11, 70, "Input",
  CellTags->{"Iterated implication", "Iterated Implication"}],
Cell[95441, 2793, 204, 4, 70, "Input"],
Cell[95648, 2799, 580, 13, 70, "Input",
  CellTags->{"Distributivity over disjunction", "Iterated Implication"}],
Cell[96231, 2814, 171, 5, 70, "Input"],
Cell[96405, 2821, 580, 13, 70, "Input",
  CellTags->{"Distributivity over conjunction", "Iterated Implication"}],
Cell[96988, 2836, 171, 5, 70, "Input"],
Cell[97162, 2843, 626, 13, 70, "Input",
  CellTags->{"Iterated Implication", "Multiple implication"}],
Cell[97791, 2858, 204, 4, 70, "Input"],
Cell[97998, 2864, 484, 11, 70, "Input",
  CellTags->{"Iterated Implication", "Multiple conjunction"}],
Cell[98485, 2877, 153, 4, 70, "Input"],
Cell[98641, 2883, 509, 11, 70, "Input",
  CellTags->{"Iterated Implication", "Redundant implication"}],
Cell[99153, 2896, 154, 4, 70, "Input"],
Cell[99310, 2902, 465, 10, 70, "Input",
  CellTags->{"Peirce implication", "Peirce Implication"}],
Cell[99778, 2914, 151, 4, 70, "Input"],
Cell[99932, 2920, 556, 13, 70, "Input",
  CellTags->{"Equivalence by implication", "Iterated Implication"}],
Cell[100491, 2935, 159, 4, 70, "Input"],
Cell[100653, 2941, 561, 13, 70, "Input",
  CellTags->{"Equivalence by disjunction", "Iterated Implication"}],
Cell[101217, 2956, 159, 4, 70, "Input"],
Cell[101379, 2962, 535, 12, 70, "Input",
  CellTags->{"Equivalence by conjunction", "Iterated Implication"}],
Cell[101917, 2976, 159, 4, 70, "Input"],
Cell[102079, 2982, 175, 4, 70, "Text"],
Cell[102257, 2988, 509, 11, 70, "Input",
  CellTags->{"Iterated Implication", "Negated equivalence"}],
Cell[102769, 3001, 152, 4, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[102958, 3010, 40, 0, 33, "Section"],
Cell[103001, 3012, 160, 4, 48, "Text"],
Cell[103164, 3018, 66, 0, 28, "Text"],
Cell[103233, 3020, 26, 0, 28, "Text"],
Cell[103262, 3022, 463, 11, 52, "Input",
  CellTags->{"Iterated Implication", "p1"}],
Cell[103728, 3035, 128, 3, 35, "Input"],
Cell[103859, 3040, 26, 0, 28, "Text"],
Cell[103888, 3042, 393, 10, 52, "Input",
  CellTags->{"Iterated Implication", "p2"}],
Cell[104284, 3054, 128, 3, 35, "Input"],
Cell[104415, 3059, 26, 0, 28, "Text"],
Cell[104444, 3061, 450, 11, 52, "Input",
  CellTags->{"Iterated Implication", "p3"}],
Cell[104897, 3074, 128, 3, 35, "Input"],
Cell[105028, 3079, 26, 0, 28, "Text"],
Cell[105057, 3081, 463, 11, 52, "Input",
  CellTags->{"Iterated Implication", "p4"}],
Cell[105523, 3094, 128, 3, 35, "Input"],
Cell[105654, 3099, 26, 0, 28, "Text"],
Cell[105683, 3101, 479, 11, 52, "Input",
  CellTags->{"Iterated Implication", "p5"}],
Cell[106165, 3114, 128, 3, 35, "Input"],
Cell[106296, 3119, 184, 4, 35, "Input"],
Cell[106483, 3125, 49, 0, 28, "Text"],
Cell[106535, 3127, 347, 9, 52, "Input",
  CellTags->{"Iterated Implication", "p6"}],
Cell[106885, 3138, 128, 3, 35, "Input"],
Cell[107016, 3143, 58, 0, 28, "Text"],
Cell[107077, 3145, 369, 9, 52, "Input",
  CellTags->{"Iterated Implication", "p7"}],
Cell[107449, 3156, 128, 3, 35, "Input"],
Cell[107580, 3161, 33, 0, 28, "Text"],
Cell[107616, 3163, 431, 10, 52, "Input",
  CellTags->{"Iterated Implication", "p8"}],
Cell[108050, 3175, 128, 3, 35, "Input"],
Cell[108181, 3180, 26, 0, 28, "Text"],
Cell[108210, 3182, 524, 12, 52, "Input",
  CellTags->{"Iterated Implication", "p9"}],
Cell[108737, 3196, 128, 3, 35, "Input"],
Cell[108868, 3201, 27, 0, 28, "Text"],
Cell[108898, 3203, 380, 9, 52, "Input",
  CellTags->{"Iterated Implication", "p10 conclusion"}],
Cell[109281, 3214, 532, 11, 93, "Input",
  CellTags->{"Iterated Implication", "p10 assumptions"}],
Cell[109816, 3227, 197, 4, 35, "Input"],
Cell[110016, 3233, 27, 0, 28, "Text"],
Cell[110046, 3235, 357, 9, 52, "Input",
  CellTags->{"Iterated Implication", "p11"}],
Cell[110406, 3246, 129, 3, 35, "Input"],
Cell[110538, 3251, 27, 0, 28, "Text"],
Cell[110568, 3253, 544, 13, 52, "Input",
  CellTags->"Proposition (p12)"],
Cell[111115, 3268, 129, 3, 35, "Input"],
Cell[111247, 3273, 187, 4, 35, "Input"],
Cell[111437, 3279, 136, 2, 35, "Input"],
Cell[111576, 3283, 479, 11, 52, "Input",
  CellTags->{"Iterated Implication", "p13"}],
Cell[112058, 3296, 129, 3, 35, "Input"],
Cell[112190, 3301, 483, 11, 52, "Input",
  CellTags->{"Iterated Implication", "p14"}],
Cell[112676, 3314, 129, 3, 35, "Input"],
Cell[112808, 3319, 456, 11, 52, "Input",
  CellTags->{"Iterated Implication", "p15"}],
Cell[113267, 3332, 129, 3, 35, "Input"],
Cell[113399, 3337, 433, 11, 52, "Input",
  CellTags->{"Iterated Implication", "p16"}],
Cell[113835, 3350, 129, 3, 35, "Input"],
Cell[113967, 3355, 632, 14, 52, "Input",
  CellTags->{"Iterated Implication", "p17"}],
Cell[114602, 3371, 129, 3, 35, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

