(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     24162,        685]*)
(*NotebookOutlinePosition[     31773,        858]*)
(*  CellTagsIndexPosition[     30102,        823]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Algorithm:  Sorting", "Section"],

Cell[CellGroupData[{

Cell["by Bruno Buchberger", "Subsubtitle",
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontVariations->{"CompatibilityType"->0}],

Cell[CellGroupData[{

Cell["Top-down exploration: sorting theory", "Subsection"],

Cell[CellGroupData[{

Cell["Predicate on Tuples: is sorted version ", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<is sorted version\>\"", ",", \(any[is\[Dash]tuple[X], \ Y]\), ",", 
        "\[IndentingNewLine]", 
        RowBox[{\(is\[Dash]sorted\[Dash]version[X, Y]\), "  ", 
          "\[DoubleLeftRightArrow]", 
          RowBox[{"(", 
            RowBox[{"\[And]", 
              RowBox[{"{", GridBox[{
                    {\(\(is\[Dash]tuple[Y]\)\(\ \)\)},
                    {\(\(X\)\(\[TildeTilde]\)\(Y\)\(\ \ \)\)},
                    {\(is\[Dash]sorted[Y]\)}
                    },
                  ColumnAlignments->{Left}], 
                StyleBox["}",
                  ShowContents->False]}]}], " ", ")"}]}]}], "]"}]], "Input",
  CellLabel->"TS_In[136]:=",
  CellTags->"Definition (is sorted version)"],

Cell[BoxData[
    \(Definition["\<is sorted version\>", \ 
      any[X, \ Y], \ \ with[
        is\[Dash]tuple[X]], \[IndentingNewLine]is\[Dash]sorted\[Dash]version[
          X, \ Y] \[DoubleLeftRightArrow] \((is\[Dash]tuple[Y] \[And] 
            X \[TildeTilde] Y \[And] is\[Dash]sorted[Y])\)\ ]\)], "Input",
  CellLabel->"TS_In[85]:=",
  InitializationCell->True,
  Background->None,
  CellTags->"Definition (is sorted version)"],

Cell[BoxData[
    \(Proposition["\<trivial tuples are sorted versions\>", \ 
      any[is\[Dash]tuple[X]], \ 
      with[is\[Dash]trivial\[Dash]tuple[
          X]], \ \[IndentingNewLine]is\[Dash]sorted\[Dash]version[X, \ 
        X]]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Predicate on Tuples: is\[Dash]sorted", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<is sorted\>\"", ",", \(any[x, y, z\&_]\), ",", 
        "\[IndentingNewLine]", GridBox[{
            {\(\(is\[Dash]sorted[\[LeftAngleBracket]\[RightAngleBracket]]\)\(\
\ \)\)},
            {\(is\[Dash]sorted[\[LeftAngleBracket]x\[RightAngleBracket]]\)},
            {
              
              RowBox[{\(is\[Dash]sorted[\[LeftAngleBracket]x, y, 
                    z\&_\[RightAngleBracket]]\), "   ", 
                "\[DoubleLeftRightArrow]", "\[IndentingNewLine]", 
                RowBox[{"(", 
                  RowBox[{"\[And]", 
                    RowBox[{
                      StyleBox["{",
                        SpanMaxSize->Infinity], GridBox[{
                          {\(x \[GreaterEqual] y\)},
                          {\(is\[Dash]sorted[\[LeftAngleBracket]y, 
                                z\&_\[RightAngleBracket]]\)}
                          },
                        ColumnAlignments->{Left}], 
                      StyleBox["}",
                        ShowContents->False]}]}], " ", ")"}]}]}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellLabel->"TS_In[82]:=",
  InitializationCell->True,
  CellTags->"Definition (is sorted)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<trivial tuples are sorted\>", \ 
      any[x\&_], \ 
      with[is\[Dash]trivial\[Dash]tuple[\[LeftAngleBracket]x\&_\
\[RightAngleBracket]]], \ \[IndentingNewLine]is\[Dash]sorted[\
\[LeftAngleBracket]x\&_\[RightAngleBracket]]\), "]"}]], "Input",
  CellLabel->"TS_In[83]:=",
  InitializationCell->True,
  Background->None,
  CellTags->"Proposition (trivial tuples are sorted)"],

Cell[BoxData[
    \(Proposition["\<trivial tuples are sorted: variant\>", \ 
      any[X], \ \[IndentingNewLine]is\[Dash]trivial\[Dash]tuple[X] \[Implies] 
        is\[Dash]sorted[X]]\)], "Input",
  CellLabel->"TS_In[84]:=",
  InitializationCell->True,
  CellTags->"Proposition (trivial tuples are sorted: variant)"]
}, Closed]],

Cell[CellGroupData[{

Cell["Relation on Tuples: is permuted version", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<is permuted version\>\"", ",", \(any[x, x\&_, y, y\&_]\), ",", 
        "\[IndentingNewLine]", GridBox[{
            {\(\(\[LeftAngleBracket]\[RightAngleBracket]\)\(\[TildeTilde]\)\(\
\[LeftAngleBracket]\[RightAngleBracket]\)\(\ \)\)},
            {\(\[LeftAngleBracket]\[RightAngleBracket] \[NotTildeTilde] \
\[LeftAngleBracket]y, y\&_\[RightAngleBracket]\)},
            {\(\[LeftAngleBracket]x, 
                    x\&_\[RightAngleBracket] \[TildeTilde] \
\[LeftAngleBracket]y\&_\[RightAngleBracket]\  \[DoubleLeftRightArrow] \((x \
\[Element] \[LeftAngleBracket]y\&_\[RightAngleBracket] \[And] \
\[LeftAngleBracket]x\&_\[RightAngleBracket] \[TildeTilde] 
                      dfo[x, \ \
\[LeftAngleBracket]y\&_\[RightAngleBracket]])\)\)}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellLabel->"TS_In[64]:=",
  InitializationCell->True,
  CellTags->"Definition (is permuted version)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], 
      "[", \("\<only empty tuple equivalent to empty tuple\>", 
      any[is\[Dash]tuple[
          X]], \[IndentingNewLine]\((X \[TildeTilde] \[LeftAngleBracket]\
\[RightAngleBracket])\) \[Implies] \((X = \[LeftAngleBracket]\
\[RightAngleBracket])\)\), "]"}]], "Input",
  CellLabel->"TS_In[65]:=",
  InitializationCell->True,
  CellTags->"Proposition (only empty tuple equivalent to empty tuple)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], 
      "[", \("\<only empty tuple equivalent to empty tuple: variant\>", 
      any[X], \[IndentingNewLine]\((X \[TildeTilde] \[LeftAngleBracket]\
\[RightAngleBracket])\) \[DoubleLeftRightArrow] \((X = \[LeftAngleBracket]\
\[RightAngleBracket])\)\), "]"}]], "Input",
  CellLabel->"TS_In[66]:=",
  InitializationCell->True,
  CellTags->
  "Proposition (only empty tuple equivalent to empty tuple: variant)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], 
      "[", \("\<only singleton equivalent to singleton\>", \ 
      any[is\[Dash]tuple[X], \ 
        y], \ \[IndentingNewLine]\((\[LeftAngleBracket]y\[RightAngleBracket] \
\[TildeTilde] 
            X)\) \[Implies] \((X = \
\[LeftAngleBracket]y\[RightAngleBracket])\)\), "]"}]], "Input",
  CellLabel->"TS_In[67]:=",
  InitializationCell->True,
  CellTags->"Proposition (only singleton equivalent to singleton)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], 
      "[", \("\<only singleton equivalent to singleton: variant\>", \ 
      any[X, \ y], \ \[IndentingNewLine]\((\[LeftAngleBracket]y\
\[RightAngleBracket] \[TildeTilde] 
            X)\) \[DoubleLeftRightArrow] \((X = \[LeftAngleBracket]y\
\[RightAngleBracket])\)\), "]"}]], "Input",
  CellLabel->"TS_In[68]:=",
  InitializationCell->True,
  CellTags->"Proposition (only singleton equivalent to singleton: variant)"],

Cell[BoxData[
    \(Proposition["\<only trivial tuple permuted version of itself\>", \ 
      any[is\[Dash]tuple[X, \ Y]], \ 
      with[is\[Dash]trivial\[Dash]tuple[
          X]], \ \[IndentingNewLine]\((X \[TildeTilde] 
            Y)\) \[DoubleLeftRightArrow] \ \((X = Y)\)]\)], "Input"],

Cell[BoxData[
    \(Proposition["\<only trivial tuple permuted version of itself\>", \ 
      any[x\&_, \ 
        Y], \ \ is\[Dash]trivial\[Dash]tuple[\[LeftAngleBracket]x\&_\
\[RightAngleBracket]], \ \[IndentingNewLine]\((Y = \[LeftAngleBracket]x\&_\
\[RightAngleBracket])\) \[Implies] \((Y \[TildeTilde] \[LeftAngleBracket]x\&_\
\[RightAngleBracket])\)]\)], "Input",
  CellLabel->"TS_In[69]:=",
  InitializationCell->True,
  Background->GrayLevel[1],
  CellTags->"Proposition (only trivial tuple permuted version of itself)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], 
      "[", \("\<permuted version with concatenation\>", \ 
      any[is\[Dash]tuple[X, \ Y, \ 
          Z]], \ \[IndentingNewLine]\((X \[TildeTilde] 
            Y)\) \[Implies] \((\((X \[CupCap] 
                Z)\) \[TildeTilde] \((Y \[CupCap] Z)\))\)\), "]"}]], "Input",
  CellLabel->"TS_In[70]:=",
  InitializationCell->True,
  CellTags->"Proposition (permuted version with concatenation)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<permuted version with append\>", \ 
      any[is\[Dash]tuple[X, \ Y], \ 
        a], \ \[IndentingNewLine]\((X \[TildeTilde] 
            Y)\) \[Implies] \((\((X\[Cap]a)\) \[TildeTilde] \((Y\[Cap]
                a)\))\)\), "]"}]], "Input",
  CellLabel->"TS_In[71]:=",
  InitializationCell->True,
  CellTags->"Proposition (permuted version with append)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<permuted version with prepend\>", \ 
      any[is\[Dash]tuple[X, \ Y], \ 
        a], \ \[IndentingNewLine]\((X \[TildeTilde] 
            Y)\) \[Implies] \((\((a\[Cup]X)\) \[TildeTilde] \((a\[Cup]
                Y)\))\)\), "]"}]], "Input",
  CellLabel->"TS_In[72]:=",
  InitializationCell->True,
  CellTags->"Proposition (permuted version with prepend)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<Membership with Equivalence\>", \ 
      any[a, \ is\[Dash]tuple[X, \ 
          Y]], \ \[IndentingNewLine]a \[Element] X \[And] 
          X \[TildeTilde] Y \[Implies] \ a\  \[Element] \ Y\), "]"}]], "Input",\

  CellLabel->"TS_In[73]:=",
  InitializationCell->True,
  CellTags->"Proposition (Membership with Equivalence)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<Deletion in permuted version\>", 
      any[a, \ is\[Dash]tuple[X, \ Y]], \[IndentingNewLine]X \[TildeTilde] 
          Y\  \[Implies] \ dfo[a, \ X] \[TildeTilde] dfo[a, \ Y]\), 
      "]"}]], "Input",
  CellLabel->"TS_In[74]:=",
  InitializationCell->True,
  CellTags->"Proposition (Deletion in permuted version)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<reflexivity of permuted version\>", 
      any[x\&_], \[IndentingNewLine]\[LeftAngleBracket]x\&_\
\[RightAngleBracket] \[TildeTilde] \
\[LeftAngleBracket]x\&_\[RightAngleBracket]\), "]"}]], "Input",
  CellLabel->"TS_In[75]:=",
  InitializationCell->True,
  CellTags->"Proposition (reflexivity of permuted version)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], 
      "[", \("\<reflexivity of permuted version: gen\>", 
      any[is\[Dash]tuple[X]], \[IndentingNewLine]X \[TildeTilde] X\), 
      "]"}]], "Input",
  CellLabel->"TS_In[76]:=",
  InitializationCell->True,
  CellTags->"Proposition (reflexivity of permuted version: gen)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<symmetry of permuted version\>", 
      any[x\&_, \ 
        y\&_], \[IndentingNewLine]\[LeftAngleBracket]x\&_\[RightAngleBracket] \
\[TildeTilde] \[LeftAngleBracket]y\&_\[RightAngleBracket] \[Implies] \
\[LeftAngleBracket]y\&_\[RightAngleBracket] \[TildeTilde] \
\[LeftAngleBracket]x\&_\[RightAngleBracket]\), "]"}]], "Input",
  CellLabel->"TS_In[77]:=",
  InitializationCell->True,
  CellTags->"Proposition (symmetry of permuted version)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<symmetry of permuted version: gen\>", 
      any[is\[Dash]tuple[X, \ Y]], \[IndentingNewLine]X \[TildeTilde] 
          Y \[Implies] Y \[TildeTilde] X\), "]"}]], "Input",
  CellLabel->"TS_In[78]:=",
  InitializationCell->True,
  CellTags->"Proposition (symmetry of permuted version: gen)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<transitivity of permuted version\>", 
      any[x\&_, \ y\&_, 
        z\&_], \[IndentingNewLine]\[LeftAngleBracket]x\&_\[RightAngleBracket] \
\[TildeTilde] \[LeftAngleBracket]y\&_\[RightAngleBracket] \[And] \
\[LeftAngleBracket]y\&_\[RightAngleBracket] \[TildeTilde] \
\[LeftAngleBracket]z\&_\[RightAngleBracket] \[Implies] \
\[LeftAngleBracket]x\&_\[RightAngleBracket] \[TildeTilde] \
\[LeftAngleBracket]z\&_\[RightAngleBracket]\), "]"}]], "Input",
  CellLabel->"TS_In[79]:=",
  InitializationCell->True,
  CellTags->"Proposition (transitivity of permuted version)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<transitivity of permuted version\>", 
      any[is\[Dash]tuple[X, \ Y, \ 
          Z]], \[IndentingNewLine]X \[TildeTilde] Y \[And] 
          Y \[TildeTilde] Z \[Implies] X \[TildeTilde] Z\), "]"}]], "Input",
  CellLabel->"TS_In[80]:=",
  InitializationCell->True,
  CellTags->"Proposition (transitivity of permuted version)"]
}, Closed]],

Cell[CellGroupData[{

Cell["Operation on tuples: deletion of first occurence", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<deletion of the first occurrence\>\"", ",", \(any[a, x, x\&_]\), 
        ",", "\[IndentingNewLine]", GridBox[{
            {\(dfo[
                  a, \ \[LeftAngleBracket]\[RightAngleBracket]] = \
\[LeftAngleBracket]\[RightAngleBracket]\)},
            {
              
              RowBox[{\(dfo[
                  a, \ \[LeftAngleBracket]x, x\&_\[RightAngleBracket]\ ]\), 
                " ", "=", 
                RowBox[{
                  StyleBox["{",
                    SpanMaxSize->Infinity], GridBox[{
                      {\(\[LeftAngleBracket]x\&_\[RightAngleBracket]\), 
                        "\[DoubleLeftArrow]", \(x = a\)},
                      {\(x\[Cup]
                          dfo[a, \ \
\[LeftAngleBracket]x\&_\[RightAngleBracket]]\), "\[DoubleLeftArrow]", 
                        "otherwise"}
                      },
                    ColumnAlignments->{Left}], 
                  StyleBox["}",
                    ShowContents->False]}], " "}]}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellLabel->"TS_In[63]:=",
  InitializationCell->True,
  CellTags->"Definition (deletion of the first occurrence)"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Algorithm: Sorting", "Subsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Algorithm",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<sorted\>\"", ",", \(any[is\[Dash]tuple[X]]\), ",", 
        "\[IndentingNewLine]", 
        RowBox[{\(sorted[X]\), "=", 
          RowBox[{
            StyleBox["{",
              SpanMaxSize->Infinity], GridBox[{
                {"X", 
                  "\[DoubleLeftArrow]", \(is\[Dash]trivial\[Dash]tuple[X]\)},
                {\(merged[
                    sorted[left\[Dash]split[
                        X]], \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \
sorted[right\[Dash]split[X]]]\), "\[DoubleLeftArrow]", "otherwise"}
                },
              ColumnAlignments->{Left}], 
            StyleBox["}",
              ShowContents->False]}]}]}], "  ", "]"}]], "Input",
  CellLabel->"TS_In[221]:=",
  InitializationCell->True,
  CellTags->"Algorithm (sorted)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<is trivial tuple\>\"", ",", \(any[x, y\&_]\), ",", 
        "\[IndentingNewLine]", GridBox[{
            {\(is\[Dash]trivial\[Dash]tuple[\[LeftAngleBracket]\
\[RightAngleBracket]]\)},
            {\(is\[Dash]trivial\[Dash]tuple[\[LeftAngleBracket]x\
\[RightAngleBracket]]\)},
            {\(\[Not] is\[Dash]trivial\[Dash]tuple[\[LeftAngleBracket]x, 
                    y\&_\[RightAngleBracket]]\)}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellLabel->"TS_In[223]:=",
  InitializationCell->True,
  CellTags->"Definition (is trivial tuple)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<splits\>\"", ",", \(any[x, y, z\&_]\), ",", "\[IndentingNewLine]", 
        GridBox[{
            {\(left\[Dash]split[\[LeftAngleBracket]\[RightAngleBracket]]\  = \
\[LeftAngleBracket]\[RightAngleBracket]\)},
            {\(left\[Dash]split[\[LeftAngleBracket]x\[RightAngleBracket]]\  = \
\[LeftAngleBracket]x\[RightAngleBracket]\)},
            {\(left\[Dash]split[\[LeftAngleBracket]x, y, 
                    z\&_\[RightAngleBracket]] = 
                x\[Cup]left\[Dash]split[\[LeftAngleBracket]z\&_\
\[RightAngleBracket]]\)},
            {\(right\[Dash]split[\[LeftAngleBracket]\[RightAngleBracket]]\  = \
\[LeftAngleBracket]\[RightAngleBracket]\)},
            {\(right\[Dash]split[\[LeftAngleBracket]x\[RightAngleBracket]]\  \
= \[LeftAngleBracket]\[RightAngleBracket]\)},
            {\(right\[Dash]split[\[LeftAngleBracket]x, y, 
                    z\&_\[RightAngleBracket]] = 
                y\[Cup]right\[Dash]split[\[LeftAngleBracket]z\&_\
\[RightAngleBracket]]\)}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellLabel->"TS_In[224]:=",
  InitializationCell->True,
  CellTags->"Definition (splits)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Algorithm",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<merged\>\"", ",", \(any[a, b\&_, x, y\&_]\), ",", 
        "\[IndentingNewLine]", GridBox[{
            {\(merged[\[LeftAngleBracket]\[RightAngleBracket], \
\[LeftAngleBracket]\[RightAngleBracket]]\  = \[LeftAngleBracket]\
\[RightAngleBracket]\)},
            {\(merged[\[LeftAngleBracket]\[RightAngleBracket], \
\[LeftAngleBracket]x, y\&_\[RightAngleBracket]]\  = \[LeftAngleBracket]x, 
                  y\&_\[RightAngleBracket]\)},
            {\(merged[\[LeftAngleBracket]a, 
                    b\&_\[RightAngleBracket], \[LeftAngleBracket]\
\[RightAngleBracket]]\  = \[LeftAngleBracket]a, b\&_\[RightAngleBracket]\)},
            {
              
              RowBox[{\(merged[\[LeftAngleBracket]a, 
                    b\&_\[RightAngleBracket], \[LeftAngleBracket]x, 
                    y\&_\[RightAngleBracket]]\), " ", "=", 
                RowBox[{
                  StyleBox["{",
                    SpanMaxSize->Infinity], GridBox[{
                      {\(a\[Cup]
                          merged[\[LeftAngleBracket]b\&_\[RightAngleBracket], \
\[LeftAngleBracket]x, y\&_\[RightAngleBracket]]\), 
                        "\[DoubleLeftArrow]", \(a \[GreaterEqual] x\)},
                      {\(x\[Cup]
                          merged[\[LeftAngleBracket]a, 
                              b\&_\[RightAngleBracket], \
\[LeftAngleBracket]y\&_\[RightAngleBracket]]\), "\[DoubleLeftArrow]", 
                        "otherwise"}
                      },
                    ColumnAlignments->{Left}], 
                  StyleBox["}",
                    ShowContents->False]}], " "}]}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellLabel->"TS_In[225]:=",
  InitializationCell->True,
  CellTags->"Algorithm (merged)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<T\>\"", ",", "\[IndentingNewLine]", GridBox[{
            {\(Algorithm["\<sorted\>"]\)},
            {\(Definition["\<is trivial tuple\>"]\)},
            {\(Algorithm["\<merged\>"]\)},
            {\(Definition["\<splits\>"]\)}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellLabel->"TS_In[226]:=",
  CellTags->"Theory (T)"],

Cell[BoxData[
    \(Use[\[LeftAngleBracket]Built\[Dash]in["\<Quantifiers\>"], 
        Built\[Dash]in["\<Connectives\>"], Built\[Dash]in["\<Numbers\>"], 
        Built\[Dash]in["\<Tuples\>"], Built\[Dash]in["\<Sets\>"], 
        Theory["\<T\>"]\[RightAngleBracket]]\)], "Input",
  CellLabel->"TS_In[227]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Computing", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[sorted[\[LeftAngleBracket]\[RightAngleBracket]]]\)], "Input",
  CellLabel->"TS_In[228]:="],

Cell[BoxData[
    \(\[LeftAngleBracket]\[RightAngleBracket]\)], "Output",
  CellLabel->"TS_Out[228]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[sorted[\[LeftAngleBracket]555\[RightAngleBracket]]]\)], "Input",\

  CellLabel->"TS_In[229]:="],

Cell[BoxData[
    \(\[LeftAngleBracket]555\[RightAngleBracket]\)], "Output",
  CellLabel->"TS_Out[229]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[
      sorted[\[LeftAngleBracket]1, 5, 233, 5, 3, 44, 5, 66, 7, 
          8\[RightAngleBracket]]]\)], "Input",
  CellLabel->"TS_In[230]:="],

Cell[BoxData[
    \(\[LeftAngleBracket]233, 66, 44, 8, 7, 5, 5, 5, 3, 
      1\[RightAngleBracket]\)], "Output",
  CellLabel->"TS_Out[230]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[
      sorted[\[LeftAngleBracket]3, 44, 5, 66, 21, 35, 233, 5, 67, 
          8\[RightAngleBracket]]]\)], "Input",
  CellLabel->"TS_In[231]:="],

Cell[BoxData[
    \(\[LeftAngleBracket]233, 67, 66, 44, 35, 21, 8, 5, 5, 
      3\[RightAngleBracket]\)], "Output",
  CellLabel->"TS_Out[231]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Proving", "Section"],

Cell[CellGroupData[{

Cell["Main theorem", "Subsubsection"],

Cell[BoxData[
    \(Theorem["\<correctness of sort\>", \ 
      any[is\[Dash]tuple[
          X]], \ \[IndentingNewLine]is\[Dash]sorted\[Dash]version[X, \ 
        sorted[X]]\[IndentingNewLine]]\)], "Input",
  CellLabel->"TS_In[17]:=",
  InitializationCell->True,
  CellTags->"Theorem (correctness of sort)"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Alternative: Eager thinking", "Subsubsection"],

Cell["\<\
Invent the necessary lemmata (further properties of the \
functions)\
\>", "Text"],

Cell["Prove the lemmata using the knowledge base.", "Text"],

Cell["Prove the theorem using the lemmata.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Alternative: Lazy  thinking", "Subsubsection"],

Cell["Try to prove the theorem: will fail! ", "Text"],

Cell["\<\
From failure extract conjectures, try to prove them (may fail \
\[LongRightArrow] new conjectures).\
\>", "Text"],

Cell["Repeat the cycle until all gaps are closed.", "Text"]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 723}},
AutoGeneratedPackage->None,
WindowSize->{1016, 696},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
Magnification->1.5,
StyleDefinitions -> "TutorialBook.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Definition (is sorted version)"->{
    Cell[2073, 67, 824, 20, 165, "Input",
      CellTags->"Definition (is sorted version)"],
    Cell[2900, 89, 433, 9, 102, "Input",
      InitializationCell->True,
      CellTags->"Definition (is sorted version)"]},
  "Definition (is sorted)"->{
    Cell[3684, 112, 1307, 31, 240, "Input",
      InitializationCell->True,
      CellTags->"Definition (is sorted)"]},
  "Proposition (trivial tuples are sorted)"->{
    Cell[4994, 145, 472, 11, 102, "Input",
      InitializationCell->True,
      CellTags->"Proposition (trivial tuples are sorted)"]},
  "Proposition (trivial tuples are sorted: variant)"->{
    Cell[5469, 158, 316, 6, 102, "Input",
      InitializationCell->True,
      CellTags->"Proposition (trivial tuples are sorted: variant)"]},
  "Definition (is permuted version)"->{
    Cell[5889, 171, 1035, 22, 165, "Input",
      InitializationCell->True,
      CellTags->"Definition (is permuted version)"]},
  "Proposition (only empty tuple equivalent to empty tuple)"->{
    Cell[6927, 195, 485, 11, 102, "Input",
      InitializationCell->True,
      CellTags->"Proposition (only empty tuple equivalent to empty tuple)"]},
  "Proposition (only empty tuple equivalent to empty tuple: variant)"->{
    Cell[7415, 208, 492, 11, 102, "Input",
      InitializationCell->True,
      CellTags->
      "Proposition (only empty tuple equivalent to empty tuple: variant)"]},
  "Proposition (only singleton equivalent to singleton)"->{
    Cell[7910, 221, 499, 12, 102, "Input",
      InitializationCell->True,
      CellTags->"Proposition (only singleton equivalent to singleton)"]},
  "Proposition (only singleton equivalent to singleton: variant)"->{
    Cell[8412, 235, 505, 11, 102, "Input",
      InitializationCell->True,
      CellTags->
      "Proposition (only singleton equivalent to singleton: variant)"]},
  "Proposition (only trivial tuple permuted version of itself)"->{
    Cell[9214, 255, 528, 10, 160, "Input",
      InitializationCell->True,
      CellTags->
      "Proposition (only trivial tuple permuted version of itself)"]},
  "Proposition (permuted version with concatenation)"->{
    Cell[9745, 267, 483, 11, 102, "Input",
      InitializationCell->True,
      CellTags->"Proposition (permuted version with concatenation)"]},
  "Proposition (permuted version with append)"->{
    Cell[10231, 280, 450, 10, 102, "Input",
      InitializationCell->True,
      CellTags->"Proposition (permuted version with append)"]},
  "Proposition (permuted version with prepend)"->{
    Cell[10684, 292, 452, 10, 102, "Input",
      InitializationCell->True,
      CellTags->"Proposition (permuted version with prepend)"]},
  "Proposition (Membership with Equivalence)"->{
    Cell[11139, 304, 420, 10, 102, "Input",
      InitializationCell->True,
      CellTags->"Proposition (Membership with Equivalence)"]},
  "Proposition (Deletion in permuted version)"->{
    Cell[11562, 316, 411, 9, 102, "Input",
      InitializationCell->True,
      CellTags->"Proposition (Deletion in permuted version)"]},
  "Proposition (reflexivity of permuted version)"->{
    Cell[11976, 327, 411, 9, 102, "Input",
      InitializationCell->True,
      CellTags->"Proposition (reflexivity of permuted version)"]},
  "Proposition (reflexivity of permuted version: gen)"->{
    Cell[12390, 338, 360, 9, 102, "Input",
      InitializationCell->True,
      CellTags->"Proposition (reflexivity of permuted version: gen)"]},
  "Proposition (symmetry of permuted version)"->{
    Cell[12753, 349, 537, 11, 102, "Input",
      InitializationCell->True,
      CellTags->"Proposition (symmetry of permuted version)"]},
  "Proposition (symmetry of permuted version: gen)"->{
    Cell[13293, 362, 385, 8, 102, "Input",
      InitializationCell->True,
      CellTags->"Proposition (symmetry of permuted version: gen)"]},
  "Proposition (transitivity of permuted version)"->{
    Cell[13681, 372, 664, 13, 102, "Input",
      InitializationCell->True,
      CellTags->"Proposition (transitivity of permuted version)"],
    Cell[14348, 387, 424, 9, 102, "Input",
      InitializationCell->True,
      CellTags->"Proposition (transitivity of permuted version)"]},
  "Definition (deletion of the first occurrence)"->{
    Cell[14885, 403, 1286, 32, 165, "Input",
      InitializationCell->True,
      CellTags->"Definition (deletion of the first occurrence)"]},
  "Algorithm (sorted)"->{
    Cell[16263, 443, 891, 23, 178, "Input",
      InitializationCell->True,
      CellTags->"Algorithm (sorted)"]},
  "Definition (is trivial tuple)"->{
    Cell[17157, 468, 688, 17, 165, "Input",
      InitializationCell->True,
      CellTags->"Definition (is trivial tuple)"]},
  "Definition (splits)"->{
    Cell[17848, 487, 1259, 27, 267, "Input",
      InitializationCell->True,
      CellTags->"Definition (splits)"]},
  "Algorithm (merged)"->{
    Cell[19110, 516, 1872, 41, 249, "Input",
      InitializationCell->True,
      CellTags->"Algorithm (merged)"]},
  "Theory (T)"->{
    Cell[20985, 559, 460, 12, 199, "Input",
      CellTags->"Theory (T)"]},
  "Theorem (correctness of sort)"->{
    Cell[23180, 645, 308, 7, 136, "Input",
      InitializationCell->True,
      CellTags->"Theorem (correctness of sort)"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Definition (is sorted version)", 24885, 704},
  {"Definition (is sorted)", 25133, 710},
  {"Proposition (trivial tuples are sorted)", 25300, 714},
  {"Proposition (trivial tuples are sorted: variant)", 25492, 718},
  {"Definition (is permuted version)", 25676, 722},
  {"Proposition (only empty tuple equivalent to empty tuple)", 25870, 726},
  {"Proposition (only empty tuple equivalent to empty tuple: variant)", \
26096, 730},
  {"Proposition (only singleton equivalent to singleton)", 26325, 735},
  {"Proposition (only singleton equivalent to singleton: variant)", 26543, \
739},
  {"Proposition (only trivial tuple permuted version of itself)", 26775, \
744},
  {"Proposition (permuted version with concatenation)", 26995, 749},
  {"Proposition (permuted version with append)", 27191, 753},
  {"Proposition (permuted version with prepend)", 27382, 757},
  {"Proposition (Membership with Equivalence)", 27572, 761},
  {"Proposition (Deletion in permuted version)", 27761, 765},
  {"Proposition (reflexivity of permuted version)", 27953, 769},
  {"Proposition (reflexivity of permuted version: gen)", 28153, 773},
  {"Proposition (symmetry of permuted version)", 28350, 777},
  {"Proposition (symmetry of permuted version: gen)", 28545, 781},
  {"Proposition (transitivity of permuted version)", 28743, 785},
  {"Definition (deletion of the first occurrence)", 29082, 792},
  {"Algorithm (sorted)", 29252, 796},
  {"Definition (is trivial tuple)", 29405, 800},
  {"Definition (splits)", 29559, 804},
  {"Algorithm (merged)", 29703, 808},
  {"Theory (T)", 29838, 812},
  {"Theorem (correctness of sort)", 29951, 815}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 38, 0, 137, "Section"],

Cell[CellGroupData[{
Cell[1768, 54, 130, 3, 47, "Subsubtitle"],

Cell[CellGroupData[{
Cell[1923, 61, 58, 0, 65, "Subsection"],

Cell[CellGroupData[{
Cell[2006, 65, 64, 0, 53, "Subsubsection"],
Cell[2073, 67, 824, 20, 165, "Input",
  CellTags->"Definition (is sorted version)"],
Cell[2900, 89, 433, 9, 102, "Input",
  InitializationCell->True,
  CellTags->"Definition (is sorted version)"],
Cell[3336, 100, 247, 5, 115, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3620, 110, 61, 0, 38, "Subsubsection"],
Cell[3684, 112, 1307, 31, 240, "Input",
  InitializationCell->True,
  CellTags->"Definition (is sorted)"],
Cell[4994, 145, 472, 11, 102, "Input",
  InitializationCell->True,
  CellTags->"Proposition (trivial tuples are sorted)"],
Cell[5469, 158, 316, 6, 102, "Input",
  InitializationCell->True,
  CellTags->"Proposition (trivial tuples are sorted: variant)"]
}, Closed]],

Cell[CellGroupData[{
Cell[5822, 169, 64, 0, 38, "Subsubsection"],
Cell[5889, 171, 1035, 22, 165, "Input",
  InitializationCell->True,
  CellTags->"Definition (is permuted version)"],
Cell[6927, 195, 485, 11, 102, "Input",
  InitializationCell->True,
  CellTags->"Proposition (only empty tuple equivalent to empty tuple)"],
Cell[7415, 208, 492, 11, 102, "Input",
  InitializationCell->True,
  CellTags->
  "Proposition (only empty tuple equivalent to empty tuple: variant)"],
Cell[7910, 221, 499, 12, 102, "Input",
  InitializationCell->True,
  CellTags->"Proposition (only singleton equivalent to singleton)"],
Cell[8412, 235, 505, 11, 102, "Input",
  InitializationCell->True,
  CellTags->"Proposition (only singleton equivalent to singleton: variant)"],
Cell[8920, 248, 291, 5, 115, "Input"],
Cell[9214, 255, 528, 10, 160, "Input",
  InitializationCell->True,
  CellTags->"Proposition (only trivial tuple permuted version of itself)"],
Cell[9745, 267, 483, 11, 102, "Input",
  InitializationCell->True,
  CellTags->"Proposition (permuted version with concatenation)"],
Cell[10231, 280, 450, 10, 102, "Input",
  InitializationCell->True,
  CellTags->"Proposition (permuted version with append)"],
Cell[10684, 292, 452, 10, 102, "Input",
  InitializationCell->True,
  CellTags->"Proposition (permuted version with prepend)"],
Cell[11139, 304, 420, 10, 102, "Input",
  InitializationCell->True,
  CellTags->"Proposition (Membership with Equivalence)"],
Cell[11562, 316, 411, 9, 102, "Input",
  InitializationCell->True,
  CellTags->"Proposition (Deletion in permuted version)"],
Cell[11976, 327, 411, 9, 102, "Input",
  InitializationCell->True,
  CellTags->"Proposition (reflexivity of permuted version)"],
Cell[12390, 338, 360, 9, 102, "Input",
  InitializationCell->True,
  CellTags->"Proposition (reflexivity of permuted version: gen)"],
Cell[12753, 349, 537, 11, 102, "Input",
  InitializationCell->True,
  CellTags->"Proposition (symmetry of permuted version)"],
Cell[13293, 362, 385, 8, 102, "Input",
  InitializationCell->True,
  CellTags->"Proposition (symmetry of permuted version: gen)"],
Cell[13681, 372, 664, 13, 102, "Input",
  InitializationCell->True,
  CellTags->"Proposition (transitivity of permuted version)"],
Cell[14348, 387, 424, 9, 102, "Input",
  InitializationCell->True,
  CellTags->"Proposition (transitivity of permuted version)"]
}, Closed]],

Cell[CellGroupData[{
Cell[14809, 401, 73, 0, 38, "Subsubsection"],
Cell[14885, 403, 1286, 32, 165, "Input",
  InitializationCell->True,
  CellTags->"Definition (deletion of the first occurrence)"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[16220, 441, 40, 0, 65, "Subsection"],
Cell[16263, 443, 891, 23, 178, "Input",
  InitializationCell->True,
  CellTags->"Algorithm (sorted)"],
Cell[17157, 468, 688, 17, 165, "Input",
  InitializationCell->True,
  CellTags->"Definition (is trivial tuple)"],
Cell[17848, 487, 1259, 27, 267, "Input",
  InitializationCell->True,
  CellTags->"Definition (splits)"],
Cell[19110, 516, 1872, 41, 249, "Input",
  InitializationCell->True,
  CellTags->"Algorithm (merged)"],
Cell[20985, 559, 460, 12, 199, "Input",
  CellTags->"Theory (T)"],
Cell[21448, 573, 307, 5, 102, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[21792, 583, 28, 0, 80, "Section"],

Cell[CellGroupData[{
Cell[21845, 587, 118, 2, 67, "Input"],
Cell[21966, 591, 102, 2, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22105, 598, 123, 3, 67, "Input"],
Cell[22231, 603, 105, 2, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22373, 610, 168, 4, 67, "Input"],
Cell[22544, 616, 141, 3, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22722, 624, 171, 4, 67, "Input"],
Cell[22896, 630, 144, 3, 66, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[23089, 639, 26, 0, 80, "Section"],

Cell[CellGroupData[{
Cell[23140, 643, 37, 0, 55, "Subsubsection"],
Cell[23180, 645, 308, 7, 136, "Input",
  InitializationCell->True,
  CellTags->"Theorem (correctness of sort)"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23525, 657, 52, 0, 55, "Subsubsection"],
Cell[23580, 659, 92, 3, 42, "Text"],
Cell[23675, 664, 59, 0, 42, "Text"],
Cell[23737, 666, 52, 0, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23826, 671, 52, 0, 55, "Subsubsection"],
Cell[23881, 673, 53, 0, 42, "Text"],
Cell[23937, 675, 123, 3, 42, "Text"],
Cell[24063, 680, 59, 0, 42, "Text"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

