(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     99219,       2704]*)
(*NotebookOutlinePosition[     99997,       2731]*)
(*  CellTagsIndexPosition[     99953,       2727]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["The Propositional Prover", "Title"],

Cell[CellGroupData[{

Cell["Package Description", "Subtitle"],

Cell[TextData[{
  "This pakage contains the implementation of ",
  StyleBox["PPND",
    FontWeight->"Bold"],
  " (Propositional Proof by Natural Deduction) for propositional logic."
}], "Text"],

Cell[BoxData[
    \(Needs["\<Theorema`\>"]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NewPackage["\<Theorema`Provers`Propositional`Prover`\>", \n\t\
{"\<Theorema`Provers`Common`ProofObjectInterface`\>", \
"\<Theorema`Provers`Common`ProofObjectManagement`\>", \n\t\t\
"\<Theorema`Provers`Propositional`Auxiliary`\>", \n\t\t\
"\<Theorema`Provers`Propositional`Keywords`\>"}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{"VersionInfo", "[", GridBox[{
          {"\"\<Revision\>\"", "\"\<$Revision: 1.10 $\>\""},
          {"\"\<Date\>\"", "\"\<$Date: 2001/11/19 12:13:35 $\>\""},
          {"\"\<Author\>\"", "\"\<$Author: npopov $\>\""}
          },
        ColumnAlignments->{Left},
        GridFrame->2,
        RowLines->True,
        ColumnLines->True], "]"}]], "Input",
  Editable->False,
  CellFrame->True,
  Evaluatable->True,
  InitializationCell->True,
  AutoItalicWords->{},
  FontFamily->"Helvetica",
  FontSize->10,
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[0.749996]],

Cell[BoxData[
    \(\(ProtectedSymbols[$Context] = 
        Hold[PPND, CopyDefinitions];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExportedSymbols[$Context] = 
        Join[ProtectedSymbols[$Context], Hold[]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Implementation", "Subtitle"],

Cell[CellGroupData[{

Cell["Begin", "Subsubtitle"],

Cell[BoxData[
    \(\(Begin["\<`Private`\>"];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Body", "Subsubtitle"],

Cell[TextData[StyleBox["ATTENTION: These rules are copied also in the \
predicate logic prover (PND) Provers/PredicateLogic/Prover - except for \
changing PPND to PND.",
  FontColor->RGBColor[1, 0, 0]]], "Text"],

Cell[CellGroupData[{

Cell["Usage for  PPND", "Subsection"],

Cell[BoxData[
    \(\(PPND::usage = "\<PPND[goal, assumptions, additionalFacts] implements \
the deduction steps for propositional proving by natural deduction\>";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Set PPND global options ",
  StyleBox["(used by several  user provers)",
    FontColor->RGBColor[1, 0, 0]]
}], "Subsection"],

Cell[BoxData[
    \(\(Options[PPND] = {TryAlternatives \[Rule] False, 
          BackChaining \[Rule] False, BackChainingDisjunction \[Rule] False, 
          BackChainingImplication \[Rule] False, 
          BackChainingEquivalence \[Rule] False, 
          TrySubgoalDisjunction \[Rule] 
            False, \n\t\tTrySubgoalImplication \[Rule] False, 
          TrySubgoalEquivalence \[Rule] False, 
          TrySubgoal \[Rule] False};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(ProcessOptions[PPND, 
        opts___?OptionQ] := \[IndentingNewLine]Module[{}, \[IndentingNewLine]\
\({$TmaPPNDTryAlternatives, $TmaPPNDBackChaining, \
$TmaPPNDBackChainingDisjunction, $TmaPPNDBackChainingImplication, \
$TmaPPNDBackChainingEquivalence, \n\t\t$TmaPPNDTrySubgoalImplication, \
$TmaPPNDTrySubgoalEquivalence, $TmaPPNDTrySubgoal} = \({TryAlternatives, 
                  BackChaining, BackChainingDisjunction, 
                  BackChainingImplication, 
                  BackChainingEquivalence, \n\t\tTrySubgoalImplication, 
                  TrySubgoalEquivalence, TrySubgoal} /. {opts}\) /. 
              Options[PPND];\)]\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Auxiliary Programs", "Section"],

Cell["\<\
The purpose of the auxiliary programs is to handle various operations which \
are used by several deduction rules.\
\>", "Text"],

Cell["\<\
This file contains only those auxiliary programs which are used only by the \
propositional prover. \
\>", "Text"],

Cell["\<\
The file \"Auxiliary.nb\" in the same directory contains the auxiliary \
programs which are used by the propositional prover and by the predicate \
provers.\
\>", "Text"],

Cell["\<\
The prover also uses some other auxiliary programs which are implemented in \
\"Provers/Common/HandleFormulae\".\
\>", "Text"],

Cell[BoxData[
    \(CopyDefinitions[src_, 
        dst_] := \n\t\((If[
          DownValues[dst] === {}, \n\t\tDownValues[dst] = 
            DownValues[src] /. 
              src \[Rule] dst, \n\t\t\((DownValues[src] /. 
                src \[Rule] 
                  dst)\) /. \((\((t : HoldPattern)\)[lhs_] \[RuleDelayed] 
                  rhs_)\) \[RuleDelayed] \((lhs := rhs)\)]; \n\t
        If[UpValues[dst] === {}, \n\t\tUpValues[dst] = 
            UpValues[src] /. 
              src \[Rule] dst, \n\t\t\((UpValues[src] /. 
                src \[Rule] 
                  dst)\) /. \n\t\t\t\t\t\((\((t : HoldPattern)\)[
                    lhs_] \[RuleDelayed] rhs_)\) \[RuleDelayed] \((dst /: 
                  lhs := rhs)\)];)\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "PPND Additional Facts: ",
  StyleBox["created but not used",
    FontColor->RGBColor[1, 0, 0]]
}], "Section"],

Cell[BoxData[
    \(\(InitLocalContext["\<PPND\>"] := 
        Block[{ppndFacts}, LookupTable[ppndFacts]; ppndFacts];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Clear PPND", "Section"],

Cell[BoxData[
    \(\(Clear[PPND];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell["Proof Rules", "Section",
  CellDingbat->None,
  FontColor->RGBColor[0, 0, 1],
  Background->None],

Cell[CellGroupData[{

Cell["Trivial Cases", "Section",
  CellDingbat->"\[FilledSquare]",
  Background->None],

Cell[CellGroupData[{

Cell["Trivial Terminal Cases", "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  "Conclusion is Assumption: Formula Proved\n",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox["\[Placeholder]", 
            RowBox[{
              RowBox[{"\[Ellipsis]", " ", 
                StyleBox["f",
                  FontSlant->"Plain"], " ", "\[Ellipsis]"}], " ", 
              "\[RightTee]", " ", 
              StyleBox["f",
                FontSlant->"Plain"]}]],
          FontWeight->"Bold"], TraditionalForm]],
    FontSize->18,
    FontWeight->"Plain",
    FontSlant->"Plain"]
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[\ \[Bullet]lf[gl_, \ 
            f_, _], \n\t\[Bullet]asml[___, \ \[Bullet]lf[al_, \ 
              f_, _], ___], \n\t_]\  := \n\t
        FinalProofStep[\n\t
          Prinfo[\[Cent]ConclusionIsAssumption, \ {gl, \ 
                al}\[LongRightArrow]{}], \ \ \[Cent]Proved];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Conclusion Subsumed by Assumption: Formula Proved\n",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox["\[Placeholder]", 
            RowBox[{
              RowBox[{"\[Ellipsis]", " ", 
                StyleBox["f",
                  FontSlant->"Plain"], 
                StyleBox[" ",
                  FontSlant->"Plain"], 
                StyleBox["\[Ellipsis]",
                  FontSlant->"Plain"]}], "  ", "\[RightTee]", " ", 
              StyleBox["G",
                FontSlant->"Plain"]}]],
          FontSize->18], TraditionalForm]]],
  "  ",
  StyleBox["f subsumes G",
    FontSlant->"Plain"]
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[\ \[Bullet]lf[gl_, \ 
              gf_, _], \n\t\[Bullet]asml[___, \ \[Bullet]lf[al_, \ 
                af_, _], ___], \n\t_]\  /; Subsumes[af, \ gf] := \n\t
        FinalProofStep[\n\t
          Prinfo[\[Cent]SubsumedConclusion, \ {gl, \ 
                al}\[LongRightArrow]{}], \ \ \[Cent]Proved];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Contradictory Assumptions: Formula Proved\n",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox["\[Placeholder]", 
            
            StyleBox[\(\[Ellipsis]\ f, \ \[Ellipsis] \(\[Not] f\ \
\[Ellipsis]\)\ \  \[RightTee] \ G\),
              FontSlant->"Plain"]],
          FontSize->18], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[\ \[Bullet]lf[gl_, 
            gf_, _], \n\t\[Bullet]asml[___, \ \[Bullet]lf[l1_, \ 
              f_, _], ___, \ \[Bullet]lf[\ 
              l2_, \[Not] f_, _], ___], \ _]\  := \n
        FinalProofStep[
          Prinfo[\[Cent]ContradictoryAssumptions, {l1, \ 
                l2}\[LongRightArrow]{}, gl], \ \[Cent]Proved];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\ \[Bullet]lf[gl_, 
            gf_, _], \n\t\[Bullet]asml[___, \ \[Bullet]lf[
              l1_, \ \[Not] f_, _], ___, \ \[Bullet]lf[\ l2_, 
              f_, _], ___], \ _]\  := \n\t
        FinalProofStep[
          Prinfo[\[Cent]ContradictoryAssumptions, {l1, \ 
                l2}\[LongRightArrow]{}, gl], \ \[Cent]Proved];\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Trivial Simplification Cases", "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  "Identical Assumptions: Delete One\n",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox[
            
            RowBox[{\(\[Ellipsis]\ f\ \[Ellipsis]\), " ", "\[RightTee]", " ", 
              
              StyleBox["G",
                FontSlant->"Plain"]}], 
            RowBox[{
              RowBox[{"\[Ellipsis]", " ", 
                StyleBox["f",
                  FontSlant->"Plain"]}], ",", " ", 
              RowBox[{
                RowBox[{"\[Ellipsis]", " ", 
                  StyleBox["f",
                    FontSlant->"Plain"], " ", "\[Ellipsis]"}], " ", 
                "\[RightTee]", " ", 
                StyleBox["G",
                  FontSlant->"Plain"]}]}]],
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]]
}], "Subsubsection"],

Cell["\<\
The second formula in the proof-object (generated later!) is deleted. Since \
this rule is applied early, this means the redundant formula is deleted \
immediately after it is generated, hence it cannot participate in any \
inference. This is good for simplification of proofs.\
\>", "Text"],

Cell[BoxData[
    \(\(PND[\ 
          goal_, \[Bullet]asml[pre___, \ \[Bullet]lf[l1_, \ f_, i1_], 
            between___, \ \[Bullet]lf[\ l2_, f_, i2_], post___], \ 
          af_]\  := \nIf[
          Order[Position[$TmaProofObject, \[Bullet]lf[l1, f, i1]], 
              Position[$TmaProofObject, \[Bullet]lf[l2, f, i2]]] === 
            1, \[IndentingNewLine]ProofStep[
            Prinfo[\[Cent]IdenticalAssumptions, {l1, 
                  l2}\[LongRightArrow]{}], \[IndentingNewLine]Psit[
              goal, \[Bullet]asml[pre, \[Bullet]lf[l1, \ f, i1], between, 
                post], \ af]], \[IndentingNewLine]ProofStep[
            Prinfo[\[Cent]IdenticalAssumptions, {l2, 
                  l1}\[LongRightArrow]{}], \[IndentingNewLine]Psit[
              goal, \[Bullet]asml[pre, between, \[Bullet]lf[l2, \ f, i2], 
                post], \ af]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Assumption Subsumes Assumption: Delete Second One\n",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(\[Ellipsis]f\[Ellipsis]\  \[RightTee] \ 
                G\)\/\(\[Ellipsis]f, \[Ellipsis]g\[Ellipsis]\  \[RightTee] \ 
                G\)\),
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]],
  ",    ",
  StyleBox["f subsumes g",
    FontSlant->"Plain"]
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[\ 
            goal_, \n\t\[Bullet]asml[pre___, \ \[Bullet]lf[l1_, \ f1_, i1_], 
              between___, \ \[Bullet]lf[\ l2_, f2_, i2_], post___], \ 
            af_]\  /; \ Subsumes[f1, \ f2] := \n
        ProofStep[
          Prinfo[\[Cent]SubsumedAssumption, {l1, 
                l2}\[LongRightArrow]{}], \n\t\tPsit[
            goal, \n\t\t\t\[Bullet]asml[pre, \ \[Bullet]lf[l1, \ f1, i1], 
              between, post], \ af]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\ 
            goal_, \n\t\[Bullet]asml[pre___, \ \[Bullet]lf[l1_, \ f1_, i1_], 
              between___, \ \[Bullet]lf[\ l2_, f2_, i2_], post___], \ 
            af_]\  /; \ Subsumes[f2, \ f1] := \n
        ProofStep[
          Prinfo[\[Cent]SubsumedAssumption, {l2, 
                l1}\[LongRightArrow]{}], \n\t\t\t\tPsit[
            goal, \[Bullet]asml[pre, \ between, \[Bullet]lf[l2, \ f2, i2], 
              post], \ af]];\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Handling Truth Constants", "Subsection"],

Cell["\<\
There is no simplification of negated truth constants, rather all the rules \
have special cases for each such constant.\
\>", "Text"],

Cell["\<\
Why? Let's make such simplification (also in subparts of formulae)\
\>", "Text",
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  Background->RGBColor[1, 0, 0]],

Cell["\<\
All truth constants and their negations are treated only when they occur as \
individual propositions - either in the assumptions or as goal.\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "Assumption  False: Formula Proved\n",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox["\[FilledSquare]", 
            
            RowBox[{\(\[Ellipsis]False\ \[Ellipsis]\), " ", "\[RightTee]", 
              " ", 
              StyleBox["G",
                FontSlant->"Plain"]}]],
          FontSize->18], TraditionalForm]]],
  ",  ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[FilledSquare]\/\(\[Ellipsis]\ \(\[Not] True\
\ \ \[Ellipsis]\)\  \[RightTee] \ G\)\),
          FontSize->18], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[\ \[Bullet]lf[
            gl_, \ _, _], \n\t\[Bullet]asml[___, \ \[Bullet]lf[l_, \ 
              False, _], ___], \n\t_]\  := \n\t
        FinalProofStep[\n\t
          Prinfo[\[Cent]FalseAssumption, {l}\[LongRightArrow]{}, 
            gl], \ \ \[Cent]Proved];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\ \[Bullet]lf[
            gl_, \ _, _], \n\t\[Bullet]asml[___, \ \[Bullet]lf[
              l_, \ \[Not] True, _], ___], \n\t_]\  := \n\t
        FinalProofStep[\n\t
          Prinfo[\[Cent]FalseAssumption, {l}\[LongRightArrow]{}, 
            gl], \ \ \[Cent]Proved];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Conclusion True: Formula Proved\n",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox["\[FilledSquare]", 
            RowBox[{
              StyleBox[\(\[Ellipsis]\ f\ \[Ellipsis]\),
                FontSlant->"Plain"], " ", "\[RightTee]", " ", "True"}]],
          FontSize->18], TraditionalForm]]],
  " ,  ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox["\[FilledSquare]", 
            RowBox[{
              StyleBox[\(\[Ellipsis]\ f\ \[Ellipsis]\),
                FontSlant->"Plain"], " ", "\[RightTee]", 
              " ", \(\[Not] False\)}]],
          FontSize->18], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[gl_, \ True, _], \ asm_, _]\  := \n
        FinalProofStep[
          Prinfo[\[Cent]TrueConclusion, 
            gl\[LongRightArrow]{}], \[Cent]Proved];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[gl_, \ \[Not] False, _], \ asm_, _]\  := \n
        FinalProofStep[
          Prinfo[\[Cent]TrueConclusion, 
            gl\[LongRightArrow]{}], \[Cent]Proved];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Assumption True, Conclusion False: Formula False\n",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[EmptySquare]\/\(\[Ellipsis]\ True\ \[Ellipsis]\  \
\[RightTee] \ False\)\),
          FontSize->18], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[EmptySquare]\/\(\[Ellipsis]\ True\ \[Ellipsis]\  \
\[RightTee] \ \[Not] True\)\),
          FontSize->18], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[EmptySquare]\/\(\[Ellipsis]\ \(\[Not] False\ \[Ellipsis]\
\)\  \[RightTee] \ False\)\),
          FontSize->18], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[EmptySquare]\/\(\[Ellipsis]\ \(\[Not] False\ \[Ellipsis]\
\)\  \[RightTee] \ \[Not] True\)\),
          FontSize->18], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[gl_, \ 
            False, _], \ \[Bullet]asml[\[Bullet]lf[l_, \ True, _]], _]\  := \n
        FinalProofStep[
          Prinfo[\[Cent]TrueAssumptionFalseConclusion, {gl, 
                l}\[LongRightArrow]{}], \[Cent]Disproved];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[gl_, \ 
            False, _], \ \[Bullet]asml[\[Bullet]lf[
              l_, \ \[Not] False, _]], _]\  := \n
        FinalProofStep[
          Prinfo[\[Cent]TrueAssumptionFalseConclusion, {gl, 
                l}\[LongRightArrow]{}], \[Cent]Disproved];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[
            gl_, \ \[Not] True, _], \ \[Bullet]asml[\[Bullet]lf[l_, \ 
              True, _]], _]\  := \n
        FinalProofStep[
          Prinfo[\[Cent]TrueAssumptionFalseConclusion, {gl, 
                l}\[LongRightArrow]{}], \[Cent]Disproved];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[
            gl_, \ \[Not] True, _], \ \[Bullet]asml[\[Bullet]lf[
              l_, \ \[Not] False, _]], _]\  := \n
        FinalProofStep[
          Prinfo[\[Cent]TrueAssumptionFalseConclusion, {gl, 
                l}\[LongRightArrow]{}], \[Cent]Disproved];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Conclusion False Without Assumptions: Formula False\n",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[EmptySquare]\/\(\(\ \)\(\(\[RightTee]\)\(\ \)\(False\)\)\
\)\),
          FontSize->18], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[EmptySquare]\/\(\(\ \)\(\(\[RightTee]\)\(\ \)\(\[Not] \
True\)\)\)\),
          FontSize->18], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[gl_, \ False, _], \ \[Bullet]asml[], _]\  := \n
        FinalProofStep[
          Prinfo[\[Cent]FalseConclusionWithoutAssumptions, 
            gl\[LongRightArrow]{}], \[Cent]Disproved];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[gl_, \ \[Not] True, _], \ \[Bullet]asml[], _]\  := \n
        FinalProofStep[
          Prinfo[\[Cent]FalseConclusionWithoutAssumptions, 
            gl\[LongRightArrow]{}], \[Cent]Disproved];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Note that all these rules depend on the absence of assumptions.
Therefore a proof simplifier must never remove unused formulae directly - \
only steps that create unused formulae\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Assumption True: Delete\n",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox[
            RowBox[{"\[Ellipsis]", " ", "\[RightTee]", " ", 
              StyleBox["G",
                FontSlant->"Plain"]}], 
            
            RowBox[{\(\[Ellipsis]\ True\ \[Ellipsis]\), " ", "\[RightTee]", 
              " ", 
              StyleBox["G",
                FontSlant->"Plain"]}]],
          FontSize->18], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[goal_, \[Bullet]asml[pre___, \[Bullet]lf[l_, True, _], post___], 
          af_] := ProofStep[
          Prinfo[\[Cent]TrueAssumption, l\[LongRightArrow]{}], 
          Psit[goal, \[Bullet]asml[pre, post], af]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[
          goal_, \[Bullet]asml[pre___, \[Bullet]lf[l_, \[Not] False, _], 
            post___], af_] := 
        ProofStep[Prinfo[\[Cent]TrueAssumption, l\[LongRightArrow]{}], 
          Psit[goal, \[Bullet]asml[pre, post], af]];\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Expansion of Compound Assumptions", "Section",
  CellDingbat->"\[FilledSquare]",
  Background->None],

Cell[CellGroupData[{

Cell["Simplification of Assumptions", "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  "Assumption Is Double Negation: Delete Double Negation\n",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(\[Ellipsis]\ f\ \[Ellipsis]\  \[RightTee] \ 
                G\)\/\(\[Ellipsis]\ \(\[Not] \(\[Not] f\ \[Ellipsis]\)\)\  \
\[RightTee] \ G\)\),
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[\ 
          goal_, \n\t\[Bullet]asml[
            pre___, \ \[Bullet]lf[l_, \ \[Not] \(\[Not] f_\), i_], 
            post___], \ af_]\  := \n\t
        Module[{pf\  = \ \[Bullet]lf[
                NewLabel[\[Cent]AssumptionIsDoubleNegation, l], \ f, i]}, \n
          ProofStep[
            Prinfo[\[Cent]AssumptionIsDoubleNegation, 
              l\[LongRightArrow]pf], \n\t\tPsit[
              goal, \[Bullet]asml[pre, pf, post], \ af]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Assumption Is Negated Conjuction: Assume Disjunction of Negations\n",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(\[Ellipsis]\ \(\[Not] f\)\  \[Or] \ \[Not] g\ \
\[Ellipsis]\  \[RightTee] \ 
                G\)\/\(\[Ellipsis] \(\[Not] \ \((f\  \[And] \ 
                          g)\)\ \[Ellipsis]\)\  \[RightTee] \ G\)\),
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[\ 
          goal_, \n\t\[Bullet]asml[
            pre___, \ \[Bullet]lf[l_, \ Not[And[f___]], i_], post___], \ 
          af_]\  := \n\t
        Module[{pf\  = \ \[Bullet]lf[
                NewLabel[\[Cent]AssumptionIsNegatedConjunction, l], \ 
                Map[Not, Or[f]], i]}, \n
          ProofStep[
            Prinfo[\[Cent]AssumptionIsNegatedConjunction, 
              l\[LongRightArrow]\ pf\ ], \n\t\tPsit[
              goal, \[Bullet]asml[pre, pf, post], \ af]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Assumption Is Negated Disjunction: Assume Conjunction of Negations\n",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(\[Ellipsis] \(\[Not] f\)\  \[And] \ \[Not] g\ \
\[Ellipsis]\ \  \[RightTee] \ 
                G\)\/\(\[Ellipsis] \(\[Not] \ \((f\  \[Or] \ 
                          g)\)\ \[Ellipsis]\)\  \[RightTee] \ G\)\),
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[\ 
          goal_, \n\t\[Bullet]asml[
            pre___, \ \[Bullet]lf[l_, \ Not[Or[f___]], i_], post___], \ 
          af_]\  := \n\t
        Module[{pf\  = \ \[Bullet]lf[
                NewLabel[\[Cent]AssumptionIsNegatedDisjunction, l], \ 
                Map[Not, And[f]], i]}, \n
          ProofStep[
            Prinfo[\[Cent]AssumptionIsNegatedDisjunction, 
              l\[LongRightArrow]\ pf], \n\t\tPsit[
              goal, \n\t\t\t\[Bullet]asml[pre, pf, post], \ 
              af]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Assumption is Conjunction: Assume Individual Parts\n",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(\[Ellipsis]\ f, \ 
              g\ \[Ellipsis]\  \[RightTee] \ 
                G\)\/\(\[Ellipsis]\ f\  \[And] \ 
                  g\ \[Ellipsis]\  \[RightTee] \ G\)\),
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[
          goal_, \[Bullet]asml[pre___, \[Bullet]lf[lab_, And[f___], inf_], 
            post___], af_] := \n\t
        Block[{newForms = \[Bullet]asml[], newLab, 
            andFormula = \[Bullet][And[f]], l, i}, 
          l = Length[andFormula]; \n\t\tDo[\n\t\t\tnewLab = 
              NewLabel[\[Cent]AssumptionIsConjunction, lab, 
                i]; \n\t\t\tAppendTo[
              newForms, \[Bullet]lf[newLab, andFormula[\([i]\)], 
                IndexedFormulaInfo[inf, i]]], \n\t\t\t{i, 
              l}]; \n\t\tProofStep[\n\t\t\t\
Prinfo[\[Cent]AssumptionIsConjunction, 
              lab\[LongRightArrow]newForms], \n\t\t\tPsit[goal, 
              Join[\[Bullet]asml[pre], newForms, \[Bullet]asml[post]], \ 
              af]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Assumption is Negated Equivalence: Assume Transformed Implication\n",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(\[Ellipsis]\ f\  \[And] \ \[Not] g\ \[Ellipsis]\  \
\[RightTee] \ G\)\/\(\[Ellipsis]\ \(\[Not] \ \((f\  \[Implies] \ 
                          g)\)\ \[Ellipsis]\) \[RightTee] \ G\)\),
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[\ 
          goal_, \n\t\[Bullet]asml[
            pre___, \ \[Bullet]lf[l_, \ \[Not] \((f_ \[Implies] g_)\), i_], 
            post___], \ af_]\  := \n\t
        Module[{pf\  = \ \[Bullet]lf[
                NewLabel[\[Cent]AssumptionIsNegatedImplication, l], \ 
                f \[And] \((\[Not] g)\), i]}, \n
          ProofStep[
            Prinfo[\[Cent]AssumptionIsNegatedImplication, 
              l\[LongRightArrow]pf], \n\t\tPsit[
              goal, \n\t\t\t\[Bullet]asml[pre, pf, post], \ 
              af]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Assumption is Negated Equivalence: Assume Transformed Equivalence\n",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(\[Ellipsis]\ f\  \[DoubleLeftRightArrow] \ \(\[Not] g\ \
\[Ellipsis]\)\  \[RightTee] \ 
                G\)\/\(\[Ellipsis]\ \(\[Not] \ \((f\  \[DoubleLeftRightArrow] \
\ g)\)\ \[Ellipsis]\) \[RightTee] \ G\)\),
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[\ 
          goal_, \n\t\[Bullet]asml[
            pre___, \ \[Bullet]lf[
              l_, \ \[Not] \((f_ \[DoubleLeftRightArrow] g_)\), i_], 
            post___], \ af_]\  := \n\t
        Module[{pf\  = \ \[Bullet]lf[
                NewLabel[\[Cent]AssumptionIsNegatedEquivalence, l], \ 
                f \[DoubleLeftRightArrow] \((\[Not] g)\), i]}, \n
          ProofStep[
            Prinfo[\[Cent]AssumptionIsNegatedEquivalence, 
              l\[LongRightArrow]pf], \n\t\tPsit[
              goal, \n\t\t\t\[Bullet]asml[pre, pf, post], \ 
              af]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Assumption Is Reversed Implication: Reverse\n",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox[
            RowBox[{
              RowBox[{
                RowBox[{
                  StyleBox[
                    RowBox[{"\[Ellipsis]", 
                      StyleBox["g",
                        FontSize->16,
                        FontSlant->"Plain"]}]], 
                  StyleBox["\[DoubleLongRightArrow]",
                    FontSize->16,
                    FontSlant->"Plain"], 
                  StyleBox["f",
                    FontSize->16,
                    FontSlant->"Plain"]}], " ", "\[Ellipsis]"}], " ", 
              "\[RightTee]", " ", "G"}], 
            RowBox[{
              RowBox[{"\[Ellipsis]", " ", 
                StyleBox[\(f\[DoubleLongLeftArrow]g\),
                  FontSize->16,
                  FontSlant->"Plain"], "  ", "\[Ellipsis]"}], " ", 
              "\[RightTee]", " ", "G"}]],
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]]
}], "Subsubsection"],

Cell["\<\
This is an invisible step: the label and the formula info remain the same, no \
text should be generated in the proof notebook.\
\>", "Text"],

Cell[BoxData[
    \(\(PPND[\ 
          goal_, \n\t\[Bullet]asml[
            pre___, \ \[Bullet]lf[l_, \ f_\[DoubleLongLeftArrow]g_, i_], 
            post___], \ af_]\  := \n\t
        Module[{pf\  = \ \[Bullet]lf[l, \ g\[DoubleLongRightArrow]f, i]}, \n
          ProofStep[
            Prinfo[\[Cent]AssumptionIsReversedImplication, 
              l\[LongRightArrow]pf], \n\t\tPsit[
              goal, \[Bullet]asml[pre, pf, post], \ af]]];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Note that the produced fomula has the same label as the used formula...\
\>", "Text",
  FontWeight->"Bold",
  FontColor->GrayLevel[1],
  Background->RGBColor[1, 0, 0]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Resolution and Modus Ponens for Propositions", "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  "Assumption is Disjunction With an Operand Complementary to an Assumption: \
Resolution\n",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(\[Ellipsis]\ f, \ \[Ellipsis]\ \[Phi]\  \[Or] \ \[Psi]\  \
\[RightTee] \ 
                G\)\/\(\[Ellipsis]\ f, \ \[Ellipsis]\ \[Phi]\  \[Or] \ \[Not] \
f\  \[Or] \ \[Psi]\ \[Ellipsis]\  \[RightTee] \ G\)\),
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[\ 
          goal_, \n\t\[Bullet]asml[pre___, \ \[Bullet]lf[l_, f_, i_], 
            between___, \n\t\t\[Bullet]lf[orl_, 
              Or[orPre___, \[Not] f_, orPost___], ori_], post___], \ 
          af_]\  := \n\t
        Module[{pf\  = \ \[Bullet]lf[NewLabel[\[Cent]Resolution, l, orl], 
                SimplifiedOr[orPre, orPost], \ 
                CombinedFormulaInfo[i, ori]]}, \n
          ProofStep[
            Prinfo[\[Cent]Resolution, {l, orl}\[LongRightArrow]\ 
                pf], \n\t\tPsit[
              goal, \[Bullet]asml[pre, \[Bullet]lf[l, f, \ i], between, pf, 
                post], \ af]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\ 
          goal_, \n\t\[Bullet]asml[
            pre___, \[Bullet]lf[orl_, \ Or[orPre___, \[Not] f_, orPost___], 
              ori_], \ between___, \[Bullet]lf[l_, f_, i_], post___], \ 
          af_]\  := \n\t
        Module[{pf\  = \ \[Bullet]lf[NewLabel[\[Cent]Resolution, l, orl], 
                SimplifiedOr[orPre, orPost], CombinedFormulaInfo[i, ori]]}, \n
          ProofStep[
            Prinfo[\[Cent]Resolution, {l, orl}\[LongRightArrow]
                pf], \n\t\tPsit[
              goal, \[Bullet]asml[pre, pf, between, \[Bullet]lf[l, f, \ i]\ , 
                post], af]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\ 
          goal_, \n\t\[Bullet]asml[pre___, \ \[Bullet]lf[l_, \[Not] f_, i_], 
            between___, \[Bullet]lf[orl_, \ Or[orPre___, f_, orPost___], 
              ori_], post___], \ af_]\  := \n\t
        Module[{pf\  = \ \[Bullet]lf[NewLabel[\[Cent]Resolution, l, orl], 
                SimplifiedOr[orPre, orPost], \ 
                CombinedFormulaInfo[i, ori]]}, \n
          ProofStep[
            Prinfo[\[Cent]Resolution, {l, orl}\[LongRightArrow]
                pf], \n\t\tPsit[
              goal, \[Bullet]asml[pre, \[Bullet]lf[l, \[Not] f, \ i], 
                between, pf, post], \ af]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\ 
          goal_, \n\t\[Bullet]asml[
            pre___, \[Bullet]lf[orl_, \ Or[orPre___, f_, orPost___], ori_], \ 
            between___, \[Bullet]lf[l_, \[Not] f_, i_], post___], \ 
          af_]\  := \nModule[{pf\  = \ \[Bullet]lf[
                NewLabel[\[Cent]Resolution, l, orl], 
                SimplifiedOr[orPre, orPost], CombinedFormulaInfo[i, ori]]}, \n
          ProofStep[
            Prinfo[\[Cent]Resolution, {l, orl}\[LongRightArrow]
                pf], \n\t\tPsit[
              goal, \[Bullet]asml[pre, pf, 
                between, \[Bullet]lf[l, \[Not] f, \ i]\ , post], 
              af]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Assumption is Implication With Assumed Hypothesis: Apply Modus Ponens\n",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(\[Ellipsis]f, \ \[Ellipsis]\ g\ \[Ellipsis]\  \
\[RightTee] \ G\)\/\(\[Ellipsis]\ f, \ \[Ellipsis]\ \((f\  \[Implies] \ 
                      g)\)\ \[Ellipsis]\  \[RightTee] \ G\)\),
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"PPND", "[", " ", 
          RowBox[{"goal_", ",", "\n", "\t", 
            RowBox[{"\[Bullet]asml", "[", 
              RowBox[{"pre___", ",", " ", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"l_", ",", 
                    StyleBox["F_",
                      FontColor->RGBColor[1, 0, 0],
                      Background->None], ",", "i_"}], "]"}], ",", 
                "between___", ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"orl_", ",", 
                    StyleBox[\(F_ \[Implies] G_\),
                      FontColor->RGBColor[1, 0, 0]], ",", "ori_"}], "]"}], 
                ",", "post___"}], "]"}], ",", "\[IndentingNewLine]", " ", 
            "af_"}], "]"}], " ", ":=", "\n", 
        RowBox[{"Module", "[", 
          RowBox[{
            RowBox[{"{", "\[IndentingNewLine]", 
              RowBox[{
                StyleBox["pf",
                  FontColor->RGBColor[1, 0, 0]], " ", "=", " ", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{\(NewLabel[\[Cent]ModusPonens, l, orl]\), ",", 
                    StyleBox["G",
                      FontColor->RGBColor[1, 0, 0]], ",", 
                    " ", \(CombinedFormulaInfo[i, ori]\)}], "]"}]}], "}"}], 
            ",", "\[IndentingNewLine]", 
            RowBox[{"ProofStep", "[", 
              
              RowBox[{\(Prinfo[\[Cent]ModusPonens, {l, orl}\[LongRightArrow]
                    pf]\), ",", "\n", "\t\t", 
                RowBox[{"Psit", "[", 
                  RowBox[{"goal", ",", 
                    RowBox[{"\[Bullet]asml", "[", 
                      RowBox[{
                        StyleBox["pf",
                          FontColor->RGBColor[1, 0, 0]], ",", "pre", ",", 
                        RowBox[{"\[Bullet]lf", "[", 
                          RowBox[{"l", ",", 
                            StyleBox["F",
                              FontColor->RGBColor[1, 0, 0]], ",", " ", "i"}], 
                          "]"}], ",", "between", ",", "post"}], "]"}], ",", 
                    " ", "af"}], "]"}]}], "]"}]}], "]"}]}], ";"}]], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\ 
          goal_, \n\t\[Bullet]asml[
            pre___, \[Bullet]lf[orl_, f_ \[Implies] g_, ori_], 
            between___, \ \[Bullet]lf[l_, f_, i_], post___], af_]\  := \n\t
        Module[{pf\  = \ \[Bullet]lf[NewLabel[\[Cent]ModusPonens, l, orl], 
                g, \ CombinedFormulaInfo[i, ori]]}, \n
          ProofStep[
            Prinfo[\[Cent]ModusPonens, {l, orl}\[LongRightArrow]
                pf], \n\t\tPsit[
              goal, \[Bullet]asml[pre, pf, between, \[Bullet]lf[l, f, \ i], 
                post], \ af]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Assumption is Implication With Assumed Negated Conclusion: Apply Modus \
Tollens\n",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(\[Ellipsis]\ \ f\ \[Ellipsis]\ \(\[Not] g\ \[Ellipsis]\)\
\  \[RightTee] \ 
                G\)\/\(\[Ellipsis]\ f, \ \[Ellipsis]\ \((g\  \[Implies] \ \
\[Not] f)\)\ \[Ellipsis]\  \[RightTee] \ G\)\),
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[\ 
          goal_, \n\t\[Bullet]asml[pre___, \ \[Bullet]lf[l_, f_, i_], 
            between___, \[Bullet]lf[orl_, g_ \[Implies] \((\[Not] f_)\), 
              ori_], post___], \ af_]\  := \n
        With[{lf\  = \ \[Bullet]lf[
                NewLabel[\[Cent]ModusTollens, l, orl], \[Not] g, \ 
                CombinedFormulaInfo[i, ori]]}, \n
          ProofStep[
            Prinfo[\[Cent]ModusTollens, {l, orl}\[LongRightArrow]
                lf], \n\t\tPsit[
              goal, \[Bullet]asml[pre, \[Bullet]lf[l, f, \ i], between, lf, 
                post], \ af]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\ 
          goal_, \n\t\[Bullet]asml[
            pre___, \[Bullet]lf[orl_, g_ \[Implies] \((\[Not] f_)\), ori_], 
            between___, \ \[Bullet]lf[l_, f_, i_], post___], \ af_]\  := \n\t
        With[{lf = \[Bullet]lf[
                NewLabel[\[Cent]ModusTollens, l, orl], \[Not] g, \ 
                CombinedFormulaInfo[i, ori]]}, \n
          ProofStep[
            Prinfo[\[Cent]ModusTollens, {l, orl}\[LongRightArrow]
                lf], \n\t\tPsit[
              goal, \n\t\t\t\[Bullet]asml[pre, lf, 
                between, \[Bullet]lf[l, f, \ i], post], \ af]]];\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\ 
          goal_, \n\t\[Bullet]asml[pre___, \ \[Bullet]lf[l_, \[Not] f_, i_], 
            between___, \[Bullet]lf[orl_, g_ \[Implies] f_, ori_], 
            post___], \ af_]\  := \n\t
        With[{lf\  = \ \[Bullet]lf[
                NewLabel[\[Cent]ModusTollens, l, orl], \[Not] g, \ 
                CombinedFormulaInfo[i, ori]]}, \n
          ProofStep[
            Prinfo[\[Cent]ModusTollens, {l, orl}\[LongRightArrow]
                lf], \n\t\tPsit[
              goal, \n\t\t\t\[Bullet]asml[pre, \[Bullet]lf[l, \[Not] f, \ i], 
                between, lf, post], \ af]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\ 
          goal_, \n\t\[Bullet]asml[
            pre___, \[Bullet]lf[orl_, g_ \[Implies] f_, ori_], \ 
            between___, \[Bullet]lf[l_, \[Not] f_, i_], post___], \ 
          af_]\  := \n\t
        With[{lf = \ \[Bullet]lf[
                NewLabel[\[Cent]ModusTollens, l, orl], \[Not] g, \ 
                CombinedFormulaInfo[i, ori]]}, \n
          ProofStep[
            Prinfo[\[Cent]ModusTollens, {l, orl}\[LongRightArrow]
                lf], \n\t\tPsit[
              goal, \n\t\t\t\[Bullet]asml[pre, lf, 
                between, \[Bullet]lf[l, \[Not] f, \ i], post], \ 
              af]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Assumption is Equivalence With Assumed Operand: Apply Modus Ponens\n",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(\[Ellipsis]\ f, \ \[Ellipsis]\ g\ \[Ellipsis]\  \
\[RightTee] \ 
                G\)\/\(\[Ellipsis]\ f, \ \[Ellipsis]\ \((f\  \
\[DoubleLeftRightArrow] \ g)\)\ \[Ellipsis]\  \[RightTee] \ G\)\),
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[\ 
          goal_, \n\t\[Bullet]asml[pre___, \ \[Bullet]lf[l_, f_, i_], 
            between___, \[Bullet]lf[orl_, f_ \[DoubleLeftRightArrow] g_, 
              ori_], post___], \ af_]\  := \n\t
        With[{pf = \[Bullet]lf[NewLabel[\[Cent]ModusPonens, l, orl], g, \ 
                CombinedFormulaInfo[i, ori]]}, \n
          ProofStep[
            Prinfo[\[Cent]ModusPonens, {l, orl}\[LongRightArrow]
                pf], \n\t\tPsit[
              goal, \[Bullet]asml[pre, \[Bullet]lf[l, f, \ i], between, pf, 
                post], \ af]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\ 
          goal_, \n\t\[Bullet]asml[
            pre___, \[Bullet]lf[orl_, f_ \[DoubleLeftRightArrow] g_, ori_], 
            between___, \ \[Bullet]lf[l_, f_, i_], post___], af_]\  := \n\t
        With[{pf = \[Bullet]lf[NewLabel[\[Cent]ModusPonens, l, orl], g, \ 
                CombinedFormulaInfo[i, ori]]}, \n
          ProofStep[
            Prinfo[\[Cent]ModusPonens, {l, orl}\[LongRightArrow]
                pf], \n\t\tPsit[
              goal, \[Bullet]asml[pre, pf, between, \[Bullet]lf[l, f, \ i], 
                post], \ af]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\ 
          goal_, \n\t\[Bullet]asml[pre___, \ \[Bullet]lf[l_, g_, i_], 
            between___, \[Bullet]lf[orl_, f_ \[DoubleLeftRightArrow] g_, 
              ori_], post___], \ af_]\  := \n\t
        With[{pf = \[Bullet]lf[NewLabel[\[Cent]ModusPonens, l, orl], f, \ 
                CombinedFormulaInfo[i, ori]]}, \n
          ProofStep[
            Prinfo[\[Cent]ModusPonens, {l, orl}\[LongRightArrow]
                pf], \n\t\tPsit[
              goal, \[Bullet]asml[pre, \[Bullet]lf[l, g, \ i], between, pf, 
                post], \ af]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\ 
          goal_, \n\t\[Bullet]asml[
            pre___, \[Bullet]lf[orl_, f_ \[DoubleLeftRightArrow] g_, ori_], 
            between___, \ \[Bullet]lf[l_, g_, i_], post___], af_]\  := \n\t
        With[{pf = \[Bullet]lf[NewLabel[\[Cent]ModusPonens, l, orl], f, \ 
                CombinedFormulaInfo[i, ori]]}, \n
          ProofStep[
            Prinfo[\[Cent]ModusPonens, {l, orl}\[LongRightArrow]
                pf], \n\t\tPsit[
              goal, \[Bullet]asml[pre, pf, between, \[Bullet]lf[l, g, \ i], 
                post], \ af]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Assumption is Equivalence With Assumed Negated Operand: Apply Modus \
Tollens\n",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(\[Ellipsis]\ \(\[Not] f\ \[Ellipsis]\ \(\[Not] g\ \
\[Ellipsis]\)\)\ \  \[RightTee] \ 
                G\)\/\(\[Ellipsis]\ \(\[Not] f\ \[Ellipsis]\ \((f\  \
\[DoubleLeftRightArrow] \ g)\)\ \[Ellipsis]\)\  \[RightTee] \ G\)\),
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]]
}], "Subsubsection"],

Cell[TextData[{
  "The assumed operand is ",
  StyleBox["Not[...].", "Input"]
}], "Text"],

Cell[BoxData[
    \(\(PPND[\ 
          goal_, \n\t\[Bullet]asml[pre___, \ \[Bullet]lf[l_, \[Not] f_, i_], 
            between___, \[Bullet]lf[orl_, f_ \[DoubleLeftRightArrow] g_, 
              ori_], post___], \ af_]\  := \n\t
        With[{lf\  = \ \[Bullet]lf[
                NewLabel[\[Cent]ModusTollens, l, orl], \[Not] g, \ 
                CombinedFormulaInfo[i, ori]]}, \n
          ProofStep[
            Prinfo[\[Cent]ModusTollens, {l, orl}\[LongRightArrow]
                lf], \n\t\tPsit[
              goal, \[Bullet]asml[pre, \[Bullet]lf[l, \[Not] f, \ i], 
                between, lf, post], \ af]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\ 
          goal_, \n\t\[Bullet]asml[
            pre___, \[Bullet]lf[orl_, f_ \[DoubleLeftRightArrow] g_, ori_], 
            between___, \ \[Bullet]lf[l_, \[Not] f_, i_], post___], 
          af_]\  := \n\t
        With[{lf = \[Bullet]lf[
                NewLabel[\[Cent]ModusTollens, l, orl], \[Not] g, \ 
                CombinedFormulaInfo[i, ori]]}, \n
          ProofStep[
            Prinfo[\[Cent]ModusTollens, {l, orl}\[LongRightArrow]
                lf], \n\t\tPsit[
              goal, \[Bullet]asml[pre, lf, 
                between, \[Bullet]lf[l, \[Not] f, \ i], post], \ 
              af]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\ 
          goal_, \n\t\[Bullet]asml[pre___, \ \[Bullet]lf[l_, \[Not] g_, i_], 
            between___, \[Bullet]lf[orl_, f_ \[DoubleLeftRightArrow] g_, 
              ori_], post___], \ af_]\  := \n\t
        With[{lf\  = \ \[Bullet]lf[
                NewLabel[\[Cent]ModusTollens, l, orl], \[Not] f, \ 
                CombinedFormulaInfo[i, ori]]}, \n
          ProofStep[
            Prinfo[\[Cent]ModusTollens, {l, orl}\[LongRightArrow]
                lf], \n\t\tPsit[
              goal, \[Bullet]asml[pre, \[Bullet]lf[l, \[Not] g, \ i], 
                between, lf, post], \ af]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\ 
          goal_, \n\t\[Bullet]asml[
            pre___, \[Bullet]lf[orl_, f_ \[DoubleLeftRightArrow] g_, ori_], 
            between___, \ \[Bullet]lf[l_, \[Not] g_, i_], post___], 
          af_]\  := \n\t
        With[{lf = \ \[Bullet]lf[
                NewLabel[\[Cent]ModusTollens, l, orl], \[Not] f, \ 
                CombinedFormulaInfo[i, ori]]}, \n
          ProofStep[
            Prinfo[\[Cent]ModusTollens, {l, orl}\[LongRightArrow]
                lf], \n\t\tPsit[
              goal, \[Bullet]asml[pre, lf, 
                between, \[Bullet]lf[l, \[Not] g, \ i], post], \ 
              af]]];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "The operand in the equivalence is ",
  StyleBox["Not[...].", "Input"]
}], "Text"],

Cell[BoxData[
    \(\(PPND[\ 
          goal_, \n\t\[Bullet]asml[pre___, \ \[Bullet]lf[l_, f_, i_], 
            between___, \[Bullet]lf[
              orl_, \((\[Not] f_)\) \[DoubleLeftRightArrow] g_, ori_], 
            post___], \ af_]\  := \n\t
        With[{lf = \[Bullet]lf[
                NewLabel[\[Cent]ModusTollens, l, orl], \[Not] g, \ 
                CombinedFormulaInfo[i, ori]]}, \n
          ProofStep[
            Prinfo[\[Cent]ModusTollens, {l, orl}\[LongRightArrow]
                lf], \n\t\tPsit[
              goal, \[Bullet]asml[pre, \[Bullet]lf[l, f, \ i], between, lf, 
                post], \ af]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\ 
          goal_, \n\t\[Bullet]asml[
            pre___, \[Bullet]lf[
              orl_, \((\[Not] f_)\) \[DoubleLeftRightArrow] g_, ori_], 
            between___, \ \[Bullet]lf[l_, f_, i_], post___], af_]\  := \n\t
        With[{lf = \[Bullet]lf[
                NewLabel[\[Cent]ModusTollens, l, orl], \[Not] g, \ 
                CombinedFormulaInfo[i, ori]]}, \n
          ProofStep[
            Prinfo[\[Cent]ModusTollens, {l, orl}\[LongRightArrow]
                lf], \n\t\tPsit[
              goal, \[Bullet]asml[pre, lf, between, \[Bullet]lf[l, f, \ i], 
                post], \ af]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\ 
          goal_, \n\t\[Bullet]asml[pre___, \ \[Bullet]lf[l_, g_, i_], 
            between___, \[Bullet]lf[orl_, 
              f_ \[DoubleLeftRightArrow] \((\[Not] g_)\), ori_], post___], \ 
          af_]\  := \n\t
        With[{lf = \[Bullet]lf[
                NewLabel[\[Cent]ModusTollens, l, orl], \[Not] f, \ 
                CombinedFormulaInfo[i, ori]]}, \n
          ProofStep[
            Prinfo[\[Cent]ModusTollens, {l, orl}\[LongRightArrow]
                lf], \n\t\tPsit[
              goal, \[Bullet]asml[pre, \[Bullet]lf[l, g, \ i], between, lf, 
                post], \ af]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\ 
          goal_, \n\t\[Bullet]asml[
            pre___, \[Bullet]lf[orl_, 
              f_ \[DoubleLeftRightArrow] \((\[Not] g_)\), ori_], 
            between___, \ \[Bullet]lf[l_, g_, i_], post___], af_]\  := \n\t
        With[{lf = \[Bullet]lf[
                NewLabel[\[Cent]ModusTollens, l, orl], \[Not] f, \ 
                CombinedFormulaInfo[i, ori]]}, \n
          ProofStep[
            Prinfo[\[Cent]ModusTollens, {l, orl}\[LongRightArrow]
                lf], \n\t\tPsit[
              goal, \[Bullet]asml[pre, lf, between, \[Bullet]lf[l, g, \ i], 
                post], \ af]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Removal of Unnecessary Assumptions", "Section",
  CellDingbat->"\[FilledSquare]",
  Background->None],

Cell[CellGroupData[{

Cell[TextData[{
  "Negated Goal is Assumed: Remove Assumption \n ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox[
            RowBox[{"\[Ellipsis]", " ", "\[RightTee]", " ", 
              StyleBox["G",
                FontSlant->"Plain"]}], 
            RowBox[{
              RowBox[{
                StyleBox["\[Ellipsis]",
                  FontSlant->"Italic"], 
                StyleBox[" ",
                  FontSlant->"Italic"], 
                RowBox[{"\[Not]", " ", 
                  RowBox[{
                    StyleBox["G",
                      FontSlant->"Plain"], 
                    StyleBox[" ",
                      FontSlant->"Italic"], 
                    StyleBox["\[Ellipsis]",
                      FontSlant->"Italic"]}]}]}], 
              StyleBox[" ",
                FontSlant->"Italic"], "\[RightTee]", " ", 
              StyleBox["G",
                FontSlant->"Plain"]}]],
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[gl_, g_, gi_], \[Bullet]asml[
            pre___, \[Bullet]lf[l_, \[Not] g_, fi_], post___], af_] := \n\t
        ProofStep[
          Prinfo[\[Cent]NegatedGoalIsAssumption, {gl, 
                l}\[LongRightArrow]{}], \n\t\t\t\tPsit[\[Bullet]lf[gl, g, 
              gi], \[Bullet]asml[pre, post], af]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[gl_, \[Not] g_, gi_], \[Bullet]asml[
            pre___, \[Bullet]lf[l_, g_, fi_], post___], af_] := \n\t
        ProofStep[
          Prinfo[\[Cent]NegatedGoalIsAssumption, {gl, 
                l}\[LongRightArrow]{}], \n\t\t\t\tPsit[\[Bullet]lf[
              gl, \[Not] g, gi], \[Bullet]asml[pre, post], af]];\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Negated Goal is Alternative in Assumed Disjunction: Remove Assumption \n \
",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox[
            RowBox[{"\[Ellipsis]", " ", "\[RightTee]", " ", 
              StyleBox["G",
                FontSlant->"Plain"]}], 
            RowBox[{
              RowBox[{
                RowBox[{
                  StyleBox["\[Ellipsis]",
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontSlant->"Italic"], "(", 
                  StyleBox[\(f\  \[Or] \[Not] \ G\),
                    FontSlant->"Plain"], 
                  StyleBox[")",
                    FontSlant->"Italic"]}], 
                StyleBox[" ",
                  FontSlant->"Italic"], 
                StyleBox["\[Ellipsis]",
                  FontSlant->"Italic"]}], 
              StyleBox[" ",
                FontSlant->"Italic"], "\[RightTee]", " ", 
              StyleBox["G",
                FontSlant->"Plain"]}]],
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]]
}], "Subsubsection"],

Cell["\<\
If the opposite of the goal is an alternative in an assumed disjunction, then \
we remove this disjunction. This is correct because if we prove by \
contradiction, then this disjunction is subsumed by the opposite of the goal.\
\
\>", "Text"],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[gl_, g_, gi_], \[Bullet]asml[
            pre___, \[Bullet]lf[l_, Or[orPre___, \[Not] g_, orPost___], fi_], 
            post___], af_] := \n\t
        ProofStep[
          Prinfo[\[Cent]NegatedGoalIsAlternative, {gl, 
                l}\[LongRightArrow]{}], \n\t\t\t\tPsit[\[Bullet]lf[gl, g, 
              gi], \[Bullet]asml[pre, post], af]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[gl_, \[Not] g_, gi_], \[Bullet]asml[
            pre___, \[Bullet]lf[l_, Or[orPre___, g_, orPost___], fi_], 
            post___], af_] := \n\t
        ProofStep[
          Prinfo[\[Cent]NegatedGoalIsAlternative, {gl, 
                l}\[LongRightArrow]{}], \n\t\t\t\tPsit[\[Bullet]lf[
              gl, \[Not] g, gi], \[Bullet]asml[pre, post], af]];\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Negated Goal is Alternative in Assumed Implication: Remove Assumption \n",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox[
            RowBox[{"\[Ellipsis]", " ", "\[RightTee]", " ", 
              StyleBox["G",
                FontSlant->"Plain"]}], 
            RowBox[{
              RowBox[{
                RowBox[{
                  StyleBox["\[Ellipsis]",
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontSlant->"Italic"], "(", 
                  StyleBox[\(f\  \[Implies] \[Not] \ G\),
                    FontSlant->"Plain"], 
                  StyleBox[")",
                    FontSlant->"Italic"]}], 
                StyleBox[" ",
                  FontSlant->"Italic"], 
                StyleBox["\[Ellipsis]",
                  FontSlant->"Italic"]}], 
              StyleBox[" ",
                FontSlant->"Italic"], "\[RightTee]", " ", 
              StyleBox["G",
                FontSlant->"Plain"]}]],
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]],
  ",  ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox[
            RowBox[{"\[Ellipsis]", " ", "\[RightTee]", " ", 
              StyleBox["G",
                FontSlant->"Plain"]}], 
            RowBox[{
              RowBox[{
                StyleBox["\[Ellipsis]",
                  FontSlant->"Italic"], 
                StyleBox[" ",
                  FontSlant->"Italic"], 
                RowBox[{"(", 
                  StyleBox[\(G\  \[Implies] f\),
                    FontSlant->"Plain"], 
                  StyleBox[")",
                    FontSlant->"Italic"]}], 
                StyleBox[" ",
                  FontSlant->"Italic"], 
                StyleBox["\[Ellipsis]",
                  FontSlant->"Italic"]}], 
              StyleBox[" ",
                FontSlant->"Italic"], "\[RightTee]", " ", 
              StyleBox["G",
                FontSlant->"Plain"]}]],
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]]
}], "Subsubsection"],

Cell["\<\
Implication is treated similarly because it is equivalent to a disjunction. \
Equivalence is treated later by the rule for back-chaining on goal.\
\>", "Text"],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[gl_, g_, gi_], \[Bullet]asml[
            pre___, \[Bullet]lf[l_, g_\[DoubleLongRightArrow]f_, fi_], 
            post___], af_] := \n\t
        ProofStep[
          Prinfo[\[Cent]GoalIsImplicand, {gl, 
                l}\[LongRightArrow]{}], \n\t\t\t\tPsit[\[Bullet]lf[gl, g, 
              gi], \[Bullet]asml[pre, post], af]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[gl_, g_, gi_], \[Bullet]asml[
            pre___, \[Bullet]lf[l_, f_\[DoubleLongRightArrow]\((\[Not] g_)\), 
              fi_], post___], af_] := \n\t
        ProofStep[
          Prinfo[\[Cent]NegatedGoalIsImplicatum, {gl, 
                l}\[LongRightArrow]{}], \n\t\t\t\tPsit[\[Bullet]lf[gl, g, 
              gi], \[Bullet]asml[pre, post], af]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[gl_, \[Not] g_, gi_], \[Bullet]asml[
            pre___, \[Bullet]lf[l_, f_\[DoubleLongRightArrow]g_, fi_], 
            post___], af_] := \n\t
        ProofStep[
          Prinfo[\[Cent]NegatedGoalIsImplicatum, {gl, 
                l}\[LongRightArrow]{}], \n\t\t\t\tPsit[\[Bullet]lf[
              gl, \[Not] g, gi], \[Bullet]asml[pre, post], af]];\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Proof Rules for Compound Conclusions", "Subsection",
  Background->None],

Cell[CellGroupData[{

Cell[TextData[{
  "Transform Double Negated Conclusion\n",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox[
            RowBox[{
              StyleBox["\[Ellipsis]",
                FontSlant->"Plain"], " ", "\[RightTee]", " ", "G"}], 
            RowBox[{"\[Ellipsis]", " ", "\[RightTee]", " ", 
              StyleBox[\(\[Not] \(\[Not] G\)\),
                FontSlant->"Plain"]}]],
          FontSize->18], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[l_, \[Not] \(\[Not] f_\), i_], asm_, af_] := \n\t
        Block[{pf\  = \ \[Bullet]lf[
                NewLabel[\[Cent]DoubleNegatedConclusion, l], f, i]}, 
          ProofStep[
            Prinfo[\[Cent]DoubleNegatedConclusion, l\[LongRightArrow]pf], 
            Psit[pf, asm, af]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Prove Negation: Proof by Contradiction\n",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox[
            RowBox[{
              StyleBox[\(G\ \[Ellipsis]\),
                FontSlant->"Plain"], " ", "\[RightTee]", " ", "False"}], 
            RowBox[{"\[Ellipsis]", " ", "\[RightTee]", " ", 
              StyleBox[\(\[Not] G\),
                FontSlant->"Plain"]}]],
          FontSize->18], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[l_, \[Not] f_, i_], \[Bullet]asml[asm___], 
          af_] := \n\t
        Block[{pg = \[Bullet]lf["\<a contradiction\>", \ False, \ Null], 
            pf\  = \ \[Bullet]lf[NewLabel[\[Cent]ProofByContradiction, l], f, 
                i]}, ProofStep[
            Prinfo[\[Cent]ProofByContradiction, l\[LongRightArrow]{pg, pf}], 
            Psit[pg, \[Bullet]asml[pf, asm], af]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Prove Conjunction: Prove Each Part Individually\n",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(\[Ellipsis]\  \[RightTee] \ 
                G\_1; \ \ \ \ \ \ \ \ \[Ellipsis]\  \[RightTee] 
                G\_2\)\/\(\[Ellipsis]\  \[RightTee] \ G\_1 \[And] \ G\_2\)\),
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[gl_, And[fl___], fi_], \[Bullet]asml[asm___], af_] := 
        Block[{andF = \[Bullet][And[fl]], proofSituations = {}, 
            subparts = {}, formulai, l, i}, \n\t\tl\  = \ 
            Length[andF]; \n\t\tDo[
            formulai = \[Bullet]lf[NewLabel[\[Cent]ProveConjunction, gl, i], 
                andF[\([i]\)], IndexedFormulaInfo[fi, i]]; \n\t\t\tAppendTo[
              subparts, formulai]; \n\t\t\tAppendTo[proofSituations, 
              Psit[formulai, \[Bullet]asml[asm], af]], \n\t\t\t{i, 
              l}]; \n\t\tPrependTo[proofSituations, 
            Prinfo[\[Cent]ProveConjunction, 
              gl\[LongRightArrow]subparts]]; \n\t\tProofStep @@ 
            proofSituations];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Prove Disjunction:  Alternatives: Try to Prove Each and Eventually Prove \
First By Assuming Negation of All Other Alternatives (Depends on Option \
TryAlternatives)\n",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(\[Ellipsis]\ \  \[RightTee] \ 
                G\_k\)\/\(\[Ellipsis]\  \[RightTee] \ 
                G\_1\  \[Or] \ G\_2\  \[Or] \ \[Ellipsis]\  \[Or] \ G\_n\)\),
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]],
  " or  ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(\[Ellipsis] \(\[Not] \ 
                    G\_2\ \ \[Ellipsis]\ \(\[Not] G\_n\ \[Ellipsis]\)\)\  \
\[RightTee] \ G\_1\)\/\(\[Ellipsis]\  \[RightTee] \ 
                G\_1\  \[Or] \ G\_2\  \[Or] \ \[Ellipsis]\  \[Or] \ G\_n\)\),
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[l_, Or[f1_, fl___], fi_], \[Bullet]asml[asm___], 
          af_] := \n\t
        If[$TmaPPNDTryAlternatives, \n
          Block[\ {lfList\  = \ \[Bullet]asml[], tryList, lft, i, i1, \ 
              len\  = \ 
                Length[\ {fl}], \n\t\t\ \ \ \ \ \ lf\  = \ \[Bullet]lf[
                  NewLabel[\[Cent]ProveDisjunction, l, 1], f1, 
                  IndexedFormulaInfo[fi, 1]]}, \n\t\tlft = \[Bullet]lf[
                NewLabel[\[Cent]TryDisjunctionOperand, l, 1], f1, 
                IndexedFormulaInfo[fi, 1]]; \n
            tryList = {ProofStep[
                  Prinfo[\[Cent]TryDisjunctionOperand, 
                    l\[LongRightArrow]lft], 
                  Psit[lft, \[Bullet]asml[asm], af]]}; \n\t\t\t\tDo[
              i1 = i + 1; \n\t\t\tlft = \[Bullet]lf[
                  NewLabel[\[Cent]TryDisjunctionOperand, l, 
                    i1], {fl}[\([i]\)], 
                  IndexedFormulaInfo[fi, i1]]; \n\t\t\tAppendTo[tryList, 
                ProofStep[
                  Prinfo[\[Cent]TryDisjunctionOperand, 
                    l\[LongRightArrow]lft], 
                  Psit[lft, \[Bullet]asml[asm], af]]]; \n\t\t\tAppendTo[\ 
                lfList, \[Bullet]lf[
                  NewLabel[\[Cent]ProveDisjunction, l, 
                    i1], \[Not] {fl}[\([i]\)], fi\ ]], \n\t\t\t\ {\ i, \ 
                len\ }]; \n
            Apply[ProofAlternatives, 
              Join[{Prinfo[\[Cent]ProveDisjunctionAlternatives, 
                    l\[LongRightArrow]{}]}, 
                tryList, \n\t{ProofStep[
                    Prinfo[\[Cent]ProveDisjunction, 
                      l\[LongRightArrow]Prepend[\ lfList, lf]], 
                    Psit[lf, Join[\ lfList, \ \[Bullet]asml[asm]], 
                      af]]}]]], \n\t\tBlock[{lf, i, i1, \ 
              len\  = \ Length[\ {fl}], 
              lfList\  = \ \[Bullet]asml[]}, \n\t\t\tlf\  = \ \[Bullet]lf[
                NewLabel[\[Cent]ProveDisjunction, l, 1], f1, 
                IndexedFormulaInfo[fi, 1]]; \n\t\t\tDo[
              i1 = i + 1; \n\t\t\tAppendTo[\ 
                lfList, \[Bullet]lf[
                  NewLabel[\[Cent]ProveDisjunction, l, 
                    i1], \[Not] {fl}[\([i]\)], fi\ ]], \n\t\t\t\ {\ i, \ 
                len\ }]; \n\t\t\tProofStep[
              Prinfo[\[Cent]ProveDisjunction, 
                l\[LongRightArrow]Prepend[\ lfList, lf]], 
              Psit[lf, Join[\ lfList, \ \[Bullet]asml[asm]], 
                af]]\n\t\t\t\t\t]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Prove Implication: Apply Deduction Rule\n",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(\[Ellipsis]\ f\ \[Ellipsis]\  \[RightTee] \ 
                g\)\/\(\[Ellipsis]\  \[RightTee] \ \((f\  \[Implies] \ 
                    g)\)\)\),
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]],
  " ,   ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(\[Ellipsis]\ f\ \[Ellipsis]\  \[RightTee] \ 
                g\)\/\(\[Ellipsis]\  \[RightTee] \ \((g\[DoubleLongLeftArrow]
                    f)\)\)\),
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[l_, f_ \[Implies] g_, fi_], \[Bullet]asml[asm___], 
          af_] := \n\t
        Block[{hyp, 
            concl}, \n\t\thyp = \[Bullet]lf[
              NewLabel[\[Cent]ProveImplication, l, 2], f, 
              IndexedFormulaInfo[fi, 2]]; \n\t\tconcl = \[Bullet]lf[
              NewLabel[\[Cent]ProveImplication, l, 1], g, 
              IndexedFormulaInfo[fi, 1]]; \n\t\tProofStep[
            Prinfo[\[Cent]ProveImplication, l\[LongRightArrow]{hyp, concl}], 
            Psit[concl, \[Bullet]asml[hyp, asm], af]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[l_, g_\[DoubleLongLeftArrow]f_, fi_], \[Bullet]asml[
            asm___], af_] := \n\t
        Block[{hyp, 
            concl}, \n\t\thyp = \[Bullet]lf[
              NewLabel[\[Cent]ProveImplication, l, 2], f, 
              IndexedFormulaInfo[fi, 2]]; \n\t\tconcl = \[Bullet]lf[
              NewLabel[\[Cent]ProveImplication, l, 1], g, 
              IndexedFormulaInfo[fi, 1]]; \n\t\tProofStep[
            Prinfo[\[Cent]ProveImplication, l\[LongRightArrow]{hyp, concl}], 
            Psit[concl, \[Bullet]asml[hyp, asm], af]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Prove Equivalence: From Left to Right and Vice Versa\n",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(f\ \[Ellipsis]\  \[RightTee] \ 
                g; \ \ \ \ g\ \[Ellipsis]\  \[RightTee] \ 
                f\)\/\(\[Ellipsis]\  \[RightTee] \ \((f\  \
\[DoubleLeftRightArrow] \ g)\)\)\),
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[l_, f_ \[DoubleLeftRightArrow] g_, 
            fi_], \[Bullet]asml[asm___], af_] := \n\t
        Block[{newlbls}, \n\t\tnewlbls = 
            Table[NewLabel[\[Cent]ProveEquivalence, l, i], {i, 
                4}]; \n\t\tProofStep[
            Prinfo[\[Cent]ProveEquivalence, 
              l\[LongRightArrow]{\[Bullet]lf[
                    newlbls\[LeftDoubleBracket]1\[RightDoubleBracket], g, 
                    fi], \[Bullet]lf[
                    newlbls\[LeftDoubleBracket]2\[RightDoubleBracket], f, 
                    fi], \[Bullet]lf[
                    newlbls\[LeftDoubleBracket]3\[RightDoubleBracket], f, 
                    fi], \[Bullet]lf[
                    newlbls\[LeftDoubleBracket]4\[RightDoubleBracket], g, 
                    fi]}], \n\t\t\tPsit[\[Bullet]lf[
                newlbls\[LeftDoubleBracket]1\[RightDoubleBracket], g, 
                fi], \[Bullet]asml[\[Bullet]lf[
                  newlbls\[LeftDoubleBracket]2\[RightDoubleBracket], f, fi], 
                asm], af], 
            Psit[\[Bullet]lf[
                newlbls\[LeftDoubleBracket]3\[RightDoubleBracket], f, 
                fi], \[Bullet]asml[\[Bullet]lf[
                  newlbls\[LeftDoubleBracket]4\[RightDoubleBracket], g, fi], 
                asm], af]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Back Chaining on Goal ", "Section",
  CellDingbat->"\[FilledSquare]",
  Background->None],

Cell["(Depends on Option BackChaining)", "Subsubsection",
  Background->None],

Cell[CellGroupData[{

Cell["Note on Back Chaining on Goal", "Subsubsection"],

Cell[TextData[{
  "If the goal is an alternative in an assumed disjunction, then the next \
step depends on the option ",
  StyleBox["BackChaining",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[TextData[{
  "If ",
  StyleBox["BackChaining",
    FontWeight->"Bold"],
  " is ",
  StyleBox["True",
    FontWeight->"Bold"],
  ", then we try two proof possibilities: The first one tries to prove the \
conjunction of the negations of the remaining alternatives (might fail), \
while the second one is like below."
}], "Text"],

Cell[TextData[{
  "If ",
  StyleBox["BackChaining",
    FontWeight->"Bold"],
  " is ",
  StyleBox["False",
    FontWeight->"Bold"],
  ", then the disjunction is modified by removing the goal from it. This is \
correct because if we prove by cases using this disjunction, then the \
non-trivial branch is the one which contains the modified disjunction."
}], "Text"],

Cell[TextData[{
  "Similar rules are applied for implication and equivalence - only that for \
the latter we also remove the redundant implication (on the principle \
detailed in subsection ",
  StyleBox["Removing Unnecessary Assumptions",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " above)."
}], "Text"],

Cell["\<\
However, the back-chaining rules should be used with care in the case of \
predicate logic, because they could generate infinite loops.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Assume Disjunction: Back Chaining on Goal\n",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox[
            RowBox[{"\[Ellipsis]", " ", "\[RightTee]", " ", 
              RowBox[{"\[Not]", 
                StyleBox["f",
                  
                  FontSlant->"Plain"]}]}], \(\[Ellipsis]\ \((f \[Or] \ 
                    G)\)\ \[Ellipsis]\  \[RightTee] \ G\)],
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]],
  " or ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(\[Ellipsis]f\[Ellipsis]\  \[RightTee] \ 
                G\)\/\(\[Ellipsis]\ \((f\  \[Or] \ 
                      G)\)\ \[Ellipsis]\  \[RightTee] \ G\)\),
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[gl_, g_, gi_], \[Bullet]asml[
            pre___, \[Bullet]lf[l_, Or[orPre___, g_, orPost___], fi_], 
            post___], af_] := 
        Block[{\n\t\t\t\ \ \ \ \ \ \ \ \ simpLF\  = \ \[Bullet]lf[
                NewLabel[\[Cent]SimplifyDisjunction, l], 
                SimplifiedOr[orPre, orPost], fi]}, \n\t\tsimpPS = 
            ProofStep[
              Prinfo[\[Cent]SimplifyDisjunction, {gl, l}\[LongRightArrow]
                  simpLF], 
              Psit[\[Bullet]lf[gl, g, gi], \[Bullet]asml[pre, simpLF, post], 
                af]]; \n\t\tIf[$TmaPPNDBackChaining\  || \ \
$TmaPPNDBackChainingDisjunction, \n\t\t\tBlock[{newGoal, 
                newForm}, \n\t\t\t\tnewForm = \[Bullet][
                  And[orPre, orPost]]; \n\t\t\t\tnewForm = 
                If[Length[newForm] === 1, \[Bullet][
                    Not[orPre, orPost]], \[Bullet][
                    Map[Not, newForm]]]; \n\t\t\t\tnewGoal = \[Bullet]lf[
                  NewLabel[\[Cent]BackChainingDisjunction, l], newForm, 
                  fi]; \n\t\t\tProofAlternatives[
                Prinfo[\[Cent]GoalIsAlternativeOfDisjunction, {gl, 
                      l}\[LongRightArrow]{}], \n\t\t\t\tProofStep[
                  Prinfo[\[Cent]BackChainingDisjunction, {gl, 
                        l}\[LongRightArrow]newGoal], 
                  Psit[newGoal, \[Bullet]asml[pre, post], 
                    af]], \n\t\t\t\tsimpPS]], \n\t\t\tsimpPS]];\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Assume Implication: Back Chaining on Goal: Positive Match\n",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(\[Ellipsis]\  \[RightTee] \ 
                f\)\/\(\[Ellipsis]\ \((f\  \[Implies] \ 
                      G)\)\ \[Ellipsis]\  \[RightTee] \ G\)\),
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]],
  " or   ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox[
            
            RowBox[{\(\[Ellipsis]\ \(\[Not] \ f\ \[Ellipsis]\)\), " ", 
              "\[RightTee]", " ", 
              StyleBox["G",
                FontSlant->"Plain"]}], 
            RowBox[{
              RowBox[{
                StyleBox["\[Ellipsis]",
                  FontSlant->"Italic"], 
                StyleBox[" ",
                  FontSlant->"Italic"], 
                RowBox[{"(", 
                  StyleBox[\(f\  \[Implies] \ G\),
                    FontSlant->"Plain"], 
                  StyleBox[")",
                    FontSlant->"Italic"]}], 
                StyleBox[" ",
                  FontSlant->"Italic"], 
                StyleBox["\[Ellipsis]",
                  FontSlant->"Italic"]}], 
              StyleBox[" ",
                FontSlant->"Italic"], "\[RightTee]", " ", 
              StyleBox["G",
                FontSlant->"Plain"]}]],
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]],
  " "
}], "Subsubsection"],

Cell["\<\
If the conclusion of an implication is identical to the goal, then we try two \
alternatives:\
\>", "Text"],

Cell["\<\
1. Back chaining on goal (when option BackChaining): try to prove the LHS of \
the implication (this might not succeed,but it looks nicer).\
\>", "Text"],

Cell["\<\
2. Transform the implication into the negated LHS of it (this does allways \
succedd, but it is not so nice). It is correct because if we transform the \
implication into disjunction and then prove by cases, the non-trivial branch \
will contain the negated LHS.\
\>", "Text"],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[gl_, g_, gi_], \[Bullet]asml[
            pre___, \[Bullet]lf[l_, f_ \[Implies] g_, fi_], post___], af_] := 
        Block[{simpLF\  = \[Bullet]lf[
                NewLabel[\[Cent]SimplifyImplicationLHS, l], \[Not] f, 
                fi]}, \n\t\tsimpPS = 
            ProofStep[
              Prinfo[\[Cent]SimplifyImplicationLHS, {gl, l}\[LongRightArrow]
                  simpLF], 
              Psit[\[Bullet]lf[gl, g, gi], \[Bullet]asml[pre, simpLF, post], 
                af]]; If[$TmaPPNDBackChaining\  || \ \
$TmaPPNDBackChainingImplication, \n\t\t\tBlock[{newGoal = \[Bullet]lf[
                    NewLabel[\[Cent]BackChainingImplication, l], f, 
                    fi]}, \n\t\t\tProofAlternatives[
                Prinfo[\[Cent]GoalIsRHSofImplication, {gl, 
                      l}\[LongRightArrow]{}], \n\t\t\t\tProofStep[
                  Prinfo[\[Cent]BackChainingImplication, {gl, 
                        l}\[LongRightArrow]newGoal], \n\t\t\t\t\t\tPsit[
                    newGoal, \[Bullet]asml[pre, post], af]], simpPS]], 
            simpPS]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Assume Implication: Back Chaining on Goal: Negative Match\n",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox[
            RowBox[{"\[Ellipsis]", " ", "\[RightTee]", " ", 
              RowBox[{"\[Not]", 
                StyleBox["f",
                  FontSlant->"Plain"]}]}], 
            RowBox[{
              RowBox[{"\[Ellipsis]", " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{"\[Not]", 
                        StyleBox["G",
                          FontSlant->"Plain"]}], ")"}], " ", "\[Implies]", 
                    " ", 
                    StyleBox["f",
                      FontSlant->"Plain"]}], ")"}], " ", "\[Ellipsis]"}], " ",
               "\[RightTee]", " ", 
              StyleBox["G",
                FontSlant->"Plain"]}]],
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]],
  " or   ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox[
            
            RowBox[{\(\[Ellipsis]\ \ f\ \[Ellipsis]\), " ", "\[RightTee]", 
              " ", 
              StyleBox["G",
                FontSlant->"Plain"]}], 
            RowBox[{
              RowBox[{"\[Ellipsis]", " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{"\[Not]", 
                        StyleBox["G",
                          FontSlant->"Plain"]}], ")"}], " ", "\[Implies]", 
                    " ", 
                    StyleBox["f",
                      FontSlant->"Plain"]}], ")"}], " ", "\[Ellipsis]"}], " ",
               "\[RightTee]", " ", 
              StyleBox["G",
                FontSlant->"Plain"]}]],
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]]
}], "Subsubsection"],

Cell["\<\
Similar rules apply when the RHS of the implication is opposite to the \
goal.\
\>", "Text"],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[gl_, g_, gi_], \[Bullet]asml[
            pre___, \[Bullet]lf[l_, \((\[Not] g_)\) \[Implies] f_, fi_], 
            post___], af_] := 
        Block[{\n\t\t\t\ \ \ \ \ \ \ \ \ simpLF\  = \[Bullet]lf[
                NewLabel[\[Cent]SimplifyImplicationRHS, l], f, 
                fi]}, \n\t\tsimpPS = 
            ProofStep[
              Prinfo[\[Cent]SimplifyImplicationRHS, {gl, l}\[LongRightArrow]
                  simpLF], 
              Psit[\[Bullet]lf[gl, g, gi], \[Bullet]asml[pre, simpLF, post], 
                af]]; \n\t\tIf[$TmaPPNDBackChaining\  || \ \
$TmaPPNDBackChainingImplication, \n\t\t\tBlock[{newGoal = \[Bullet]lf[
                    NewLabel[\[Cent]BackChainingImplicationRHS, l], \[Not] f, 
                    fi]}, \n\t\t\tProofAlternatives[
                Prinfo[\[Cent]GoalNegatesLHSofImplication, {gl, 
                      l}\[LongRightArrow]{}], \n\t\t\t\tProofStep[
                  Prinfo[\[Cent]BackChainingImplication, {gl, 
                        l}\[LongRightArrow]newGoal], 
                  Psit[newGoal, \[Bullet]asml[pre, post], 
                    af]], \n\t\t\t\tsimpPS]], \n\t\t\tsimpPS]];\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[gl_, \[Not] g_, gi_], \[Bullet]asml[
            pre___, \[Bullet]lf[l_, g_ \[Implies] f_, fi_], post___], af_] := 
        Block[{\n\t\t\t\ \ \ \ \ \ \ \ \ simpLF\  = \[Bullet]lf[
                NewLabel[\[Cent]SimplifyImplicationRHS, l], f, 
                fi]}, \n\t\tsimpPS = 
            ProofStep[
              Prinfo[\[Cent]SimplifyImplicationRHS, {gl, l}\[LongRightArrow]
                  simpLF], 
              Psit[\[Bullet]lf[gl, \[Not] g, gi], \[Bullet]asml[pre, simpLF, 
                  post], af]]; \n\t\tIf[$TmaPPNDBackChaining\  || \ \
$TmaPPNDBackChainingImplication, \n\t\t\tBlock[{newGoal = \[Bullet]lf[
                    NewLabel[\[Cent]BackChainingImplicationRHS, l], \[Not] f, 
                    fi]}, \n\t\t\tProofAlternatives[
                Prinfo[\[Cent]GoalNegatesLHSofImplication, {gl, 
                      l}\[LongRightArrow]{}], \n\t\t\t\tProofStep[
                  Prinfo[\[Cent]BackChainingImplication, {gl, 
                        l}\[LongRightArrow]newGoal], 
                  Psit[newGoal, \[Bullet]asml[pre, post], 
                    af]], \n\t\t\t\tsimpPS]], \n\t\t\tsimpPS]];\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Assume Equivalence: Back Chaining on Goal: Positive Match\n",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(\[Ellipsis]\  \[RightTee] \ 
                f\)\/\(\(\(\[Ellipsis]\)\(\ \)\((f\  \[DoubleLeftRightArrow] \
\ G)\)\(\ \)\(\[Ellipsis]\)\(\ \)\)\(\[RightTee]\)\(\ \)\(G\)\(\ \)\)\),
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]],
  "  ",
  StyleBox["or  ",
    FontSlant->"Plain"],
  "   ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(\[Ellipsis]\ \(\[Not] f\ \[Ellipsis]\)\  \[RightTee] \ 
                G\)\/\(\[Ellipsis]\ \((f\  \[DoubleLeftRightArrow] \ 
                      G)\)\ \[Ellipsis]\  \[RightTee] \ G\)\),
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[gl_, g_, gi_], \[Bullet]asml[
            pre___, \[Bullet]lf[l_, f_\[DoubleLongLeftRightArrow]g_, fi_], 
            post___], af_] := 
        Block[{\n\t\t\t\ \ \ \ \ \ \ \ \ simpLF\  = \ \[Bullet]lf[
                NewLabel[\[Cent]SimplifyEquivalence, l], \[Not] f, 
                fi]}, \n\t\tsimpPS = 
            ProofStep[
              Prinfo[\[Cent]SimplifyEquivalence, {gl, l}\[LongRightArrow]
                  simpLF], 
              Psit[\[Bullet]lf[gl, g, gi], \[Bullet]asml[pre, simpLF, post], 
                af]]; \n\t\tIf[$TmaPPNDBackChaining\  || \ \
$TmaPPNDBackChainingEquivalence, \n\t\t\tBlock[{newGoal = \[Bullet]lf[
                    NewLabel[\[Cent]BackChainingEquivalence, l], f, 
                    fi]}, \n\t\t\tProofAlternatives[
                Prinfo[\[Cent]GoalIsSideOfEquivalence, {gl, 
                      l}\[LongRightArrow]{}], \n\t\t\t\tProofStep[
                  Prinfo[\[Cent]BackChainingEquivalence, {gl, 
                        l}\[LongRightArrow]newGoal], 
                  Psit[newGoal, \[Bullet]asml[pre, post], 
                    af]], \n\t\t\t\tsimpPS]], \n\t\t\tsimpPS]];\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[gl_, g_, gi_], \[Bullet]asml[
            pre___, \[Bullet]lf[l_, g_\[DoubleLongLeftRightArrow]f_, fi_], 
            post___], af_] := 
        Block[{\n\t\t\t\ \ \ \ \ \ \ \ \ simpLF\  = \ \[Bullet]lf[
                NewLabel[\[Cent]SimplifyEquivalence, l], \[Not] f, 
                fi]}, \n\t\tsimpPS = 
            ProofStep[
              Prinfo[\[Cent]SimplifyEquivalence, {gl, l}\[LongRightArrow]
                  simpLF], 
              Psit[\[Bullet]lf[gl, g, gi], \[Bullet]asml[pre, simpLF, post], 
                af]]; \n\t\tIf[$TmaPPNDBackChaining\  || \ \
$TmaPPNDBackChainingEquivalence, \n\t\t\tBlock[{newGoal = \[Bullet]lf[
                    NewLabel[\[Cent]BackChainingEquivalence, l], f, 
                    fi]}, \n\t\t\tProofAlternatives[
                Prinfo[\[Cent]GoalIsSideOfEquivalence, {gl, 
                      l}\[LongRightArrow]{}], \n\t\t\t\tProofStep[
                  Prinfo[\[Cent]BackChainingEquivalence, {gl, 
                        l}\[LongRightArrow]newGoal], 
                  Psit[newGoal, \[Bullet]asml[pre, post], 
                    af]], \n\t\t\t\tsimpPS]], \n\t\t\tsimpPS]];\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Assume Equivalence: Back Chaining on Goal: Negative Match\n",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(\[Ellipsis]\  \[RightTee] \ \[Not] f\)\/\(\[Ellipsis]\ \
\((f\  \[DoubleLeftRightArrow] \ \((\[Not] G)\))\)\ \[Ellipsis]\  \[RightTee] \
\ G\)\),
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]],
  "  ",
  StyleBox["or  ",
    FontSlant->"Plain"],
  " ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(\[Ellipsis]\ f\ \[Ellipsis]\  \[RightTee] \ 
                G\)\/\(\[Ellipsis]\ \((f\  \[DoubleLeftRightArrow] \ \
\((\[Not] G)\))\)\ \[Ellipsis]\  \[RightTee] \ G\)\),
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[gl_, g_, gi_], \[Bullet]asml[
            pre___, \[Bullet]lf[l_, 
              f_\[DoubleLongLeftRightArrow]\((\[Not] g_)\), fi_], post___], 
          af_] := Block[{\n\t\t\t\ \ \ \ \ \ \ \ \ simpLF\  = \ \[Bullet]lf[
                NewLabel[\[Cent]SimplifyEquivalenceNegated, l], f, 
                fi]}, \n\t\tsimpPS = 
            ProofStep[
              Prinfo[\[Cent]SimplifyEquivalenceNegated, {gl, 
                    l}\[LongRightArrow]simpLF], 
              Psit[\[Bullet]lf[gl, g, gi], \[Bullet]asml[pre, simpLF, post], 
                af]]; \n\t\tIf[$TmaPPNDBackChaining\  || \ \
$TmaPPNDBackChainingEquivalence, \n\t\t\tBlock[{newGoal = \[Bullet]lf[
                    NewLabel[\[Cent]BackChainingEquivalenceNegated, 
                      l], \[Not] f, fi]}, \n\t\t\tProofAlternatives[
                Prinfo[\[Cent]GoalIsNegatedSideOfEquivalence, {gl, 
                      l}\[LongRightArrow]{}], \n\t\t\t\tProofStep[
                  Prinfo[\[Cent]BackChainingEquivalence, {gl, 
                        l}\[LongRightArrow]newGoal], 
                  Psit[newGoal, \[Bullet]asml[pre, post], 
                    af]], \n\t\t\t\tsimpPS]], \n\t\t\tsimpPS]];\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[gl_, g_, gi_], \[Bullet]asml[
            pre___, \[Bullet]lf[
              l_, \((\[Not] g_)\)\[DoubleLongLeftRightArrow]f_, fi_], 
            post___], af_] := 
        Block[{\n\t\t\t\ \ \ \ \ \ \ \ \ simpLF\  = \ \[Bullet]lf[
                NewLabel[\[Cent]SimplifyEquivalenceNegated, l], f, 
                fi]}, \n\t\tsimpPS = 
            ProofStep[
              Prinfo[\[Cent]SimplifyEquivalenceNegated, {gl, 
                    l}\[LongRightArrow]simpLF], 
              Psit[\[Bullet]lf[gl, g, gi], \[Bullet]asml[pre, simpLF, post], 
                af]]; \n\t\tIf[$TmaPPNDBackChaining\  || \ \
$TmaPPNDBackChainingEquivalence, \n\t\t\tBlock[{newGoal = \[Bullet]lf[
                    NewLabel[\[Cent]BackChainingEquivalenceNegated, 
                      l], \[Not] f, fi]}, \n\t\t\tProofAlternatives[
                Prinfo[\[Cent]GoalIsNegatedSideOfEquivalence, {gl, 
                      l}\[LongRightArrow]{}], \n\t\t\t\tProofStep[
                  Prinfo[\[Cent]BackChainingEquivalence, {gl, 
                        l}\[LongRightArrow]newGoal], 
                  Psit[newGoal, \[Bullet]asml[pre, post], 
                    af]], \n\t\t\t\tsimpPS]], \n\t\t\tsimpPS]];\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[gl_, \[Not] g_, gi_], \[Bullet]asml[
            pre___, \[Bullet]lf[l_, f_\[DoubleLongLeftRightArrow]g_, fi_], 
            post___], af_] := 
        Block[{\n\t\t\t\ \ \ \ \ \ \ \ \ simpLF\  = \ \[Bullet]lf[
                NewLabel[\[Cent]SimplifyEquivalenceNegated, l], f, 
                fi]}, \n\t\tsimpPS = 
            ProofStep[
              Prinfo[\[Cent]SimplifyEquivalenceNegated, {gl, 
                    l}\[LongRightArrow]simpLF], 
              Psit[\[Bullet]lf[gl, \[Not] g, gi], \[Bullet]asml[pre, simpLF, 
                  post], af]]; \n\t\tIf[$TmaPPNDBackChaining\  || \ \
$TmaPPNDBackChainingEquivalence, \n\t\t\tBlock[{newGoal = \[Bullet]lf[
                    NewLabel[\[Cent]BackChainingEquivalenceNegated, 
                      l], \[Not] f, fi]}, \n\t\t\tProofAlternatives[
                Prinfo[\[Cent]GoalIsNegatedSideOfEquivalence, {gl, 
                      l}\[LongRightArrow]{}], \n\t\t\t\tProofStep[
                  Prinfo[\[Cent]BackChainingEquivalence, {gl, 
                        l}\[LongRightArrow]newGoal], 
                  Psit[newGoal, \[Bullet]asml[pre, post], 
                    af]], \n\t\t\t\tsimpPS]], \n\t\t\tsimpPS]];\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[gl_, \[Not] g_, gi_], \[Bullet]asml[
            pre___, \[Bullet]lf[l_, g_\[DoubleLongLeftRightArrow]f_, fi_], 
            post___], af_] := 
        Block[{\n\t\t\t\ \ \ \ \ \ \ \ \ simpLF\  = \ \[Bullet]lf[
                NewLabel[\[Cent]SimplifyEquivalenceNegated, l], f, 
                fi]}, \n\t\tsimpPS = 
            ProofStep[
              Prinfo[\[Cent]SimplifyEquivalenceNegated, {gl, 
                    l}\[LongRightArrow]simpLF], 
              Psit[\[Bullet]lf[gl, \[Not] g, gi], \[Bullet]asml[pre, simpLF, 
                  post], af]]; \n\t\tIf[$TmaPPNDBackChaining\  || \ \
$TmaPPNDBackChainingEquivalence, \n\t\t\tBlock[{newGoal = \[Bullet]lf[
                    NewLabel[\[Cent]BackChainingEquivalenceNegated, 
                      l], \[Not] f, fi]}, \n\t\t\tProofAlternatives[
                Prinfo[\[Cent]GoalIsNegatedSideOfEquivalence, {gl, 
                      l}\[LongRightArrow]{}], \n\t\t\t\tProofStep[
                  Prinfo[\[Cent]BackChainingEquivalence, {gl, 
                        l}\[LongRightArrow]newGoal], 
                  Psit[newGoal, \[Bullet]asml[pre, post], 
                    af]], \n\t\t\t\tsimpPS]], \n\t\t\tsimpPS]];\)\)], "Input",\

  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Case Distinction", "Section",
  CellDingbat->"\[FilledSquare]",
  Background->None],

Cell["\<\
This rule is applied last because in splits the proof tree: if we apply it \
earlier then much work will be done two times.\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "Assumption is Disjunction: Case Distinction\n",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(\[Ellipsis]\ f\ \[Ellipsis]\  \[RightTee] \ 
                G; \ \ \ \ \ \ \[Ellipsis]\ g\ \[Ellipsis]\ \  \[RightTee] \ 
                G\)\/\(\[Ellipsis]\ f\  \[Or] \ 
                  g\ \[Ellipsis]\  \[RightTee] \ G\)\),
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]],
  " "
}], "Subsubsection"],

Cell[BoxData[
    \(\(PPND[\[Bullet]lf[lp_, fp_, pi_], \[Bullet]asml[
            pre___, \[Bullet]lf[l_, Or[fl___], fi_], post___], af_] := 
        Block[{orF = \[Bullet][Or[fl]], 
            proofSituations = {}, \n\t\t\tnewcases = {}, formulai, n, 
            i}, \n\t\tn\  = \ 
            Length[orF]; \n\t\tDo[\n\t\t\tformulai = \[Bullet]lf[
                NewLabel[\[Cent]CaseDistinction, l, i], orF[\([i]\)], 
                IndexedFormulaInfo[fi, i]]; \n\t\t\tAppendTo[newcases, 
              formulai]; \n\t\t\tAppendTo[proofSituations, 
              Psit[\[Bullet]lf[lp, fp, pi], \[Bullet]asml[pre, formulai, 
                  post], af]], \n\t\t\t{i, n}]; \t\t\n\t\tPrependTo[
            proofSituations, 
            Prinfo[\[Cent]CaseDistinction, {lp, l}\[LongRightArrow]
                newcases]]; \n\t\tProofStep @@ proofSituations];\)\)], "Input",\

  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Back Chaining on Assumptions", "Section",
  CellDingbat->"\[FilledSquare]",
  Background->None],

Cell["(Depends on Option TrySubgoal)", "Subsubsection"],

Cell[CellGroupData[{

Cell[TextData[{
  "Implication: Prove sub-goal\n",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(\[Ellipsis]\  \[RightTee] \ 
                f; \ \ \ \ \ \[Ellipsis]\ g\ \[Ellipsis]\  \[RightTee] \ 
                G\)\/\(\[Ellipsis]\ \((f\  \[Implies] \ 
                      g)\)\ \[Ellipsis]\  \[RightTee] \ G\)\),
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]],
  "     or        ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(\[Ellipsis] \(\[Not] f\)\  \[Or] \ 
                  g\[Ellipsis]\  \[RightTee] \ 
                G\)\/\(\[Ellipsis]\ \((f\  \[Implies] \ 
                      g)\)\ \[Ellipsis]\  \[RightTee] \ G\)\),
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]]
}], "Subsubsection"],

Cell[TextData[{
  StyleBox["Back track: ",
    FontWeight->"Bold"],
  "try to prove LHS of the implication, alternatively transform implication  \
into disjunction."
}], "Text"],

Cell["\<\
If the LHS of the implication can be proven, then modus-ponens is \
automatically applied (the RHS is assumed).\
\>", "Text"],

Cell[BoxData[
    \(\(PPND[
          goal_, \[Bullet]asml[
            pre___, \[Bullet]lf[l_, f_ \[Implies] g_, fi_], post___], af_] := 
        Block[{pf2\  = \ \[Bullet]lf[
                NewLabel[\[Cent]TransformImplication, 
                  l], \((\[Not] f)\) \[Or] g, fi]}, \n\t\t\tsimpPS = 
            ProofStep[
              Prinfo[\[Cent]TransformImplication, 
                l\[LongRightArrow]pf2], \n\t\t\t\tPsit[
                goal, \[Bullet]asml[pre, pf2, post], 
                af]]; \n\t\tIf[$TmaPPNDTrySubgoal\  || \ \
$TmaPPNDTrySubgoalImplication, \n\t
            With[{pf1\  = \ \[Bullet]lf[NewLabel[\[Cent]ProveSubgoal, l], f, 
                    fi], pfs\  = \ \[Bullet]lf[
                    NewLabel[\[Cent]SubgoalProved, l], g, fi]}, \n\t
              ProofAlternatives[
                Prinfo[\[Cent]AssumeImplication, 
                  l\[LongRightArrow]{}], \n\t\tProofStep[
                  Prinfo[\[Cent]ProveSubgoal, 
                    l\[LongRightArrow]{pf1, pfs}], \n\t\t\t\tPsit[
                    pf1, \ \ \[Bullet]asml[pre, post], af], \n\t\t\t\tPsit[
                    goal, \[Bullet]asml[pre, pfs, post], 
                    af]], \n\t\t\tsimpPS]], \n\t\t\tsimpPS]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Equivalence: Prove sub-goal\n",
  Cell[BoxData[
      FormBox[
        StyleBox[
          
          FractionBox[\(\[Ellipsis]\  \[RightTee] \ 
              f; \ \ \ \ \ \[Ellipsis]\ g\ \[Ellipsis]\  \[RightTee] \ G\), 
            RowBox[{
              RowBox[{"\[Ellipsis]", " ", 
                RowBox[{"(", 
                  RowBox[{"f", 
                    StyleBox[" ",
                      FontWeight->"Plain",
                      FontSlant->"Italic"], 
                    StyleBox["\[DoubleLeftRightArrow]",
                      FontSize->18,
                      FontWeight->"Plain",
                      FontSlant->"Plain"], 
                    StyleBox[" ",
                      FontWeight->"Plain",
                      FontSlant->"Italic"], 
                    StyleBox["g",
                      FontSlant->"Plain"]}], ")"}], " ", "\[Ellipsis]"}], " ",
               "\[RightTee]", " ", 
              StyleBox["G",
                FontSlant->"Plain"]}]],
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]],
  "      or      ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          
          FractionBox[\(\[Ellipsis]\  \[RightTee] \ 
              g; \ \ \ \ \ \[Ellipsis]\ f\ \[Ellipsis]\  \[RightTee] \ G\), 
            RowBox[{
              RowBox[{"\[Ellipsis]", " ", 
                RowBox[{"(", 
                  RowBox[{"f", " ", 
                    StyleBox["\[DoubleLeftRightArrow]",
                      FontSize->18,
                      FontSlant->"Plain"], " ", 
                    StyleBox["g",
                      FontSlant->"Plain"]}], ")"}], " ", "\[Ellipsis]"}], " ",
               "\[RightTee]", " ", 
              StyleBox["G",
                FontSlant->"Plain"]}]],
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]],
  "      or      ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          
          FractionBox[\(\[Ellipsis]\ \((\((f\  \[And] \ 
                        g)\)\  \[Or] \ \((\[Not] f\  \[And] \ \[Not] g)\))\) \
\[Ellipsis]\  \[RightTee] \ G\), 
            RowBox[{
              RowBox[{"\[Ellipsis]", " ", 
                RowBox[{"(", 
                  RowBox[{"f", " ", 
                    StyleBox["\[DoubleLeftRightArrow]",
                      FontSize->18,
                      FontSlant->"Plain"], " ", 
                    StyleBox["g",
                      FontSlant->"Plain"]}], ")"}], " ", "\[Ellipsis]"}], " ",
               "\[RightTee]", " ", 
              StyleBox["G",
                FontSlant->"Plain"]}]],
          FontSize->18,
          FontSlant->"Plain"], TraditionalForm]]]
}], "Subsubsection"],

Cell[TextData[{
  StyleBox["Back track: ",
    FontWeight->"Bold"],
  "try to prove the LHS of the equivalence, or the RHS, or transform  \
equivalence into disjunction."
}], "Text"],

Cell["\<\
If the LHS (RHS) can be proven, then modus-ponens is automatically applied: \
the LHS (RHS) is assumed. \
\>", "Text"],

Cell[BoxData[
    \(\(PPND[
          goal_, \[Bullet]asml[
            pre___, \[Bullet]lf[l_, f_\[DoubleLongLeftRightArrow]g_, fi_], 
            post___], af_] := 
        Block[{simpLF\  = \ \[Bullet]lf[
                NewLabel[\[Cent]TransformEquivalence, 
                  l], \((f \[And] 
                      g)\) \[Or] \((\((\[Not] f)\) \[And] \((\[Not] g)\))\), 
                fi]}, \n\t\t\tsimpPS = 
            ProofStep[
              Prinfo[\[Cent]TransformEquivalence, 
                l\[LongRightArrow]simpLF], \n\t\t\t\tPsit[
                goal, \[Bullet]asml[pre, simpLF, post], 
                af]]; \n\t\tIf[$TmaPPNDTrySubgoal\  || \ \
$TmaPPNDTrySubgoalEquivalence, \n\t
            With[{psf\  = \ \[Bullet]lf[NewLabel[\[Cent]ProveSubgoal, l, 1], 
                    f, fi], \n\t\t\t\ \ \ \ \ \ \ \ \ \ psg\  = \ \[Bullet]lf[
                    NewLabel[\[Cent]ProveSubgoal, l, 2], g, 
                    fi], \n\t\t\t\ \ \ \ \ \ \ \ \ \ spf\  = \ \[Bullet]lf[
                    NewLabel[\[Cent]SubgoalProved, l], f, 
                    fi], \n\t\t\t\ \ \ \ \ \ \ \ \ \ spg\ \  = \ \[Bullet]lf[
                    NewLabel[\[Cent]SubgoalProved, l], g, fi]}, \n\t
              ProofAlternatives[
                Prinfo[\[Cent]AssumeEquivalence, 
                  l\[LongRightArrow]{}], \n\t\tProofStep[
                  Prinfo[\[Cent]ProveSubgoal, 
                    l\[LongRightArrow]{psf, spg\ }], \n\t\t\t\t\tPsit[
                    psf, \[Bullet]asml[pre, post], af], \n\t\t\t\t\tPsit[
                    goal, \[Bullet]asml[pre, spg, post], 
                    af]], \n\t\tProofStep[
                  Prinfo[\[Cent]ProveSubgoal, 
                    l\[LongRightArrow]{psg, spf}], \n\t\t\t\tPsit[
                    psg, \[Bullet]asml[pre, post], af], \n\t\t\t\t\tPsit[
                    goal, \[Bullet]asml[pre, spf, post], 
                    af]], \n\t\tsimpPS\n\t\t]], \n\t\t\tsimpPS]];\)\)], \
"Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Default: PPND fails:",
  StyleBox[" Disactivated",
    FontColor->RGBColor[1, 0, 0]]
}], "Section",
  CellDingbat->None],

Cell[BoxData[
    \(\(PPND[___] := Null;\)\)], "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["End", "Subsubtitle"],

Cell[BoxData[
    \(\(End[];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(CollectHandledProofSituations[PPND];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(HideSymbols[ProtectedSymbols[$Context]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(EndNewPackage[$Context];\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(SaveInitialization[{$TheoremaPrivateDirectory, "\<Theorema\>", \
"\<Provers\>", "\<Propositional\>"}, "\<Prover\>"];\)\)], "Input"],

Cell[BoxData[
    \("/home/npopov/Theorema/Provers/Propositional/Prover.m"\)], "Print"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Package Demo", "Subtitle"],

Cell["See Demo directory", "Text"],

Cell[BoxData[
    \(\(Needs["\<Theorema`Provers`Propositional`Prover`\>"];\)\)], "Input"],

Cell[BoxData[
    \(Names["\<Theorema`Provers`Propositional`Prover`*\>"]\)], "Input"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 723}},
NotebookAutoSave->True,
AutoGeneratedPackage->None,
Evaluator->"Local",
WindowSize->{1016, 696},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.5,
StyleDefinitions -> "TheoremaPackage.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 41, 0, 153, "Title"],

Cell[CellGroupData[{
Cell[1793, 56, 39, 0, 95, "Subtitle"],
Cell[1835, 58, 193, 5, 47, "Text"],
Cell[2031, 65, 83, 2, 42, "Input",
  InitializationCell->True],
Cell[2117, 69, 352, 6, 146, "Input",
  InitializationCell->True],
Cell[2472, 77, 600, 18, 125, "Input",
  Evaluatable->True,
  InitializationCell->True],
Cell[3075, 97, 131, 3, 42, "Input",
  InitializationCell->True],
Cell[3209, 102, 143, 3, 42, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3389, 110, 34, 0, 77, "Subtitle"],

Cell[CellGroupData[{
Cell[3448, 114, 28, 0, 91, "Subsubtitle"],
Cell[3479, 116, 88, 2, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3604, 123, 27, 0, 65, "Subsubtitle"],
Cell[3634, 125, 211, 3, 73, "Text"],

Cell[CellGroupData[{
Cell[3870, 132, 37, 0, 68, "Subsection"],
Cell[3910, 134, 208, 4, 68, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[4155, 143, 143, 4, 42, "Subsection"],
Cell[4301, 149, 480, 9, 146, "Input",
  InitializationCell->True],
Cell[4784, 160, 703, 12, 302, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[5524, 177, 37, 0, 46, "Section"],
Cell[5564, 179, 138, 3, 47, "Text"],
Cell[5705, 184, 124, 3, 47, "Text"],
Cell[5832, 189, 180, 4, 73, "Text"],
Cell[6015, 195, 136, 3, 47, "Text"],
Cell[6154, 200, 782, 16, 250, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[6973, 221, 128, 4, 46, "Section"],
Cell[7104, 227, 160, 3, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[7301, 235, 29, 0, 46, "Section"],
Cell[7333, 237, 77, 2, 70, "Input",
  InitializationCell->True]
}, Closed]],
Cell[7425, 242, 103, 3, 46, "Section"],

Cell[CellGroupData[{
Cell[7553, 249, 86, 2, 78, "Section"],

Cell[CellGroupData[{
Cell[7664, 255, 44, 0, 68, "Subsection"],

Cell[CellGroupData[{
Cell[7733, 259, 555, 17, 70, "Subsubsection"],
Cell[8291, 278, 348, 7, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[8676, 290, 667, 20, 70, "Subsubsection"],
Cell[9346, 312, 372, 7, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[9755, 324, 372, 11, 70, "Subsubsection"],
Cell[10130, 337, 397, 8, 70, "Input",
  InitializationCell->True],
Cell[10530, 347, 399, 8, 70, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[10978, 361, 50, 0, 42, "Subsection"],

Cell[CellGroupData[{
Cell[11053, 365, 824, 24, 104, "Subsubsection"],
Cell[11880, 391, 301, 5, 70, "Text"],
Cell[12184, 398, 906, 16, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[13127, 419, 424, 12, 82, "Subsubsection"],
Cell[13554, 433, 505, 10, 70, "Input",
  InitializationCell->True],
Cell[14062, 445, 501, 10, 70, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[14612, 461, 46, 0, 42, "Subsection"],
Cell[14661, 463, 144, 3, 70, "Text"],
Cell[14808, 468, 172, 5, 70, "Text"],
Cell[14983, 475, 165, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[15173, 482, 581, 18, 70, "Subsubsection"],
Cell[15757, 502, 333, 7, 70, "Input",
  InitializationCell->True],
Cell[16093, 511, 339, 7, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[16469, 523, 681, 20, 70, "Subsubsection"],
Cell[17153, 545, 234, 5, 70, "Input",
  InitializationCell->True],
Cell[17390, 552, 242, 5, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[17669, 562, 843, 25, 70, "Subsubsection"],
Cell[18515, 589, 312, 6, 70, "Input",
  InitializationCell->True],
Cell[18830, 597, 335, 7, 70, "Input",
  InitializationCell->True],
Cell[19168, 606, 333, 7, 70, "Input",
  InitializationCell->True],
Cell[19504, 615, 341, 7, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[19882, 627, 430, 13, 70, "Subsubsection"],
Cell[20315, 642, 268, 5, 70, "Input",
  InitializationCell->True],
Cell[20586, 649, 274, 5, 70, "Input",
  InitializationCell->True],
Cell[20863, 656, 202, 4, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[21102, 665, 490, 15, 70, "Subsubsection"],
Cell[21595, 682, 281, 5, 70, "Input",
  InitializationCell->True],
Cell[21879, 689, 300, 6, 70, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[22240, 702, 106, 2, 46, "Section"],

Cell[CellGroupData[{
Cell[22371, 708, 51, 0, 68, "Subsection"],

Cell[CellGroupData[{
Cell[22447, 712, 366, 9, 101, "Subsubsection"],
Cell[22816, 723, 514, 11, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[23367, 739, 444, 10, 85, "Subsubsection"],
Cell[23814, 751, 549, 12, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[24400, 768, 446, 10, 85, "Subsubsection"],
Cell[24849, 780, 570, 13, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[25456, 798, 391, 10, 84, "Subsubsection"],
Cell[25850, 810, 815, 16, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[26702, 831, 420, 9, 85, "Subsubsection"],
Cell[27125, 842, 593, 13, 198, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[27755, 860, 446, 10, 84, "Subsubsection"],
Cell[28204, 872, 638, 14, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[28879, 891, 1067, 29, 90, "Subsubsection"],
Cell[29949, 922, 151, 3, 70, "Text"],
Cell[30103, 927, 487, 10, 70, "Input",
  InitializationCell->True],
Cell[30593, 939, 177, 5, 70, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[30819, 950, 66, 0, 42, "Subsection"],

Cell[CellGroupData[{
Cell[30910, 954, 465, 11, 108, "Subsubsection"],
Cell[31378, 967, 689, 14, 70, "Input",
  InitializationCell->True],
Cell[32070, 983, 664, 13, 70, "Input",
  InitializationCell->True],
Cell[32737, 998, 679, 13, 70, "Input",
  InitializationCell->True],
Cell[33419, 1013, 690, 14, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[34146, 1032, 423, 9, 84, "Subsubsection"],
Cell[34572, 1043, 2215, 47, 224, "Input",
  InitializationCell->True],
Cell[36790, 1092, 607, 12, 198, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[37434, 1109, 450, 11, 84, "Subsubsection"],
Cell[37887, 1122, 646, 13, 198, "Input",
  InitializationCell->True],
Cell[38536, 1137, 652, 14, 224, "Input",
  InitializationCell->True],
Cell[39191, 1153, 655, 13, 224, "Input",
  InitializationCell->True],
Cell[39849, 1168, 679, 15, 224, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[40565, 1188, 431, 10, 84, "Subsubsection"],
Cell[40999, 1200, 618, 12, 70, "Input",
  InitializationCell->True],
Cell[41620, 1214, 614, 12, 70, "Input",
  InitializationCell->True],
Cell[42237, 1228, 618, 12, 70, "Input",
  InitializationCell->True],
Cell[42858, 1242, 614, 12, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[43509, 1259, 473, 11, 84, "Subsubsection"],
Cell[43985, 1272, 89, 3, 70, "Text"],
Cell[44077, 1277, 662, 13, 70, "Input",
  InitializationCell->True],
Cell[44742, 1292, 680, 15, 70, "Input",
  InitializationCell->True],
Cell[45425, 1309, 662, 13, 70, "Input",
  InitializationCell->True],
Cell[46090, 1324, 682, 15, 70, "Input",
  InitializationCell->True],
Cell[46775, 1341, 100, 3, 70, "Text"],
Cell[46878, 1346, 670, 14, 70, "Input",
  InitializationCell->True],
Cell[47551, 1362, 668, 14, 70, "Input",
  InitializationCell->True],
Cell[48222, 1378, 668, 14, 70, "Input",
  InitializationCell->True],
Cell[48893, 1394, 668, 14, 70, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[49622, 1415, 107, 2, 46, "Section"],

Cell[CellGroupData[{
Cell[49754, 1421, 1033, 29, 101, "Subsubsection"],
Cell[50790, 1452, 387, 7, 70, "Input",
  InitializationCell->True],
Cell[51180, 1461, 396, 8, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[51613, 1474, 1107, 31, 82, "Subsubsection"],
Cell[52723, 1507, 252, 5, 73, "Text"],
Cell[52978, 1514, 426, 8, 120, "Input",
  InitializationCell->True],
Cell[53407, 1524, 435, 9, 120, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[53879, 1538, 2097, 59, 82, "Subsubsection"],
Cell[55979, 1599, 169, 3, 70, "Text"],
Cell[56151, 1604, 410, 8, 70, "Input",
  InitializationCell->True],
Cell[56564, 1614, 433, 8, 70, "Input",
  InitializationCell->True],
Cell[57000, 1624, 434, 9, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[57471, 1638, 78, 1, 42, "Subsection"],

Cell[CellGroupData[{
Cell[57574, 1643, 473, 13, 101, "Subsubsection"],
Cell[58050, 1658, 367, 7, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[58454, 1670, 474, 13, 78, "Subsubsection"],
Cell[58931, 1685, 463, 8, 120, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[59431, 1698, 389, 9, 83, "Subsubsection"],
Cell[59823, 1709, 782, 13, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[60642, 1727, 868, 20, 106, "Subsubsection"],
Cell[61513, 1749, 2573, 48, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[64123, 1802, 647, 17, 84, "Subsubsection"],
Cell[64773, 1821, 602, 11, 70, "Input",
  InitializationCell->True],
Cell[65378, 1834, 614, 11, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[66029, 1850, 409, 10, 84, "Subsubsection"],
Cell[66441, 1862, 1354, 25, 70, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[67856, 1894, 95, 2, 46, "Section"],
Cell[67954, 1898, 77, 1, 62, "Subsubsection"],

Cell[CellGroupData[{
Cell[68056, 1903, 54, 0, 39, "Subsubsection"],
Cell[68113, 1905, 191, 6, 70, "Text"],
Cell[68307, 1913, 331, 10, 70, "Text"],
Cell[68641, 1925, 365, 10, 70, "Text"],
Cell[69009, 1937, 314, 8, 70, "Text"],
Cell[69326, 1947, 159, 3, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[69522, 1955, 799, 22, 82, "Subsubsection"],
Cell[70324, 1979, 1524, 27, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[71885, 2011, 1435, 41, 82, "Subsubsection"],
Cell[73323, 2054, 117, 3, 70, "Text"],
Cell[73443, 2059, 163, 3, 70, "Text"],
Cell[73609, 2064, 286, 5, 70, "Text"],
Cell[73898, 2071, 1149, 20, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[75084, 2096, 1857, 52, 82, "Subsubsection"],
Cell[76944, 2150, 102, 3, 70, "Text"],
Cell[77049, 2155, 1227, 22, 70, "Input",
  InitializationCell->True],
Cell[78279, 2179, 1217, 21, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[79533, 2205, 785, 20, 82, "Subsubsection"],
Cell[80321, 2227, 1218, 22, 70, "Input",
  InitializationCell->True],
Cell[81542, 2251, 1218, 22, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[82797, 2278, 729, 20, 82, "Subsubsection"],
Cell[83529, 2300, 1267, 22, 70, "Input",
  InitializationCell->True],
Cell[84799, 2324, 1278, 23, 70, "Input",
  InitializationCell->True],
Cell[86080, 2349, 1266, 22, 70, "Input",
  InitializationCell->True],
Cell[87349, 2373, 1266, 22, 70, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[88664, 2401, 89, 2, 46, "Section"],
Cell[88756, 2405, 147, 3, 47, "Text"],

Cell[CellGroupData[{
Cell[88928, 2412, 448, 11, 107, "Subsubsection"],
Cell[89379, 2425, 904, 16, 70, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[90332, 2447, 101, 2, 46, "Section"],
Cell[90436, 2451, 55, 0, 62, "Subsubsection"],

Cell[CellGroupData[{
Cell[90516, 2455, 772, 19, 108, "Subsubsection"],
Cell[91291, 2476, 177, 5, 70, "Text"],
Cell[91471, 2483, 135, 3, 70, "Text"],
Cell[91609, 2488, 1269, 24, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[92915, 2517, 2689, 72, 85, "Subsubsection"],
Cell[95607, 2591, 182, 5, 70, "Text"],
Cell[95792, 2598, 128, 3, 70, "Text"],
Cell[95923, 2603, 1991, 37, 70, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[97963, 2646, 139, 5, 46, "Section"],
Cell[98105, 2653, 55, 1, 70, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[98209, 2660, 26, 0, 91, "Subsubtitle"],
Cell[98238, 2662, 71, 2, 42, "Input",
  InitializationCell->True],
Cell[98312, 2666, 101, 2, 42, "Input",
  InitializationCell->True],
Cell[98416, 2670, 105, 2, 42, "Input",
  InitializationCell->True],
Cell[98524, 2674, 89, 2, 42, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[98638, 2680, 153, 2, 68, "Input"],
Cell[98794, 2684, 87, 1, 35, "Print"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[98942, 2692, 32, 0, 95, "Subtitle"],
Cell[98977, 2694, 34, 0, 47, "Text"],
Cell[99014, 2696, 89, 1, 42, "Input"],
Cell[99106, 2699, 85, 1, 42, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

