(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     24031,        915]*)
(*NotebookOutlinePosition[     24674,        937]*)
(*  CellTagsIndexPosition[     24630,        933]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions", "Subtitle"],

Cell["\<\
Modify the definitions below to change the default appearance of all \
cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Section"],

Cell[StyleData[All, "Working"],
  PageWidth->WindowWidth,
  ScriptMinSize->9],

Cell[StyleData[All, "Presentation"],
  PageWidth->WindowWidth,
  ScriptMinSize->12,
  FontSize->16],

Cell[StyleData[All, "Condensed"],
  PageWidth->WindowWidth,
  CellBracketOptions->{"Margins"->{1, 1},
  "Widths"->{0, 5}},
  ScriptMinSize->8,
  FontSize->11],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  ScriptMinSize->5,
  FontSize->10,
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Notebook Options", "Section"],

Cell["\<\
The options defined for the style below will be used at the Notebook \
level.\
\>", "Text"],

Cell[StyleData["Notebook"],
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"], None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  CellFrameLabelMargins->6,
  AutoItalicWords->{"Theorema"},
  LimitsPositioningTokens->{},
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headings", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Title"],
  CellMargins->{{12, Inherited}, {20, 40}},
  CellGroupingRules->{"TitleGrouping", 0},
  PageBreakBelow->False,
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {
      "Figure", 0}, {"Subtitle", 0}, {"Subsubtitle", 0}},
  FontFamily->"Helvetica",
  FontSize->36,
  FontWeight->"Bold",
  Background->RGBColor[0, 1, 1]],

Cell[StyleData["Title", "Presentation"],
  CellMargins->{{24, 10}, {20, 40}},
  LineSpacing->{1, 0},
  FontSize->44],

Cell[StyleData["Title", "Condensed"],
  CellMargins->{{8, 10}, {4, 8}},
  FontSize->20],

Cell[StyleData["Title", "Printout"],
  CellMargins->{{2, 10}, {12, 30}},
  FontSize->24]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subtitle"],
  CellMargins->{{12, Inherited}, {20, 15}},
  CellGroupingRules->{"TitleGrouping", 10},
  PageBreakBelow->False,
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {
      "Figure", 0}, {"Subsubtitle", 0}},
  FontFamily->"Helvetica",
  FontSize->24,
  Background->RGBColor[0, 1, 1]],

Cell[StyleData["Subtitle", "Presentation"],
  CellMargins->{{24, 10}, {20, 20}},
  LineSpacing->{1, 0},
  FontSize->36],

Cell[StyleData["Subtitle", "Condensed"],
  CellMargins->{{8, 10}, {4, 4}},
  FontSize->14],

Cell[StyleData["Subtitle", "Printout"],
  CellMargins->{{2, 10}, {12, 8}},
  FontSize->18]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubtitle"],
  CellMargins->{{12, Inherited}, {20, 15}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {
      "Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->14,
  FontSlant->"Italic"],

Cell[StyleData["Subsubtitle", "Presentation"],
  CellMargins->{{24, 10}, {20, 20}},
  LineSpacing->{1, 0},
  FontSize->24],

Cell[StyleData["Subsubtitle", "Condensed"],
  CellMargins->{{8, 10}, {8, 8}},
  FontSize->12],

Cell[StyleData["Subsubtitle", "Printout"],
  CellMargins->{{2, 10}, {12, 8}},
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Section"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{25, Inherited}, {8, 24}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->16,
  FontWeight->"Bold",
  Background->RGBColor[0, 1, 1]],

Cell[StyleData["Section", "Presentation"],
  CellMargins->{{40, 10}, {11, 32}},
  LineSpacing->{1, 0},
  FontSize->24],

Cell[StyleData["Section", "Condensed"],
  CellMargins->{{18, Inherited}, {6, 12}},
  FontSize->12],

Cell[StyleData["Section", "Printout"],
  CellMargins->{{13, 0}, {7, 22}},
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsection"],
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{22, Inherited}, {8, 20}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  FontSize->14,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->RGBColor[0.4, 1, 1]],

Cell[StyleData["Subsection", "Presentation"],
  CellMargins->{{36, 10}, {11, 32}},
  LineSpacing->{1, 0},
  FontSize->22,
  Background->RGBColor[0.6, 1, 1]],

Cell[StyleData["Subsection", "Condensed"],
  CellMargins->{{16, Inherited}, {6, 12}},
  FontSize->12],

Cell[StyleData["Subsection", "Printout"],
  CellMargins->{{9, 0}, {7, 22}},
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsection"],
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{22, Inherited}, {8, 18}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  CounterIncrements->"Subsubsection",
  FontWeight->"Bold",
  Background->RGBColor[0.700008, 1, 1]],

Cell[StyleData["Subsubsection", "Presentation"],
  CellMargins->{{34, 10}, {11, 26}},
  LineSpacing->{1, 0},
  FontSize->18],

Cell[StyleData["Subsubsection", "Condensed"],
  CellMargins->{{17, Inherited}, {6, 12}},
  FontSize->10],

Cell[StyleData["Subsubsection", "Printout"],
  CellMargins->{{9, 0}, {7, 14}},
  FontSize->11]
}, Closed]],

Cell[StyleData["Subsubsubsection"],
  CellDingbat->"\[EmptySmallSquare]",
  CellMargins->{{22, Inherited}, {8, 18}},
  CellGroupingRules->{"SectionGrouping", 60},
  PageBreakBelow->False,
  CounterIncrements->"Subsubsection",
  FontWeight->"Bold",
  Background->RGBColor[0.900008, 1, 1]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Styles for Body Text", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Text"],
  CellMargins->{{12, 10}, {7, 7}},
  TextJustification->1,
  LineSpacing->{1, 3},
  CounterIncrements->"Text"],

Cell[StyleData["Text", "Presentation"],
  CellMargins->{{24, 10}, {10, 10}},
  LineSpacing->{1, 5}],

Cell[StyleData["Text", "Condensed"],
  CellMargins->{{8, 10}, {6, 6}},
  LineSpacing->{1, 1}],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SmallText"],
  CellMargins->{{12, 10}, {6, 6}},
  LineSpacing->{1, 3},
  CounterIncrements->"SmallText",
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["SmallText", "Presentation"],
  CellMargins->{{24, 10}, {8, 8}},
  LineSpacing->{1, 5},
  FontSize->12],

Cell[StyleData["SmallText", "Condensed"],
  CellMargins->{{8, 10}, {5, 5}},
  LineSpacing->{1, 2},
  FontSize->9],

Cell[StyleData["SmallText", "Printout"],
  CellMargins->{{2, 2}, {5, 5}},
  FontSize->7]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Input/Output", "Section"],

Cell["\<\
The cells in this section define styles used for input and output to \
the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these \
style names. Some attributes for these styles are actually set in \
FormatType Styles (in the last section of this stylesheet). \
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  CellMargins->{{45, 10}, {5, 7}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultInputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input",
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  Background->RGBColor[1, 1, 0],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[StyleData["Input", "Presentation"],
  CellMargins->{{72, Inherited}, {8, 10}},
  LineSpacing->{1, 0}],

Cell[StyleData["Input", "Condensed"],
  CellMargins->{{40, 10}, {2, 3}}],

Cell[StyleData["Input", "Printout"],
  CellMargins->{{39, 0}, {4, 6}},
  FontSize->9]
}, Closed]],

Cell[StyleData["InputOnly"],
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  DefaultFormatType->DefaultInputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input",
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  CellMargins->{{47, 10}, {7, 5}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Output"],

Cell[StyleData["Output", "Presentation"],
  CellMargins->{{72, Inherited}, {10, 8}},
  LineSpacing->{1, 0}],

Cell[StyleData["Output", "Condensed"],
  CellMargins->{{41, Inherited}, {3, 2}}],

Cell[StyleData["Output", "Printout"],
  CellMargins->{{39, 0}, {6, 4}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Message",
  StyleMenuListing->None,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["Message", "Presentation"],
  CellMargins->{{72, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0}],

Cell[StyleData["Message", "Condensed"],
  CellMargins->{{41, Inherited}, {Inherited, Inherited}}],

Cell[StyleData["Message", "Printout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontSize->8,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Print"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Print",
  StyleMenuListing->None],

Cell[StyleData["Print", "Presentation"],
  CellMargins->{{72, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0}],

Cell[StyleData["Print", "Condensed"],
  CellMargins->{{41, Inherited}, {Inherited, Inherited}}],

Cell[StyleData["Print", "Printout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  CellMargins->{{4, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  CounterIncrements->"Graphics",
  ImageMargins->{{43, Inherited}, {Inherited, 0}},
  StyleMenuListing->None],

Cell[StyleData["Graphics", "Presentation"],
  ImageMargins->{{62, Inherited}, {Inherited, 0}}],

Cell[StyleData["Graphics", "Condensed"],
  ImageMargins->{{38, Inherited}, {Inherited, 0}},
  Magnification->0.6],

Cell[StyleData["Graphics", "Printout"],
  ImageMargins->{{30, Inherited}, {Inherited, 0}},
  FontSize->9,
  Magnification->0.8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["CellLabel", "Presentation"],
  FontSize->12],

Cell[StyleData["CellLabel", "Condensed"],
  FontSize->9],

Cell[StyleData["CellLabel", "Printout"],
  FontFamily->"Courier",
  FontSize->8,
  FontSlant->"Italic",
  FontColor->GrayLevel[0]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Formulas and Programming", "Section"],

Cell[CellGroupData[{

Cell[StyleData["InlineFormula"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  ScriptLevel->1,
  SingleLetterItalics->True],

Cell[StyleData["InlineFormula", "Presentation"],
  CellMargins->{{24, 10}, {10, 10}},
  LineSpacing->{1, 5}],

Cell[StyleData["InlineFormula", "Condensed"],
  CellMargins->{{8, 10}, {6, 6}},
  LineSpacing->{1, 1}],

Cell[StyleData["InlineFormula", "Printout"],
  CellMargins->{{2, 0}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DisplayFormula"],
  CellMargins->{{42, Inherited}, {Inherited, Inherited}},
  CellHorizontalScrolling->True,
  DefaultFormatType->DefaultInputFormatType,
  ScriptLevel->0,
  SingleLetterItalics->True,
  UnderoverscriptBoxOptions->{LimitsPositioning->True}],

Cell[StyleData["DisplayFormula", "Presentation"],
  LineSpacing->{1, 5}],

Cell[StyleData["DisplayFormula", "Condensed"],
  LineSpacing->{1, 1}],

Cell[StyleData["DisplayFormula", "Printout"]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headers and Footers", "Section"],

Cell[StyleData["Header"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontSize->10,
  FontSlant->"Italic"],

Cell[StyleData["Footer"],
  CellMargins->{{0, 0}, {0, 4}},
  StyleMenuListing->None,
  FontSize->9,
  FontSlant->"Italic"],

Cell[StyleData["PageNumber"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell["Palette Styles", "Section"],

Cell["\<\
The cells below define styles that define standard ButtonFunctions, \
for use in palette buttons.\
\>", "Text"],

Cell[StyleData["Paste"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, After]}]&)}],

Cell[StyleData["Evaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["EvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionMove[ 
        FrontEnd`InputNotebook[ ], All, Cell, 1], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperlink Styles", "Section"],

Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same \
Notebook, or between Notebooks.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "Presentation"]],

Cell[StyleData["Hyperlink", "Condensed"]],

Cell[StyleData["Hyperlink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["MainBookLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["MainBookLink", "Presentation"]],

Cell[StyleData["MainBookLink", "Condensed"]],

Cell[StyleData["MainBookLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AddOnsLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["AddOnsLink", "Presentation"]],

Cell[StyleData["AddOnsLink", "Condensed"]],

Cell[StyleData["AddOnLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefGuideLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["RefGuideLink", "Presentation"]],

Cell[StyleData["RefGuideLink", "Condensed"]],

Cell[StyleData["RefGuideLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["GettingStartedLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["GettingStartedLink", "Presentation"]],

Cell[StyleData["GettingStartedLink", "Condensed"]],

Cell[StyleData["GettingStartedLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["OtherInformationLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["OtherInformationLink", "Presentation"]],

Cell[StyleData["OtherInformationLink", "Condensed"]],

Cell[StyleData["OtherInformationLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Placeholder Styles", "Section"],

Cell["\<\
The cells below define styles useful for making placeholder objects \
in palette templates.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Placeholder"],
  Editable->False,
  Selectable->False,
  StyleBoxAutoDelete->True,
  Placeholder->True,
  StyleMenuListing->None],

Cell[StyleData["Placeholder", "Presentation"]],

Cell[StyleData["Placeholder", "Condensed"]],

Cell[StyleData["Placeholder", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SelectionPlaceholder"],
  Editable->False,
  Selectable->False,
  StyleBoxAutoDelete->True,
  Placeholder->PrimaryPlaceholder,
  StyleMenuListing->None,
  DrawHighlighted->True],

Cell[StyleData["SelectionPlaceholder", "Presentation"]],

Cell[StyleData["SelectionPlaceholder", "Condensed"]],

Cell[StyleData["SelectionPlaceholder", "Printout"]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FormatType Styles", "Section"],

Cell["\<\
The cells below define styles that are mixed in with the styles of \
most cells.  If a cell's FormatType matches the name of one of the \
styles defined below, then that style is applied between the cell's \
style and its own options. This is particularly true of Input and \
Output.\
\>", "Text"],

Cell[StyleData["CellExpression"],
  PageWidth->Infinity,
  CellMargins->{{6, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  ShowSpecialCharacters->False,
  AllowInlineCells->False,
  AutoItalicWords->{},
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->12,
  Background->GrayLevel[1]],

Cell[StyleData["InputForm"],
  AllowInlineCells->False,
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["OutputForm"],
  PageWidth->Infinity,
  TextAlignment->Left,
  LineSpacing->{0.6, 1},
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["StandardForm"],
  LineSpacing->{1.25, 0},
  StyleMenuListing->None],

Cell[StyleData["TraditionalForm"],
  LineSpacing->{1.25, 0},
  SingleLetterItalics->True,
  TraditionalFunctionNotation->True,
  DelimiterMatching->None,
  StyleMenuListing->None],

Cell["\<\
The style defined below is mixed in to any cell that is in an inline \
cell within another.\
\>", "Text"],

Cell[StyleData["InlineCell"],
  TextAlignment->Left,
  ScriptLevel->1,
  StyleMenuListing->None],

Cell[StyleData["InlineCellEditing"],
  StyleMenuListing->None,
  Background->RGBColor[1, 0.749996, 0.8]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 723}},
WindowSize->{496, 565},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 37, 0, 64, "Subtitle"],
Cell[1767, 54, 193, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[1985, 62, 42, 0, 59, "Section"],
Cell[2030, 64, 77, 2, 70, 31, 0, "StyleData", "All", "Working"],
Cell[2110, 68, 99, 3, 70, 36, 0, "StyleData", "All", "Presentation"],
Cell[2212, 73, 158, 5, 70, 33, 0, "StyleData", "All", "Condensed"],
Cell[2373, 80, 140, 4, 70, 32, 0, "StyleData", "All", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[2550, 89, 35, 0, 39, "Section"],
Cell[2588, 91, 101, 3, 70, "Text"],
Cell[2692, 96, 490, 13, 70, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[3219, 114, 38, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[3282, 118, 380, 10, 136, 24, 0, "StyleData", "Title", "All",
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {
      "Figure", 0}, {"Subtitle", 0}, {"Subsubtitle", 0}}],
Cell[3665, 130, 116, 3, 70, 40, 0, "StyleData", "Title", \
"Presentation"],
Cell[3784, 135, 87, 2, 70, 37, 0, "StyleData", "Title", "Condensed"],
Cell[3874, 139, 88, 2, 70, 36, 0, "StyleData", "Title", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[3999, 146, 348, 9, 84, 27, 0, "StyleData", "Subtitle", "All",
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {
      "Figure", 0}, {"Subsubtitle", 0}}],
Cell[4350, 157, 119, 3, 70, 43, 0, "StyleData", "Subtitle", \
"Presentation"],
Cell[4472, 162, 90, 2, 70, 40, 0, "StyleData", "Subtitle", \
"Condensed"],
Cell[4565, 166, 90, 2, 70, 39, 0, "StyleData", "Subtitle", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[4692, 173, 324, 9, 57, 30, 0, "StyleData", "Subsubtitle", "All",
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {
      "Figure", 0}}],
Cell[5019, 184, 122, 3, 70, 46, 0, "StyleData", "Subsubtitle", \
"Presentation"],
Cell[5144, 189, 93, 2, 70, 43, 0, "StyleData", "Subsubtitle", \
"Condensed"],
Cell[5240, 193, 93, 2, 70, 42, 0, "StyleData", "Subsubtitle", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[5370, 200, 369, 10, 64, 26, 0, "StyleData", "Section", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}}],
Cell[5742, 212, 118, 3, 70, 42, 0, "StyleData", "Section", \
"Presentation"],
Cell[5863, 217, 98, 2, 70, 39, 0, "StyleData", "Section", \
"Condensed"],
Cell[5964, 221, 89, 2, 70, 38, 0, "StyleData", "Section", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[6090, 228, 363, 10, 70, 29, 0, "StyleData", "Subsection", "All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}}],
Cell[6456, 240, 156, 4, 70, 45, 0, "StyleData", "Subsection", \
"Presentation"],
Cell[6615, 246, 101, 2, 70, 42, 0, "StyleData", "Subsection", \
"Condensed"],
Cell[6719, 250, 91, 2, 70, 41, 0, "StyleData", "Subsection", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[6847, 257, 285, 7, 70, 32, 0, "StyleData", "Subsubsection", \
"All",
  CounterIncrements->"Subsubsection"],
Cell[7135, 266, 124, 3, 70, 48, 0, "StyleData", "Subsubsection", \
"Presentation"],
Cell[7262, 271, 104, 2, 70, 45, 0, "StyleData", "Subsubsection", \
"Condensed"],
Cell[7369, 275, 94, 2, 70, 44, 0, "StyleData", "Subsubsection", \
"Printout"]
}, Closed]],
Cell[7478, 280, 287, 7, 70, 35, 0, "StyleData", "Subsubsubsection", \
"All",
  CounterIncrements->"Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7802, 292, 39, 0, 70, "Section"],

Cell[CellGroupData[{
Cell[7866, 296, 134, 4, 70, 23, 0, "StyleData", "Text", "All",
  CounterIncrements->"Text"],
Cell[8003, 302, 99, 2, 70, 39, 0, "StyleData", "Text", \
"Presentation"],
Cell[8105, 306, 93, 2, 70, 36, 0, "StyleData", "Text", "Condensed"],
Cell[8201, 310, 68, 1, 70, 35, 0, "StyleData", "Text", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[8306, 316, 162, 5, 70, 28, 0, "StyleData", "SmallText", "All",
  CounterIncrements->"SmallText"],
Cell[8471, 323, 118, 3, 70, 44, 0, "StyleData", "SmallText", \
"Presentation"],
Cell[8592, 328, 113, 3, 70, 41, 0, "StyleData", "SmallText", \
"Condensed"],
Cell[8708, 333, 88, 2, 70, 40, 0, "StyleData", "SmallText", \
"Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8845, 341, 42, 0, 70, "Section"],
Cell[8890, 343, 364, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[9279, 353, 627, 20, 70, 24, 0, "StyleData", "Input", "All",
  CounterIncrements->"Input"],
Cell[9909, 375, 106, 2, 70, 40, 0, "StyleData", "Input", \
"Presentation"],
Cell[10018, 379, 72, 1, 70, 37, 0, "StyleData", "Input", \
"Condensed"],
Cell[10093, 382, 85, 2, 70, 36, 0, "StyleData", "Input", "Printout"]
}, Closed]],
Cell[10193, 387, 309, 10, 70, 28, 0, "StyleData", "InputOnly", "All",
  CounterIncrements->"Input",
  StyleMenuListing->None],

Cell[CellGroupData[{
Cell[10527, 401, 454, 13, 70, 25, 0, "StyleData", "Output", "All",
  CounterIncrements->"Output"],
Cell[10984, 416, 107, 2, 70, 41, 0, "StyleData", "Output", \
"Presentation"],
Cell[11094, 420, 80, 1, 70, 38, 0, "StyleData", "Output", \
"Condensed"],
Cell[11177, 423, 86, 2, 70, 37, 0, "StyleData", "Output", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[11300, 430, 501, 14, 70, 26, 0, "StyleData", "Message", "All",
  CounterIncrements->"Message",
  StyleMenuListing->None],
Cell[11804, 446, 123, 2, 70, 42, 0, "StyleData", "Message", \
"Presentation"],
Cell[11930, 450, 97, 1, 70, 39, 0, "StyleData", "Message", \
"Condensed"],
Cell[12030, 453, 138, 3, 70, 38, 0, "StyleData", "Message", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[12205, 461, 465, 13, 70, 24, 0, "StyleData", "Print", "All",
  CounterIncrements->"Print",
  StyleMenuListing->None],
Cell[12673, 476, 121, 2, 70, 40, 0, "StyleData", "Print", \
"Presentation"],
Cell[12797, 480, 95, 1, 70, 37, 0, "StyleData", "Print", \
"Condensed"],
Cell[12895, 483, 109, 2, 70, 36, 0, "StyleData", "Print", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[13041, 490, 439, 12, 70, 27, 0, "StyleData", "Graphics", "All",
  CounterIncrements->"Graphics",
  StyleMenuListing->None],
Cell[13483, 504, 94, 1, 70, 43, 0, "StyleData", "Graphics", \
"Presentation"],
Cell[13580, 507, 113, 2, 70, 40, 0, "StyleData", "Graphics", \
"Condensed"],
Cell[13696, 511, 127, 3, 70, 39, 0, "StyleData", "Graphics", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[13860, 519, 128, 4, 70, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[13991, 525, 60, 1, 70, 44, 0, "StyleData", "CellLabel", \
"Presentation"],
Cell[14054, 528, 56, 1, 70, 41, 0, "StyleData", "CellLabel", \
"Condensed"],
Cell[14113, 531, 130, 4, 70, 40, 0, "StyleData", "CellLabel", \
"Printout"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[14292, 541, 43, 0, 70, "Section"],

Cell[CellGroupData[{
Cell[14360, 545, 146, 4, 70, 32, 0, "StyleData", "InlineFormula", \
"All"],
Cell[14509, 551, 108, 2, 70, 48, 0, "StyleData", "InlineFormula", \
"Presentation"],
Cell[14620, 555, 102, 2, 70, 45, 0, "StyleData", "InlineFormula", \
"Condensed"],
Cell[14725, 559, 77, 1, 70, 44, 0, "StyleData", "InlineFormula", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[14839, 565, 272, 6, 70, 33, 0, "StyleData", "DisplayFormula", \
"All"],
Cell[15114, 573, 72, 1, 70, 49, 0, "StyleData", "DisplayFormula", \
"Presentation"],
Cell[15189, 576, 69, 1, 70, 46, 0, "StyleData", "DisplayFormula", \
"Condensed"],
Cell[15261, 579, 45, 0, 70, 45, 0, "StyleData", "DisplayFormula", \
"Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[15355, 585, 49, 0, 70, "Section"],
Cell[15407, 587, 123, 4, 70, 25, 0, "StyleData", "Header", "All",
  StyleMenuListing->None],
Cell[15533, 593, 122, 4, 70, 25, 0, "StyleData", "Footer", "All",
  StyleMenuListing->None],
Cell[15658, 599, 127, 4, 70, 29, 0, "StyleData", "PageNumber", "All",
  StyleMenuListing->None]
}, Open  ]],

Cell[CellGroupData[{
Cell[15822, 608, 33, 0, 70, "Section"],
Cell[15858, 610, 121, 3, 70, "Text"],
Cell[15982, 615, 226, 5, 70, 24, 0, "StyleData", "Paste", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[16211, 622, 295, 7, 70, 27, 0, "StyleData", "Evaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[16509, 631, 400, 9, 70, 31, 0, "StyleData", "EvaluateCell", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[16912, 642, 387, 9, 70, 31, 0, "StyleData", "CopyEvaluate", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[17302, 653, 401, 9, 70, 35, 0, "StyleData", "CopyEvaluateCell", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic]
}, Closed]],

Cell[CellGroupData[{
Cell[17740, 667, 35, 0, 70, "Section"],
Cell[17778, 669, 184, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[17987, 677, 302, 8, 70, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[18292, 687, 44, 0, 70, 44, 0, "StyleData", "Hyperlink", \
"Presentation"],
Cell[18339, 689, 41, 0, 70, 41, 0, "StyleData", "Hyperlink", \
"Condensed"],
Cell[18383, 691, 107, 2, 70, 40, 0, "StyleData", "Hyperlink", \
"Printout"]
}, Closed]],
Cell[18505, 696, 104, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[18634, 703, 316, 8, 70, 31, 0, "StyleData", "MainBookLink", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[18953, 713, 47, 0, 70, 47, 0, "StyleData", "MainBookLink", \
"Presentation"],
Cell[19003, 715, 44, 0, 70, 44, 0, "StyleData", "MainBookLink", \
"Condensed"],
Cell[19050, 717, 110, 2, 70, 43, 0, "StyleData", "MainBookLink", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[19197, 724, 337, 9, 70, 29, 0, "StyleData", "AddOnsLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[19537, 735, 45, 0, 70, 45, 0, "StyleData", "AddOnsLink", \
"Presentation"],
Cell[19585, 737, 42, 0, 70, 42, 0, "StyleData", "AddOnsLink", \
"Condensed"],
Cell[19630, 739, 107, 2, 70, 40, 0, "StyleData", "AddOnLink", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[19774, 746, 345, 9, 70, 31, 0, "StyleData", "RefGuideLink", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[20122, 757, 47, 0, 70, 47, 0, "StyleData", "RefGuideLink", \
"Presentation"],
Cell[20172, 759, 44, 0, 70, 44, 0, "StyleData", "RefGuideLink", \
"Condensed"],
Cell[20219, 761, 110, 2, 70, 43, 0, "StyleData", "RefGuideLink", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[20366, 768, 328, 8, 70, 37, 0, "StyleData", \
"GettingStartedLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[20697, 778, 53, 0, 70, 53, 0, "StyleData", "GettingStartedLink", \
"Presentation"],
Cell[20753, 780, 50, 0, 70, 50, 0, "StyleData", "GettingStartedLink", \
"Condensed"],
Cell[20806, 782, 116, 2, 70, 49, 0, "StyleData", \
"GettingStartedLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[20959, 789, 332, 8, 70, 39, 0, "StyleData", \
"OtherInformationLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[21294, 799, 55, 0, 70, 55, 0, "StyleData", \
"OtherInformationLink", "Presentation"],
Cell[21352, 801, 52, 0, 70, 52, 0, "StyleData", \
"OtherInformationLink", "Condensed"],
Cell[21407, 803, 118, 2, 70, 51, 0, "StyleData", \
"OtherInformationLink", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[21574, 811, 37, 0, 70, "Section"],
Cell[21614, 813, 115, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[21754, 820, 145, 5, 70, 30, 0, "StyleData", "Placeholder", "All",
  
  StyleMenuListing->None],
Cell[21902, 827, 46, 0, 70, 46, 0, "StyleData", "Placeholder", \
"Presentation"],
Cell[21951, 829, 43, 0, 70, 43, 0, "StyleData", "Placeholder", \
"Condensed"],
Cell[21997, 831, 42, 0, 70, 42, 0, "StyleData", "Placeholder", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[22076, 836, 193, 6, 70, 39, 0, "StyleData", \
"SelectionPlaceholder", "All",
  StyleMenuListing->None],
Cell[22272, 844, 55, 0, 70, 55, 0, "StyleData", \
"SelectionPlaceholder", "Presentation"],
Cell[22330, 846, 52, 0, 70, 52, 0, "StyleData", \
"SelectionPlaceholder", "Condensed"],
Cell[22385, 848, 51, 0, 70, 51, 0, "StyleData", \
"SelectionPlaceholder", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[22485, 854, 36, 0, 70, "Section"],
Cell[22524, 856, 307, 6, 70, "Text"],
Cell[22834, 864, 314, 10, 70, 33, 0, "StyleData", "CellExpression", \
"All",
  StyleMenuListing->None],
Cell[23151, 876, 106, 3, 70, 28, 0, "StyleData", "InputForm", "All",
  StyleMenuListing->None],
Cell[23260, 881, 151, 5, 70, 29, 0, "StyleData", "OutputForm", "All",
  StyleMenuListing->None],
Cell[23414, 888, 83, 2, 70, 31, 0, "StyleData", "StandardForm", "All",
  
  StyleMenuListing->None],
Cell[23500, 892, 179, 5, 70, 34, 0, "StyleData", "TraditionalForm", \
"All",
  StyleMenuListing->None],
Cell[23682, 899, 115, 3, 70, "Text"],
Cell[23800, 904, 96, 3, 70, 29, 0, "StyleData", "InlineCell", "All",
  StyleMenuListing->None],
Cell[23899, 909, 104, 2, 70, 36, 0, "StyleData", "InlineCellEditing", \
"All",
  StyleMenuListing->None]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

